(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    485806,      11483]*)
(*NotebookOutlinePosition[    486522,      11508]*)
(*  CellTagsIndexPosition[    486478,      11504]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["NMR", "Title",
  TextAlignment->Center],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\  (*Clear\ all\ previous\ global\ settings\ \
from\ currently\ open\ sessions*) \), "\n", 
    \(Needs["\<Statistics`NonlinearFit`\>"]; 
    Needs["\<Graphics`MultipleListPlot`\>"];\)}], "Input"],

Cell[CellGroupData[{

Cell["Schr\[ODoubleDot]dinger equation", "Section"],

Cell[TextData[{
  "The Hamiltonian of a Spin-1/2 particle in a homogenous, constant magntic \
field in z-direction is:\n\n",
  Cell[BoxData[
      \(TraditionalForm\`H\_0 = \ \(\(e\ g\)\/\(2\ m\)\) \(B\_z\) S\_z\)],
    FontColor->GrayLevel[0]],
  StyleBox["\t,\t",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`S\_z = \(\[HBar]\/2\) \[Sigma]\_3\)],
    FontColor->GrayLevel[0]],
  "\n\nwith ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            FormBox[\(\[Omega]\_0\),
              "TraditionalForm"], "=", \(\(e\ g\ B\_z\)\/\(2  m\)\)}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  ", this becomes:\n\n",
  Cell[BoxData[
      \(TraditionalForm\`H\_0 = \ \(\[Omega]\_0\) S\_z\)],
    FontColor->GrayLevel[0]],
  "\n\nThe eigenvalues of this Hamiltonian are ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{\(E\_\[Sigma]\), "=", 
            RowBox[{
              FractionBox[
                StyleBox["\[Sigma]",
                  FontColor->GrayLevel[0]], "2"], 
              " ", \(\[HBar]\[Omega]\_0\)}]}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  ", with ",
  StyleBox["\[Sigma]=\[PlusMinus]1",
    FontColor->GrayLevel[0]],
  ". The propability of finding the system in one of these eigenvectors is \
time-independent:\n\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            RowBox[{
              FormBox["|",
                
                "TraditionalForm"], \(\[LeftAngleBracket]\[Sigma] | \[Psi](
                    t)\[RightAngleBracket]\), \( | \^2\)}], "="}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            FormBox["|",
              
              "TraditionalForm"], \(\[LeftAngleBracket]\[Sigma] | 
                e\^\(\(\(-it\)\/\[HBar]\) H\) | \[Psi](
                  t = 0)\[RightAngleBracket]\), \( | \^2\)}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  StyleBox["= ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\(|\)\(e\^\(\(it\/\[HBar]\) E\_\[Sigma]\)\)\),
              
              "TraditionalForm"], \(\[LeftAngleBracket]\[Sigma] | \[Psi](
                  0)\[RightAngleBracket]\)}], \( | \^2\)}], TraditionalForm]],
    
    FontColor->GrayLevel[0]],
  StyleBox["= ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[LeftAngleBracket]\[Sigma] | \[Psi](
              0)\[RightAngleBracket]\)\( | \^2\)\)\)],
    FontColor->GrayLevel[0]],
  "\n\nIn order to obtain a transition between the eigenstates, we need a \
time-dependent Hamiltonian. One posibility is an additional periodic field in \
x-direction:\n\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(H = H\_0\),
          FontColor->GrayLevel[0]], TraditionalForm]]],
  StyleBox[" + ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(\(e\ g\)\/\(2\ m\)\) \(B\_x\) \(cos(\[Omega]t)\) S\_x\),
            
            "TraditionalForm"], "=", 
          RowBox[{
            FormBox[\(\(\[Omega]\_0\) S\_z\),
              "TraditionalForm"], 
            "+", \(\(\[Omega]\_1\) \(cos(\[Omega]t)\) S\_x\)}]}], 
        TraditionalForm]],
    FontColor->GrayLevel[0]],
  "\n\nWe express H and |\[Psi](t)\[RightAngleBracket] in  the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\_z - basis\)\(,\)\)\)]],
  " the eigenbasis of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(H\_0\)\(,\)\(\ \)\)\)]],
  "the eigenvectors are ",
  StyleBox["|+z\[RightAngleBracket]=",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"1"},
              {"0"}
              }], ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  " for ",
  StyleBox["\[Sigma]=+1",
    FontColor->GrayLevel[0]],
  " and ",
  StyleBox["|-z\[RightAngleBracket]=",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NegativeThinSpace]", ")"}],
              FontColor->GrayLevel[0]], " ", "for", " ", 
            StyleBox["\[Sigma]",
              FontColor->GrayLevel[0]]}], 
          StyleBox["=",
            FontColor->GrayLevel[0]], 
          StyleBox[\(\(-1\)\(:\)\),
            FontColor->GrayLevel[0]]}], TraditionalForm]]]
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.847059]],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\[Sigma]\_1\), " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0", "1"},
              {"1", "0"}
              }], ")"}]}], ";", "  ", 
      RowBox[{\(\[Sigma]\_2\), " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0", \(-\[ImaginaryI]\)},
              {"\[ImaginaryI]", "0"}
              }], ")"}]}], ";", "  ", 
      RowBox[{\(\[Sigma]\_3\), " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"1", "0"},
              {"0", \(-1\)}
              }], ")"}]}], ";"}]], "Input"],

Cell[BoxData[{
    \(\(H\_0 = \[Omega]\_0\ \[Sigma]\_3/2;\)\), "\[IndentingNewLine]", 
    \(H = 
      H\_0 + \(\[Omega]\_1\/2\) Cos[\[Omega]\ t]\ \[Sigma]\_1 // 
        MatrixForm\)}], "Input"],

Cell[TextData[{
  "\nWith \t",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            RowBox[{
              RowBox[{
                
                FormBox[\(\(\(\(|\)\(\[Psi](
                          t)\)\)\(\[RightAngleBracket]\)\) = \[Sum]\+\[Sigma]\
\),
                  "TraditionalForm"], \(\(C\_\[Sigma]\)(t)\)}], "|", 
              "\[Sigma]"}], "\[RightAngleBracket]"}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  StyleBox["=",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(a(t)\)},
              {\(b(t)\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  ",\n\nthe time-dependent Schroedinger equation becomes:\n\n",
  Cell[BoxData[
      \(TraditionalForm\`i \[PartialD]\/\[PartialD]t\)],
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(a(t)\)},
              {\(b(t)\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  StyleBox["=H ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {\(a(t)\)},
                  {\(b(t)\)}
                  }], "\[NegativeThinSpace]", ")"}],
            "TraditionalForm"], "=", \(1\/2\)}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(\[Omega]\_0\), \(\(\[Omega]\_1\) \(cos(\[Omega]t)\)\)},
              {\(\(\[Omega]\_1\) \(cos(\[Omega]t)\)\), \(-\[Omega]\_0\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(a(t)\)},
              {\(b(t)\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]]
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.847059]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical Solution", "Section"],

Cell["\<\
We solve this equation for the coefficients a(t) and b(t) \
numerically.\
\>", "Text"],

Cell[BoxData[
    \(\(numsol[\[Omega]0_, \[Omega]1_, \ \[Omega]_] := 
        Block[{sol, t}, \[IndentingNewLine]\[Omega]est = 
            Max[\((\[Omega] - \[Omega]0)\), \[Omega]1/
                2]; \[IndentingNewLine]tmax = 
            N[2  \[Pi]/\[Omega]est]; \[IndentingNewLine]sol = 
            NDSolve[{I\ \(a'\)[
                      t] \[Equal] \[Omega]0\ a[t]/
                        2 + \[Omega]1\ Cos[\[Omega]\ t]\ b[t]/2, 
                I\ \(b'\)[
                      t] == \(-\[Omega]0\)\ b[t]/
                        2\  + \[Omega]1\ Cos[\[Omega]\ t]\ a[t]/2, 
                a[0] \[Equal] 1, b[0] \[Equal] 0}, {a[t], b[t]}, {t, 0, \ 
                tmax}]; \[IndentingNewLine]pup[t_] = 
            Abs[a[t]]\^2 /. sol[\([1]\)]; \[IndentingNewLine]pdown[t_] = 
            Abs[b[t]]\^2 /. sol[\([1]\)];\[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(numsol[\[Omega]0 = 1, \[Omega]1 = 0.05, \[Omega] = 
          0.9];\)\), "\[IndentingNewLine]", 
    \(\(plOsc = 
        Plot[{pup[t], pdown[t]}, {t, 0, \ tmax}, 
          PlotRange \[Rule] {{0, 1.1  tmax}, {0, 1}}, 
          PlotStyle \[Rule] {Hue[1], Hue[0.6]}, 
          AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
          DisplayFunction -> Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[plOsc, 
        Graphics[{Text[\*"\"\<|a(t)\!\(\( | \^2\)\)\>\"", {1.1\ tmax, 
                pup[tmax]}, TextStyle \[Rule] {FontColor -> Hue[1]}], 
            Text[\*"\"\<|b(t)\!\(\( | \^2\)\)\>\"", {1.1\ tmax, pdown[tmax]}, 
              TextStyle \[Rule] {FontColor -> Hue[0.6]}]}], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.87314e-18 0.00361716 0 0.618034 [
[.18086 -0.0125 -6 -9 ]
[.18086 -0.0125 6 0 ]
[.36172 -0.0125 -9 -9 ]
[.36172 -0.0125 9 0 ]
[.54257 -0.0125 -9 -9 ]
[.54257 -0.0125 9 0 ]
[.72343 -0.0125 -9 -9 ]
[.72343 -0.0125 9 0 ]
[.90429 -0.0125 -9 -9 ]
[.90429 -0.0125 9 0 ]
[1.025 0 0 -4.90625 ]
[1.025 0 10 4.90625 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18086 0 m
.18086 .00625 L
s
[(50)] .18086 -0.0125 0 1 Mshowa
.36172 0 m
.36172 .00625 L
s
[(100)] .36172 -0.0125 0 1 Mshowa
.54257 0 m
.54257 .00625 L
s
[(150)] .54257 -0.0125 0 1 Mshowa
.72343 0 m
.72343 .00625 L
s
[(200)] .72343 -0.0125 0 1 Mshowa
.90429 0 m
.90429 .00625 L
s
[(250)] .90429 -0.0125 0 1 Mshowa
.125 Mabswid
.03617 0 m
.03617 .00375 L
s
.07234 0 m
.07234 .00375 L
s
.10851 0 m
.10851 .00375 L
s
.14469 0 m
.14469 .00375 L
s
.21703 0 m
.21703 .00375 L
s
.2532 0 m
.2532 .00375 L
s
.28937 0 m
.28937 .00375 L
s
.32554 0 m
.32554 .00375 L
s
.39789 0 m
.39789 .00375 L
s
.43406 0 m
.43406 .00375 L
s
.47023 0 m
.47023 .00375 L
s
.5064 0 m
.5064 .00375 L
s
.57875 0 m
.57875 .00375 L
s
.61492 0 m
.61492 .00375 L
s
.65109 0 m
.65109 .00375 L
s
.68726 0 m
.68726 .00375 L
s
.7596 0 m
.7596 .00375 L
s
.79577 0 m
.79577 .00375 L
s
.83195 0 m
.83195 .00375 L
s
.86812 0 m
.86812 .00375 L
s
.94046 0 m
.94046 .00375 L
s
.97663 0 m
.97663 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .61803 m
.00112 .61799 L
.00214 .61791 L
.00324 .6178 L
.00444 .61769 L
.00554 .61764 L
.00656 .61763 L
.00753 .61764 L
.00857 .61763 L
.00968 .61754 L
.01087 .61731 L
.012 .61697 L
.01303 .61658 L
.01424 .61611 L
.01488 .61588 L
.01556 .61568 L
.0168 .61544 L
.01795 .61535 L
.01857 .61535 L
.01923 .61535 L
.02041 .6153 L
.02106 .6152 L
.02167 .61506 L
.02235 .61482 L
.02306 .61448 L
.02554 .61283 L
.02675 .61203 L
.02788 .61147 L
.02897 .61116 L
.03013 .61106 L
.0313 .61107 L
.03196 .61107 L
.03259 .61102 L
.03366 .61075 L
.03465 .61026 L
.03574 .60945 L
.03688 .60838 L
.03818 .60712 L
.0394 .60612 L
.0405 .60553 L
.04169 .60527 L
.04231 .60525 L
.04299 .60529 L
.04365 .60534 L
.04436 .60536 L
.04503 .60529 L
.04564 .60513 L
.04683 .60449 L
.05609 .59888 L
.06699 .59205 L
Mistroke
.06763 .59224 L
.0683 .59245 L
.06904 .59261 L
.06972 .59262 L
.07095 .59219 L
.07165 .59166 L
.0723 .591 L
.07359 .58937 L
.07481 .58777 L
.07591 .58663 L
.0771 .58594 L
.07817 .58588 L
.07931 .58625 L
.08029 .58674 L
.08135 .58716 L
.08246 .58723 L
.08351 .58679 L
.08475 .58566 L
.08589 .58426 L
.08695 .58293 L
.08808 .58182 L
.08931 .58123 L
.09046 .58135 L
.09108 .58163 L
.09175 .58206 L
.09297 .5829 L
.09416 .58344 L
.09526 .58343 L
.0964 .58281 L
.09763 .58159 L
.09869 .58036 L
.09984 .5792 L
.10054 .57873 L
.10119 .5785 L
.10182 .57849 L
.10248 .57869 L
.10362 .57945 L
.10488 .58057 L
.10552 .5811 L
.10619 .58154 L
.1074 .58184 L
.10808 .58171 L
.1087 .58139 L
.10939 .58086 L
.11012 .58018 L
.11076 .57954 L
.11145 .5789 L
.11271 .5781 L
.11393 .57803 L
.11505 .57864 L
Mistroke
.13294 .58536 L
.13546 .58417 L
.13615 .58384 L
.13689 .58363 L
.13759 .58365 L
.13822 .58386 L
.13946 .58481 L
.14015 .5856 L
.1408 .58642 L
.14205 .58807 L
.14323 .5893 L
.14428 .58996 L
.14541 .59013 L
.14666 .58981 L
.1478 .58937 L
.14899 .58912 L
.14966 .58918 L
.15028 .58941 L
.15142 .59026 L
.15263 .59166 L
.1537 .59308 L
.15482 .59447 L
.15605 .59557 L
.15718 .59606 L
.15824 .5961 L
.15922 .59592 L
.1603 .59569 L
.16145 .59567 L
.16271 .59615 L
.16342 .59668 L
.16407 .59732 L
.16655 .60031 L
.16771 .60151 L
.16879 .60224 L
.16993 .60257 L
.17117 .60256 L
.17241 .60243 L
.17311 .60242 L
.17375 .60251 L
.17494 .60298 L
.1762 .60395 L
.17841 .60627 L
.17956 .60739 L
.18079 .60822 L
.18148 .6085 L
.18224 .60867 L
.18293 .60872 L
.18358 .60871 L
.18424 .60868 L
.18485 .60868 L
Mistroke
.18555 .60873 L
.18621 .60886 L
.18743 .60936 L
.18856 .6101 L
.18986 .61118 L
.19111 .61219 L
.19222 .61292 L
.19343 .61344 L
.19453 .61365 L
.19555 .6137 L
.19676 .6137 L
.19786 .61377 L
.19848 .61388 L
.19914 .61405 L
.20033 .61452 L
.20252 .61567 L
.20372 .61623 L
.20483 .61661 L
.20579 .6168 L
.20681 .61689 L
.20794 .6169 L
.20897 .61691 L
.21019 .61697 L
.21081 .61704 L
.21149 .61714 L
.21382 .61762 L
.21445 .61775 L
.21512 .61786 L
.21586 .61794 L
.21653 .61799 L
.21775 .618 L
.21844 .61798 L
.21908 .61796 L
.22033 .61792 L
.22151 .61792 L
.22256 .61794 L
.22371 .61797 L
.22496 .61794 L
.22559 .61789 L
.22629 .6178 L
.22751 .61756 L
.22866 .61727 L
.23341 .61661 L
.23403 .61661 L
.2347 .6166 L
.23592 .61651 L
.23665 .61637 L
.23732 .61618 L
.23794 .61595 L
.23859 .61564 L
Mistroke
.24092 .61433 L
.24216 .61372 L
.24285 .61347 L
.24348 .61331 L
.24468 .61316 L
.24583 .61315 L
.24688 .61313 L
.24802 .61299 L
.24911 .61261 L
.25014 .61202 L
.25126 .61115 L
.25248 .61009 L
.25368 .60911 L
.25434 .60868 L
.25495 .60836 L
.25603 .60802 L
.25721 .60792 L
.25832 .60797 L
.25936 .60796 L
.2603 .60779 L
.26132 .60734 L
.26243 .60651 L
.2636 .60532 L
.26571 .60307 L
.26687 .60216 L
.26813 .60164 L
.26932 .60156 L
.27043 .60169 L
.27142 .60177 L
.27251 .60163 L
.27366 .60107 L
.27473 .60013 L
.277 .59737 L
.27824 .59599 L
.27939 .59513 L
.28064 .59477 L
.28131 .59479 L
.28201 .59492 L
.28327 .59522 L
.28442 .59529 L
.28552 .59495 L
.28668 .59406 L
.28784 .5927 L
.28913 .591 L
.29024 .58967 L
.29143 .5887 L
.29255 .58834 L
.29358 .58846 L
.29464 .58885 L
.29562 .58924 L
Mistroke
.2967 .58944 L
.29785 .58917 L
.29895 .58836 L
.29998 .5872 L
.30191 .58472 L
.30302 .58363 L
.30421 .58305 L
.30533 .58312 L
.30636 .58358 L
.30756 .5843 L
.30823 .58465 L
.30886 .58485 L
.31001 .5848 L
.31123 .58406 L
.3124 .58284 L
.31365 .58132 L
.31483 .58011 L
.31591 .57948 L
.31712 .57949 L
.3178 .57978 L
.31843 .5802 L
.3197 .58123 L
.32037 .58172 L
.32108 .5821 L
.32228 .58226 L
.32338 .5818 L
.32441 .58093 L
.32555 .57973 L
.32656 .57874 L
.32765 .57805 L
.32867 .57792 L
.32961 .57827 L
.33077 .57921 L
.33184 .58029 L
.33302 .58134 L
.33428 .5819 L
.33548 .58174 L
.33661 .58103 L
.33771 .58008 L
.33872 .57928 L
.33983 .57875 L
.34102 .57884 L
.34213 .57956 L
.34318 .58065 L
.34431 .58198 L
.34552 .58318 L
.34615 .58359 L
.34684 .58384 L
.34806 .58372 L
.34872 .58341 L
Mistroke
.34934 .58302 L
.35052 .58225 L
.35178 .58173 L
.35249 .58172 L
.35315 .58193 L
.35436 .58286 L
.35546 .58415 L
.35666 .58569 L
.35731 .58645 L
.35792 .58704 L
.35901 .58772 L
.3602 .58785 L
.3612 .58755 L
.36229 .58705 L
.36289 .58679 L
.36355 .5866 L
.36476 .58666 L
.36593 .58733 L
.36701 .58845 L
.36804 .58979 L
.36915 .59125 L
.3702 .59239 L
.37116 .59308 L
.37218 .59339 L
.37326 .59332 L
.37436 .59301 L
.37557 .59274 L
.37683 .59285 L
.37799 .59351 L
.37859 .59406 L
.37926 .5948 L
.38061 .59652 L
.38179 .59797 L
.38245 .59863 L
.38307 .59912 L
.38427 .59968 L
.38537 .59976 L
.38644 .59963 L
.38758 .59948 L
.38865 .59957 L
.38963 .59995 L
.39078 .60082 L
.39202 .60214 L
.39311 .60341 L
.39427 .60464 L
.39552 .60559 L
.39669 .60605 L
.3974 .60614 L
.39808 .60614 L
.39868 .6061 L
Mistroke
.39934 .60606 L
.39998 .60606 L
.40069 .60615 L
.40143 .60636 L
.40212 .6067 L
.40336 .60759 L
.40469 .60882 L
.40595 .60999 L
.40712 .61087 L
.40835 .61145 L
.409 .61161 L
.40969 .61169 L
.41427 .61222 L
.41657 .61356 L
.41784 .61441 L
.41904 .61507 L
.42016 .61548 L
.42138 .6157 L
.42248 .61575 L
.42351 .61576 L
.4247 .61581 L
.42577 .61595 L
.42701 .61626 L
.42817 .61665 L
.42937 .61707 L
.43063 .61744 L
.43129 .61758 L
.43202 .61768 L
.43268 .61774 L
.43329 .61777 L
.43396 .61777 L
.43469 .61776 L
.43537 .61776 L
.43601 .61776 L
.4372 .6178 L
.43781 .61784 L
.43847 .61789 L
.43918 .61794 L
.43985 .61799 L
.44063 .61802 L
.44134 .61802 L
.442 .618 L
.44262 .61795 L
.4433 .61788 L
.44402 .61779 L
.44531 .61762 L
.44652 .61751 L
.44778 .61746 L
.44845 .61746 L
.44917 .61746 L
Mistroke
.44978 .61746 L
.45044 .61744 L
.45164 .61731 L
.45282 .61703 L
.4539 .61665 L
.45626 .61565 L
.4569 .61541 L
.4576 .6152 L
.45886 .61496 L
.45952 .61491 L
.46021 .61489 L
.46145 .61489 L
.46214 .61485 L
.46277 .61477 L
.46347 .6146 L
.46422 .61433 L
.47393 .61039 L
.49209 .59998 L
.5111 .59186 L
.5211 .58556 L
.52175 .58589 L
.52246 .58625 L
.52313 .58652 L
.52374 .58665 L
.52446 .58662 L
.52523 .58632 L
.52594 .5858 L
.52658 .58517 L
.52778 .58371 L
.52904 .58216 L
.5297 .58151 L
.53043 .581 L
.53109 .58076 L
.5317 .58074 L
.53293 .58119 L
.53405 .58195 L
.53467 .58239 L
.53535 .58281 L
.53657 .58316 L
.53773 .58286 L
.53895 .58189 L
.5401 .58062 L
.54115 .57947 L
.54238 .57852 L
.54303 .5783 L
.54371 .5783 L
.54485 .57881 L
.5461 .57986 L
.54747 .58107 L
.54823 .58155 L
Mistroke
.54893 .58177 L
.54958 .58177 L
.55028 .58153 L
.55094 .58111 L
.55155 .5806 L
.55261 .57959 L
.55375 .57862 L
.55482 .57811 L
.55579 .57814 L
.55694 .57879 L
.55818 .58002 L
.55935 .5813 L
.56045 .58226 L
.56158 .58273 L
.56282 .58254 L
.56403 .58181 L
.56465 .58133 L
.56534 .58083 L
.56649 .58023 L
.5677 .58021 L
.56882 .58084 L
.56986 .5819 L
.57107 .58339 L
.5722 .58469 L
.57337 .58561 L
.574 .58584 L
.57467 .58589 L
.5754 .58574 L
.57609 .58544 L
.57676 .58507 L
.57738 .58473 L
.57858 .58428 L
.57921 .58424 L
.57989 .58441 L
.58112 .58526 L
.58181 .586 L
.58245 .5868 L
.5836 .58833 L
.58486 .58977 L
.58599 .59059 L
.58705 .59084 L
.58816 .59067 L
.58936 .59025 L
.59055 .58993 L
.59164 .59001 L
.59285 .59068 L
.59346 .59124 L
.59413 .592 L
.5963 .59481 L
.59752 .59607 L
Mistroke
.59864 .59675 L
.59965 .59694 L
.60077 .59683 L
.60185 .5966 L
.603 .59651 L
.60411 .59678 L
.60512 .59742 L
.60614 .59841 L
.6071 .59954 L
.60819 .60089 L
.60923 .60201 L
.61043 .60292 L
.61152 .60334 L
.61272 .60341 L
.6134 .60335 L
.61403 .60329 L
.61517 .60329 L
.61638 .60361 L
.61705 .60398 L
.61766 .60443 L
.61904 .60574 L
.62023 .607 L
.62087 .60763 L
.62154 .60822 L
.62272 .60897 L
.62381 .60933 L
.62507 .60943 L
.62621 .6094 L
.62731 .60944 L
.62847 .6097 L
.62946 .61016 L
.63055 .61088 L
.63282 .61267 L
.63348 .61312 L
.6341 .61348 L
.63527 .61396 L
.63636 .61417 L
.63738 .61422 L
.63849 .61422 L
.63969 .61429 L
.6408 .6145 L
.64186 .61485 L
.64383 .61578 L
.64494 .6163 L
.64612 .61675 L
.64724 .61701 L
.64827 .61713 L
.64946 .61716 L
.65014 .61716 L
.65077 .61716 L
Mistroke
.65192 .61721 L
.65314 .61734 L
.65539 .61772 L
.65601 .61782 L
.65666 .61791 L
.65782 .618 L
.65848 .61802 L
.65909 .61801 L
.65976 .61798 L
.66048 .61795 L
.66115 .61791 L
.66179 .61789 L
.66298 .61787 L
.664 .61789 L
.66512 .6179 L
.66629 .61788 L
.66738 .61778 L
.6684 .61759 L
.66934 .61736 L
.67144 .61675 L
.67261 .61648 L
.67369 .61633 L
.67488 .61627 L
.67554 .61627 L
.67614 .61627 L
.67725 .61622 L
.67844 .61602 L
.67957 .61564 L
.68061 .61512 L
.71834 .59718 L
.73732 .58847 L
.73832 .58874 L
.7394 .58864 L
.74041 .58807 L
.74134 .58717 L
.74337 .5846 L
.74446 .58338 L
.74561 .5826 L
.74677 .58246 L
.74785 .58283 L
.74903 .58355 L
.75029 .58424 L
.75146 .58443 L
.75256 .58404 L
.75355 .58323 L
.75462 .58203 L
.75587 .58055 L
.75704 .5795 L
.75826 .57907 L
.75891 .57915 L
Mistroke
.7596 .57946 L
.7618 .58117 L
.76304 .58193 L
.7642 .58208 L
.76538 .58157 L
.76663 .58046 L
.76782 .57922 L
.76894 .57829 L
.76993 .57789 L
.77099 .57802 L
.77218 .5788 L
.77326 .57987 L
.77442 .58103 L
.77567 .58187 L
.77684 .58202 L
.7779 .5816 L
.77919 .58062 L
.77989 .58002 L
.78055 .57953 L
.78171 .579 L
.78232 .57897 L
.78299 .57916 L
.78366 .57958 L
.78431 .58015 L
.78551 .58153 L
.7862 .58235 L
.78694 .58314 L
.78763 .58373 L
.78826 .58409 L
.78948 .58425 L
.79064 .58382 L
.79189 .58304 L
.79258 .58263 L
.79324 .58235 L
.79442 .58226 L
.7955 .58278 L
.79666 .5839 L
.79793 .58551 L
.79903 .58688 L
.80021 .58797 L
.80121 .58844 L
.80231 .58845 L
.80294 .58827 L
.8036 .58799 L
.80478 .58749 L
.80544 .58732 L
.80606 .58729 L
.80673 .58743 L
.80745 .58782 L
.80807 .58833 L
Mistroke
.80875 .58906 L
.80998 .59064 L
.81108 .59208 L
.81227 .59333 L
.81352 .59406 L
.81469 .59418 L
.8154 .59406 L
.81608 .59387 L
.81675 .5937 L
.81735 .59359 L
.818 .59357 L
.81869 .59371 L
.81993 .59443 L
.82062 .59509 L
.82137 .59595 L
.82273 .59769 L
.82334 .59844 L
.824 .59915 L
.82518 .6001 L
.82641 .60056 L
.82712 .6006 L
.82776 .60055 L
.8289 .60039 L
.83013 .60037 L
.8313 .60073 L
.83238 .60145 L
.84098 .60686 L
.84211 .60687 L
.84332 .60716 L
.84446 .60777 L
.84549 .60857 L
.84776 .61062 L
.84837 .6111 L
.84903 .61154 L
.85023 .61207 L
.85087 .61223 L
.85157 .61231 L
.85231 .61233 L
.85299 .61232 L
.85422 .61236 L
.85491 .61245 L
.85554 .61261 L
.85673 .61309 L
.85803 .61383 L
.85925 .61461 L
.86039 .61526 L
.86153 .61574 L
.86279 .61603 L
.86401 .61612 L
.8647 .61613 L
Mistroke
.86533 .61613 L
.8664 .61617 L
.86756 .6163 L
.86878 .61657 L
.86991 .61691 L
.87113 .61728 L
.87179 .61746 L
.87241 .61761 L
.87351 .61778 L
.87472 .61786 L
.8754 .61787 L
.87604 .61786 L
.87724 .61784 L
.87791 .61785 L
.87853 .61786 L
.87922 .61789 L
.87994 .61793 L
.88117 .61799 L
.88187 .61801 L
.8825 .61801 L
.88368 .61795 L
.88491 .61779 L
.88709 .61745 L
.88831 .61731 L
.88942 .61725 L
.8905 .61724 L
.89167 .61724 L
.89277 .61717 L
.89379 .61699 L
.89474 .61672 L
.89577 .61631 L
.89788 .61532 L
.89908 .61485 L
.90018 .61456 L
.90139 .61442 L
.902 .61441 L
.90266 .61441 L
.90379 .61438 L
.90499 .6142 L
.90613 .61379 L
.90716 .6132 L
.90909 .61173 L
Mfstroke
0 .4 1 r
0 0 m
.00112 4e-05 L
.00214 .00012 L
.00324 .00023 L
.00444 .00034 L
.00554 .00039 L
.00656 .0004 L
.00753 .00039 L
.00857 .00041 L
.00968 .00049 L
.01087 .00072 L
.012 .00106 L
.01303 .00145 L
.01424 .00192 L
.01488 .00215 L
.01556 .00235 L
.0168 .00259 L
.01795 .00268 L
.01857 .00268 L
.01923 .00268 L
.02041 .00273 L
.02106 .00283 L
.02167 .00297 L
.02235 .00321 L
.02306 .00355 L
.02554 .0052 L
.02675 .006 L
.02788 .00656 L
.02897 .00687 L
.03013 .00697 L
.0313 .00696 L
.03196 .00696 L
.03259 .00701 L
.03366 .00728 L
.03465 .00777 L
.03574 .00858 L
.03688 .00965 L
.03818 .01091 L
.0394 .01191 L
.0405 .0125 L
.04169 .01276 L
.04231 .01278 L
.04299 .01274 L
.04365 .01269 L
.04436 .01267 L
.04503 .01274 L
.04564 .0129 L
.04683 .01354 L
.05609 .01915 L
.06699 .02598 L
Mistroke
.06763 .02579 L
.0683 .02558 L
.06904 .02542 L
.06972 .02541 L
.07095 .02584 L
.07165 .02637 L
.0723 .02703 L
.07359 .02866 L
.07481 .03026 L
.07591 .0314 L
.0771 .03209 L
.07817 .03215 L
.07931 .03178 L
.08029 .03129 L
.08135 .03087 L
.08246 .0308 L
.08351 .03124 L
.08475 .03237 L
.08589 .03377 L
.08695 .0351 L
.08808 .03621 L
.08931 .0368 L
.09046 .03668 L
.09108 .0364 L
.09175 .03597 L
.09297 .03513 L
.09416 .03459 L
.09526 .0346 L
.0964 .03522 L
.09763 .03644 L
.09869 .03766 L
.09984 .03883 L
.10054 .0393 L
.10119 .03953 L
.10182 .03954 L
.10248 .03934 L
.10362 .03858 L
.10488 .03746 L
.10552 .03693 L
.10619 .03649 L
.1074 .03619 L
.10808 .03632 L
.1087 .03664 L
.10939 .03717 L
.11012 .03785 L
.11076 .03849 L
.11145 .03913 L
.11271 .03993 L
.11393 .04 L
.11505 .03939 L
Mistroke
.13294 .03267 L
.13546 .03386 L
.13615 .03419 L
.13689 .03439 L
.13759 .03438 L
.13822 .03417 L
.13946 .03322 L
.14015 .03243 L
.1408 .0316 L
.14205 .02996 L
.14323 .02872 L
.14428 .02807 L
.14541 .0279 L
.14666 .02821 L
.1478 .02866 L
.14899 .02891 L
.14966 .02885 L
.15028 .02862 L
.15142 .02776 L
.15263 .02637 L
.1537 .02495 L
.15482 .02356 L
.15605 .02246 L
.15718 .02197 L
.15824 .02192 L
.15922 .02211 L
.1603 .02234 L
.16145 .02236 L
.16271 .02188 L
.16342 .02135 L
.16407 .02071 L
.16655 .01771 L
.16771 .01652 L
.16879 .01579 L
.16993 .01546 L
.17117 .01547 L
.17241 .0156 L
.17311 .01561 L
.17375 .01552 L
.17494 .01505 L
.1762 .01408 L
.17841 .01176 L
.17956 .01064 L
.18079 .00981 L
.18148 .00952 L
.18224 .00936 L
.18293 .00931 L
.18358 .00932 L
.18424 .00934 L
.18485 .00935 L
Mistroke
.18555 .0093 L
.18621 .00917 L
.18743 .00867 L
.18856 .00792 L
.18986 .00685 L
.19111 .00584 L
.19222 .00511 L
.19343 .00459 L
.19453 .00438 L
.19555 .00433 L
.19676 .00433 L
.19786 .00425 L
.19848 .00415 L
.19914 .00398 L
.20033 .00351 L
.20252 .00236 L
.20372 .0018 L
.20483 .00142 L
.20579 .00123 L
.20681 .00114 L
.20794 .00112 L
.20897 .00112 L
.21019 .00106 L
.21081 .00099 L
.21149 .00089 L
.21382 .0004 L
.21445 .00028 L
.21512 .00017 L
.21586 9e-05 L
.21653 4e-05 L
.21775 3e-05 L
.21844 4e-05 L
.21908 7e-05 L
.22033 .00011 L
.22151 .00011 L
.22256 8e-05 L
.22371 6e-05 L
.22496 9e-05 L
.22559 .00014 L
.22629 .00023 L
.22751 .00047 L
.22866 .00075 L
.23341 .00142 L
.23403 .00142 L
.2347 .00143 L
.23592 .00152 L
.23665 .00166 L
.23732 .00185 L
.23794 .00208 L
.23859 .00238 L
Mistroke
.24092 .00369 L
.24216 .0043 L
.24285 .00456 L
.24348 .00472 L
.24468 .00487 L
.24583 .00488 L
.24688 .00489 L
.24802 .00504 L
.24911 .00542 L
.25014 .00601 L
.25126 .00688 L
.25248 .00794 L
.25368 .00891 L
.25434 .00935 L
.25495 .00967 L
.25603 .01001 L
.25721 .0101 L
.25832 .01006 L
.25936 .01007 L
.2603 .01024 L
.26132 .01069 L
.26243 .01152 L
.2636 .0127 L
.26571 .01496 L
.26687 .01587 L
.26813 .01639 L
.26932 .01646 L
.27043 .01634 L
.27142 .01626 L
.27251 .0164 L
.27366 .01696 L
.27473 .0179 L
.277 .02065 L
.27824 .02203 L
.27939 .0229 L
.28064 .02326 L
.28131 .02324 L
.28201 .02311 L
.28327 .0228 L
.28442 .02273 L
.28552 .02308 L
.28668 .02397 L
.28784 .02532 L
.28913 .02703 L
.29024 .02836 L
.29143 .02933 L
.29255 .02968 L
.29358 .02957 L
.29464 .02918 L
.29562 .02879 L
Mistroke
.2967 .02859 L
.29785 .02886 L
.29895 .02966 L
.29998 .03082 L
.30191 .0333 L
.30302 .0344 L
.30421 .03498 L
.30533 .03491 L
.30636 .03445 L
.30756 .03372 L
.30823 .03338 L
.30886 .03318 L
.31001 .03323 L
.31123 .03396 L
.3124 .03518 L
.31365 .0367 L
.31483 .03792 L
.31591 .03854 L
.31712 .03854 L
.3178 .03824 L
.31843 .03782 L
.3197 .0368 L
.32037 .03631 L
.32108 .03593 L
.32228 .03576 L
.32338 .03622 L
.32441 .0371 L
.32555 .0383 L
.32656 .03929 L
.32765 .03998 L
.32867 .04011 L
.32961 .03975 L
.33077 .03882 L
.33184 .03774 L
.33302 .03669 L
.33428 .03612 L
.33548 .03629 L
.33661 .03699 L
.33771 .03794 L
.33872 .03875 L
.33983 .03928 L
.34102 .03919 L
.34213 .03847 L
.34318 .03738 L
.34431 .03604 L
.34552 .03485 L
.34615 .03443 L
.34684 .03419 L
.34806 .03431 L
.34872 .03462 L
Mistroke
.34934 .035 L
.35052 .03577 L
.35178 .0363 L
.35249 .03631 L
.35315 .03609 L
.35436 .03516 L
.35546 .03388 L
.35666 .03234 L
.35731 .03158 L
.35792 .03098 L
.35901 .03031 L
.3602 .03018 L
.3612 .03047 L
.36229 .03097 L
.36289 .03123 L
.36355 .03142 L
.36476 .03137 L
.36593 .03069 L
.36701 .02957 L
.36804 .02824 L
.36915 .02678 L
.3702 .02564 L
.37116 .02495 L
.37218 .02463 L
.37326 .02471 L
.37436 .02501 L
.37557 .02529 L
.37683 .02517 L
.37799 .02452 L
.37859 .02397 L
.37926 .02323 L
.38061 .02151 L
.38179 .02006 L
.38245 .0194 L
.38307 .0189 L
.38427 .01835 L
.38537 .01826 L
.38644 .0184 L
.38758 .01854 L
.38865 .01846 L
.38963 .01807 L
.39078 .01721 L
.39202 .01589 L
.39311 .01462 L
.39427 .01338 L
.39552 .01243 L
.39669 .01198 L
.3974 .01189 L
.39808 .01189 L
.39868 .01192 L
Mistroke
.39934 .01196 L
.39998 .01196 L
.40069 .01188 L
.40143 .01166 L
.40212 .01133 L
.40336 .01044 L
.40469 .0092 L
.40595 .00803 L
.40712 .00715 L
.40835 .00658 L
.409 .00641 L
.40969 .00633 L
.41427 .00581 L
.41657 .00446 L
.41784 .00362 L
.41904 .00296 L
.42016 .00254 L
.42138 .00232 L
.42248 .00227 L
.42351 .00227 L
.4247 .00222 L
.42577 .00207 L
.42701 .00176 L
.42817 .00138 L
.42937 .00096 L
.43063 .00059 L
.43129 .00045 L
.43202 .00034 L
.43268 .00028 L
.43329 .00026 L
.43396 .00025 L
.43469 .00026 L
.43537 .00027 L
.43601 .00027 L
.4372 .00023 L
.43781 .00019 L
.43847 .00014 L
.43918 8e-05 L
.43985 4e-05 L
.44063 1e-05 L
.44134 0 L
.442 3e-05 L
.44262 7e-05 L
.4433 .00014 L
.44402 .00023 L
.44531 .0004 L
.44652 .00052 L
.44778 .00057 L
.44845 .00057 L
.44917 .00056 L
Mistroke
.44978 .00057 L
.45044 .00059 L
.45164 .00072 L
.45282 .00099 L
.4539 .00137 L
.45626 .00237 L
.4569 .00261 L
.4576 .00283 L
.45886 .00306 L
.45952 .00311 L
.46021 .00313 L
.46145 .00314 L
.46214 .00317 L
.46277 .00326 L
.46347 .00342 L
.46422 .00369 L
.47393 .00763 L
.49209 .01804 L
.5111 .02617 L
.5211 .03246 L
.52175 .03214 L
.52246 .03177 L
.52313 .0315 L
.52374 .03137 L
.52446 .03141 L
.52523 .0317 L
.52594 .03222 L
.52658 .03286 L
.52778 .03432 L
.52904 .03586 L
.5297 .03651 L
.53043 .03702 L
.53109 .03726 L
.5317 .03729 L
.53293 .03684 L
.53405 .03607 L
.53467 .03563 L
.53535 .03522 L
.53657 .03487 L
.53773 .03517 L
.53895 .03613 L
.5401 .0374 L
.54115 .03855 L
.54238 .0395 L
.54303 .03972 L
.54371 .03972 L
.54485 .03922 L
.5461 .03817 L
.54747 .03696 L
.54823 .03648 L
Mistroke
.54893 .03625 L
.54958 .03626 L
.55028 .03649 L
.55094 .03691 L
.55155 .03742 L
.55261 .03843 L
.55375 .0394 L
.55482 .03991 L
.55579 .03988 L
.55694 .03924 L
.55818 .038 L
.55935 .03672 L
.56045 .03576 L
.56158 .0353 L
.56282 .03548 L
.56403 .03622 L
.56465 .03669 L
.56534 .0372 L
.56649 .03779 L
.5677 .03781 L
.56882 .03718 L
.56986 .03613 L
.57107 .03463 L
.5722 .03333 L
.57337 .03241 L
.574 .03218 L
.57467 .03213 L
.5754 .03229 L
.57609 .03259 L
.57676 .03295 L
.57738 .0333 L
.57858 .03375 L
.57921 .03378 L
.57989 .03362 L
.58112 .03277 L
.58181 .03202 L
.58245 .03122 L
.5836 .0297 L
.58486 .02825 L
.58599 .02744 L
.58705 .02718 L
.58816 .02735 L
.58936 .02778 L
.59055 .02809 L
.59164 .02801 L
.59285 .02734 L
.59346 .02678 L
.59413 .02602 L
.5963 .02321 L
.59752 .02195 L
Mistroke
.59864 .02128 L
.59965 .02108 L
.60077 .02119 L
.60185 .02142 L
.603 .02151 L
.60411 .02124 L
.60512 .0206 L
.60614 .01962 L
.6071 .01848 L
.60819 .01714 L
.60923 .01601 L
.61043 .0151 L
.61152 .01468 L
.61272 .01461 L
.6134 .01467 L
.61403 .01474 L
.61517 .01474 L
.61638 .01441 L
.61705 .01404 L
.61766 .01359 L
.61904 .01228 L
.62023 .01102 L
.62087 .0104 L
.62154 .00981 L
.62272 .00905 L
.62381 .00869 L
.62507 .00859 L
.62621 .00862 L
.62731 .00858 L
.62847 .00832 L
.62946 .00787 L
.63055 .00714 L
.63282 .00535 L
.63348 .0049 L
.6341 .00454 L
.63527 .00406 L
.63636 .00385 L
.63738 .0038 L
.63849 .0038 L
.63969 .00374 L
.6408 .00352 L
.64186 .00317 L
.64383 .00224 L
.64494 .00172 L
.64612 .00127 L
.64724 .00101 L
.64827 .0009 L
.64946 .00086 L
.65014 .00087 L
.65077 .00086 L
Mistroke
.65192 .00082 L
.65314 .00068 L
.65539 .0003 L
.65601 .0002 L
.65666 .00011 L
.65782 2e-05 L
.65848 1e-05 L
.65909 1e-05 L
.65976 4e-05 L
.66048 7e-05 L
.66115 .00011 L
.66179 .00013 L
.66298 .00015 L
.664 .00014 L
.66512 .00012 L
.66629 .00014 L
.66738 .00025 L
.6684 .00043 L
.66934 .00066 L
.67144 .00127 L
.67261 .00154 L
.67369 .00169 L
.67488 .00175 L
.67554 .00175 L
.67614 .00175 L
.67725 .0018 L
.67844 .002 L
.67957 .00238 L
.68061 .0029 L
.71834 .02084 L
.73732 .02955 L
.73832 .02928 L
.7394 .02939 L
.74041 .02995 L
.74134 .03085 L
.74337 .03342 L
.74446 .03464 L
.74561 .03542 L
.74677 .03556 L
.74785 .03519 L
.74903 .03447 L
.75029 .03378 L
.75146 .03359 L
.75256 .03398 L
.75355 .03479 L
.75462 .036 L
.75587 .03747 L
.75704 .03852 L
.75826 .03895 L
.75891 .03887 L
Mistroke
.7596 .03857 L
.7618 .03685 L
.76304 .03609 L
.7642 .03594 L
.76538 .03645 L
.76663 .03757 L
.76782 .0388 L
.76894 .03973 L
.76993 .04013 L
.77099 .04 L
.77218 .03922 L
.77326 .03815 L
.77442 .03699 L
.77567 .03615 L
.77684 .036 L
.7779 .03642 L
.77919 .0374 L
.77989 .038 L
.78055 .03849 L
.78171 .03902 L
.78232 .03905 L
.78299 .03886 L
.78366 .03844 L
.78431 .03787 L
.78551 .03649 L
.7862 .03567 L
.78694 .03488 L
.78763 .03429 L
.78826 .03393 L
.78948 .03377 L
.79064 .0342 L
.79189 .03498 L
.79258 .03539 L
.79324 .03567 L
.79442 .03576 L
.7955 .03525 L
.79666 .03412 L
.79793 .03252 L
.79903 .03114 L
.80021 .03005 L
.80121 .02958 L
.80231 .02957 L
.80294 .02975 L
.8036 .03003 L
.80478 .03053 L
.80544 .0307 L
.80606 .03073 L
.80673 .03059 L
.80745 .0302 L
.80807 .02969 L
Mistroke
.80875 .02896 L
.80998 .02738 L
.81108 .02594 L
.81227 .02469 L
.81352 .02396 L
.81469 .02384 L
.8154 .02396 L
.81608 .02415 L
.81675 .02432 L
.81735 .02443 L
.818 .02445 L
.81869 .02431 L
.81993 .02359 L
.82062 .02293 L
.82137 .02207 L
.82273 .02033 L
.82334 .01958 L
.824 .01887 L
.82518 .01792 L
.82641 .01746 L
.82712 .01742 L
.82776 .01747 L
.8289 .01763 L
.83013 .01765 L
.8313 .01729 L
.83238 .01657 L
.84098 .01116 L
.84211 .01115 L
.84332 .01086 L
.84446 .01025 L
.84549 .00945 L
.84776 .0074 L
.84837 .00692 L
.84903 .00648 L
.85023 .00595 L
.85087 .00579 L
.85157 .00571 L
.85231 .00569 L
.85299 .0057 L
.85422 .00566 L
.85491 .00557 L
.85554 .00541 L
.85673 .00493 L
.85803 .00419 L
.85925 .00341 L
.86039 .00276 L
.86153 .00228 L
.86279 .00199 L
.86401 .0019 L
.8647 .00189 L
Mistroke
.86533 .00189 L
.8664 .00185 L
.86756 .00172 L
.86878 .00145 L
.86991 .00111 L
.87113 .00074 L
.87179 .00056 L
.87241 .00041 L
.87351 .00024 L
.87472 .00016 L
.8754 .00015 L
.87604 .00016 L
.87724 .00017 L
.87791 .00017 L
.87853 .00016 L
.87922 .00013 L
.87994 9e-05 L
.88117 3e-05 L
.88187 1e-05 L
.8825 1e-05 L
.88368 7e-05 L
.88491 .00022 L
.88709 .00057 L
.88831 .00071 L
.88942 .00077 L
.8905 .00077 L
.89167 .00078 L
.89277 .00085 L
.89379 .00103 L
.89474 .0013 L
.89577 .00171 L
.89788 .0027 L
.899 .00315 L
.90018 .00346 L
.9008 .00355 L
.90148 .0036 L
.90266 .00361 L
.90379 .00364 L
.90499 .00382 L
.90613 .00423 L
.90716 .00482 L
.90909 .00628 L
Mfstroke
0 g
gsave
1 .61173 -87.75 -10.9688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
63.000 14.750 moveto
(\\310) show
70.188 14.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
77.375 14.750 moveto
(H) show
84.562 14.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
91.750 14.750 moveto
(L) show
98.938 14.750 moveto
(\\310) show
106.125 10.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(2) show
112.500 14.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
1 .00628 -87.75 -10.9688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
63.000 14.750 moveto
(\\310) show
70.188 14.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
77.375 14.750 moveto
(H) show
84.562 14.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
91.750 14.750 moveto
(L) show
98.938 14.750 moveto
(\\310) show
106.125 10.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
(2) show
112.500 14.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000C03Vc804
000000D0i/b00`00000X0>K<P0H00000103Vc803000000D0i/b00`00000S0>K<P0H000000`3Vc804
000000D0i/b00`00000T0>K<P0H00000103Vc803000000D0i/b00`00000S0>K<P0H000000`3Vc804
000000D0i/b00`00000Z0>K<P000D03Vc8001@000000i/b00>K<P03Vc80000000080i/b000<00000
0>K<P03Vc800:@3Vc8000`000000i/b00>K<P0030>K<P0040000003Vc800i/b0000000@0i/b000@0
00000>K<P03Vc80000009P3Vc8000`000000i/b00>K<P0070>K<P0050000003Vc800i/b00>K<P000
00000P3Vc8000`000000i/b00>K<P00S0>K<P0050000003Vc800i/b00>K<P00000000`3Vc8001000
0000i/b00>K<P00000040>K<P0040000003Vc800i/b0000002@0i/b000D000000>K<P03Vc800i/b0
000000070>K<P0050000003Vc800i/b00>K<P00000000P3Vc8000`000000i/b00>K<P00X0>K<P000
D03Vc80010000000i/b00>K<P00000040>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P0020>K<P0040000003Vc800i/b0000000@0i/b000<000000>K<
P03Vc8008`3Vc8000`000000i/b00>K<P0070>K<P0040000003Vc800i/b0000000@0i/b000<00000
0>K<P03Vc8008`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b000@00000
0>K<P03Vc8000000103Vc8000`000000i/b00>K<P00R0>K<P0030000003Vc800i/b000P0i/b000@0
00000>K<P03Vc8000000103Vc8000`000000i/b00>K<P00W0>K<P000D03Vc80010000000i/b00>K<
P00000040>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b0
0>K<P0020>K<P0040000003Vc800i/b0000000@0i/b000<000000>K<P03Vc8008`3Vc8000`000000
i/b00>K<P0070>K<P0040000003Vc800i/b0000000@0i/b000<000000>K<P03Vc800903Vc8020000
00<0i/b000<000000>K<P03Vc8000P3Vc80010000000i/b00>K<P00000040>K<P0030000003Vc800
i/b002<0i/b00P0000080>K<P0040000003Vc800i/b0000000@0i/b000<000000>K<P03Vc8009`3V
c80004`0i/b0100000030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800:03Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc8000000103V
c8000`000000i/b00>K<P00S0>K<P0030000003Vc800i/b000<0i/b0100000030>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc8009@3Vc80200000080i/b000<000000>K<P03Vc8000P3V
c80010000000i/b00>K<P00000040>K<P0030000003Vc800i/b002@0i/b00P0000030>K<P0@00000
0`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b002L0i/b0001<0>K<P0030000003V
c800i/b000@0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00X0>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc8000P3Vc80010000000i/b00>K<P00000040>K<P0030000
003Vc800i/b002<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0040>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc8009P3Vc80010000000i/b00>K<P00000040>K<P004
0000003Vc800i/b0000000@0i/b000<000000>K<P03Vc8009@3Vc8001@000000i/b00>K<P03Vc800
000000H0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00W0>K<P000C03Vc8000`00
0000i/b00>K<P0050>K<P0040000003Vc800i/b0000002/0i/b000<000000>K<P03Vc8000`3Vc800
10000000i/b00>K<P00000040>K<P0040000003Vc800i/b0000002H0i/b000<000000>K<P03Vc800
0`3Vc8000`000000i/b00>K<P0050>K<P0040000003Vc800i/b0000002@0i/b000<000000>K<P03V
c8000P3Vc8001@000000i/b00>K<P03Vc80000000080i/b000<000000>K<P03Vc8000P3Vc8001000
0000i/b00>K<P000000S0>K<P0030000003Vc800i/b00080i/b000D000000>K<P03Vc800i/b00000
00070>K<P0040000003Vc800i/b0000002X0i/b0001<0>K<P0@00000103Vc804000002T0i/b00`00
00050>K<P0@00000103Vc804000002@0i/b00`0000050>K<P0@00000103Vc804000002@0i/b01@00
00040>K<P0@00000103Vc804000002<0i/b01@0000040>K<P0@00000103Vc804000002X0i/b0003o
0>K<P6T0i/b0003o0>K<P3P0i/b000<006Ko0>K<P03Vc8004@3Vc8000`00I_l0i/b00>K<P00;0>K<
P003001Vo`3Vc800i/b000P0i/b000<006Ko0>K<P03Vc8000@3Vc8000?l0i/b0>03Vc8000`00I_l0
i/b00>K<P00@0>K<P003001Vo`3Vc800i/b000d0i/b000<006Ko0>K<P03Vc8001`3Vc8000`00I_l0
i/b00>K<P0010>K<P000o`3Vc80h0>K<P003001Vo`3Vc800i/b00100i/b000<006Ko0>K<P03Vc800
3@3Vc8000`00I_l0i/b00>K<P0070>K<P003001Vo`3Vc800i/b00040i/b0003o0>K<P3P0i/b000<0
06Ko0>K<P03Vc8000P3Vc802001Vo`030>K<P000I_l006Ko008006Ko1P3Vc8000`00I_l0i/b00>K<
P0060>K<P0@006Ko1@3Vc8000`00I_l0i/b00>K<P0020>K<P0@0000000<006Ko0>K<P03Vc8000@3V
c8000?l0i/b0>03Vc8000`00I_l0i/b00>K<P0030>K<P08006Ko103Vc8000`00I_l0i/b00>K<P003
0>K<P003001Vo`3Vc800i/b000D0i/b000<006Ko0>K<P03Vc8001`3Vc8001@00I_l0i/b00>K<P03V
c800000000@0i/b000<006Ko0>K<P03Vc8000@3Vc80001X0i/b01@00I_lk000000P006Ko?P000008
001Voc`000002@00I_lm000000P006Ko1@0000000`00I_l000000000000300000003001Vo`000000
000000@0000000<006Ko0000000000000P0000000`00I_l000000000000500000003001Vo`000000
i/b000L0i/b000D006Ko0>K<P03Vc800i/b0000000040>K<P003001Vo`3Vc800i/b00040i/b0000J
0>K<P0040000003Vc800i/b00>K<P0@006Ko0`3Vc8000`000000i/b00>K<P0080>K<P0030000003V
c800i/b000T0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0080>K<P0030000003V
c800i/b00080i/b01000I_l30>K<P0040000003Vc800i/b00>K<P0D006Ko0P3Vc8000`000000i/b0
0>K<P0080>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc800203Vc8000`000000i/b0
0>K<P0080>K<P0030000003Vc800i/b000<0i/b01@00I_l00`000000i/b00>K<P0040>K<P0D006Ko
00<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000T0i/b0
00<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0030>K<P0@006Ko00<0i/b00000003Vc800
1@3Vc803001Vo`80i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0080>K<P0030000
003Vc800i/b000P0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0050>K<P0@006Ko
203Vc804001Vo`030>K<P000I_l0i/b000@0i/b000@006Ko0>K<P03Vc80000000`3Vc8000`00I_l0
i/b00>K<P0020>K<P003001Vo`3Vc800000000D0i/b000<006Ko0>K<P03Vc8001`3Vc8001@00I_l0
i/b00>K<P03Vc800000000@0i/b000<006Ko0>K<P03Vc8000@3Vc80001X0i/b000<000000>K<P03V
c8001@3Vc803001Vobd0i/b000<000000>K<P03Vc8000P00I_l?0>K<P0<006Ko8P3Vc8000`000000
i/b00>K<P00;0>K<P0<006Ko4@3Vc802001Voa@0i/b000<000000>K<P03Vc8006@3Vc802001Vo`h0
i/b00P00I_l;0>K<P0030000003Vc800i/b002@0i/b00`00I_l>0>K<P00400000000I_l006Ko001V
o`D0i/b00P00I_l50>K<P003001Vo`3Vc800i/b00080i/b000<006Ko0>K<P03Vc8001@3Vc8000`00
I_l0i/b00>K<P0070>K<P005001Vo`3Vc800i/b00>K<P0000000103Vc8000`00I_l0i/b00>K<P001
0>K<P0006P3Vc8000`000000i/b00>K<P0080>K<P08006Ko:`3Vc804001Voa<0i/b01000I_l[0>K<
P08006Ko5@3Vc802001Vob/0i/b00`00I_lB0>K<P08006Ko;P3Vc802001Voa@0i/b000<006Ko0>K<
P03Vc8000`3Vc803001Vo`<0i/b000<006Ko0>K<P03Vc8000`3Vc8000`00I_l0i/b00>K<P0050>K<
P003001Vo`3Vc800i/b000L0i/b000<006Ko0>K<P03Vc8001@0000000`3Vc80006Ko0>K<P0020>K<
P0006P3Vc8000`000000i/b00>K<P0090>K<P0@006Ko9`3Vc802001VoaT0i/b000<006Ko0>K<P03V
c8009P3Vc803001VoaT0i/b000<006Ko0>K<P03Vc8009`3Vc802001VoaH0i/b00P00I_l[0>K<P080
06Ko5@3Vc8000`00I_l0i/b00>K<P0030>K<P003001Vo`3Vc80006Ko00<006Ko1`3Vc8000`00I_l0
i/b00>K<P0030>K<P0D006Ko1@3Vc8000`00I_l0i/b00>K<P0020>K<P0030000003Vc800i/b00080
i/b000<006Ko0>K<P03Vc8000@3Vc80001X0i/b000<000000>K<P03Vc8003@3Vc8000`00I_l0i/b0
0>K<P00Q0>K<P0@006Ko6`3Vc803001Vob@0i/b00P00I_lL0>K<P08006Ko903Vc803001VoaX0i/b0
0P00I_lW0>K<P08006Ko5`3Vc8000`00I_l0i/b00>K<P0030>K<P003001Vo`3Vc800i/b000X0i/b0
00<006Ko0>K<P03Vc800103Vc8000`00I_l0i/b00>K<P0060>K<P003001Vo`3Vc800i/b00080i/b0
00<000000>K<P03Vc8000P3Vc8000`00I_l0i/b00>K<P0010>K<P0006P3Vc8000`000000i/b00>K<
P00>0>K<P003001Vo`3Vc800i/b00200i/b000<006Ko0>K<P03Vc8007`3Vc8000`00I_l0i/b00>K<
P00N0>K<P0@006Ko7`3Vc802001Vob40i/b000<006Ko0>K<P03Vc8007@3Vc802001Vob80i/b00`00
I_lI0>K<P003001Vo`3Vc800i/b000<0i/b000<006Ko0>K<P03Vc8002`3Vc8000`00I_l0i/b00>K<
P0030>K<P003001Vo`3Vc800i/b000D0i/b000<006Ko0>K<P03Vc800203Vc8000`00I_l0i/b00>K<
P0010>K<P0006P3Vc8000`000000i/b00>K<P00?0>K<P08006Ko703Vc804001Vob80i/b01000I_lL
0>K<P08006Ko903Vc803001Voa/0i/b01000I_lQ0>K<P0<006Ko7P3Vc8000`00I_l0i/b00>K<P01;
0>K<P0006P3Vc8000`000000i/b00>K<P00A0>K<P0<006Ko6@3Vc8000`00I_l0i/b00>K<P00V0>K<
P08006Ko603Vc804001VobP0i/b00P00I_lH0>K<P003001Vo`3Vc800i/b002H0i/b00`00I_lH0>K<
P0@006KoC@3Vc80001X0i/b000<000000>K<P03Vc8004`3Vc802001Voa@0i/b01000I_lZ0>K<P0@0
06Ko4P3Vc8001000I_l0i/b00>K<P000I_l]0>K<P08006Ko4`3Vc804001Vob/0i/b00`00I_lB0>K<
P0@006KoD03Vc80001X0i/b00P00000E0>K<P0@006Ko3@3Vc802001Vo`030>K<P000I_l006Ko0340
i/b000@006Ko0>K<P000I_l006Ko3@3Vc804001Voc00i/b00P00I_l>0>K<P0@006Ko<03Vc8000`00
I_l0i/b00>K<P00?0>K<P004001Vo`3Vc80006Ko001Voe40i/b0000J0>K<P0030000003Vc800i/b0
01P0i/b01000I_l20>K<P08006Ko0`3Vc802001Vo`80i/b00P00I_lc0>K<P0<006Ko0P3Vc802001V
o`80i/b00P00I_l00`3Vc80006Ko001Vo`03001VocD0i/b000@006Ko0>K<P000I_l006Ko0P3Vc802
001Vo`80i/b00P00I_l01@3Vc80006Ko0>K<P03Vc80006Ko0380i/b01@00I_l00`3Vc80006Ko001V
o`020>K<P08006Ko00<0i/b0001Vo`00I_l00`00I_mD0>K<P0006P3Vc8000`000000i/b00>K<P00I
0>K<P003001Vo`3Vc800i/b000L006Ko?03Vc80:001VocX0i/b000<006Ko0>K<P03Vc8002P00I_li
0>K<P0X006KoF03Vc80001X0i/b000<000000>K<P03Vc800803Vc8000`00I_l0i/b00>K<P0100>K<
P08006KoA@3Vc8000`00I_l0i/b00>K<P0100>K<P08006KoG03Vc80001X0i/b000<000000>K<P03V
c800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003V
c800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`00
0000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0800000o`3Vc81=0>K<P0006P3Vc8000`000000i/b0
0>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<00000
0>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P003
0000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3V
c8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc800
01X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc80200000?l0i/b0C@3Vc80001X0i/b0
00<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J
0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<
P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0
C03Vc80000040>K<P00000000000000000D0i/b00P0000040>K<P0H000001@3Vc8000`000000i/b0
0>K<P03o0>K<P4`0i/b0000010000000i/b00>K<P00000050>K<P08000001@3Vc8001@000000i/b0
0>K<P03Vc800000000D0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P000103Vc8000`000000i/b0
0>K<P00:0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P000103V
c8000`000000i/b00>K<P00;0>K<P08000001P3Vc80300000?l0i/b0C03Vc80000@0i/b000<00000
0>K<P03Vc800303Vc802000000D0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P000103Vc8000`00
0000i/b00>K<P00=0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800o`3Vc81<0>K<
P00000@000000>K<P03Vc80000002`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0001000000;0>K<P0D000001P3Vc8000`000000
i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<0
00000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<
P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b00P00003o0>K<P4d0i/b0000J0>K<P0030000
003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc800
0`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0
i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0
000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<
0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0800000o`3Vc81=0>K<P000
6P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03V
c80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<
P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800
o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800
i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc80200000?l0
i/b0C@3Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<
P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<
P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000
003Vc800i/b00?l0i/b0C03Vc80000040>K<P00000000000000000D0i/b00P0000060>K<P0<00000
1P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000010000000i/b00>K<P00000050>K<P0800000
1`3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b00?l0i/b0C03Vc80000@0i/b000<0
00000>K<P03Vc800203Vc805000000H0i/b00`00003o0>K<P4`0i/b000040>K<P0030000003Vc800
i/b000P0i/b000@000000>K<P03Vc80000001`3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b00004
0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P00000001`3Vc8000`000000i/b00>K<P03o
0>K<P4`0i/b000040>K<P0030000003Vc800i/b000X0i/b00P0000070>K<P0030000003Vc800i/b0
0?l0i/b0C03Vc80000040000003Vc800i/b0000000d0i/b00P0000070>K<P0030000003Vc800i/b0
0?l0i/b0C03Vc80000@000003P3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b00?l0
i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<
P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<
P03Vc800o`3Vc81<0>K<P0006P3Vc80200000?l0i/b0C@3Vc80001X0i/b000<000000>K<P03Vc800
o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800
i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000
i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<0
00000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<
P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b00P00003o0>K<P4d0i/b0000J0>K<P0030000
003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc800
0`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0
i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0
000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<
0>K<P0006P3Vc80200000?l0i/b0C@3Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P000
6P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03V
c80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<
P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80000040>K<P00000000000000000D0
i/b00P0000050>K<P0@000001P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000010000000i/b0
0>K<P00000050>K<P08000001@3Vc8001@000000i/b00>K<P03Vc800000000D0i/b000<000000>K<
P03Vc800o`3Vc81<0>K<P000103Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b00080
i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b000040>K<P0030000
003Vc800i/b000P0i/b000@000000>K<P03Vc800i/b00P0000050>K<P0<00000o`3Vc81<0>K<P000
103Vc8000`000000i/b00>K<P0080>K<P0D000001P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0
00040>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<
P03o0>K<P4`0i/b0000010000000i/b00>K<P000000<0>K<P0030000003Vc800i/b000L0i/b000<0
00000>K<P03Vc800o`3Vc81<0>K<P0001000000=0>K<P0@000001@3Vc8000`000000i/b00>K<P03o
0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03V
c800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003V
c800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8020000
0?l0i/b0C@3Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b0
0>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<00000
0>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P003
0000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3V
c8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0800000o`3Vc81=0>K<P0006P3Vc8000`00
0000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b0
00<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J
0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<
P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0
C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc80200000?l0i/b0C@3Vc800
01X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0
i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3V
c81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b0
0?l0i/b0C03Vc80000040>K<P00000000000000000D0i/b00P0000050>K<P0@000001P3Vc8000`00
0000i/b00>K<P03o0>K<P4`0i/b0000010000000i/b00>K<P00000050>K<P0800000103Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800o`3Vc81<0>K<
P000103Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c8000`3Vc80300000?l0i/b0C03Vc80000@0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b0
0>K<P002000000D0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P000103Vc8000`000000i/b00>K<
P0090>K<P0@000001P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b000040>K<P0030000003Vc800
i/b000P0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800
i/b00?l0i/b0C03Vc80000040000003Vc800i/b0000000/0i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P0030>K<P0030000003Vc800i/b00?l0i/b0C03Vc80000@00000303Vc8040000
00H0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0
i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3V
c81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0800000o`3Vc81=0>K<
P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0
C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o
0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03V
c800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003V
c800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8020000
0?l0i/b0C@3Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b0
0>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<00000
0>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P003
0000003Vc800i/b00?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800703Vc8070?l003`0i/b0
0P3o00000`3Vc800o`000?l000050?l003X0i/b000<0o`000>K<P03Vc8000P3o00001@3Vc800o`00
0?l0003o0000i/b000<0o`00>@3Vc8020?l000050>K<P03o0000o`000?l0003Vc8000`3o001H0>K<
P0006P3Vc8000`000000i/b00>K<P00H0>K<P0@0o`000P3Vc8020?l000<0i/b00P3o00020>K<P080
o`00<`3Vc8040?l000030>K<P03o0000o`000080i/b00P3o00000`3Vc800o`000?l000030?l003D0
i/b0103o00020>K<P080o`000P3Vc8020?l000030>K<P03o0000i/b003@0i/b01@3o00000`3Vc800
o`000?l000020>K<P080o`0000<0i/b00?l0003o00000`3o001D0>K<P0006P3Vc802000001H0i/b0
103o000<0>K<P0D0o`00<@3Vc800103o0000i/b00?l0003o000=0>K<P0@0o`00<03Vc8020?l000h0
i/b0103o000`0>K<P080o`0000<0i/b00?l0003o00002P3Vc8001@3o0000i/b00>K<P03o0000i/b0
0080o`00D@3Vc80001X0i/b000<000000>K<P03Vc800503Vc8000`3o0000i/b00>K<P00B0>K<P0@0
o`00:`3Vc8030?l00180i/b00P3o00000`3Vc800o`000>K<P00/0>K<P080o`004`3Vc8040?l002/0
i/b00`3o000B0>K<P0<0o`00803Vc8000`3o0000i/b00>K<P00A0>K<P0030?l0003Vc800i/b000/0
i/b000<0o`000>K<P03Vc800203Vc8000`3o0000i/b00>K<P0010>K<P0006P3Vc8000`000000i/b0
0>K<P00A0>K<P0<0o`006@3Vc8000`3o0000i/b00>K<P00W0>K<P0030?l0003Vc800i/b001H0i/b0
103o000X0>K<P080o`005P3Vc8030?l002T0i/b00P3o000H0>K<P0@0o`00703Vc8000`3o0000i/b0
0>K<P00@0>K<P0030?l0003Vc800i/b000d0i/b000<0o`000>K<P03Vc8001`3Vc8000`3o0000i/b0
0>K<P0010>K<P0006P3Vc8000`000000i/b00>K<P00?0>K<P080o`00703Vc8040?l002<0i/b00`3o
000L0>K<P080o`00903Vc8030?l001/0i/b0103o000S0>K<P080o`006`3Vc8030?l001`0i/b000<0
o`000>K<P03Vc800403Vc8000`3o0000i/b00>K<P00=0>K<P0030?l0003Vc800i/b000L0i/b000<0
o`000>K<P03Vc8000@3Vc80001X0i/b000<000000>K<P03Vc8003P3Vc8000`3o0000i/b00>K<P00O
0>K<P0030?l0003Vc800i/b00200i/b000<0o`000>K<P03Vc8007P3Vc8040?l001l0i/b00P3o000Q
0>K<P0030?l0003Vc800i/b001l0i/b00P3o000P0>K<P080o`006P3Vc8000`3o0000i/b00>K<P004
0>K<P0<0o`0000@0i/b00?l0003o0000o`00103Vc8000`3o0000i/b00>K<P0060>K<P0@0o`001@3V
c8000`3o0000i/b00>K<P0060>K<P0030?l0003Vc800i/b00040i/b0000J0>K<P0030000003Vc800
i/b000d0i/b000<0o`000>K<P03Vc8008@3Vc8040?l001/0i/b00`3o000T0>K<P0030?l0003Vc800
i/b001/0i/b00P3o000T0>K<P0<0o`00703Vc8020?l002<0i/b00`3o000H0>K<P0030?l0003Vc800
i/b000<0i/b000@0o`000>K<P03Vc800i/b00P3o00060>K<P0030?l0003Vc800i/b000D0i/b000<0
o`000>K<P03Vc8001`3Vc8000`3o0000i/b00>K<P0060>K<P0030?l0003Vc800i/b00040i/b0000J
0>K<P0030000003Vc800i/b000T0i/b0103o000W0>K<P080o`006@3Vc8000`3o0000i/b00>K<P00V
0>K<P0<0o`006@3Vc8000`3o0000i/b00>K<P00U0>K<P0<0o`00603Vc8030?l002P0i/b00P3o000F
0>K<P0030?l0003Vc800i/b000<0i/b000<0o`000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P004
0>K<P0030?l0003Vc800i/b000D0i/b000<0o`000>K<P03Vc8001`3Vc8000`3o0000i/b00>K<P006
0>K<P0030?l0003Vc800i/b00040i/b0000J0>K<P0030000003Vc800i/b000P0i/b00P3o000[0>K<
P0<0o`00503Vc8040?l002X0i/b00P3o000F0>K<P080o`00:`3Vc8030?l001<0i/b00P3o000]0>K<
P080o`00503Vc8000`3o0000i/b00>K<P0040>K<P0D0o`001P3Vc8000`3o0000i/b00>K<P0050>K<
P0030?l0003Vc800i/b000L0i/b000<0o`000>K<P03Vc8001P3Vc8000`3o0000i/b00>K<P0010>K<
P0003`3Vc806000000D0i/b000<000000>K<P03Vc8001@3Vc8040?l002l0i/b00P3o000A0>K<P080
o`00;`3Vc8030?l00140i/b00P3o000_0>K<P0<0o`003`3Vc8020?l00340i/b00`3o000@0>K<P080
o`002P3Vc8000`3o0000i/b00>K<P0040>K<P0030?l0003Vc800i/b000D0i/b000<0o`000>K<P03V
c8001`3Vc8000`3o0000i/b00>K<P0060>K<P0030?l0003Vc800i/b00040i/b0000B0>K<P0030000
003Vc800i/b000D0i/b000@000000>K<P03Vc800i/b0103o000d0>K<P0@0o`002P3Vc8040?l003@0
i/b0103o00080>K<P0D0o`00<`3Vc8040?l000X0i/b00P3o000e0>K<P0@0o`002@3Vc8040?l00003
0>K<P03o0000i/b000T0i/b000<0o`000>K<P03Vc800103Vc8000`3o0000i/b00>K<P0050>K<P003
0?l0003Vc800i/b000L0i/b000<0o`000>K<P03Vc8001P3Vc8000`3o0000i/b00>K<P0010>K<P000
4P3Vc8000`000000i/b00>K<P0050>K<P0D0o`00>`3Vc80;0?l003X0i/b02P3o000j0>K<P0/0o`00
>`3Vc80:0?l000@0i/b000<0o`000>K<P03Vc800103Vc8040?l000P0i/b000<0o`000>K<P03Vc800
0`3Vc8050?l000D0i/b000<0o`000>K<P03Vc8001`3Vc8000`3o0000i/b00>K<P0010>K<P0004P3V
c8000`000000i/b00>K<P03o0>K<P2<0i/b000<0o`000>K<P03Vc800403Vc8000`3o0000i/b00>K<
P0040>K<P0030?l0003Vc800i/b000H0i/b000<0o`000>K<P03Vc8001`3Vc8000`3o0000i/b00>K<
P0010>K<P0004P3Vc8000`000000i/b00>K<P03o0>K<P2<0i/b000<0o`000>K<P03Vc8004@3Vc800
0`3o0000i/b00>K<P0030>K<P0030?l0003Vc800i/b000D0i/b000<0o`000>K<P03Vc800203Vc800
0`3o0000i/b00>K<P0010>K<P0004P3Vc8000`000000i/b00>K<P03o0>K<P5@0i/b0000B0>K<P003
0000003Vc800i/b00?l0i/b0E03Vc8000100i/b00`00003o0>K<P5H0i/b0003o0>K<P6T0i/b0003o
0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b00000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-23.3759, -0.0981885, \
1.1066, 0.00647657}}]
}, Open  ]],

Cell["\<\

The propabilities to find the state in a particular eigenstate are now time \
dependent, we obtain a superposition of a fast and a slow oscillation. The \
frequncy of the slow oscillation is called the Rabi frequncy.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rabi Frequency", "Section"],

Cell[TextData[{
  "In order to find the involved frequencies, we perform a Fourier transform \
on ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(a(t)\)\( | \^2\)\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\( \
(*Fourier*) \)\(\[IndentingNewLine]\)\(numfourier[fname_, tmax_] := 
        Block[{t, n00, n0m1, n0p1, nmax = 1000, at, lmax, 
            i}, \[IndentingNewLine]func[t_] = 
            fname[t]; \[IndentingNewLine]meanpop = 
            NIntegrate[func[t], {t, 0, tmax}]/tmax; \[IndentingNewLine]at = 
            Table[func[i\ tmax\/nmax], {i, 0, nmax}] - 
              meanpop; \[IndentingNewLine]fA = 
            Fourier[at]; \[IndentingNewLine]lmax = 
            Position[Abs[Take[fA, Round[nmax/2]]], 
              Max[Abs[Take[fA, Round[nmax/2]]]]]; \[IndentingNewLine]n00 = 
            Min[Flatten[lmax]]; \[IndentingNewLine]n0m1 = 
            Max[n00 - 1, 1]; \[IndentingNewLine]n0p1 = 
            n00 + 1; \[IndentingNewLine]n0 = \((n00*Abs[fA[\([n00]\)]] + 
                    n0m1*Abs[fA[\([n0m1]\)]] + 
                    n0p1*Abs[fA[\([n0p1]\)]])\)/\((Abs[fA[\([n00]\)]] + 
                    Abs[fA[\([n0m1]\)]] + Abs[fA[\([n0p1]\)]])\) - 
              1;\[IndentingNewLine]];\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(numfourier[pup, tmax];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Abs[fA], \ PlotJoined \[Rule] True, 
        PlotRange \[Rule] {{0, 100}, All}, PlotStyle \[Rule] {Hue[1]}, 
        AxesLabel \[Rule] {"\<\[Omega]\>", "\<\>"}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.01 0.0145057 1.22824 [
[.2 .00201 -6 -9 ]
[.2 .00201 6 0 ]
[.4 .00201 -6 -9 ]
[.4 .00201 6 0 ]
[.6 .00201 -6 -9 ]
[.6 .00201 6 0 ]
[.8 .00201 -6 -9 ]
[.8 .00201 6 0 ]
[1 .00201 -9 -9 ]
[1 .00201 9 0 ]
[1.025 .01451 0 -4.90625 ]
[1.025 .01451 10 4.90625 ]
[-0.0125 .13733 -18 -4.5 ]
[-0.0125 .13733 0 4.5 ]
[-0.0125 .26015 -18 -4.5 ]
[-0.0125 .26015 0 4.5 ]
[-0.0125 .38298 -18 -4.5 ]
[-0.0125 .38298 0 4.5 ]
[-0.0125 .5058 -18 -4.5 ]
[-0.0125 .5058 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .01451 m
.2 .02076 L
s
[(20)] .2 .00201 0 1 Mshowa
.4 .01451 m
.4 .02076 L
s
[(40)] .4 .00201 0 1 Mshowa
.6 .01451 m
.6 .02076 L
s
[(60)] .6 .00201 0 1 Mshowa
.8 .01451 m
.8 .02076 L
s
[(80)] .8 .00201 0 1 Mshowa
1 .01451 m
1 .02076 L
s
[(100)] 1 .00201 0 1 Mshowa
.125 Mabswid
.05 .01451 m
.05 .01826 L
s
.1 .01451 m
.1 .01826 L
s
.15 .01451 m
.15 .01826 L
s
.25 .01451 m
.25 .01826 L
s
.3 .01451 m
.3 .01826 L
s
.35 .01451 m
.35 .01826 L
s
.45 .01451 m
.45 .01826 L
s
.5 .01451 m
.5 .01826 L
s
.55 .01451 m
.55 .01826 L
s
.65 .01451 m
.65 .01826 L
s
.7 .01451 m
.7 .01826 L
s
.75 .01451 m
.75 .01826 L
s
.85 .01451 m
.85 .01826 L
s
.9 .01451 m
.9 .01826 L
s
.95 .01451 m
.95 .01826 L
s
.25 Mabswid
0 .01451 m
1 .01451 L
s
gsave
1.025 .01451 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .13733 m
.00625 .13733 L
s
[(0.1)] -0.0125 .13733 1 0 Mshowa
0 .26015 m
.00625 .26015 L
s
[(0.2)] -0.0125 .26015 1 0 Mshowa
0 .38298 m
.00625 .38298 L
s
[(0.3)] -0.0125 .38298 1 0 Mshowa
0 .5058 m
.00625 .5058 L
s
[(0.4)] -0.0125 .5058 1 0 Mshowa
.125 Mabswid
0 .03907 m
.00375 .03907 L
s
0 .06364 m
.00375 .06364 L
s
0 .0882 m
.00375 .0882 L
s
0 .11276 m
.00375 .11276 L
s
0 .16189 m
.00375 .16189 L
s
0 .18646 m
.00375 .18646 L
s
0 .21102 m
.00375 .21102 L
s
0 .23559 m
.00375 .23559 L
s
0 .28472 m
.00375 .28472 L
s
0 .30928 m
.00375 .30928 L
s
0 .33385 m
.00375 .33385 L
s
0 .35841 m
.00375 .35841 L
s
0 .40754 m
.00375 .40754 L
s
0 .43211 m
.00375 .43211 L
s
0 .45667 m
.00375 .45667 L
s
0 .48124 m
.00375 .48124 L
s
0 .53037 m
.00375 .53037 L
s
0 .55493 m
.00375 .55493 L
s
0 .57949 m
.00375 .57949 L
s
0 .60406 m
.00375 .60406 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.01 .01547 m
.02 .05149 L
.03 .06068 L
.04 .09109 L
.05 .60332 L
.06 .09857 L
.07 .05126 L
.08 .03734 L
.09 .03083 L
.1 .02711 L
.11 .02473 L
.12 .02309 L
.13 .0219 L
.14 .02099 L
.15 .02029 L
.16 .01972 L
.17 .01926 L
.18 .01887 L
.19 .01854 L
.2 .01826 L
.21 .01802 L
.22 .01781 L
.23 .01762 L
.24 .01745 L
.25 .0173 L
.26 .01717 L
.27 .01704 L
.28 .01693 L
.29 .01683 L
.3 .01674 L
.31 .01665 L
.32 .01657 L
.33 .01649 L
.34 .01642 L
.35 .01636 L
.36 .0163 L
.37 .01624 L
.38 .01619 L
.39 .01614 L
.4 .01609 L
.41 .01604 L
.42 .016 L
.43 .01596 L
.44 .01592 L
.45 .01588 L
.46 .01584 L
.47 .01581 L
.48 .01578 L
.49 .01574 L
.5 .01571 L
Mistroke
.51 .01568 L
.52 .01565 L
.53 .01563 L
.54 .0156 L
.55 .01557 L
.56 .01554 L
.57 .01552 L
.58 .01549 L
.59 .01547 L
.6 .01544 L
.61 .01541 L
.62 .01539 L
.63 .01536 L
.64 .01533 L
.65 .01531 L
.66 .01528 L
.67 .01524 L
.68 .01521 L
.69 .01509 L
.7 .01508 L
.71 .01507 L
.72 .0156 L
.73 .04294 L
.74 .01848 L
.75 .0181 L
.76 .01996 L
.77 .04453 L
.78 .0223 L
.79 .0181 L
.8 .01696 L
.81 .01644 L
.82 .01615 L
.83 .01596 L
.84 .01583 L
.85 .01574 L
.86 .01566 L
.87 .01561 L
.88 .01556 L
.89 .01552 L
.9 .01549 L
.91 .01546 L
.92 .01543 L
.93 .01541 L
.94 .01539 L
.95 .01537 L
.96 .01535 L
.97 .01533 L
.98 .01532 L
.99 .0153 L
1 .01529 L
Mistroke
Mfstroke
1 .01529 m
1 .01529 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000D@3Vc806
000000@0i/b00`00000d0>K<P0<000001@3Vc80300000380i/b0100000050>K<P0<00000<`3Vc804
000000D0i/b00`00000]0>K<P0H00000103Vc803000000D0i/b00`00000<0>K<P000DP3Vc8001@00
0000i/b00>K<P03Vc800000000<0i/b000@000000>K<P03Vc8000000=@3Vc8000`000000i/b00>K<
P0030>K<P0040000003Vc800i/b000000380i/b000D000000>K<P03Vc800i/b0000000030>K<P004
0000003Vc800i/b000000380i/b000<000000>K<P03Vc8000P3Vc8001@000000i/b00>K<P03Vc800
00000080i/b000<000000>K<P03Vc800;P3Vc8000`000000i/b00>K<P0030>K<P0040000003Vc800
i/b0000000@0i/b000@000000>K<P03Vc8000000303Vc80005<0i/b000<000000>K<P03Vc8000`3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b002l0i/b01@0000030>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc800;P3Vc8000`000000i/b00>K<P0020>K<P0040000003V
c800i/b0000000@0i/b000<000000>K<P03Vc800;`3Vc8000`000000i/b00>K<P0020>K<P0040000
003Vc800i/b0000000@0i/b000<000000>K<P03Vc800;@3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b00080i/b000@000000>K<P03Vc8000000103Vc8000`000000i/b00>K<P0090>K<
P000E03Vc802000000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00_0>K<P004
0000003Vc800i/b0000000@0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00^0>K<
P0040000003Vc800i/b00>K<P08000000P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800
i/b00300i/b000<000000>K<P03Vc8000P0000020>K<P0030000003Vc800i/b00080i/b000<00000
0>K<P03Vc800;@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b000@00000
0>K<P03Vc8000000103Vc8000`000000i/b00>K<P0090>K<P000E@3Vc80200000080i/b000<00000
0>K<P03Vc8000P3Vc8000`000000i/b00>K<P00`0>K<P0030000003Vc800000000@0i/b000<00000
0>K<P03Vc8000P3Vc8000`000000i/b00>K<P00^0>K<P0D000000`3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b00300i/b0100000030>K<P0030000003Vc800i/b00080i/b000<00000
0>K<P03Vc800;@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b000@00000
0>K<P03Vc8000000103Vc8000`000000i/b00>K<P0090>K<P000EP3Vc80010000000i/b00>K<P000
00040>K<P0030000003Vc800i/b00340i/b00P0000040>K<P0030000003Vc800i/b00080i/b000<0
00000>K<P03Vc800;`3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b00080i/b000<0
00000>K<P03Vc800;`3Vc8000`000000i/b00>K<P0020>K<P0040000003Vc800i/b0000000@0i/b0
00<000000>K<P03Vc800;@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b0
00@000000>K<P03Vc8000000103Vc8000`000000i/b00>K<P0090>K<P000D@3Vc8000`000000i/b0
0>K<P0020>K<P0050000003Vc800i/b00>K<P00000000P3Vc8000`000000i/b00>K<P00b0>K<P080
00001@3Vc80010000000i/b00>K<P000000b0>K<P0030000003Vc800i/b000D0i/b000@000000>K<
P03Vc8000000<P3Vc8000`000000i/b00>K<P0020>K<P0050000003Vc800i/b00>K<P00000000P3V
c8000`000000i/b00>K<P00^0>K<P0030000003Vc800i/b000<0i/b000@000000>K<P03Vc8000000
103Vc80010000000i/b00>K<P000000<0>K<P000D@3Vc805000000@0i/b01000000e0>K<P0030000
003Vc800i/b000<0i/b01000000c0>K<P0@000000`3Vc804000003<0i/b0100000040>K<P0@00000
;P3Vc803000000D0i/b0100000040>K<P0@00000303Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc800
01X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0
i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0@P3Vc805000000D0i/b0000J0>K<P0030000003V
c800i/b00?l0i/b0@@3Vc80010000000i/b00>K<P00000020>K<P0030000003Vc800i/b00080i/b0
000J0>K<P0<0000000<0o`00000000000000X@00000k0?l002`00000:`3o000:0>K<P0040000003V
c800i/b000000080i/b000<000000>K<P03Vc8000P3Vc80001X0i/b000@000000>K<P03Vc800o`00
303Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800
203Vc81]0?l000D0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00=0>K<P0030000
003Vc800i/b000d0i/b000<000000>K<P03Vc8000`3Vc8000`3o0000i/b00>K<P0030>K<P0D0o`00
2P3Vc80H0?l000/0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00<0>K<P0030000
003Vc800i/b000P0i/b000@000000>K<P03Vc80000000P3Vc8000`000000i/b00>K<P0020>K<P000
6P3Vc80010000000i/b00>K<P03o000S0>K<P1<0o`00103Vc8000`000000i/b00>K<P00l0>K<P003
0000003Vc800i/b003/0i/b000<000000>K<P03Vc800903Vc8000`3o0000i/b00>K<P0020>K<P003
0?l0003Vc800i/b00080i/b00P3o00060>K<P080o`00103Vc8000`000000i/b00>K<P00k0>K<P003
0000003Vc800i/b000T0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0020>K<P000
6P3Vc8001@000000i/b00>K<P03Vc800o`0001`0i/b01P3o002k0>K<P0050?l0003Vc800i/b00>K<
P03o00001P3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0003Vc800i/b004l0i/b000D000000>K<
P03Vc800i/b0000000040>K<P0006P3Vc8001@000000i/b00>K<P03Vc800o`0001T0i/b00`3o0031
0>K<P0050?l0003Vc800i/b00>K<P03o00001`3Vc8000`3o0000i/b00>K<P0020>K<P0030?l0003V
c800i/b005P0i/b0000J0>K<P0050000003Vc800i/b00>K<P03o00005`3Vc8020?l00<D0i/b000@0
o`000>K<P03Vc800o`001`3Vc8001@3o0000i/b00>K<P03Vc800o`0005/0i/b0000J0>K<P0050000
003Vc800i/b00>K<P03o00005@3Vc8020?l00<L0i/b000<0o`000>K<P03o0000203Vc8001@3o0000
i/b00>K<P03Vc800o`0005/0i/b0000J0>K<P0030000003Vc800i/b00080i/b000<0o`000>K<P03V
c8004@3Vc8000`3o0000i/b00>K<P0370>K<P0030?l0003Vc800o`0000T0i/b000<0o`000>K<P03o
0000G03Vc80001X0i/b00P0000030>K<P0030?l0003Vc800i/b00100i/b000<0o`000>K<P03Vc800
b@3Vc8000`3o0000i/b00>K<P0080>K<P0030?l0003Vc800o`0005`0i/b0000J0>K<P0030000003V
c800i/b00080i/b000<0o`000>K<P03Vc800403Vc8000`3o0000i/b00>K<P0390>K<P0030?l0003V
c800i/b000T0i/b000<0o`000>K<P03Vc800F`3Vc80001X0i/b000<000000>K<P03Vc8000P3Vc800
0`3o0000i/b00>K<P00?0>K<P0030?l0003Vc800i/b00=H0i/b000<0o`000>K<P03Vc800F`3Vc800
01X0i/b000<000000>K<P03Vc8000`3Vc8000`3o0000i/b00>K<P00>0>K<P0030?l0003Vc800i/b0
0?l0i/b0=@3Vc80001X0i/b000<000000>K<P03Vc8000`3Vc8000`3o0000i/b00>K<P00=0>K<P003
0?l0003Vc800i/b00?l0i/b0=P3Vc80001X0i/b000<000000>K<P03Vc800103Vc8000`3o0000i/b0
0>K<P00<0>K<P0030?l0003Vc800i/b00?l0i/b0=P3Vc80001X0i/b000<000000>K<P03Vc8001@3V
c8000`3o0000i/b00>K<P00;0>K<P0030?l0003Vc800i/b00?l0i/b0=P3Vc80001X0i/b00P000007
0>K<P0030?l0003Vc800i/b000T0i/b000<0o`000>K<P03Vc800o`3Vc80g0>K<P0006P3Vc8000`00
0000i/b00>K<P0060>K<P0030?l0003Vc800i/b000T0i/b000<0o`000>K<P03Vc800o`3Vc80g0>K<
P0006P3Vc8000`000000i/b00>K<P0070>K<P0030?l0003Vc800i/b000P0i/b000<0o`000>K<P03V
c800o`3Vc80g0>K<P0006P3Vc8000`000000i/b00>K<P0070>K<P0030?l0003Vc800i/b000P0i/b0
00<0o`000>K<P03Vc800o`3Vc80g0>K<P0006P3Vc8000`000000i/b00>K<P0070>K<P0030?l0003V
c800i/b000P0i/b000<0o`000>K<P03Vc800o`3Vc80g0>K<P0006P3Vc8000`000000i/b00>K<P008
0>K<P0030?l0003Vc800i/b000H0i/b000<0o`000>K<P03Vc800o`3Vc80h0>K<P0006P3Vc8000`00
0000i/b00>K<P0080>K<P0030?l0003Vc800i/b000H0i/b000<0o`000>K<P03Vc800o`3Vc80h0>K<
P0006P3Vc8000`000000i/b00>K<P0080>K<P0030?l0003Vc800i/b000H0i/b000<0o`000>K<P03V
c800o`3Vc80h0>K<P0006P3Vc802000000X0i/b000<0o`000>K<P03Vc8001@3Vc8000`3o0000i/b0
0>K<P03o0>K<P3P0i/b0000J0>K<P0030000003Vc800i/b000T0i/b000<0o`000>K<P03Vc800103V
c8000`3o0000i/b00>K<P03o0>K<P3T0i/b0000J0>K<P0030000003Vc800i/b000T0i/b000<0o`00
0>K<P03Vc800103Vc8000`3o0000i/b00>K<P03o0>K<P3T0i/b0000J0>K<P0030000003Vc800i/b0
00T0i/b000<0o`000>K<P03Vc800103Vc8000`3o0000i/b00>K<P03o0>K<P3T0i/b0000J0>K<P003
0000003Vc800i/b000T0i/b000<0o`000>K<P03Vc800103Vc8000`3o0000i/b00>K<P03o0>K<P3T0
i/b0000J0>K<P0030000003Vc800i/b000T0i/b000<0o`000>K<P03Vc800103Vc8000`3o0000i/b0
0>K<P03o0>K<P3T0i/b0000J0>K<P0030000003Vc800i/b000T0i/b000<0o`000>K<P03Vc800103V
c8000`3o0000i/b00>K<P03o0>K<P3T0i/b0000J0>K<P0030000003Vc800i/b000T0i/b000<0o`00
0>K<P03Vc800103Vc8000`3o0000i/b00>K<P03o0>K<P3T0i/b0000J0>K<P08000002P3Vc8000`3o
0000i/b00>K<P0040>K<P0030?l0003Vc800i/b00?l0i/b0>@3Vc80001X0i/b000<000000>K<P03V
c8002@3Vc8000`3o0000i/b00>K<P0040>K<P0030?l0003Vc800i/b00?l0i/b0>@3Vc80001X0i/b0
00<000000>K<P03Vc8002@3Vc8000`3o0000i/b00>K<P0040>K<P0030?l0003Vc800i/b00?l0i/b0
>@3Vc80001X0i/b000<000000>K<P03Vc8002@3Vc8000`3o0000i/b00>K<P0040>K<P0030?l0003V
c800i/b00?l0i/b0>@3Vc80001X0i/b000<000000>K<P03Vc8002@3Vc8000`3o0000i/b00>K<P004
0>K<P0030?l0003Vc800i/b00?l0i/b0>@3Vc80000040>K<P00000000000000000D0i/b00P000004
0>K<P0H000001@3Vc8000`000000i/b00>K<P0090>K<P0030?l0003Vc800i/b000@0i/b000<0o`00
0>K<P03Vc800o`3Vc80i0>K<P00000@000000>K<P03Vc80000001@3Vc802000000L0i/b000<00000
0>K<P03Vc8001@3Vc8000`000000i/b00>K<P0090>K<P0030?l0003Vc800i/b000@0i/b000<0o`00
0>K<P03Vc800o`3Vc80i0>K<P000103Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b0
00D0i/b000<000000>K<P03Vc8002@3Vc8000`3o0000i/b00>K<P0040>K<P0030?l0003Vc800i/b0
0?l0i/b0>@3Vc80000@0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P0050>K<P0<0
00002@3Vc8000`3o0000i/b00>K<P0040>K<P0030?l0003Vc800i/b00?l0i/b0>@3Vc80000@0i/b0
00<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000T0i/b0
00<0o`000>K<P03Vc800103Vc8000`3o0000i/b00>K<P03o0>K<P3T0i/b000040>K<P0030000003V
c800i/b000/0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0090>K<P0030?l0003V
c800i/b000@0i/b000<0o`000>K<P03Vc800o`3Vc80i0>K<P00000@000000>K<P03Vc80000003P3V
c8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000T0i/b000<0o`000>K<P03Vc800103V
c8000`3o0000i/b00>K<P03o0>K<P3T0i/b00004000000`0i/b00`0000070>K<P0030000003Vc800
i/b000T0i/b000<0o`000>K<P03Vc800103Vc8000`3o0000i/b00>K<P03o0>K<P3T0i/b0000J0>K<
P0030000003Vc800i/b000T0i/b000<0o`000>K<P03Vc800103Vc8000`3o0000i/b00>K<P03o0>K<
P3T0i/b0000J0>K<P0030000003Vc800i/b000X0i/b000<0o`000>K<P03Vc8000`3Vc8000`3o0000
i/b00>K<P03o0>K<P3T0i/b0000J0>K<P08000002`3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0
003Vc800i/b00?l0i/b0>@3Vc80001X0i/b000<000000>K<P03Vc8002P3Vc8000`3o0000i/b00>K<
P0030>K<P0030?l0003Vc800i/b00?l0i/b0>@3Vc80001X0i/b000<000000>K<P03Vc8002P3Vc800
0`3o0000i/b00>K<P0030>K<P0030?l0003Vc800i/b00?l0i/b0>@3Vc80001X0i/b000<000000>K<
P03Vc8002P3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0003Vc800i/b00?l0i/b0>@3Vc80001X0
i/b000<000000>K<P03Vc8002P3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0003Vc800i/b00?l0
i/b0>@3Vc80001X0i/b000<000000>K<P03Vc8002P3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0
003Vc800i/b00?l0i/b0>@3Vc80001X0i/b000<000000>K<P03Vc8002P3Vc8000`3o0000i/b00>K<
P0030>K<P0030?l0003Vc800i/b00?l0i/b0>@3Vc80001X0i/b000<000000>K<P03Vc8002P3Vc800
0`3o0000i/b00>K<P0020>K<P0030?l0003Vc800i/b00?l0i/b0>P3Vc80001X0i/b00P00000;0>K<
P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc80j0>K<P0006P3Vc8000`000000
i/b00>K<P00:0>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc80j0>K<P000
6P3Vc8000`000000i/b00>K<P00:0>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800
o`3Vc80j0>K<P0006P3Vc8000`000000i/b00>K<P00:0>K<P0030?l0003Vc800i/b00080i/b000<0
o`000>K<P03Vc800o`3Vc80j0>K<P0006P3Vc8000`000000i/b00>K<P00:0>K<P0030?l0003Vc800
i/b00080i/b000<0o`000>K<P03Vc800o`3Vc80j0>K<P0006P3Vc8000`000000i/b00>K<P00:0>K<
P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc80j0>K<P0006P3Vc8000`000000
i/b00>K<P00:0>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc80j0>K<P000
6P3Vc8000`000000i/b00>K<P00:0>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800
o`3Vc80j0>K<P0006P3Vc802000000/0i/b000<0o`000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<
P03o0>K<P3X0i/b0000J0>K<P0030000003Vc800i/b000X0i/b000<0o`000>K<P03Vc8000P3Vc800
0`3o0000i/b00>K<P03o0>K<P3X0i/b0000J0>K<P0030000003Vc800i/b000X0i/b000<0o`000>K<
P03Vc8000P3Vc8000`3o0000i/b00>K<P03o0>K<P3X0i/b0000J0>K<P0030000003Vc800i/b000X0
i/b000<0o`000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P03o0>K<P3X0i/b0000J0>K<P0030000
003Vc800i/b000X0i/b000<0o`000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P03o0>K<P3X0i/b0
000J0>K<P0030000003Vc800i/b000X0i/b000<0o`000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<
P03o0>K<P3X0i/b0000J0>K<P0030000003Vc800i/b000X0i/b000<0o`000>K<P03Vc8000P3Vc800
0`3o0000i/b00>K<P03o0>K<P3X0i/b0000J0>K<P08000002`3Vc8000`3o0000i/b00>K<P0020>K<
P0030?l0003Vc800i/b00?l0i/b0>P3Vc80001X0i/b000<000000>K<P03Vc8002P3Vc8000`3o0000
i/b00>K<P0020>K<P0030?l0003Vc800i/b00?l0i/b0>P3Vc80001X0i/b000<000000>K<P03Vc800
2P3Vc8000`3o0000i/b00>K<P0020>K<P0030?l0003Vc800i/b00?l0i/b0>P3Vc80001X0i/b000<0
00000>K<P03Vc8002P3Vc8000`3o0000i/b00>K<P0020>K<P0030?l0003Vc800i/b00?l0i/b0>P3V
c80001X0i/b000<000000>K<P03Vc8002P3Vc8000`3o0000i/b00>K<P0020>K<P0030?l0003Vc800
i/b00?l0i/b0>P3Vc80000040>K<P00000000000000000D0i/b00P0000040>K<P0H000001@3Vc800
0`000000i/b00>K<P00:0>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc80j
0>K<P00000@000000>K<P03Vc80000001@3Vc802000000D0i/b000D000000>K<P03Vc800i/b00000
00050>K<P0030000003Vc800i/b000X0i/b000<0o`000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<
P03o0>K<P3X0i/b000040>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8001P3Vc800
0`000000i/b00>K<P00:0>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc80j
0>K<P000103Vc8000`000000i/b00>K<P00;0>K<P08000001P3Vc803000000X0i/b000<0o`000>K<
P03Vc8000P3Vc8000`3o0000i/b00>K<P03o0>K<P3X0i/b000040>K<P0030000003Vc800i/b000`0
i/b00P0000050>K<P0030000003Vc800i/b000X0i/b000<0o`000>K<P03Vc8000P3Vc8000`3o0000
i/b00>K<P03o0>K<P3X0i/b000040>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800
0`3Vc8000`000000i/b00>K<P00:0>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800
o`3Vc80j0>K<P00000@000000>K<P03Vc80000002`3Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8002P3Vc8000`3o0000i/b00>K<P0020>K<P0030?l0
003Vc800i/b00?l0i/b0>P3Vc80000@000002`3Vc805000000H0i/b000<000000>K<P03Vc8002P3V
c8000`3o0000i/b00>K<P0020>K<P0030?l0003Vc800i/b00?l0i/b0>P3Vc80001X0i/b000<00000
0>K<P03Vc8002P3Vc8000`3o0000i/b00>K<P0020>K<P0030?l0003Vc800i/b00?l0i/b0>P3Vc800
01X0i/b000<000000>K<P03Vc8002P3Vc8000`3o0000i/b00>K<P0020>K<P0030?l0003Vc800i/b0
0?l0i/b0>P3Vc80001X0i/b000<000000>K<P03Vc8002P3Vc8000`3o0000i/b00>K<P0020>K<P003
0?l0003Vc800i/b00?l0i/b0>P3Vc80001X0i/b00P00000<0>K<P0050?l0003Vc800i/b00>K<P03o
0000o`3Vc80l0>K<P0006P3Vc8000`000000i/b00>K<P00;0>K<P0050?l0003Vc800i/b00>K<P03o
0000o`3Vc80l0>K<P0006P3Vc8000`000000i/b00>K<P00;0>K<P0050?l0003Vc800i/b00>K<P03o
0000o`3Vc80l0>K<P0006P3Vc8000`000000i/b00>K<P00;0>K<P0050?l0003Vc800i/b00>K<P03o
0000o`3Vc80l0>K<P0006P3Vc8000`000000i/b00>K<P00;0>K<P0050?l0003Vc800i/b00>K<P03o
0000o`3Vc80l0>K<P0006P3Vc8000`000000i/b00>K<P00;0>K<P0050?l0003Vc800i/b00>K<P03o
0000o`3Vc80l0>K<P0006P3Vc8000`000000i/b00>K<P00;0>K<P0050?l0003Vc800i/b00>K<P03o
0000o`3Vc80l0>K<P0006P3Vc802000000`0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<P3`0
i/b0000J0>K<P0030000003Vc800i/b000/0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<P3`0
i/b0000J0>K<P0030000003Vc800i/b000/0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<P3`0
i/b0000J0>K<P0030000003Vc800i/b000/0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<P3`0
i/b0000J0>K<P0030000003Vc800i/b000/0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<P3`0
i/b0000J0>K<P0030000003Vc800i/b000/0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<P3`0
i/b0000J0>K<P0030000003Vc800i/b000/0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<P3`0
i/b0000J0>K<P0030000003Vc800i/b000/0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<P3`0
i/b0000J0>K<P0800000303Vc8001@3o0000i/b00>K<P03Vc800o`000?l0i/b0?03Vc80001X0i/b0
00<000000>K<P03Vc8002`3Vc8001@3o0000i/b00>K<P03Vc800o`000?l0i/b0?03Vc80001X0i/b0
00<000000>K<P03Vc8002`3Vc8001@3o0000i/b00>K<P03Vc800o`000?l0i/b0?03Vc80001X0i/b0
00<000000>K<P03Vc8002`3Vc8001@3o0000i/b00>K<P03Vc800o`000?l0i/b0?03Vc80001X0i/b0
00<000000>K<P03Vc8002`3Vc8001@3o0000i/b00>K<P03Vc800o`000?l0i/b0?03Vc80001X0i/b0
00<000000>K<P03Vc8002`3Vc8001@3o0000i/b00>K<P03Vc800o`000?l0i/b0?03Vc80001X0i/b0
00<000000>K<P03Vc8002`3Vc800103o0000i/b00>K<P03o003o0>K<P3d0i/b0000J0>K<P0030000
003Vc800i/b000/0i/b000@0o`000>K<P03Vc800o`00o`3Vc80m0>K<P0006P3Vc802000000`0i/b0
00@0o`000>K<P03Vc800o`00o`3Vc80m0>K<P0006P3Vc8000`000000i/b00>K<P00;0>K<P0040?l0
003Vc800i/b00?l00?l0i/b0?@3Vc80001X0i/b000<000000>K<P03Vc8002`3Vc800103o0000i/b0
0>K<P03o003o0>K<P3d0i/b0000J0>K<P0030000003Vc800i/b000/0i/b000@0o`000>K<P03Vc800
o`00o`3Vc80m0>K<P0006P3Vc8000`000000i/b00>K<P00;0>K<P0040?l0003Vc800i/b00?l00?l0
i/b0?@3Vc80000040>K<P00000000000000000D0i/b00P0000040>K<P0@000001`3Vc8000`000000
i/b00>K<P00;0>K<P0040?l0003Vc800i/b00?l00?l0i/b0?@3Vc80000040000003Vc800i/b00000
00D0i/b00P0000080>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8002`3Vc800103o
0000i/b00>K<P03o003o0>K<P3d0i/b000040>K<P0030000003Vc800i/b000`0i/b000<000000>K<
P03Vc800103Vc803000000/0i/b000@0o`000>K<P03Vc800o`00o`3Vc80m0>K<P000103Vc8000`00
0000i/b00>K<P00<0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8002`3Vc800103o
0000i/b00>K<P03o003o0>K<P3d0i/b000040>K<P0030000003Vc800i/b000X0i/b00P0000070>K<
P0030000003Vc800i/b000/0i/b000@0o`000>K<P03Vc800o`00o`3Vc80m0>K<P000103Vc8000`00
0000i/b00>K<P00<0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8002`3Vc800103o
0000i/b00>K<P03o003o0>K<P3d0i/b0000010000000i/b00>K<P000000?0>K<P0030000003Vc800
i/b000@0i/b000<000000>K<P03Vc8002`3Vc800103o0000i/b00>K<P03o003o0>K<P3d0i/b00004
000000/0i/b0100000070>K<P0030000003Vc800i/b000/0i/b000@0o`000>K<P03Vc800o`00o`3V
c80m0>K<P0006P3Vc8000`000000i/b00>K<P00;0>K<P0040?l0003Vc800i/b00?l00?l0i/b0?@3V
c80001X0i/b000<000000>K<P03Vc8002`3Vc800103o0000i/b00>K<P03o003o0>K<P3d0i/b0000J
0>K<P0800000303Vc800103o0000i/b00>K<P03o003o0>K<P3d0i/b0000J0>K<P0030000003Vc800
i/b000/0i/b000@0o`000>K<P03Vc800o`00o`3Vc80m0>K<P0006P3Vc8000`000000i/b00>K<P00<
0>K<P0030?l0003Vc800o`000?l0i/b0?@3Vc80001X0i/b000<000000>K<P03Vc800303Vc8000`3o
0000i/b00?l0003o0>K<P3d0i/b0000J0>K<P0030000003Vc800i/b000`0i/b000<0o`000>K<P03o
0000o`3Vc80m0>K<P0006P3Vc8000`000000i/b00>K<P00<0>K<P0030?l0003Vc800o`000?l0i/b0
?@3Vc80001X0i/b000<000000>K<P03Vc800303Vc8000`3o0000i/b00?l0003o0>K<P3d0i/b0000J
0>K<P0030000003Vc800i/b000`0i/b000<0o`000>K<P03o0000o`3Vc80m0>K<P0006P3Vc8020000
00d0i/b000<0o`000>K<P03o0000o`3Vc80m0>K<P0006P3Vc8000`000000i/b00>K<P00<0>K<P003
0?l0003Vc800o`000?l0i/b0?@3Vc80001X0i/b000<000000>K<P03Vc800303Vc8000`3o0000i/b0
0?l0003o0>K<P3d0i/b0000J0>K<P0030000003Vc800i/b000`0i/b000<0o`000>K<P03o0000o`3V
c80m0>K<P0006P3Vc8000`000000i/b00>K<P00<0>K<P0030?l0003Vc800o`000?l0i/b0?@3Vc800
01X0i/b000<000000>K<P03Vc800303Vc8000`3o0000i/b00?l0003o0>K<P3d0i/b0000J0>K<P003
0000003Vc800i/b000`0i/b000<0o`000>K<P03o0000o`3Vc80m0>K<P0006P3Vc802000000d0i/b0
00<0o`000>K<P03o0000o`3Vc80m0>K<P0006P3Vc8000`000000i/b00>K<P00<0>K<P0030?l0003V
c800o`000?l0i/b0?@3Vc80001X0i/b000<000000>K<P03Vc800303Vc8000`3o0000i/b00?l0003o
0>K<P3d0i/b0000J0>K<P0030000003Vc800i/b000`0i/b000<0o`000>K<P03o0000o`3Vc80m0>K<
P0006P3Vc8000`000000i/b00>K<P00<0>K<P0030?l0003Vc800o`000?l0i/b0?@3Vc80001X0i/b0
00<000000>K<P03Vc800303Vc8000`3o0000i/b00?l0003o0>K<P3d0i/b0000J0>K<P0030000003V
c800i/b000`0i/b000<0o`000>K<P03o0000o`3Vc80m0>K<P0006P3Vc8000`000000i/b00>K<P00<
0>K<P0030?l0003Vc800o`000?l0i/b0?@3Vc80001X0i/b00P00000=0>K<P0030?l0003Vc800o`00
0?l0i/b0?@3Vc80001X0i/b000<000000>K<P03Vc800303Vc8000`3o0000i/b00?l0003o0>K<P3d0
i/b0000J0>K<P0030000003Vc800i/b000`0i/b000<0o`000>K<P03o0000o`3Vc80m0>K<P0006P3V
c8000`000000i/b00>K<P00<0>K<P0030?l0003Vc800o`000?l0i/b0?@3Vc80001X0i/b000<00000
0>K<P03Vc800303Vc8000`3o0000i/b00?l0003o0>K<P3d0i/b00000103Vc8000000000000000005
0>K<P08000001P3Vc803000000H0i/b000<000000>K<P03Vc800303Vc8000`3o0000i/b00?l0003o
0>K<P3d0i/b0000010000000i/b00>K<P00000050>K<P08000001`3Vc8000`000000i/b00>K<P005
0>K<P0030000003Vc800i/b000`0i/b000<0o`000>K<P03o0000o`3Vc80m0>K<P000103Vc8000`00
0000i/b00>K<P0080>K<P0D000001P3Vc8000`000000i/b00>K<P00<0>K<P0030?l0003Vc800o`00
0?l0i/b0?@3Vc80000@0i/b000<000000>K<P03Vc800203Vc80010000000i/b00>K<P00000070>K<
P0<00000303Vc8000`3o0000i/b00?l0003o0>K<P3d0i/b000040>K<P0030000003Vc800i/b000T0
i/b000<000000>K<P00000001`3Vc8000`000000i/b00>K<P00<0>K<P0030?l0003Vc800o`000?l0
i/b0?@3Vc80000@0i/b000<000000>K<P03Vc8002P3Vc802000000L0i/b000<000000>K<P03Vc800
303Vc8000`3o0000i/b00?l0003o0>K<P3d0i/b0000010000000i/b00>K<P000000=0>K<P0800000
1`3Vc8000`000000i/b00>K<P00<0>K<P0030?l0003Vc800o`000?l0i/b0?@3Vc80000@000003P3V
c8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000`0i/b00P3o003o0>K<P3h0i/b0000J
0>K<P0030000003Vc800i/b000`0i/b00P3o003o0>K<P3h0i/b0000J0>K<P0030000003Vc800i/b0
00`0i/b00P3o003o0>K<P3h0i/b0000J0>K<P08000003@3Vc8020?l00?l0i/b0?P3Vc80001X0i/b0
00<000000>K<P03Vc800303Vc8020?l00?l0i/b0?P3Vc80001X0i/b000<000000>K<P03Vc800303V
c8020?l00?l0i/b0?P3Vc80001X0i/b000<000000>K<P03Vc800303Vc8020?l00?l0i/b0?P3Vc800
01X0i/b000<000000>K<P03Vc8003@3Vc8000`3o0000i/b00>K<P03o0>K<P3`0i/b0000J0>K<P003
0000003Vc800i/b000d0i/b000<0o`000>K<P03Vc800o`3Vc80l0>K<P0006P3Vc8000`000000i/b0
0>K<P00=0>K<P0030?l0003Vc800i/b00?l0i/b0?03Vc80001X0i/b000<000000>K<P03Vc8003@3V
c8000`3o0000i/b00>K<P03o0>K<P3`0i/b0000J0>K<P08000003P3Vc8000`3o0000i/b00>K<P03o
0>K<P3`0i/b0000J0>K<P0030000003Vc800i/b000d0i/b000<0o`000>K<P03Vc800o`3Vc80l0>K<
P0006P3Vc8000`000000i/b00>K<P00=0>K<P0030?l0003Vc800i/b00?l0i/b0?03Vc80001X0i/b0
00<000000>K<P03Vc8003@3Vc8000`3o0000i/b00>K<P03o0>K<P3`0i/b0000J0>K<P0030000003V
c800i/b000d0i/b000<0o`000>K<P03Vc800o`3Vc80l0>K<P0006P3Vc8000`000000i/b00>K<P00=
0>K<P0030?l0003Vc800i/b00?l0i/b0?03Vc80001X0i/b000<000000>K<P03Vc8003@3Vc8000`3o
0000i/b00>K<P03o0>K<P3`0i/b0000J0>K<P0030000003Vc800i/b000d0i/b000<0o`000>K<P03V
c800o`3Vc80l0>K<P0006P3Vc802000000h0i/b000<0o`000>K<P03Vc800o`3Vc80l0>K<P0006P3V
c8000`000000i/b00>K<P00=0>K<P0030?l0003Vc800i/b00?l0i/b0?03Vc80001X0i/b000<00000
0>K<P03Vc8003@3Vc8000`3o0000i/b00>K<P03o0>K<P3`0i/b0000J0>K<P0030000003Vc800i/b0
00d0i/b000<0o`000>K<P03Vc800o`3Vc80l0>K<P0006P3Vc8000`000000i/b00>K<P00=0>K<P003
0?l0003Vc800i/b00?l0i/b0?03Vc80001X0i/b000<000000>K<P03Vc8003@3Vc8000`3o0000i/b0
0>K<P03o0>K<P3`0i/b0000J0>K<P0030000003Vc800i/b000d0i/b000<0o`000>K<P03Vc800o`3V
c80l0>K<P0006P3Vc802000000h0i/b000<0o`000>K<P03Vc800o`3Vc80l0>K<P0006P3Vc8000`00
0000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0C03Vc80001X0i/b0
00<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J
0>K<P0030000003Vc800i/b00?l0i/b0C03Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0
J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0
J@3Vc8000001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-8.45545, -0.0626431, \
0.400274, 0.00325892}}]
}, Open  ]],

Cell["\<\

We get a large peak at a low frequency (the Rabi frequency) and a small peak \
at a high frequency. The aproximate Rabi frequncy is: \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Print[\*"\"\<\!\(\[Omega]\_R\)= \>\"", \[Omega]est\ n0];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("\!\(\[Omega]\_R\)= \
"\[InvisibleSpace]0.10024969386815173`\),
      SequenceForm[ "\!\(\[Omega]\_R\)= ", 0.10024969386815173],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
Unfortunately, the frequency resolution is not very good and we \
need an additional nonlinear fit. We will use the frequency obtained from the \
Fourier transform as a starring point for this fit:\
\>", "Text"],

Cell[BoxData[
    \(\(\( (*Nonlinear\ Fit*) \)\(\[IndentingNewLine]\)\(cosfit[funcname_, 
          offset_, amplitude_, frequency_] := 
        Block[{nmax = 1000, afit, i, t, amp1, a0, 
            n1}, \[IndentingNewLine]func[t_] = 
            funcname[t]; \[IndentingNewLine]afit = 
            Table[{N[\(\(\ \)\(i\)\)\/nmax], 
                func[N[i\ \(\(\ \)\(tmax\)\)\/nmax]]}, {i, 0, 
                nmax}]; \[IndentingNewLine]fitres = 
            BestFitParameters /. 
              NonlinearRegress[afit, a0 + amp1\ Cos[2\ \[Pi]\ n1\ t], 
                t, {{a0, offset}, {amp1, amplitude}, {n1, frequency}}, 
                RegressionReport \[Rule] 
                  BestFitParameters];\[IndentingNewLine]];\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cosfit[pup, meanpop, 1 - meanpop, n0];\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]R = \[Omega]est\ n1 /. fitres;\)\), "\[IndentingNewLine]", 
    \(\(ampR = amp1 /. fitres;\)\), "\[IndentingNewLine]", 
    \(\(meanpop = a0 /. fitres;\)\), "\[IndentingNewLine]", 
    \(\(plfit = 
        Plot[{meanpop + ampR\ Cos[\[Omega]R\ t], pup[t]}, {t, 0, tmax}, 
          PlotStyle \[Rule] {{Hue[1], Thickness[0.01]}, {GrayLevel[0]}}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[plfit, 
        Graphics[{Text["\<fit\>", {\ tmax, meanpop}, 
              TextStyle \[Rule] {FontColor \[Rule] Hue[1]}], 
            Text[\*"\"\<|a(t)\!\(\( | \^2\)\)\>\"", {\ tmax, 
                meanpop - ampR/2}]}], AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Mean Propability of measuring |+z\[RightAngleBracket]: \>", 
        meanpop];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Amplitude of oscillation: \>", 
        ampR];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rabi frequency: \>", \[Omega]R, "\<  Period of \
Rabi-oscillation: \>", 2\ \[Pi]/\[Omega]R];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0037894 -8.45856 9.06188 [
[.21328 .59082 -6 -9 ]
[.21328 .59082 6 0 ]
[.40275 .59082 -9 -9 ]
[.40275 .59082 9 0 ]
[.59222 .59082 -9 -9 ]
[.59222 .59082 9 0 ]
[.78169 .59082 -9 -9 ]
[.78169 .59082 9 0 ]
[.97116 .59082 -9 -9 ]
[.97116 .59082 9 0 ]
[1.025 .60332 0 -4.90625 ]
[1.025 .60332 10 4.90625 ]
[.01131 .05961 -24 -4.5 ]
[.01131 .05961 0 4.5 ]
[.01131 .15023 -24 -4.5 ]
[.01131 .15023 0 4.5 ]
[.01131 .24085 -24 -4.5 ]
[.01131 .24085 0 4.5 ]
[.01131 .33146 -24 -4.5 ]
[.01131 .33146 0 4.5 ]
[.01131 .42208 -24 -4.5 ]
[.01131 .42208 0 4.5 ]
[.01131 .5127 -24 -4.5 ]
[.01131 .5127 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21328 .60332 m
.21328 .60957 L
s
[(50)] .21328 .59082 0 1 Mshowa
.40275 .60332 m
.40275 .60957 L
s
[(100)] .40275 .59082 0 1 Mshowa
.59222 .60332 m
.59222 .60957 L
s
[(150)] .59222 .59082 0 1 Mshowa
.78169 .60332 m
.78169 .60957 L
s
[(200)] .78169 .59082 0 1 Mshowa
.97116 .60332 m
.97116 .60957 L
s
[(250)] .97116 .59082 0 1 Mshowa
.125 Mabswid
.0617 .60332 m
.0617 .60707 L
s
.0996 .60332 m
.0996 .60707 L
s
.13749 .60332 m
.13749 .60707 L
s
.17539 .60332 m
.17539 .60707 L
s
.25117 .60332 m
.25117 .60707 L
s
.28907 .60332 m
.28907 .60707 L
s
.32696 .60332 m
.32696 .60707 L
s
.36486 .60332 m
.36486 .60707 L
s
.44064 .60332 m
.44064 .60707 L
s
.47854 .60332 m
.47854 .60707 L
s
.51643 .60332 m
.51643 .60707 L
s
.55433 .60332 m
.55433 .60707 L
s
.63011 .60332 m
.63011 .60707 L
s
.66801 .60332 m
.66801 .60707 L
s
.7059 .60332 m
.7059 .60707 L
s
.7438 .60332 m
.7438 .60707 L
s
.81958 .60332 m
.81958 .60707 L
s
.85748 .60332 m
.85748 .60707 L
s
.89537 .60332 m
.89537 .60707 L
s
.93327 .60332 m
.93327 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05961 m
.03006 .05961 L
s
[(0.94)] .01131 .05961 1 0 Mshowa
.02381 .15023 m
.03006 .15023 L
s
[(0.95)] .01131 .15023 1 0 Mshowa
.02381 .24085 m
.03006 .24085 L
s
[(0.96)] .01131 .24085 1 0 Mshowa
.02381 .33146 m
.03006 .33146 L
s
[(0.97)] .01131 .33146 1 0 Mshowa
.02381 .42208 m
.03006 .42208 L
s
[(0.98)] .01131 .42208 1 0 Mshowa
.02381 .5127 m
.03006 .5127 L
s
[(0.99)] .01131 .5127 1 0 Mshowa
.125 Mabswid
.02381 .07773 m
.02756 .07773 L
s
.02381 .09585 m
.02756 .09585 L
s
.02381 .11398 m
.02756 .11398 L
s
.02381 .1321 m
.02756 .1321 L
s
.02381 .16835 m
.02756 .16835 L
s
.02381 .18647 m
.02756 .18647 L
s
.02381 .2046 m
.02756 .2046 L
s
.02381 .22272 m
.02756 .22272 L
s
.02381 .25897 m
.02756 .25897 L
s
.02381 .27709 m
.02756 .27709 L
s
.02381 .29522 m
.02756 .29522 L
s
.02381 .31334 m
.02756 .31334 L
s
.02381 .34959 m
.02756 .34959 L
s
.02381 .36771 m
.02756 .36771 L
s
.02381 .38584 m
.02756 .38584 L
s
.02381 .40396 m
.02756 .40396 L
s
.02381 .44021 m
.02756 .44021 L
s
.02381 .45833 m
.02756 .45833 L
s
.02381 .47645 m
.02756 .47645 L
s
.02381 .49458 m
.02756 .49458 L
s
.02381 .53083 m
.02756 .53083 L
s
.02381 .54895 m
.02756 .54895 L
s
.02381 .56707 m
.02756 .56707 L
s
.02381 .5852 m
.02756 .5852 L
s
.02381 .04148 m
.02756 .04148 L
s
.02381 .02336 m
.02756 .02336 L
s
.02381 .00524 m
.02756 .00524 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .60245 m
.02499 .6023 L
.02605 .60192 L
.02729 .60119 L
.02846 .60021 L
.03053 .59777 L
.03279 .59413 L
.03527 .58893 L
.0379 .5821 L
.04262 .56653 L
.05205 .52367 L
.06244 .46132 L
.08274 .31307 L
.09394 .22959 L
.10458 .15811 L
.11464 .10308 L
.12033 .07899 L
.12305 .06951 L
.12562 .06185 L
.12797 .05595 L
.1305 .05081 L
.13281 .04725 L
.13384 .04603 L
.13494 .04495 L
.13613 .04406 L
.13724 .0435 L
.13856 .04316 L
.13977 .04317 L
.14102 .0435 L
.14173 .04383 L
.14239 .04423 L
.14359 .04519 L
.14487 .04654 L
.14725 .04995 L
.14976 .05477 L
.15424 .06649 L
.15906 .08337 L
.16434 .10654 L
.18262 .21751 L
.20387 .37643 L
.22318 .50699 L
.23282 .55529 L
.23825 .57568 L
.24084 .58346 L
.24326 .58958 L
.24556 .59429 L
.24765 .59767 L
.24876 .5991 L
.24997 .60038 L
.25126 .60139 L
Mistroke
.25247 .60205 L
.25376 .6024 L
.25492 .60242 L
.25557 .60232 L
.25627 .6021 L
.25753 .60146 L
.25872 .60055 L
.25998 .59928 L
.26222 .59619 L
.26478 .59143 L
.2672 .58573 L
.27173 .57201 L
.2766 .55301 L
.2819 .52778 L
.30025 .41154 L
.31967 .26552 L
.32998 .19188 L
.34108 .12422 L
.34625 .09857 L
.35168 .07639 L
.35631 .06169 L
.35894 .0552 L
.36138 .05039 L
.36257 .04848 L
.36386 .04673 L
.365 .04548 L
.3662 .04444 L
.36729 .04376 L
.36848 .0433 L
.36957 .04313 L
.37058 .0432 L
.37185 .04358 L
.37306 .04425 L
.37414 .04511 L
.37532 .04633 L
.37796 .05007 L
.3804 .0548 L
.38502 .06696 L
.39001 .08462 L
.39904 .12749 L
.41964 .26393 L
.43926 .41144 L
.44964 .48195 L
.45535 .51564 L
.46074 .54321 L
.46589 .56511 L
.46861 .57476 L
.47148 .58348 L
.4739 .58958 L
.47656 .59495 L
Mistroke
.47772 .59686 L
.47898 .5986 L
.48008 .59986 L
.48124 .60093 L
.48251 .60177 L
.48369 .60225 L
.48441 .6024 L
.48509 .60245 L
.48636 .60228 L
.48757 .6018 L
.48869 .60109 L
.48992 .60002 L
.49122 .59855 L
.49347 .59518 L
.49556 .59111 L
.50033 .57863 L
.50535 .56088 L
.5108 .53656 L
.5207 .48076 L
.53926 .3492 L
.55866 .20521 L
.56896 .13953 L
.57437 .1105 L
.58007 .08493 L
.58512 .067 L
.58779 .05945 L
.59064 .05294 L
.59327 .04837 L
.59452 .0467 L
.59566 .04545 L
.59682 .04445 L
.59807 .04369 L
.59917 .04328 L
.60033 .04313 L
.60151 .04326 L
.60259 .04363 L
.60383 .04435 L
.60501 .04534 L
.60711 .04779 L
.60939 .05149 L
.6119 .05674 L
.61456 .0637 L
.61935 .0796 L
.62967 .12748 L
.64082 .19626 L
.66101 .34526 L
.68061 .48401 L
.68598 .5156 L
.69172 .54482 L
.69711 .56729 L
Mistroke
.70208 .58339 L
.70456 .58964 L
.70718 .59494 L
.70982 .59886 L
.71132 .60045 L
.71199 .60101 L
.71273 .60152 L
.71402 .60215 L
.71526 .60243 L
.71646 .60239 L
.71757 .60209 L
.71826 .60178 L
.7189 .60139 L
.7201 .60045 L
.72139 .5991 L
.72279 .59726 L
.72507 .59341 L
.72756 .58799 L
.73261 .57334 L
.73728 .55555 L
.74164 .53552 L
.76198 .40815 L
.78054 .26852 L
.79057 .19651 L
.80122 .13035 L
.81032 .08645 L
.8155 .06776 L
.81783 .06102 L
.82037 .05483 L
.8228 .05013 L
.82505 .04682 L
.8263 .04544 L
.82744 .04446 L
.82875 .04367 L
.82999 .04324 L
.83106 .04313 L
.83219 .04327 L
.83315 .0436 L
.83422 .04418 L
.83536 .04507 L
.83659 .04633 L
.83881 .04938 L
.84136 .05412 L
.84413 .06077 L
.84919 .07668 L
.85869 .11884 L
.86903 .18006 L
.87839 .24537 L
.89937 .40306 L
.90875 .46816 L
Mistroke
.91865 .52655 L
.92383 .55145 L
.9295 .57352 L
.932 .58135 L
.93466 .58841 L
.937 .59343 L
.93948 .59757 L
.94055 .59898 L
.94171 .60022 L
.94298 .60128 L
.94418 .60196 L
.94528 .60233 L
.94644 .60245 L
.94743 .60232 L
.94852 .60196 L
.94981 .6012 L
.95098 .60022 L
.95233 .59873 L
.95361 .59699 L
.95588 .59306 L
.95834 .58765 L
.96286 .57463 L
.96763 .55672 L
.97619 .51499 L
Mfstroke
0 g
.5 Mabswid
.02381 .60332 m
.02499 .60275 L
.02605 .60152 L
.02721 .59985 L
.02846 .59831 L
.02961 .59754 L
.03068 .59742 L
.0317 .59753 L
.03279 .59733 L
.03395 .59602 L
.0352 .59273 L
.03638 .58773 L
.03746 .58202 L
.03873 .57509 L
.03939 .57179 L
.04011 .56881 L
.04141 .56524 L
.04262 .56403 L
.04327 .56393 L
.04396 .56392 L
.04519 .56318 L
.04588 .56183 L
.04652 .55969 L
.04722 .55623 L
.04797 .55122 L
.05056 .52708 L
.05184 .51528 L
.05302 .5071 L
.05416 .50256 L
.05538 .50103 L
.0566 .50124 L
.0573 .50117 L
.05795 .50043 L
.05908 .49657 L
.06011 .4894 L
.06125 .47751 L
.06244 .46181 L
.0638 .44323 L
.06509 .4286 L
.06624 .42004 L
.06748 .41615 L
.06813 .41592 L
.06885 .41647 L
.06954 .41721 L
.07029 .41745 L
.07098 .41649 L
.07162 .41417 L
.07287 .40472 L
.08257 .32251 L
.09399 .22229 L
Mistroke
.09466 .22516 L
.09537 .22824 L
.09614 .23053 L
.09685 .23071 L
.09814 .2244 L
.09887 .21667 L
.09955 .207 L
.1009 .18308 L
.10218 .15964 L
.10333 .14283 L
.10458 .13277 L
.1057 .13181 L
.10689 .13732 L
.10792 .14442 L
.10903 .15059 L
.1102 .1516 L
.1113 .14525 L
.1126 .12869 L
.11379 .10807 L
.1149 .08866 L
.11608 .07229 L
.11737 .06364 L
.11858 .06539 L
.11923 .06961 L
.11993 .07584 L
.12121 .08811 L
.12246 .09603 L
.1236 .09588 L
.1248 .0868 L
.12609 .06901 L
.1272 .05099 L
.12841 .03395 L
.12914 .02699 L
.12982 .02365 L
.13047 .02348 L
.13117 .02641 L
.13236 .03757 L
.13368 .05406 L
.13435 .06183 L
.13506 .06823 L
.13633 .07268 L
.13703 .07065 L
.13769 .06598 L
.13841 .05832 L
.13918 .04822 L
.13984 .03895 L
.14057 .02954 L
.14188 .01782 L
.14316 .01679 L
.14434 .02564 L
Mistroke
.16308 .12424 L
.16572 .1068 L
.16645 .10191 L
.16722 .09894 L
.16795 .09913 L
.16861 .10219 L
.16991 .11615 L
.17064 .12776 L
.17131 .13985 L
.17263 .16392 L
.17386 .18208 L
.17496 .19169 L
.17614 .19412 L
.17745 .18954 L
.17865 .18309 L
.1799 .17937 L
.1806 .1803 L
.18125 .18365 L
.18244 .19614 L
.18371 .21664 L
.18483 .23742 L
.186 .25776 L
.18729 .27394 L
.18848 .28114 L
.18958 .28179 L
.19061 .27911 L
.19174 .27571 L
.19295 .27539 L
.19427 .28241 L
.19501 .29023 L
.19569 .29961 L
.19829 .34352 L
.1995 .36097 L
.20064 .37169 L
.20183 .37657 L
.20314 .37642 L
.20443 .37451 L
.20516 .37439 L
.20584 .37567 L
.20708 .38263 L
.2084 .39681 L
.21071 .43083 L
.21192 .44719 L
.21321 .45941 L
.21393 .46358 L
.21473 .46603 L
.21546 .46674 L
.21613 .4666 L
.21683 .46622 L
.21746 .46613 L
Mistroke
.21819 .46685 L
.21888 .46876 L
.22016 .4761 L
.22134 .48705 L
.22272 .50276 L
.22402 .5176 L
.22518 .52833 L
.22645 .53591 L
.2276 .53907 L
.22867 .53978 L
.22994 .53979 L
.2311 .54085 L
.23174 .54237 L
.23243 .54492 L
.23368 .55184 L
.23597 .56859 L
.23723 .57685 L
.2384 .58239 L
.23939 .58519 L
.24046 .5865 L
.24165 .58675 L
.24274 .58682 L
.24401 .58772 L
.24466 .58871 L
.24537 .59024 L
.24781 .59729 L
.24847 .59911 L
.24918 .6007 L
.24995 .60196 L
.25065 .60264 L
.25193 .60285 L
.25265 .60257 L
.25332 .60222 L
.25463 .60167 L
.25586 .60165 L
.25697 .60201 L
.25817 .60237 L
.25948 .60197 L
.26014 .60123 L
.26087 .5999 L
.26216 .59637 L
.26336 .59217 L
.26833 .58241 L
.26898 .58241 L
.26969 .58229 L
.27096 .58093 L
.27173 .57893 L
.27243 .57612 L
.27308 .57269 L
.27376 .56827 L
Mistroke
.2762 .54907 L
.2775 .54013 L
.27822 .53642 L
.27888 .53401 L
.28015 .53182 L
.28134 .53164 L
.28244 .53147 L
.28364 .5293 L
.28478 .52381 L
.28586 .51516 L
.28704 .50239 L
.28831 .48685 L
.28957 .47251 L
.29026 .46614 L
.2909 .46148 L
.29203 .45647 L
.29327 .45508 L
.29443 .45572 L
.29552 .45562 L
.29651 .45313 L
.29757 .44655 L
.29874 .43436 L
.29997 .41697 L
.30217 .38388 L
.30338 .37053 L
.30471 .36291 L
.30596 .36181 L
.30711 .36362 L
.30815 .36482 L
.3093 .36277 L
.3105 .35459 L
.31163 .3408 L
.314 .30037 L
.3153 .28015 L
.31651 .26751 L
.31782 .2622 L
.31851 .26251 L
.31925 .26443 L
.32056 .26885 L
.32177 .26989 L
.32292 .26483 L
.32414 .25174 L
.32536 .23191 L
.32671 .20687 L
.32787 .18744 L
.32911 .17318 L
.33029 .16798 L
.33137 .16968 L
.33248 .17539 L
.33351 .18107 L
Mistroke
.33464 .18401 L
.33584 .18004 L
.33699 .16827 L
.33807 .15129 L
.3401 .11489 L
.34126 .09885 L
.3425 .09038 L
.34368 .09139 L
.34475 .09815 L
.34601 .10873 L
.34672 .11379 L
.34738 .11676 L
.34858 .11598 L
.34986 .10522 L
.35108 .08735 L
.35239 .06503 L
.35363 .04724 L
.35477 .0381 L
.35603 .0381 L
.35674 .04248 L
.3574 .04865 L
.35874 .06362 L
.35944 .07082 L
.36018 .07643 L
.36143 .07882 L
.36259 .07208 L
.36367 .05924 L
.36486 .04164 L
.36592 .02714 L
.36706 .01701 L
.36813 .01514 L
.36911 .02034 L
.37033 .034 L
.37146 .04988 L
.37269 .06523 L
.37401 .07355 L
.37527 .07114 L
.37645 .0608 L
.3776 .04687 L
.37865 .03505 L
.37982 .0273 L
.38107 .02863 L
.38223 .03916 L
.38333 .05514 L
.38452 .07474 L
.38578 .09228 L
.38644 .09836 L
.38717 .10192 L
.38845 .10013 L
.38913 .09566 L
Mistroke
.38979 .09 L
.39102 .07868 L
.39234 .07102 L
.39309 .07086 L
.39378 .07399 L
.39505 .0876 L
.3962 .10645 L
.39745 .12906 L
.39814 .14023 L
.39878 .14894 L
.39991 .15878 L
.40116 .16069 L
.40221 .15639 L
.40335 .14905 L
.40398 .14525 L
.40468 .14244 L
.40593 .14327 L
.40716 .15315 L
.40829 .16959 L
.40937 .18915 L
.41054 .21054 L
.41164 .22728 L
.41264 .23744 L
.41371 .24201 L
.41484 .24093 L
.416 .23645 L
.41727 .23238 L
.41858 .23413 L
.4198 .24374 L
.42043 .2518 L
.42113 .26262 L
.42254 .28782 L
.42378 .30909 L
.42447 .31878 L
.42512 .32604 L
.42638 .33416 L
.42753 .33544 L
.42865 .33342 L
.42984 .33129 L
.43097 .33255 L
.43199 .33821 L
.43319 .3509 L
.4345 .37021 L
.43564 .38886 L
.43686 .40697 L
.43817 .42091 L
.43939 .42754 L
.44014 .42891 L
.44084 .42892 L
.44148 .42838 L
Mistroke
.44217 .42781 L
.44284 .42781 L
.44358 .42905 L
.44435 .43221 L
.44508 .4371 L
.44637 .45018 L
.44777 .46825 L
.44909 .48542 L
.45032 .49831 L
.4516 .50677 L
.45228 .50915 L
.453 .51037 L
.4578 .51803 L
.46022 .53779 L
.46155 .55013 L
.46281 .55985 L
.46398 .5659 L
.46525 .56914 L
.46641 .5699 L
.46749 .56995 L
.46873 .57065 L
.46985 .57278 L
.47115 .57732 L
.47237 .58302 L
.47362 .58917 L
.47495 .59458 L
.47564 .59663 L
.4764 .59819 L
.47709 .59903 L
.47773 .59939 L
.47843 .59947 L
.4792 .59936 L
.47991 .59926 L
.48058 .59929 L
.48183 .59985 L
.48247 .6004 L
.48316 .60114 L
.4839 .60195 L
.48461 .60262 L
.48542 .60311 L
.48616 .60315 L
.48686 .60281 L
.48751 .60215 L
.48822 .60112 L
.48897 .59978 L
.49033 .59731 L
.49159 .59561 L
.49292 .59489 L
.49361 .59485 L
.49436 .59491 L
Mistroke
.495 .59487 L
.4957 .59455 L
.49696 .59266 L
.49819 .58866 L
.49933 .58308 L
.50179 .56837 L
.50247 .56485 L
.5032 .56174 L
.50452 .55829 L
.50521 .55754 L
.50594 .55729 L
.50724 .5572 L
.50795 .55667 L
.50862 .55545 L
.50935 .55304 L
.51013 .54901 L
.52031 .49124 L
.53934 .3386 L
.55925 .21951 L
.56973 .12716 L
.57041 .13199 L
.57115 .13729 L
.57185 .14126 L
.57249 .14322 L
.57324 .14269 L
.57405 .13832 L
.57479 .13075 L
.57546 .12139 L
.57672 .1 L
.57804 .07736 L
.57874 .0678 L
.57949 .06036 L
.58019 .05684 L
.58083 .05646 L
.58212 .06304 L
.58329 .07426 L
.58394 .08076 L
.58465 .08678 L
.58593 .09195 L
.58714 .08755 L
.58843 .07337 L
.58963 .05478 L
.59073 .03789 L
.59202 .02398 L
.5927 .02072 L
.59341 .02073 L
.59461 .02818 L
.59591 .04355 L
.59735 .06129 L
.59815 .06832 L
Mistroke
.59888 .07159 L
.59956 .07154 L
.60029 .0681 L
.60099 .06199 L
.60163 .05452 L
.60274 .0397 L
.60392 .02548 L
.60505 .01799 L
.60607 .0184 L
.60727 .02784 L
.60857 .04594 L
.6098 .06477 L
.61095 .0788 L
.61213 .08565 L
.61343 .0829 L
.6147 .07213 L
.61535 .06516 L
.61607 .05779 L
.61727 .04908 L
.61854 .04873 L
.61971 .05797 L
.62081 .07347 L
.62207 .09535 L
.62325 .11444 L
.62449 .12791 L
.62514 .13135 L
.62584 .13207 L
.62661 .12977 L
.62733 .12537 L
.62803 .11999 L
.62869 .11497 L
.62994 .10838 L
.6306 .10788 L
.63131 .11028 L
.6326 .12273 L
.63332 .13368 L
.63399 .14538 L
.6352 .16773 L
.63652 .18892 L
.6377 .20086 L
.63881 .20465 L
.63998 .20216 L
.64124 .19591 L
.64248 .19128 L
.64363 .19248 L
.64489 .20224 L
.64553 .21048 L
.64623 .22161 L
.6485 .26284 L
.64978 .28129 L
Mistroke
.65096 .29119 L
.65202 .2941 L
.65318 .29242 L
.65432 .28908 L
.65553 .28771 L
.65669 .29171 L
.65775 .30108 L
.65881 .31554 L
.65981 .33218 L
.66096 .35191 L
.66205 .36837 L
.6633 .38178 L
.66445 .38784 L
.66571 .38889 L
.66642 .38803 L
.66708 .38711 L
.66827 .38707 L
.66954 .39188 L
.67024 .39724 L
.67088 .40383 L
.67233 .42307 L
.67358 .44156 L
.67424 .45073 L
.67495 .45937 L
.67618 .47042 L
.67733 .47576 L
.67864 .47723 L
.67984 .47677 L
.68099 .47733 L
.6822 .48116 L
.68324 .48783 L
.68439 .49845 L
.68677 .52464 L
.68745 .53127 L
.6881 .53659 L
.68933 .54356 L
.69047 .54663 L
.69154 .54737 L
.69271 .54738 L
.69396 .54837 L
.69513 .55149 L
.69623 .5567 L
.6983 .57029 L
.69946 .57796 L
.7007 .58448 L
.70187 .58835 L
.70295 .59002 L
.7042 .59048 L
.70491 .59046 L
.70557 .59051 L
Mistroke
.70677 .5912 L
.70805 .59314 L
.71041 .59878 L
.71105 .60024 L
.71173 .6015 L
.71295 .60285 L
.71364 .60306 L
.71428 .60295 L
.71499 .60259 L
.71574 .60206 L
.71645 .60156 L
.71711 .60119 L
.71836 .60094 L
.71943 .60114 L
.7206 .6014 L
.72182 .60106 L
.72297 .59955 L
.72404 .59686 L
.72502 .59343 L
.72722 .58451 L
.72844 .58056 L
.72958 .57836 L
.73082 .57752 L
.73152 .57747 L
.73215 .57744 L
.73331 .57672 L
.73456 .5738 L
.73574 .5682 L
.73683 .56066 L
.77635 .29759 L
.79624 .16986 L
.79729 .17378 L
.79841 .17228 L
.79948 .16396 L
.80045 .15081 L
.80258 .11307 L
.80372 .09527 L
.80492 .08381 L
.80614 .08167 L
.80727 .08719 L
.80851 .09771 L
.80983 .10782 L
.81105 .11064 L
.8122 .10492 L
.81324 .09303 L
.81436 .07534 L
.81567 .05367 L
.8169 .03836 L
.81818 .03205 L
.81886 .03324 L
Mistroke
.81958 .03767 L
.82189 .06279 L
.82319 .074 L
.8244 .07616 L
.82563 .06866 L
.82694 .05233 L
.82819 .03423 L
.82936 .02057 L
.8304 .01472 L
.83152 .01666 L
.83276 .02807 L
.8339 .04377 L
.83511 .06075 L
.83641 .07304 L
.83764 .07527 L
.83876 .0691 L
.8401 .05473 L
.84084 .04598 L
.84153 .03871 L
.84274 .03097 L
.84339 .03055 L
.84408 .03332 L
.84479 .03945 L
.84546 .04792 L
.84673 .06808 L
.84745 .08011 L
.84822 .09169 L
.84894 .10033 L
.8496 .10559 L
.85089 .10794 L
.8521 .10171 L
.8534 .09028 L
.85413 .08424 L
.85482 .08007 L
.85606 .07884 L
.85719 .08634 L
.85841 .10282 L
.85974 .12637 L
.86089 .14652 L
.86212 .1625 L
.86317 .16937 L
.86433 .16953 L
.86498 .16688 L
.86568 .16285 L
.86692 .15547 L
.86761 .15294 L
.86825 .15249 L
.86895 .15465 L
.86971 .16027 L
.87036 .16784 L
Mistroke
.87107 .17844 L
.87235 .20161 L
.87351 .22281 L
.87476 .24107 L
.87607 .25175 L
.8773 .25353 L
.87804 .25174 L
.87875 .24908 L
.87945 .24647 L
.88008 .24486 L
.88076 .24463 L
.88148 .24667 L
.88278 .25722 L
.88351 .26684 L
.8843 .27948 L
.88572 .30496 L
.88636 .31595 L
.88705 .32644 L
.88828 .34037 L
.88957 .34706 L
.89031 .34774 L
.89099 .34701 L
.89218 .34466 L
.89347 .34436 L
.8947 .34954 L
.89583 .36014 L
.90483 .43947 L
.90602 .4397 L
.90728 .44391 L
.90848 .4528 L
.90956 .46454 L
.91194 .49455 L
.91258 .50162 L
.91327 .50806 L
.91453 .51594 L
.9152 .51818 L
.91594 .51937 L
.9167 .51965 L
.91742 .51954 L
.91871 .52006 L
.91943 .52147 L
.92008 .52374 L
.92133 .53081 L
.9227 .54174 L
.92397 .55307 L
.92517 .56261 L
.92636 .56964 L
.92768 .57395 L
.92897 .57532 L
.92969 .57542 L
Mistroke
.93035 .57544 L
.93147 .57594 L
.93269 .57793 L
.93396 .58188 L
.93515 .58678 L
.93642 .59227 L
.93712 .59494 L
.93777 .59705 L
.93892 .59962 L
.94019 .6008 L
.94089 .60091 L
.94156 .60081 L
.94282 .60054 L
.94352 .60056 L
.94418 .60075 L
.94489 .60115 L
.94565 .60173 L
.94694 .60272 L
.94767 .60303 L
.94834 .60302 L
.94957 .60207 L
.95086 .59982 L
.95314 .5947 L
.95442 .59266 L
.95558 .59184 L
.95671 .59174 L
.95794 .59166 L
.95909 .59061 L
.96017 .58806 L
.96115 .5841 L
.96224 .57807 L
.96444 .56357 L
.9657 .55657 L
.96686 .55238 L
.96812 .55039 L
.96876 .55016 L
.96946 .55017 L
.97064 .54977 L
.9719 .54709 L
.97308 .54107 L
.97416 .53243 L
.97619 .51095 L
Mfstroke
gsave
.97619 .32279 -73.7812 -9.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.75 translate 1 -1 scale
63.000 12.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(fit) show
84.562 12.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .18296 -83.7812 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.188 moveto
(\\310) show
69.000 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.188 moveto
(H) show
81.000 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.188 moveto
(L) show
93.000 13.188 moveto
(\\310) show
99.000 9.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
104.562 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P0008@3Vc8000`000000i/b00>K<
P03o0>K<P4D0i/b0000Q0>K<P0<00000o`3Vc8150>K<P0008@3Vc8000`000000i/b00>K<P03o0>K<
P4D0i/b0000Q0>K<P0030000003Vc800i/b00?l0i/b0A@3Vc8000240i/b000<000000>K<P03Vc800
J@3Vc8000`000000i/b00>K<P02=0>K<P0030000003Vc800i/b004P0i/b0000Q0>K<P0030000003V
c800i/b00280i/b00P0000150>K<P0030000003Vc800i/b004L0i/b000<000000>K<P03Vc800@`3V
c802000004T0i/b0000Q0>K<P0030000003Vc800i/b00280i/b00P0000150>K<P0030000003Vc800
i/b004<0i/b000D000000>K<P03Vc800i/b0000000150>K<P0800000B@3Vc8000240i/b00`00000O
0>K<P0030000003Vc800i/b000800000A03Vc802000004D0i/b000@000000>K<P03Vc800i/b00P00
00140>K<P0800000B@3Vc8000240i/b000<000000>K<P03Vc8007P3Vc80200000080i/b00P000014
0>K<P08000000`3Vc8000`000000i/b00>K<P00o0>K<P08000000P3Vc802000004@0i/b00P000019
0>K<P0008@3Vc8000`000000i/b00>K<P00N0>K<P08000000P3Vc802000004@0i/b000<000000>K<
P00000000P3Vc8000`000000i/b00>K<P00o0>K<P08000000P3Vc802000004@0i/b00P0000020>K<
P0030000003Vc800i/b004@0i/b0000Q0>K<P0030000003Vc800i/b001h0i/b00P0000020>K<P080
0000A03Vc80010000000i/b00000003Vc80200000400i/b000<000000>K<P00000000P3Vc8020000
0400i/b00P0000020>K<P08000000P3Vc802000004D0i/b0000Q0>K<P0030000003Vc800i/b001h0
i/b00P0000020>K<P0030000003Vc80000000400i/b000L000000>K<P03Vc80000000>K<P0000000
i/b000800000@03Vc8001`000000i/b00000003Vc80000000>K<P0000000@03Vc80200000080i/b0
0P0000020>K<P0800000A@3Vc8000240i/b000<000000>K<P03Vc8007P3Vc80200000080o`0000<0
00000?l000000000@03Vc8001`000000i/b00?l000000000o`000000003o00000P0000100>K<P007
0000003o000000000?l000000000o`00000000100>K<P08000000P3o0002000000040?l0003Vc800
0000000004D0i/b0000Q0>K<P0<000007P3Vc80200000080o`0000<000000?l000000000?`3Vc802
000000060>K<P03o000000000?l000000000o`000P0000100>K<P0080000003o000000000?l00000
0000o`000000003o000o0>K<P08000000P3o000200000080o`000P0000150>K<P0008@3Vc8000`00
0000i/b00>K<P00N0>K<P0040000003o0000000000000080o`0000<000000?l0003Vc800?@3Vc802
00000080o`0000@000000?l000000000o`000P0000100>K<P0080000003o000000000?l000000000
o`000000003o000o0>K<P080000000@0o`000000003o000000000P3o0002000004D0i/b0000Q0>K<
P0030000003Vc800i/b001h0i/b000@000000?l00000000000000P3o00000`000000o`000>K<P00m
0>K<P00;0000003Vc80000000?l000000000o`000000003o000000000?l000000000?P3Vc8002`3o
000000000?l000000000o`000000003o000000000?l0003Vc800000003d0i/b00P000000103o0000
00000?l0000000020?l000800000A@3Vc80000040>K<P00000000000000000D0i/b00P0000040>K<
P0<000001`3Vc803000000D0i/b000<000000>K<P03Vc8007@3Vc8000`3o000000000?l000020000
00050>K<P03o0000o`000000003o0000?@3Vc8002`000000o`000000003o000000000>K<P0000000
o`000000003o0000000003h0i/b000P0o`000000003o000000000>K<P0000000o`0000000080o`00
00<000000>K<P03Vc800>`3Vc8002P000000o`00000000000000i/b00000003o000000000?l00000
00150>K<P00000@000000>K<P03Vc80000001@3Vc802000000L0i/b000<000000>K<P03Vc8001@3V
c8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b001d0i/b000<0o`000000003o00000P00
00020>K<P0030?l000000000o`0003d0i/b000/000000?l000000000o`000000003Vc80000000>K<
P0000000o`000000000l0>K<P00;0000003o0000o`000000003o000000000>K<P0000000o`000000
003o00000P00000m0>K<P0040000003o0000000000000080i/b00P0000000`3o000000000>K<P014
0>K<P000103Vc8000`000000i/b00>K<P00<0>K<P0040000003Vc800i/b00>K<P0D000001@3Vc803
000001`0i/b00P3o000010000000o`000000000000020>K<P0030?l000000000o`0003d0i/b000/0
00000?l000000000o`000000003Vc80000000>K<P0000000o`000000000l0>K<P00;0000003o0000
o`000000003Vc80000000>K<P0000000i/b00000003o00000P00000l0>K<P0030?l000000000o`00
008000000P3Vc802000000030?l000000000o`0004@0i/b000040>K<P0030000003Vc800i/b000T0
i/b0100000030>K<P0040000003Vc800i/b0000000H0i/b000<000000>K<P03Vc8006`3Vc8001@00
0000o`000000003o0000i/b0008000000`3Vc8000`000000o`000?l0000l0>K<P00<0000003o0000
00000>K<P0000000i/b00000003Vc80000000?l000000000o`00>`3Vc802000000090?l000000000
i/b00000003Vc80000000>K<P0000000o`0000800000?03Vc8000`3o000000000?l0000200000080
i/b00P0000000`3o000000000?l000140>K<P000103Vc8000`000000i/b00>K<P0080>K<P0050000
003Vc800i/b00>K<P0000000103Vc8000`000000i/b0000000060>K<P0030000003Vc800i/b001/0
i/b000D000000?l000000000o`000>K<P002000000<0i/b000<000000?l0003o0000?03Vc8003000
0000o`000000003Vc80000000>K<P0000000i/b00000003o000000000?l003/0i/b00P0000002@3o
000000000>K<P0000000i/b00000003Vc80000000?l00002000003`0i/b000<000000?l0003o0000
0P0000020>K<P080000000<0o`000000003o0000A03Vc80000@0i/b000<000000>K<P03Vc800203V
c8001@000000i/b00>K<P03Vc800000000D0i/b00P0000060>K<P0030000003Vc800i/b001X0i/b0
0P000000103o000000000>K<P03Vc802000000<0i/b000<0o`000000003o0000>`3Vc8000`3o0000
00000?l0000200000080i/b00P000000103Vc800o`000000003o000k0>K<P080000000D0o`000000
003Vc800i/b0000000020>K<P0050000003o000000000?l000000000>`3Vc8000`000000o`000?l0
000200000080i/b00P0000000`3o000000000?l000140>K<P00000@000000>K<P03Vc80000002`3V
c8001@000000i/b00>K<P03Vc800000000D0i/b00P0000060>K<P0030000003Vc800i/b001X0i/b0
0P0000000`3o000000000>K<P0020>K<P0030000003Vc800i/b00080i/b000<000000?l0003o0000
>P3Vc8000`3o000000000?l00002000000<0i/b000D000000>K<P03Vc80000000?l00002000003T0
i/b00P0000001@3o000000000>K<P03Vc80000000080i/b000D000000>K<P0000000o`000000000k
0>K<P0030000003o0000o`00008000000P3Vc802000000040>K<P0000000o`000?l004<0i/b00004
000000`0i/b00`0000070>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8006P3Vc802
000000030?l000000000i/b000L0i/b000<000000?l0003o0000>P3Vc8000`3o000000000?l00002
000000<0i/b000D000000>K<P03Vc80000000?l00002000003P0i/b000D000000?l000000000o`00
000000060>K<P080000000<0o`000000003Vc800>@3Vc8001@3o000000000?l0003Vc800000000@0
i/b000<000000>K<P00000000P3o00130>K<P0008@3Vc803000001X0i/b00P0000000`3o00000000
0>K<P0070>K<P0030000003o0000o`0003X0i/b000D0o`000000003o0000i/b0000000060>K<P004
0000003o00000000000003P0i/b000D000000?l000000000o`00000000060>K<P0040000003o0000
o`00000003X0i/b000<0o`000000003o0000203Vc800103o000000000?l0000000120>K<P0008@3V
c8000`000000i/b00>K<P00J0>K<P080000000<0o`000000003Vc8001`3Vc80010000000o`000?l0
003o000h0>K<P080o`0000<000000>K<P03Vc8001`3Vc80010000000o`0000000000000h0>K<P004
0000003o00000000000000L0i/b000@000000?l0003o00000000>@3Vc80010000000o`000000003o
00080>K<P0040?l000000000o`0000000480i/b0000Q0>K<P0030000003Vc800i/b001X0i/b000@0
00000?l00000000000002@3Vc8000`000000o`000?l0000h0>K<P080o`0000<000000>K<P03Vc800
1`3Vc80010000000o`0000000000000h0>K<P0040000003o00000000000000L0i/b000D000000?l0
003o000000000?l0000g0>K<P080000000<0o`000000003Vc800203Vc8000`3o000000000?l00002
00000440i/b0000Q0>K<P0030000003Vc800i/b001X0i/b000@000000?l00000000000002@3Vc800
0`000000o`000?l0000h0>K<P080o`0000<000000>K<P03Vc8001`3Vc80010000000o`0000000000
000h0>K<P0040000003o0000o`00000000T0i/b000<0o`000000003o0000=`3Vc802000000030?l0
00000000i/b000T0i/b000@000000?l0000000000000@@3Vc8000240i/b000<000000>K<P03Vc800
6P3Vc80010000000o`000000000000090>K<P0030000003o0000o`0003L0i/b000@000000?l0003o
000000002@3Vc8001@000000o`00000000000000o`0003H0i/b000D0o`000000003o0000o`000000
00090>K<P0030?l000000000o`0003L0i/b00P0000000`3o000000000>K<P0090>K<P080000000<0
o`000000003Vc800@03Vc8000240i/b00`00000J0>K<P0040000003o00000000000000T0i/b000<0
00000?l0003o0000=`3Vc80010000000o`000?l0000000090>K<P080000000<0o`000000003o0000
=P3Vc8000`3o000000000?l0000;0>K<P0030?l000000000o`0003L0i/b00P0000000`3o00000000
0>K<P0090>K<P080000000<0o`000000003Vc800@03Vc8000240i/b000<000000>K<P03Vc8006@3V
c800103o000000000?l00000000:0>K<P0040000003o0000o`00000003H0i/b00`00000;0>K<P004
0000003o000000000?l003H0i/b000<0o`000000003o0000303Vc8000`000000o`000?l0000f0>K<
P080000000<0o`000000003Vc8002@3Vc802000000030?l000000000i/b00400i/b0000Q0>K<P003
0000003Vc800i/b001T0i/b000<0o`000000003o0000303Vc80010000000o`0000000000000e0>K<
P0<000002`3Vc80010000000o`000?l00000000f0>K<P0030?l000000000o`0000`0i/b000<00000
0?l0003o0000=P3Vc802000000030?l000000000i/b000T0i/b00P0000000`3o000000000>K<P010
0>K<P0008@3Vc8000`000000i/b00>K<P00I0>K<P0030?l000000000o`0000`0i/b000@000000?l0
000000000000=03Vc800103o0000000000000000000<0>K<P080o`0000<000000>K<P03Vc800<`3V
c8020?l000030000003o0000i/b000/0i/b000<000000?l0003o0000=P3Vc80010000000o`000000
0000000:0>K<P080000000<0o`000000003Vc800@03Vc8000240i/b000<000000>K<P03Vc8006@3V
c8000`3o000000000?l0000<0>K<P0040000003o00000000000003@0i/b000@000000?l000000000
00003@3Vc8000`3o000000000?l0000d0>K<P080o`0000<000000>K<P03Vc8002`3Vc800103o0000
00000?l00000000e0>K<P0040000003o00000000000000X0i/b00P0000000`3o000000000>K<P010
0>K<P0008@3Vc8000`000000i/b00>K<P00I0>K<P0030?l000000000o`0000`0i/b000@000000?l0
000000000000=03Vc80010000000o`0000000000000=0>K<P0030?l000000000o`0003@0i/b00P3o
00000`000000i/b00>K<P00<0>K<P0030000003o0000000003@0i/b000@0o`000000003o00000000
303Vc8020?l000030000003Vc800i/b003l0i/b0000Q0>K<P0<00000603Vc8020?l000030000003V
c800i/b000/0i/b000@000000?l0000000000000=03Vc80010000000o`0000000000000=0>K<P003
0?l000000000o`0003@0i/b00P3o00000`000000i/b00>K<P00<0>K<P0<00000=03Vc8000`3o0000
00000?l0000=0>K<P080o`0000<000000?l0003Vc800?`3Vc8000240i/b000<000000>K<P03Vc800
603Vc8020?l000030000003Vc800i/b000`0i/b000<000000?l000000000<`3Vc8000`3o00000000
0?l00002000000d0i/b000<0o`000000003o0000=03Vc8020?l000030000003Vc800i/b000`0i/b0
0`00000d0>K<P0030?l000000000o`0000h0i/b000<0o`000000003o0000@03Vc8000240i/b000<0
00000>K<P03Vc800603Vc8000`3o000000000?l0000>0>K<P0030000003o0000000003<0i/b000<0
o`000000003o00003`3Vc800103o000000000?l0003o000c0>K<P080o`0000<000000>K<P03Vc800
303Vc803000000030?l0003Vc800i/b00340i/b000<0o`000000003o00003P3Vc8000`3o00000000
0?l000100>K<P0008@3Vc8000`000000i/b00>K<P00H0>K<P0030?l000000000o`0000h0i/b000<0
00000?l000000000<`3Vc8000`3o000000000?l0000@0>K<P0030000003o0000o`0003<0i/b00P3o
00000`000000i/b00>K<P00<0>K<P0<0000000<0o`000>K<P03Vc800<03Vc8020?l000030000003o
0000i/b000d0i/b000<0o`000000003o0000@03Vc8000240i/b000<000000>K<P03Vc800603Vc800
0`3o000000000?l0000>0>K<P080o`0000<000000>K<P03Vc800<@3Vc8000`3o000000000?l0000@
0>K<P0030000003o0000o`000380i/b000<0o`000000000000003`3Vc803000000030?l0003Vc800
i/b00300i/b00P3o00000`000000i/b00>K<P00=0>K<P0030?l000000000o`000400i/b0000Q0>K<
P0030000003Vc800i/b001P0i/b000<0o`000000003o00003P3Vc8020?l000030000003Vc800i/b0
0340i/b000<0o`000000003o0000403Vc8000`000000o`000?l0000b0>K<P0030?l0000000000000
00l0i/b00P0000000`3o000000000>K<P00a0>K<P080o`0000<000000>K<P03Vc8003@3Vc8000`3o
000000000?l000100>K<P0008@3Vc803000001L0i/b000<000000?l0000000003`3Vc8020?l00003
0000003Vc800i/b00340i/b000<0o`000000003o0000403Vc8000`000000o`000?l0000b0>K<P003
0?l000000000000000l0i/b000@000000?l0003o00000000<P3Vc8020?l000030000003Vc800i/b0
00h0i/b000<000000?l0003o0000?`3Vc8000240i/b000<000000>K<P03Vc8005`3Vc8000`000000
o`000000000@0>K<P0030?l000000000o`000340i/b00P3o00000`000000i/b00>K<P00?0>K<P003
0000003o0000o`000380i/b000<0o`00000000000000403Vc8020?l000030000003Vc800i/b00300
i/b000<0o`000000003o0000403Vc8000`000000o`000?l0000o0>K<P0008@3Vc8000`000000i/b0
0>K<P00F0>K<P080000000<0o`000000003Vc8003`3Vc8000`3o000000000?l0000a0>K<P080o`00
00<000000>K<P03Vc8003`3Vc80010000000o`000?l0003o000a0>K<P0030?l00000000000000140
i/b000<0o`000000003o0000<@3Vc8000`3o000000000?l0000@0>K<P0030?l000000000o`0003l0
i/b00000103Vc80000000000000000050>K<P0800000103Vc803000000H0i/b0100000050>K<P003
0000003Vc800i/b001H0i/b000@000000?l0000000000000403Vc8000`3o000000000?l0000a0>K<
P080o`0000<000000>K<P03Vc8003`3Vc80010000000o`0000000000000a0>K<P0030000003o0000
00000140i/b000<0o`000000003o0000<03Vc8020?l000030000003Vc800i/b000l0i/b000<0o`00
0000003o0000?`3Vc80000040000003Vc800i/b0000000D0i/b00P0000070>K<P0030000003Vc800
i/b000L0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00F0>K<P0040000003o0000
000000000100i/b000<0o`000000003o0000<@3Vc8020?l000030000003Vc800i/b000l0i/b000@0
00000?l0000000000000<@3Vc8000`000000o`000?l0000A0>K<P0030?l000000000o`000300i/b0
0P3o00000`000000i/b00>K<P00?0>K<P0030?l000000000o`0003l0i/b000040>K<P0030000003V
c800i/b000`0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P0020>K<P0<000005P3V
c80010000000o`0000000000000@0>K<P0030?l000000000o`000340i/b00P3o00000`000000i/b0
0>K<P00?0>K<P0040000003o0000000000000300i/b000<0o`000000003o00004P3Vc8000`3o0000
00000?l0000`0>K<P080o`0000<000000>K<P03Vc8003`3Vc8000`3o000000000?l0000o0>K<P000
103Vc8000`000000i/b00>K<P0090>K<P0@00000203Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b001H0i/b000<000000?l0000000004@3Vc8000`3o000000000?l0000a0>K<P080o`00
00<000000>K<P03Vc8003`3Vc80010000000o`0000000000000`0>K<P0030?l000000000o`000180
i/b000<0o`000000003o0000<03Vc8020?l000030000003Vc800i/b00100i/b000<000000?l00000
0000?P3Vc80000@0i/b000<000000>K<P03Vc800203Vc8001@000000i/b00>K<P03Vc800000000@0
i/b0100000050>K<P0030000003Vc800i/b001H0i/b000<000000?l0003o00004P3Vc8000`3o0000
00000?l0000`0>K<P080o`0000<000000>K<P03Vc800403Vc80300000300i/b000<0o`000000003o
00004P3Vc8000`3o000000000?l0000`0>K<P080o`0000<000000>K<P03Vc800403Vc8000`000000
o`000000000n0>K<P000103Vc8000`000000i/b00>K<P0080>K<P0050000003Vc800i/b00>K<P000
0000103Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b001H0i/b000<000000?l0003o
00004P3Vc8000`3o000000000?l0000_0>K<P0<0o`0000<000000>K<P03Vc800403Vc80300000300
i/b000<0o`000000003o00004P3Vc8000`3o000000000?l0000`0>K<P080o`0000<000000>K<P03V
c800403Vc8000`000000o`000000000n0>K<P00000@000000>K<P03Vc80000002`3Vc8001@000000
i/b00>K<P03Vc800000000@0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00F0>K<
P0030000003o0000o`000180i/b000<0o`000000003o0000;`3Vc8020?l000030000003Vc800i/b0
0140i/b000@000000?l000000000o`00;`3Vc8000`3o000000000?l0000B0>K<P0040?l000000000
o`000?l002l0i/b00P3o00000`000000i/b00>K<P00@0>K<P080000000<0o`000000003Vc800?03V
c80000@00000303Vc803000000D0i/b0100000050>K<P0030000003Vc800i/b001H0i/b000<00000
0?l0003o00004P3Vc8000`3o000000000?l0000_0>K<P080o`0000<000000>K<P03Vc8004P3Vc800
0`3o000000000?l0000^0>K<P080o`0000<000000?l0003Vc8004P3Vc8000`000000o`000?l0000^
0>K<P0<0o`0000<000000>K<P03Vc800403Vc802000000030?l000000000i/b003`0i/b0000Q0>K<
P0<000005@3Vc8000`3o000000000?l0000C0>K<P0030?l000000000o`0002l0i/b000<000000?l0
00000000503Vc8000`3o000000000?l0000^0>K<P080o`0000<000000>K<P03Vc8004P3Vc8000`00
0000o`000?l0000^0>K<P0<0o`0000<000000>K<P03Vc800403Vc802000000030?l000000000i/b0
00T0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b0
00L0i/b000<000000>K<P03Vc8002`3Vc8000240i/b000<000000>K<P03Vc8005@3Vc8000`3o0000
00000?l0000D0>K<P0030000003o0000o`0002h0i/b000<000000?l000000000503Vc8000`3o0000
00000?l0000^0>K<P080o`0000<000000>K<P03Vc8004P3Vc8000`000000o`000?l0000^0>K<P080
o`0000<000000>K<P03Vc8004P3Vc8020?l000030000003Vc800i/b000P0i/b000<000000>K<P03V
c8003@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03V
c8002`3Vc8000240i/b000<000000>K<P03Vc8005@3Vc8000`000000o`000?l0000D0>K<P0030000
003o0000o`0002h0i/b00`00000D0>K<P0030?l000000000o`0002h0i/b000<0o`000000003o0000
503Vc8000`000000o`000?l0000^0>K<P080o`0000<000000>K<P03Vc8004P3Vc8020?l000030000
003Vc800i/b000P0i/b000@000000>K<P03Vc800i/b01P0000050>K<P0030000003Vc800i/b000<0
i/b0100000040>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8002`3Vc8000240i/b0
00<000000>K<P03Vc8005@3Vc8000`000000o`000?l0000D0>K<P0030000003o0000o`0002h0i/b0
0`00000D0>K<P0030?l000000000o`0002h0i/b000<0o`000000003o0000503Vc8000`000000o`00
0?l0000^0>K<P080o`0000<000000>K<P03Vc8004P3Vc8020?l000030000003Vc800i/b000P0i/b0
00D000000>K<P03Vc800i/b0000000030>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03V
c8002`3Vc8000240i/b000<000000>K<P03Vc8005@3Vc8000`000000o`000?l0000D0>K<P0030000
003o0000000002d0i/b000@0o`000000000000000000503Vc8000`3o000000000?l0000]0>K<P080
o`0000<000000?l0003Vc8004`3Vc8000`3o000000000?l0000^0>K<P0030?l000000000o`0001@0
i/b00P3o00000`000000i/b00>K<P0080>K<P0050000003Vc800i/b00>K<P00000000`3Vc8000`00
0000i/b00>K<P0040>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8001P3Vc8000`00
0000i/b00>K<P0050>K<P0030000003Vc800i/b000/0i/b0000Q0>K<P0030000003Vc800i/b001D0
i/b000<000000?l0003o0000503Vc80010000000o`0000000000000/0>K<P0030000003o00000000
01D0i/b00P3o00000`000000o`000>K<P00[0>K<P080o`0000<000000>K<P03Vc8004`3Vc8000`3o
000000000?l0000^0>K<P0030?l000000000o`0001@0i/b00P3o00000`000000i/b00>K<P0080>K<
P0030000003Vc800i/b00080i/b0100000060>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc8001P3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000/0i/b0000Q0>K<P0<0
0000503Vc8000`3o000000000?l0000E0>K<P0040?l0000000000000000002`0i/b000<000000?l0
003o00005P3Vc8000`3o000000000?l0000/0>K<P080o`0000<000000>K<P03Vc800503Vc8000`00
0000o`000?l0000/0>K<P080o`0000<000000>K<P03Vc8004`3Vc8020?l000030000003Vc800i/b0
00P0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b0
0080i/b0100000050>K<P0008@3Vc8000`000000i/b00>K<P00D0>K<P0030?l000000000o`0001H0
i/b000<000000?l000000000;03Vc8000`000000o`000?l0000F0>K<P0030?l000000000o`0002`0
i/b00P3o00000`000000i/b00>K<P00D0>K<P0030000003o0000000002`0i/b00P3o00000`000000
i/b00>K<P00C0>K<P080o`0000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0020>K<P0@0
00001P3Vc80010000000i/b00>K<P03Vc805000000D0i/b000<000000>K<P03Vc8001@3Vc8000`00
0000i/b00>K<P0030>K<P0030000003Vc800i/b000D0i/b0000Q0>K<P0030000003Vc800i/b001@0
i/b000<0o`000000003o00005P3Vc8000`000000o`000000000/0>K<P0030000003o0000o`0001H0
i/b000<0o`000000003o0000;03Vc8020?l000030000003Vc800i/b001@0i/b000<000000?l00000
0000;03Vc8020?l000030000003Vc800i/b001@0i/b000<0o`000000003o00002@3Vc8000`000000
i/b00>K<P00=0>K<P0050000003Vc800i/b00>K<P00000001`3Vc8000`000000i/b00>K<P0060>K<
P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc800103Vc8000240i/b000<000000>K<P03V
c800503Vc8000`3o000000000?l0000F0>K<P080o`0000<000000>K<P03Vc800:P3Vc8000`000000
o`000?l0000F0>K<P0030?l000000000o`0002`0i/b00P3o00000`000000i/b00>K<P00D0>K<P0<0
0000;03Vc8020?l000030000003Vc800i/b001@0i/b000<0o`000000003o00002@3Vc8000`000000
i/b00>K<P00>0>K<P0040000003Vc800i/b0000000H0i/b000<000000>K<P03Vc8001`3Vc8000`00
0000i/b00>K<P0050>K<P0030000003Vc800i/b000<0i/b0000Q0>K<P0030000003Vc800i/b001@0
i/b000<0o`000000003o00005P3Vc8020?l000030000003Vc800i/b002X0i/b000<000000?l0003o
00005P3Vc8000`3o000000000?l0000[0>K<P0<0o`0000<000000>K<P03Vc800503Vc803000002`0
i/b000<0o`000000003o00005P3Vc8000`3o000000000?l0000c0>K<P0040000003Vc800i/b00000
00D0i/b0000Q0>K<P0<000004`3Vc8020?l000030000003Vc800i/b001D0i/b00P3o00000`000000
i/b00>K<P00Y0>K<P0030?l000000000o`0001L0i/b000<0o`000000003o0000:`3Vc8030?l00003
0000003Vc800i/b001@0i/b00`00000/0>K<P0030?l000000000o`0001H0i/b000<0o`000000003o
0000=03Vc802000000H0i/b0000Q0>K<P0030000003Vc800i/b001<0i/b00P3o00000`000000i/b0
0>K<P00E0>K<P080o`0000<000000>K<P03Vc800:@3Vc8000`3o000000000?l0000G0>K<P0040?l0
00000000o`000?l002X0i/b00P3o00000`000000i/b00>K<P00E0>K<P080o`0000<000000>K<P03V
c800:P3Vc8000`3o000000000?l0000F0>K<P0030?l000000000o`0003`0i/b0000Q0>K<P0030000
003Vc800i/b001<0i/b00P3o00000`000000i/b00>K<P00F0>K<P0030?l000000000o`0002X0i/b0
00<0o`000000003o0000603Vc8000`000000o`000?l0000Z0>K<P080o`0000<000000>K<P03Vc800
5P3Vc8020?l000030000003Vc800i/b002P0i/b00P3o00000`000000i/b00>K<P00E0>K<P0030?l0
00000000o`0003`0i/b0000Q0>K<P0030000003Vc800i/b001<0i/b00P3o00000`000000i/b00>K<
P00F0>K<P0030?l000000000o`0002X0i/b000<0o`000000003o0000603Vc8000`000000o`000?l0
000Z0>K<P080o`0000<000000>K<P03Vc8005P3Vc8020?l000030000003Vc800i/b002P0i/b00P3o
00000`000000i/b00>K<P00E0>K<P0040?l000000000o`000?l003/0i/b0000Q0>K<P0030000003V
c800i/b001<0i/b00P3o00000`000000i/b00>K<P00F0>K<P0030?l000000000o`0002X0i/b000<0
o`000000003o0000603Vc8000`000000o`000?l0000Z0>K<P080o`0000<000000>K<P03Vc8005P3V
c8020?l000030000003Vc800i/b002P0i/b000<0o`000000003o0000603Vc8000`3o000000000?l0
000k0>K<P0008@3Vc8000`000000i/b00>K<P00C0>K<P080o`0000<000000>K<P03Vc8005P3Vc800
0`3o000000000?l0000Z0>K<P0030?l000000000o`0001P0i/b000<000000?l0003o0000:@3Vc803
0?l000030000003Vc800i/b001H0i/b00P3o00000`000000i/b00>K<P00X0>K<P0030?l000000000
o`0001P0i/b000<0o`000000003o0000>`3Vc8000240i/b00`00000B0>K<P0040?l000000000o`00
000001P0i/b000<0o`000000003o0000:P3Vc8000`3o000000000?l0000H0>K<P0030000003o0000
o`0002T0i/b00`3o00000`000000i/b00>K<P00F0>K<P080o`0000<000000>K<P03Vc800:03Vc800
0`3o000000000?l0000H0>K<P0030?l000000000o`0003/0i/b0000Q0>K<P0030000003Vc800i/b0
0180i/b000@0o`000000000000000000603Vc8000`3o000000000?l0000Z0>K<P0030?l000000000
o`0001P0i/b000<000000?l0003o0000:@3Vc8030?l000030000003Vc800i/b001H0i/b00P3o0000
0`000000i/b00>K<P00X0>K<P0030?l000000000o`0001P0i/b000<0o`000000003o0000>`3Vc800
0240i/b000<000000>K<P03Vc8004P3Vc800103o0000000000000000000I0>K<P0030?l000000000
o`0002P0i/b00P3o00000`000000i/b00>K<P00G0>K<P0030000003o0000o`0002T0i/b00P3o0000
0`000000i/b00>K<P00G0>K<P080o`0000<000000>K<P03Vc800:03Vc8000`3o000000000?l0000H
0>K<P0030?l000000000o`0003/0i/b00000103Vc80000000000000000050>K<P0800000103Vc803
000000H0i/b0100000050>K<P0030000003Vc800i/b00180i/b000<0o`000000000000006P3Vc800
0`3o000000000?l0000X0>K<P080o`0000<000000>K<P03Vc8005`3Vc80010000000o`000000003o
000X0>K<P080o`0000<000000>K<P03Vc8005`3Vc8020?l000030000003Vc800i/b002L0i/b00P3o
00000`000000o`000>K<P00G0>K<P0030?l000000000o`0003/0i/b0000010000000i/b00>K<P000
00050>K<P08000001`3Vc8000`000000i/b00>K<P0030>K<P0050000003Vc800i/b00>K<P0000000
103Vc8000`000000i/b00>K<P00B0>K<P0030?l000000000o`0001X0i/b000<0o`000000003o0000
:03Vc8020?l000030000003Vc800i/b001P0i/b00`00000X0>K<P080o`0000<000000>K<P03Vc800
603Vc8000`3o000000000?l0000X0>K<P0030?l000000000o`0001X0i/b000<000000?l0003o0000
>P3Vc80000@0i/b000<000000>K<P03Vc800303Vc8001@000000i/b00>K<P03Vc800000000@0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00B0>K<P0030?l000000000o`0001X0i/b0
00<0o`000000003o0000:03Vc8020?l000030000003Vc800i/b001P0i/b00`00000X0>K<P080o`00
00<000000>K<P03Vc800603Vc8000`3o000000000?l0000X0>K<P0030?l000000000o`0001X0i/b0
00<000000?l0003o0000>P3Vc80000@0i/b000<000000>K<P03Vc8002@3Vc804000000<0i/b000@0
00000>K<P03Vc800i/b00P0000040>K<P0<000004P3Vc8000`000000o`000?l0000J0>K<P0030?l0
00000000o`0002P0i/b00P3o00000`000000i/b00>K<P00H0>K<P0030000003o0000000002P0i/b0
0P3o00000`000000i/b00>K<P00H0>K<P0030?l000000000o`0002P0i/b000<0o`000000003o0000
6P3Vc8000`000000o`000?l0000j0>K<P000103Vc8000`000000i/b00>K<P0080>K<P0050000003V
c800i/b00>K<P00000000`3Vc805000000D0i/b000<000000>K<P03Vc8004@3Vc8000`3o00000000
0?l0000K0>K<P0030?l000000000o`0002P0i/b000<0o`000000003o00006P3Vc8020?l000030000
003Vc800i/b002D0i/b00P3o00000`000000i/b00>K<P00I0>K<P0030?l000000000o`0002P0i/b0
00<0o`000000003o00006P3Vc8000`000000o`000000000j0>K<P000103Vc8000`000000i/b00>K<
P0080>K<P0050000003Vc800i/b00>K<P0000000103Vc8000`000000i/b00>K<P0060>K<P0030000
003Vc800i/b00140i/b000<0o`000000003o00006`3Vc8000`3o000000000?l0000X0>K<P0030?l0
00000000o`0001X0i/b00P3o00000`000000i/b00>K<P00U0>K<P080o`0000<000000>K<P03Vc800
6@3Vc8000`3o000000000?l0000X0>K<P0030?l000000000o`0001X0i/b000<0o`00000000000000
>P3Vc80000040000003Vc800i/b0000000/0i/b000D000000>K<P03Vc800i/b0000000040>K<P003
0000003Vc800i/b000H0i/b000<000000>K<P03Vc8004@3Vc8000`3o000000000?l0000L0>K<P003
0000003o0000o`0002L0i/b000<0o`000000003o00006P3Vc8020?l000030000003Vc800i/b002D0
i/b00P3o00000`000000i/b00>K<P00I0>K<P0030?l000000000o`0002P0i/b000<0o`000000003o
00006P3Vc8000`3o000000000000000j0>K<P0001000000<0>K<P0<000001P3Vc804000000@0i/b0
00<000000>K<P03Vc8004@3Vc8000`3o000000000?l0000L0>K<P0030000003o0000o`0002H0i/b0
0P3o00000`000000i/b00>K<P00J0>K<P0030?l000000000o`0002H0i/b00P3o00000`000000i/b0
0>K<P00I0>K<P0030?l000000000o`0002P0i/b000<000000?l0003o00006P3Vc800103o00000000
0?l00000000i0>K<P0008@3Vc80300000140i/b000<0o`000000003o0000703Vc8000`000000o`00
0?l0000V0>K<P080o`0000<000000>K<P03Vc8006P3Vc8000`3o000000000?l0000V0>K<P080o`00
00<000000>K<P03Vc8006@3Vc8000`3o000000000?l0000W0>K<P0030?l000000000o`0001`0i/b0
0P3o00000`000000i/b00>K<P00g0>K<P0008@3Vc8000`000000i/b00>K<P00A0>K<P0030?l00000
0000o`0001`0i/b000<000000?l0003o00009P3Vc8000`000000o`000000000L0>K<P0030?l00000
0000o`0002H0i/b00P3o00000`000000i/b00>K<P00J0>K<P0030000003o0000o`0002H0i/b000<0
o`000000003o0000703Vc8020?l000030000003Vc800i/b003L0i/b0000Q0>K<P0030000003Vc800
i/b00140i/b000<0o`000000003o0000703Vc8000`000000o`000?l0000V0>K<P0<00000703Vc800
0`3o000000000?l0000V0>K<P0030?l000000000o`0001`0i/b000<000000?l0003o00009P3Vc800
0`3o000000000?l0000L0>K<P080o`0000<000000>K<P03Vc800=`3Vc8000240i/b000<000000>K<
P03Vc8004@3Vc8000`3o000000000?l0000L0>K<P0030000003o0000o`0002H0i/b00`00000L0>K<
P0030?l000000000o`0002D0i/b00P3o00000`000000i/b00>K<P00K0>K<P0030000003o0000o`00
02H0i/b000<0o`000000003o0000703Vc8020?l000030000003Vc800i/b003L0i/b0000Q0>K<P003
0000003Vc800i/b00100i/b00P3o00000`000000o`000>K<P00K0>K<P0030000003o0000o`0002H0
i/b00P0000000`3o0000i/b00>K<P00J0>K<P0030?l000000000o`0002D0i/b00P3o00000`000000
i/b00>K<P00K0>K<P0030000003o0000o`0002H0i/b000<000000?l0003o0000703Vc8020?l00003
0000003Vc800i/b003L0i/b0000Q0>K<P0030000003Vc800i/b00100i/b000<0o`000000003o0000
7@3Vc80010000000o`000?l0003o000U0>K<P0030000003o0000o`0001`0i/b000<0o`000000003o
00009@3Vc8020?l000030000003Vc800i/b001/0i/b000<0o`000000003o00009P3Vc8000`000000
o`000?l0000L0>K<P080o`0000<000000>K<P03Vc800=`3Vc8000240i/b00`00000@0>K<P0030?l0
00000000o`0001d0i/b000@000000?l000000000o`00903Vc8000`000000o`000?l0000N0>K<P003
0?l000000000o`0002@0i/b00P3o00000`000000i/b00>K<P00K0>K<P0030?l000000000o`0002H0
i/b000<000000?l0003o0000703Vc8020?l000030000003Vc800i/b003L0i/b0000Q0>K<P0030000
003Vc800i/b00100i/b000<0o`000000003o00007P3Vc802000000030?l0003Vc800i/b00280i/b0
00<000000?l0003o00007P3Vc8000`3o000000000?l0000T0>K<P0030?l000000000o`0001d0i/b0
00<0o`000000003o00009@3Vc8000`3o000000000?l0000N0>K<P0030?l000000000o`0003P0i/b0
000Q0>K<P0030000003Vc800i/b00100i/b000<0o`000000003o00007P3Vc8000`000000o`000000
000T0>K<P0030000003o0000o`0001h0i/b000<0o`000000003o0000903Vc8000`3o000000000?l0
000N0>K<P0030000003o0000o`0002@0i/b000<0o`000000003o00007P3Vc8000`3o000000000?l0
000h0>K<P0008@3Vc8000`000000i/b00>K<P00@0>K<P0030?l000000000o`0001h0i/b00P3o0000
0`000000i/b00>K<P00R0>K<P0030000003o0000o`0001h0i/b000<0o`000000003o0000903Vc800
0`3o000000000?l0000N0>K<P0030000003o0000000002@0i/b000<0o`000000003o00007P3Vc800
0`3o000000000?l0000h0>K<P0008@3Vc8000`000000i/b00>K<P00@0>K<P0030?l000000000o`00
01h0i/b00P3o00000`000000i/b00>K<P00R0>K<P0030000003o0000o`0001h0i/b000<0o`000000
003o0000903Vc8000`3o000000000?l0000N0>K<P0<00000903Vc8000`000000o`000?l0000N0>K<
P0030?l000000000o`0003P0i/b0000Q0>K<P0030000003Vc800i/b00100i/b000<0o`000000003o
00007P3Vc8020?l000030000003Vc800i/b00280i/b000<000000?l0003o00007P3Vc8000`3o0000
00000?l0000S0>K<P080o`0000<000000>K<P03Vc8007@3Vc8000`3o000000000000000T0>K<P003
0000003o0000o`0001h0i/b000<0o`000000003o0000>03Vc8000240i/b00`00000@0>K<P0030?l0
00000000o`0001h0i/b00P3o00000`000000o`000>K<P00R0>K<P0030000003o0000o`0001h0i/b0
00<0o`000000003o00008`3Vc8000`3o000000000?l0000O0>K<P080o`0000<000000>K<P03Vc800
8P3Vc8000`000000o`000?l0000N0>K<P080o`0000<000000>K<P03Vc800=P3Vc8000240i/b000<0
00000>K<P03Vc8003`3Vc8020?l000030000003Vc800i/b001h0i/b000<0o`000000003o00008`3V
c8000`000000o`000?l0000N0>K<P0030?l000000000o`0002<0i/b000<0o`000000003o00007`3V
c8020?l000030000003Vc800i/b00280i/b000<000000?l0003o00007P3Vc8020?l000030000003V
c800i/b003H0i/b0000Q0>K<P0030000003Vc800i/b000l0i/b00P3o00000`000000i/b00>K<P00N
0>K<P0030?l000000000o`000280i/b000<0o`000000003o0000803Vc8000`000000o`000?l0000R
0>K<P0030?l000000000o`0001l0i/b00P3o00000`000000i/b00>K<P00Q0>K<P0040?l000000000
o`000?l001l0i/b000<0o`000000003o0000=`3Vc8000240i/b000<000000>K<P03Vc8003`3Vc800
0`3o000000000?l0000P0>K<P0030?l000000000o`000280i/b000<0o`000000003o0000803Vc800
0`000000o`000?l0000R0>K<P0030?l000000000o`0001l0i/b00P3o00000`000000i/b00>K<P00Q
0>K<P0030?l000000000o`000200i/b000<0o`000000003o0000=`3Vc8000240i/b000<000000>K<
P03Vc8003`3Vc8000`3o000000000?l0000P0>K<P0030?l000000000o`000280i/b000<0o`000000
003o0000803Vc8000`000000o`000?l0000R0>K<P0030?l000000000o`000200i/b000<0o`000000
003o00008P3Vc8000`000000o`000?l0000P0>K<P0030?l000000000o`0003L0i/b0000Q0>K<P0<0
00003`3Vc8000`3o000000000?l0000P0>K<P0030?l000000000o`000280i/b000<0o`000000003o
0000803Vc8000`000000o`000?l0000R0>K<P0030?l000000000o`000200i/b00P3o00000`000000
i/b00>K<P00P0>K<P0030000003o0000o`000200i/b000<0o`000000003o0000=`3Vc8000240i/b0
00<000000>K<P03Vc8003`3Vc8000`3o000000000?l0000P0>K<P0030?l000000000o`000280i/b0
00<0o`000000003o0000803Vc8000`3o000000000?l0000Q0>K<P0030?l000000000o`000240i/b0
0P3o00000`000000i/b00>K<P00P0>K<P0030000003o0000o`000200i/b000<0o`000000003o0000
3P3Vc8050?l000@0i/b01P3o00050>K<P0@0o`004@3Vc8000240i/b000<000000>K<P03Vc8003`3V
c8000`3o000000000?l0000P0>K<P0030?l000000000o`000280i/b000<0o`000000003o0000803V
c8000`3o000000000?l0000Q0>K<P0030?l000000000o`000240i/b00P3o00000`000000i/b00>K<
P00P0>K<P0030000003o0000o`000200i/b000<0o`000000003o00003`3Vc8000`3o0000i/b00>K<
P0070>K<P0030?l0003Vc800i/b000D0i/b000<0o`000>K<P03Vc8004`3Vc8000240i/b000<00000
0>K<P03Vc8003`3Vc8000`3o000000000?l0000Q0>K<P0030000003o0000o`000240i/b000<00000
0?l0003o0000803Vc8000`3o000000000?l0000Q0>K<P0030?l000000000o`000240i/b00P3o0000
0`000000i/b00>K<P00P0>K<P0030000003o0000o`000200i/b000<0o`000000003o00003`3Vc800
0`3o0000i/b00>K<P0070>K<P0030?l0003Vc800i/b000D0i/b000<0o`000>K<P03Vc8004`3Vc800
00040>K<P00000000000000000D0i/b00P0000040>K<P0<000001`3Vc8000`000000i/b00>K<P005
0>K<P0030000003Vc800i/b000h0i/b00P3o00000`000000i/b00>K<P00P0>K<P0030?l000000000
o`000240i/b000<000000?l0003o0000803Vc8000`3o000000000?l0000Q0>K<P0030?l000000000
o`000240i/b00P3o00000`000000i/b00>K<P00P0>K<P0030000003o0000o`000240i/b000<00000
0?l0003o00003P3Vc8000`3o0000i/b00>K<P0070>K<P0030?l0003Vc800i/b000D0i/b000<0o`00
0>K<P03Vc8004`3Vc80000040000003Vc800i/b0000000D0i/b00P0000070>K<P0030000003Vc800
i/b000D0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00>0>K<P080o`0000<00000
0>K<P03Vc800803Vc8000`3o000000000?l0000P0>K<P0030?l000000000o`000280i/b000<00000
0?l0003o0000803Vc8000`3o000000000?l0000Q0>K<P080o`0000<000000>K<P03Vc8007`3Vc800
0`3o000000000?l0000R0>K<P0030000003o0000o`0000h0i/b000<0o`000>K<P03Vc8001`3Vc800
0`3o0000i/b00>K<P0050>K<P0030?l0003Vc800i/b001<0i/b000040>K<P0030000003Vc800i/b0
00`0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0040>K<P0<000003P3Vc8020?l0
00030000003Vc800i/b00200i/b000<0o`000000003o0000803Vc8000`3o000000000?l0000R0>K<
P0<00000803Vc8000`000000o`000?l0000Q0>K<P080o`0000<000000>K<P03Vc8007`3Vc8000`00
0000o`000?l0000R0>K<P0030000003o0000o`0000h0i/b000<0o`000>K<P03Vc8001`3Vc8000`3o
0000i/b00>K<P0050>K<P0030?l0003Vc800i/b001<0i/b000040>K<P0030000003Vc800i/b000T0
i/b0100000060>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8003P3Vc8020?l00003
0000003Vc800i/b00200i/b000<0o`000000003o0000803Vc8000`3o000000000?l0000R0>K<P0<0
0000803Vc8000`000000o`000?l0000R0>K<P0030?l000000000o`000200i/b000<000000?l0003o
00008P3Vc8000`000000o`000?l0000=0>K<P0D0o`00103Vc8030?l000H0i/b01@3o000B0>K<P000
103Vc8000`000000i/b00>K<P0080>K<P0050000003Vc800i/b00>K<P00000001`3Vc8000`000000
i/b00>K<P0030>K<P0030000003Vc800i/b000h0i/b000<0o`000000003o00008P3Vc8000`3o0000
00000?l0000P0>K<P0030?l000000000o`000280i/b00P3o00000`000000i/b00>K<P00N0>K<P003
0000003o0000o`000280i/b000<0o`000000003o0000803Vc8000`000000o`000?l0000R0>K<P003
0000003o0000o`0000h0i/b000<0o`000>K<P03Vc8003`3Vc8000`3o0000i/b00>K<P00C0>K<P000
103Vc8000`000000i/b00>K<P0080>K<P0050000003Vc800i/b00>K<P00000001`3Vc8000`000000
i/b00>K<P0030>K<P0030000003Vc800i/b000h0i/b000<0o`000000003o00008P3Vc8000`3o0000
00000?l0000P0>K<P0030?l000000000o`000280i/b00P3o00000`000000i/b00>K<P00M0>K<P003
0?l000000000o`0002<0i/b000<0o`000000003o0000803Vc8000`000000o`000?l0000R0>K<P003
0000003o0000o`0000h0i/b01@3o00050>K<P0030?l0003Vc800i/b000D0i/b000<0o`000>K<P03V
c8004`3Vc80000040000003Vc800i/b0000000/0i/b000D000000>K<P03Vc800i/b0000000030>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00=0>K<
P080o`0000<000000?l0003Vc8008P3Vc8000`000000o`000?l0000O0>K<P0030?l000000000o`00
0280i/b00P3o00000`000000i/b00>K<P00M0>K<P0030?l000000000o`0002<0i/b000<0o`000000
003o0000803Vc8000`000000o`000?l0000R0>K<P0030000003o0000000001P0i/b000<0o`000>K<
P03Vc8006`3Vc80000@00000303Vc803000000@0i/b01P0000040>K<P0030000003Vc800i/b000d0
i/b00P3o00000`000000i/b00>K<P00R0>K<P0030000003o0000o`0001l0i/b000<0o`000000003o
00008P3Vc8020?l000030000003Vc800i/b001d0i/b000<0o`000000003o00008`3Vc8000`3o0000
00000?l0000P0>K<P0030000003o0000o`0002<0i/b00P0000000`3o0000i/b00>K<P00c0>K<P000
8@3Vc803000000d0i/b00P3o00000`000000i/b00>K<P00R0>K<P0030000003o0000o`0001h0i/b0
0P3o00000`000000i/b00>K<P00R0>K<P0030?l000000000o`0001h0i/b000<0o`000000003o0000
8`3Vc8000`3o000000000?l0000O0>K<P0030?l000000000o`0002@0i/b000<0o`000000003o0000
=@3Vc8000240i/b000<000000>K<P03Vc8003@3Vc8020?l000030000003Vc800i/b00280i/b000<0
00000?l0003o00007P3Vc8020?l000030000003Vc800i/b00280i/b000<0o`000000003o00007P3V
c8000`000000o`000?l0000S0>K<P0030?l000000000o`0001l0i/b000<000000?l0003o0000903V
c8000`3o000000000?l0000e0>K<P0008@3Vc8000`000000i/b00>K<P00=0>K<P080o`0000<00000
0>K<P03Vc8008P3Vc8000`000000o`000?l0000N0>K<P080o`0000<000000>K<P03Vc8008P3Vc800
0`3o000000000?l0000N0>K<P0030000003o0000o`0002@0i/b000<000000?l0003o00007P3Vc800
0`000000o`000?l0000T0>K<P080o`0000<000000>K<P03Vc800<`3Vc8000240i/b000<000000>K<
P03Vc8003@3Vc8020?l000030000003Vc800i/b00280i/b000<000000?l0003o00007P3Vc8020?l0
00030000003Vc800i/b00280i/b000<0o`000000003o00007P3Vc8000`000000o`000?l0000T0>K<
P0030000003o0000o`0001h0i/b000<000000?l0003o0000903Vc8020?l000030000003Vc800i/b0
03<0i/b0000Q0>K<P0030000003Vc800i/b000d0i/b00P3o00000`000000i/b00>K<P00R0>K<P003
0000003o0000o`0001h0i/b00`00000T0>K<P080o`0000<000000>K<P03Vc800703Vc8000`000000
o`000?l0000T0>K<P0030?l000000000o`0001h0i/b000<000000?l0003o0000903Vc8020?l00003
0000003Vc800i/b003<0i/b0000Q0>K<P0<00000303Vc8020?l000030000003Vc800i/b002<0i/b0
00@000000?l0003o0000o`007@3Vc8000`000000o`000?l0000T0>K<P080o`0000<000000>K<P03V
c8006`3Vc8000`3o000000000?l0000U0>K<P0030?l000000000o`0001h0i/b000<000000?l0003o
0000903Vc8020?l000030000003Vc800i/b003<0i/b0000Q0>K<P0030000003Vc800i/b000`0i/b0
0P3o00000`000000i/b00>K<P00T0>K<P0030000003o0000o`0001d0i/b000<000000?l0003o0000
903Vc8020?l000030000003Vc800i/b001/0i/b000<0o`000000003o00009@3Vc8000`3o00000000
0?l0000N0>K<P0030000003o0000o`0002D0i/b000<0o`000000003o0000=03Vc8000240i/b000<0
00000>K<P03Vc800303Vc8020?l000030000003Vc800i/b002@0i/b00P0000000`3o0000i/b00>K<
P00K0>K<P0030000003o0000o`0002@0i/b00P3o00000`000000i/b00>K<P00K0>K<P0030?l00000
0000o`0002D0i/b000<0o`000000003o00007@3Vc800103o000000000?l0003o000U0>K<P0030?l0
00000000o`0003@0i/b0000Q0>K<P0030000003Vc800i/b000`0i/b00P3o00000`000000i/b00>K<
P00T0>K<P080000000<0o`000>K<P03Vc8006P3Vc8000`3o000000000?l0000V0>K<P0030?l00000
0000o`0001`0i/b000<0o`000000003o00009@3Vc8000`3o000000000?l0000M0>K<P0030000003o
0000o`0002H0i/b000<0o`000000003o0000=03Vc8000240i/b000<000000>K<P03Vc800303Vc802
0?l000030000003Vc800i/b002@0i/b000<0o`000000003o0000703Vc8000`000000o`000?l0000V
0>K<P0030?l000000000o`0001`0i/b000<000000?l0003o00009@3Vc800103o000000000?l0003o
000L0>K<P0030000003o0000o`0002H0i/b000<0o`000000003o0000=03Vc8000240i/b000<00000
0>K<P03Vc800303Vc8020?l000030000003Vc800i/b002@0i/b00P3o00000`000000i/b00>K<P00J
0>K<P0030000003o0000o`0002H0i/b000<0o`000000003o0000703Vc8000`000000o`000?l0000V
0>K<P0030000003o0000o`0001`0i/b000<000000?l0003o00009P3Vc8020?l000030000003Vc800
i/b00380i/b0000Q0>K<P0<00000303Vc8020?l000030000003Vc800i/b002@0i/b00P3o00000`00
0000i/b00>K<P00J0>K<P0030000003o0000o`0002H0i/b000<0o`000000003o0000703Vc8000`00
0000o`000?l0000V0>K<P0<00000703Vc8000`000000o`000?l0000V0>K<P080o`0000<000000>K<
P03Vc800<P3Vc8000240i/b000<000000>K<P03Vc8002`3Vc8030?l000030000003Vc800i/b002D0
i/b000<0o`000000003o00006`3Vc8000`000000o`000?l0000V0>K<P0030?l000000000o`0001`0
i/b000<000000?l0003o00009P3Vc803000001`0i/b000<000000?l0003o00009P3Vc8020?l00003
0000003Vc800i/b00380i/b0000Q0>K<P0030000003Vc800i/b000/0i/b00P3o00000`000000i/b0
0>K<P00V0>K<P0030?l000000000o`0001/0i/b000<000000?l0003o00009P3Vc8000`3o00000000
0?l0000K0>K<P0030?l000000000o`0002L0i/b00P3o00000`000000i/b00>K<P00J0>K<P0030000
003o0000o`0002L0i/b000<0o`000000003o0000<`3Vc8000240i/b000<000000>K<P03Vc8002`3V
c8020?l000030000003Vc800i/b002H0i/b000<0o`000000003o00006`3Vc8000`000000o`000?l0
000V0>K<P0030?l000000000o`0001/0i/b000<0o`000000003o00009`3Vc8020?l000030000003V
c800i/b001X0i/b000<000000?l0003o00009`3Vc8000`3o000000000?l0000c0>K<P0008@3Vc800
0`000000i/b00>K<P00;0>K<P080o`0000<000000>K<P03Vc8009P3Vc8000`3o000000000?l0000K
0>K<P0030000003o0000o`0002H0i/b000<0o`000000003o00006`3Vc8000`3o000000000?l0000W
0>K<P080o`0000<000000>K<P03Vc8006@3Vc8000`000000o`000?l0000X0>K<P0030?l000000000
o`0003<0i/b0000Q0>K<P0030000003Vc800i/b000/0i/b00P3o00000`000000i/b00>K<P00V0>K<
P0030?l000000000o`0001X0i/b000<0o`000000003o0000:03Vc8000`000000o`000?l0000J0>K<
P0030?l000000000o`0002L0i/b00P3o00000`000000i/b00>K<P00I0>K<P0030000003o0000o`00
02P0i/b000<0o`000000003o0000<`3Vc8000240i/b00`00000;0>K<P080o`0000<000000>K<P03V
c8009P3Vc8000`3o000000000?l0000J0>K<P0030?l000000000o`0002P0i/b000<000000?l0003o
00006P3Vc8000`000000o`000?l0000X0>K<P0030?l000000000o`0001X0i/b000<000000?l0003o
0000:03Vc8000`3o000000000?l0000c0>K<P0008@3Vc8000`000000i/b00>K<P00;0>K<P080o`00
00<000000>K<P03Vc8009P3Vc8000`3o000000000?l0000J0>K<P0030?l000000000o`0002P0i/b0
00<000000?l0003o00006P3Vc8000`000000o`000?l0000X0>K<P0030?l000000000o`0001X0i/b0
00<000000?l0003o0000:03Vc8000`3o000000000?l0000c0>K<P0008@3Vc8000`000000i/b00>K<
P00:0>K<P080o`0000<000000>K<P03Vc800:03Vc8000`000000o`000?l0000I0>K<P0030?l00000
0000o`0002P0i/b000<000000?l0003o00006P3Vc8000`000000o`000?l0000X0>K<P0030?l00000
0000o`0001X0i/b000<000000?l0003o0000:03Vc8000`3o000000000?l0000c0>K<P00000@0i/b0
00000000000000001@3Vc802000000@0i/b00`0000060>K<P0@000001@3Vc8000`000000i/b00>K<
P00:0>K<P0030?l000000000000002X0i/b000<0o`000000003o00006@3Vc8000`3o000000000?l0
000X0>K<P0030000003o0000o`0001X0i/b000<000000?l0003o0000:03Vc8000`3o000000000?l0
000J0>K<P0030000003o0000o`0002T0i/b000<000000?l0003o0000<P3Vc80000040000003Vc800
i/b0000000D0i/b00P0000070>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000X0i/b000<0o`00000000000000:P3V
c8000`3o000000000?l0000I0>K<P0030?l000000000o`0002P0i/b000<0o`000000003o00006@3V
c8000`3o000000000?l0000Y0>K<P080o`0000<000000>K<P03Vc800603Vc8000`000000o`000?l0
000Y0>K<P0030000003o0000o`000380i/b000040>K<P0030000003Vc800i/b000`0i/b000D00000
0>K<P03Vc800i/b0000000040>K<P0030000003Vc800i/b00080i/b00`00000:0>K<P0030?l00000
0000o`0002X0i/b000<0o`000000003o0000603Vc8020?l000030000003o0000i/b002L0i/b000<0
o`000000003o00006@3Vc8000`3o000000000?l0000Y0>K<P080o`0000<000000>K<P03Vc8005`3V
c8000`000000o`000?l0000Z0>K<P0030?l000000000o`000380i/b000040>K<P0030000003Vc800
i/b000T0i/b0100000040>K<P0030000003Vc800i/b000800000103Vc8000`000000i/b00>K<P00:
0>K<P0030?l000000000o`0002X0i/b000<0o`000000003o0000603Vc8020?l000030000003Vc800
i/b002P0i/b000<000000?l0003o0000603Vc8000`3o000000000?l0000Y0>K<P080o`0000<00000
0>K<P03Vc8005`3Vc8000`000000o`000?l0000Z0>K<P0030?l000000000o`000380i/b000040>K<
P0030000003Vc800i/b000P0i/b000D000000>K<P03Vc800i/b0000000040>K<P0@000001@3Vc800
0`000000i/b00>K<P00:0>K<P0030000003o0000o`0002X0i/b000<0o`000000003o0000603Vc800
0`3o000000000?l0000Z0>K<P080000000<0o`000>K<P03Vc8005P3Vc8000`3o000000000?l0000Z
0>K<P0030?l000000000o`0001P0i/b000<000000?l0003o0000:P3Vc8000`3o000000000?l0000b
0>K<P000103Vc8000`000000i/b00>K<P0080>K<P0050000003Vc800i/b00>K<P00000000`3Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002@3Vc800
103o000000000?l0003o000Z0>K<P0040?l000000000o`000?l001L0i/b000<0o`000000003o0000
:P3Vc8000`3o000000000?l0000H0>K<P0030000003o0000o`0002X0i/b000<0o`000000003o0000
603Vc8000`000000o`000?l0000Z0>K<P0030?l000000000o`000380i/b0000010000000i/b00>K<
P000000;0>K<P0050000003Vc800i/b00>K<P00000000`3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8002@3Vc8000`3o000000000?l0000/0>K<P003
0000003o0000o`0001L0i/b000<0o`000000003o0000:P3Vc8020?l000030000003Vc800i/b001H0
i/b000<000000?l0003o0000:P3Vc8000`3o000000000?l0000H0>K<P0030000003o0000o`0002X0
i/b000<0o`000000003o0000<P3Vc80000@00000303Vc803000000D0i/b0100000050>K<P0030000
003Vc800i/b000T0i/b000<0o`000000003o0000;03Vc8000`000000o`000?l0000G0>K<P0030?l0
00000000o`0002X0i/b00P3o00000`000000i/b00>K<P00F0>K<P0030000003o0000o`0002X0i/b0
00<0o`000000003o0000603Vc8000`000000o`000?l0000[0>K<P0030000003o0000o`000340i/b0
000Q0>K<P0<000002@3Vc8000`3o000000000?l0000/0>K<P0030000003o0000o`0001H0i/b00P3o
00000`000000o`000>K<P00Y0>K<P080o`0000<000000>K<P03Vc8005P3Vc8000`000000o`000?l0
000Z0>K<P0030?l000000000o`0001L0i/b000@000000?l0003o0000o`00:`3Vc802000000030?l0
003Vc800i/b002l0i/b0000Q0>K<P0030000003Vc800i/b000T0i/b000<0o`000000003o0000;03V
c8000`000000o`000?l0000F0>K<P080o`0000<000000>K<P03Vc800:@3Vc8020?l000030000003V
c800i/b001D0i/b000<0o`000000003o0000:`3Vc8000`3o000000000?l0000G0>K<P0030000003o
0000o`0002`0i/b000<0o`000000003o0000<@3Vc8000240i/b000<000000>K<P03Vc8002@3Vc800
0`3o000000000?l0000/0>K<P0030000003o0000o`0001H0i/b00P3o00000`000000i/b00>K<P00Y
0>K<P080o`0000<000000?l0003Vc8005@3Vc8000`3o000000000?l0000[0>K<P0030?l000000000
o`0001L0i/b000<000000?l0003o0000;03Vc8000`3o000000000?l0000a0>K<P0008@3Vc8000`00
0000i/b00>K<P0090>K<P0030?l000000000o`0002`0i/b000<000000?l0003o00005P3Vc8020?l0
00030000003Vc800i/b002X0i/b000<0o`000000003o00005P3Vc8000`3o000000000?l0000[0>K<
P0040?l000000000o`000?l001H0i/b000<000000?l0003o0000;03Vc8020?l000030000003Vc800
i/b002l0i/b0000Q0>K<P0030000003Vc800i/b000P0i/b00P3o00000`000000i/b00>K<P00[0>K<
P0040000003o0000o`000?l001D0i/b00P3o00000`000000i/b00>K<P00Z0>K<P0030?l000000000
o`0001H0i/b000<0o`000000003o0000;03Vc8000`000000o`000?l0000F0>K<P0030000003o0000
o`0002`0i/b00P3o00000`000000i/b00>K<P00_0>K<P0008@3Vc8000`000000i/b00>K<P0080>K<
P0030?l000000000o`0002h0i/b000<000000?l0003o00005@3Vc802000000030?l0003Vc800i/b0
02X0i/b000<0o`000000003o00005P3Vc8000`000000o`000?l0000/0>K<P0030?l000000000o`00
01H0i/b000<000000?l0003o0000;03Vc8020?l000030000003Vc800i/b002l0i/b0000Q0>K<P0<0
0000203Vc8000`3o000000000?l0000^0>K<P0030000003o0000o`0001@0i/b000@0o`000000003o
0000o`00;03Vc8000`3o000000000?l0000F0>K<P0030000003o0000o`0002`0i/b000<0o`000000
003o00005P3Vc8000`000000o`000?l0000]0>K<P0030?l000000000o`000300i/b0000Q0>K<P003
0000003Vc800i/b000P0i/b000<0o`000000003o0000;P3Vc8000`000000o`000?l0000D0>K<P003
0?l000000000o`0002d0i/b00P3o00000`000000i/b00>K<P00D0>K<P0030000003o0000o`0002`0
i/b000<0o`000000003o00005@3Vc8000`000000o`000?l0000^0>K<P0030?l000000000o`000300
i/b0000Q0>K<P0030000003Vc800i/b000P0i/b000<0o`000000003o0000;P3Vc802000000030?l0
003Vc800i/b00180i/b000<0o`000000003o0000;@3Vc8020?l000030000003Vc800i/b001@0i/b0
00<000000?l0003o0000;03Vc8000`3o000000000?l0000E0>K<P0030000003o0000o`0002h0i/b0
00<0o`000000003o0000<03Vc8000240i/b000<000000>K<P03Vc800203Vc8000`3o000000000?l0
000^0>K<P0030?l000000000o`0001@0i/b000<0o`000000003o0000;@3Vc8020?l000030000003V
c800i/b001<0i/b000<0o`000000003o0000;@3Vc8000`3o000000000?l0000E0>K<P0030000003o
0000o`0002h0i/b000<0o`000000003o0000<03Vc8000240i/b000<000000>K<P03Vc800203Vc800
0`3o000000000?l0000^0>K<P0030?l000000000o`0001@0i/b000<000000?l0003o0000;P3Vc800
0`3o000000000?l0000D0>K<P0030?l000000000o`0002d0i/b000<0o`000000003o00005@3Vc800
0`000000o`000?l0000^0>K<P0030?l000000000o`000300i/b0000Q0>K<P0<000001`3Vc8020?l0
00030000003Vc800i/b002h0i/b000<0o`000000003o00004`3Vc8000`000000o`000?l0000^0>K<
P0030?l000000000o`0001@0i/b000<0o`000000003o0000;P3Vc802000000030?l0003Vc800i/b0
0180i/b000<000000?l0003o0000;P3Vc8000`3o000000000?l0000`0>K<P0008@3Vc8000`000000
i/b00>K<P0070>K<P080o`0000<000000>K<P03Vc800;P3Vc8000`3o000000000?l0000B0>K<P004
0?l000000000o`000?l002h0i/b000<0o`000000003o0000503Vc8000`3o000000000?l0000^0>K<
P0030?l000000000000001@0i/b000<000000?l0003o0000;P3Vc800103o000000000?l0003o000_
0>K<P0008@3Vc8000`000000i/b00>K<P0070>K<P080o`0000<000000>K<P03Vc800;P3Vc8000`3o
000000000?l0000B0>K<P0030?l000000000o`0002l0i/b000<0o`000000003o0000503Vc8000`00
0000o`000?l0000^0>K<P080o`0000<000000>K<P03Vc8004P3Vc8000`000000o`000?l0000_0>K<
P0030?l000000000o`0002l0i/b0000Q0>K<P0030000003Vc800i/b000L0i/b00P3o00000`000000
i/b00>K<P00^0>K<P0030?l000000000o`000180i/b000<0o`000000003o0000;`3Vc8000`3o0000
00000?l0000D0>K<P0030000003o0000o`0002h0i/b00P3o00000`000000i/b00>K<P00A0>K<P003
0000003o0000o`000300i/b000<0o`000000003o0000;`3Vc8000240i/b000<000000>K<P03Vc800
1`3Vc8020?l000030000003Vc800i/b002h0i/b000<0o`000000003o00004P3Vc8000`3o00000000
0?l0000_0>K<P0030?l000000000o`0001<0i/b000@0o`000000003o0000o`00;P3Vc8020?l00003
0000003Vc800i/b00140i/b000<000000?l0003o0000<03Vc8000`3o000000000?l0000_0>K<P000
8@3Vc8000`000000i/b00>K<P0070>K<P080o`0000<000000>K<P03Vc800;P3Vc8000`3o00000000
0?l0000B0>K<P0030?l000000000o`000300i/b000<000000?l0003o00004P3Vc8000`3o00000000
0?l0000_0>K<P080o`0000<000000>K<P03Vc8004@3Vc8000`000000o`000?l0000`0>K<P0030?l0
00000000o`0002l0i/b0000Q0>K<P0<000001P3Vc8020?l000030000003Vc800i/b002l0i/b000<0
o`000000003o00004P3Vc8000`3o000000000?l0000`0>K<P0030?l000000000o`000180i/b000<0
o`000000003o0000<03Vc8020?l000030000003Vc800i/b00100i/b000<000000?l0003o0000<03V
c8000`3o000000000?l0000_0>K<P0008@3Vc8000`000000i/b00>K<P0060>K<P080o`0000<00000
0>K<P03Vc800<03Vc8000`3o000000000?l0000@0>K<P080o`0000<000000?l0003Vc800;`3Vc800
0`3o000000000?l0000B0>K<P0030?l000000000o`000300i/b00P3o00000`000000i/b00>K<P00@
0>K<P0030000003o0000o`000300i/b000@0o`000000003o0000o`00;P3Vc8000240i/b000<00000
0>K<P03Vc8001P3Vc8000`3o000000000000000b0>K<P0030?l000000000o`000100i/b00P3o0000
0`000000i/b00>K<P00_0>K<P0030?l000000000o`000180i/b000<0o`000000003o0000<03Vc802
0?l000030000003Vc800i/b00100i/b000<000000?l0003o0000<@3Vc8000`000000o`000?l0000^
0>K<P00000@0i/b000000000000000001@3Vc802000000@0i/b00`0000050>K<P0<000001`3Vc800
0`000000i/b00>K<P0060>K<P0030?l000000000o`000380i/b000<0o`000000003o0000403Vc802
0?l000030000003Vc800i/b002l0i/b000<0o`000000003o00004@3Vc8000`3o000000000?l0000a
0>K<P080o`0000<000000>K<P03Vc8003`3Vc800103o000000000?l0003o000a0>K<P0030000003o
0000o`0002h0i/b0000010000000i/b00>K<P00000050>K<P08000001`3Vc8000`000000i/b00>K<
P0050>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8001P3Vc8000`3o000000000?l0
000b0>K<P0030?l000000000o`000100i/b00P3o00000`000000i/b00>K<P00_0>K<P0030?l00000
0000o`000140i/b000<0o`000000003o0000<@3Vc8020?l000030000003Vc800i/b000l0i/b000<0
00000?l0003o0000<P3Vc8000`000000o`000?l0000^0>K<P000103Vc8000`000000i/b00>K<P00<
0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P006
0>K<P0030?l000000000o`000380i/b000<0o`000000003o0000403Vc8000`3o000000000?l0000b
0>K<P0030000003o0000o`000100i/b000<0o`000000003o0000<P3Vc8000`3o000000000?l0000@
0>K<P0030000003o0000o`000380i/b000<000000?l0003o0000403Vc8000`3o000000000?l0000K
0>K<P000103Vc8000`000000i/b00>K<P0090>K<P0@00000103Vc804000000D0i/b00`0000050>K<
P0030?l000000000o`0003<0i/b000<0o`000000003o0000403Vc8000`3o000000000?l0000b0>K<
P0030?l000000000o`000100i/b000<0o`000000003o0000<P3Vc8000`3o000000000?l0000@0>K<
P0030000003o0000o`000380i/b000<0o`000000003o0000403Vc8000`3o000000000?l0000K0>K<
P000103Vc8000`000000i/b00>K<P0080>K<P0050000003Vc800i/b00>K<P00000000`3Vc8001@00
0000i/b00>K<P03Vc800000000D0i/b000<000000>K<P03Vc8001@3Vc8000`3o000000000?l0000d
0>K<P0030000003o0000o`0000h0i/b00P3o00000`000000o`000>K<P00a0>K<P080o`0000<00000
0>K<P03Vc8003@3Vc8020?l000030000003Vc800i/b00340i/b000<0o`000000003o0000403Vc800
0`000000o`000?l0000b0>K<P0040?l000000000o`000?l000l0i/b000<0o`000000003o00006`3V
c80000@0i/b000<000000>K<P03Vc800203Vc8001@000000i/b00>K<P03Vc800000000<0i/b000D0
00000>K<P03Vc800i/b0000000050>K<P0030000003Vc800i/b000D0i/b000<0o`000000003o0000
=03Vc8000`000000o`000?l0000>0>K<P080o`0000<000000>K<P03Vc800<@3Vc8020?l000030000
003Vc800i/b000d0i/b00P3o00000`000000i/b00>K<P00a0>K<P0030?l000000000o`000100i/b0
00<000000?l0003o0000<`3Vc802000000030?l0003Vc800i/b000`0i/b00P3o00000`000000o`00
0>K<P00J0>K<P00000@000000>K<P03Vc80000002`3Vc8001@000000i/b00>K<P03Vc800000000<0
i/b000D000000>K<P03Vc800i/b0000000050>K<P0030000003Vc800i/b000D0i/b000<0o`000000
003o0000=03Vc8000`000000o`000?l0000>0>K<P080o`0000<000000>K<P03Vc800<@3Vc8020?l0
00030000003o0000i/b000d0i/b000<0o`000000003o0000<`3Vc8000`3o000000000?l0000@0>K<
P0030000003o0000o`0003<0i/b000<0o`000000003o00003P3Vc8000`3o000000000?l0000L0>K<
P0001000000<0>K<P0<000001@3Vc803000000H0i/b000<000000>K<P03Vc8001@3Vc8000`3o0000
00000?l0000d0>K<P0030000003o0000o`0000h0i/b00P3o00000`000000i/b00>K<P00b0>K<P003
0?l000000000o`0000h0i/b000<0o`000000003o0000=03Vc8000`000000o`000?l0000>0>K<P003
0?l000000000o`0003@0i/b000<0o`000000003o00003P3Vc8000`3o000000000?l0000L0>K<P000
8@3Vc803000000@0i/b00P3o00000`000000o`000>K<P00c0>K<P0030000003o0000o`0000h0i/b0
00<0o`00000000000000=03Vc8020?l000030000003Vc800i/b000/0i/b00P3o00000`000000o`00
0>K<P00c0>K<P0030?l000000000o`0000h0i/b000<000000?l0003o0000=03Vc8020?l000030000
003Vc800i/b000`0i/b000<0o`000000003o0000703Vc8000240i/b000<000000>K<P03Vc800103V
c8020?l000030000003Vc800i/b003<0i/b000@000000?l0003o0000o`00303Vc800103o00000000
0000003o000d0>K<P080o`0000<000000>K<P03Vc8002`3Vc8020?l000030000003Vc800i/b003<0
i/b000<0o`000000003o00003P3Vc8000`000000o`000?l0000d0>K<P080o`0000<000000>K<P03V
c800303Vc8000`3o000000000?l0000L0>K<P0008@3Vc8000`000000i/b00>K<P0040>K<P080o`00
00<000000>K<P03Vc800=03Vc8000`000000o`000?l0000<0>K<P0030?l000000000o`0003D0i/b0
0P3o00000`000000o`000>K<P00;0>K<P080o`0000<000000>K<P03Vc800<`3Vc8000`3o00000000
0?l0000>0>K<P0030000003o0000o`0003@0i/b00P3o00000`000000i/b00>K<P00;0>K<P080o`00
00<000000>K<P03Vc8006`3Vc8000240i/b000<000000>K<P03Vc800103Vc8020?l000030000003V
c800i/b003@0i/b00P0000000`3o0000i/b00>K<P00:0>K<P0030?l000000000o`0003H0i/b000<0
o`000000003o0000303Vc8020?l000030000003Vc800i/b003@0i/b000<000000?l0003o00003@3V
c8000`000000o`000?l0000d0>K<P080o`0000<000000?l0003Vc8002`3Vc8020?l000030000003V
c800i/b001/0i/b0000Q0>K<P0030000003Vc800i/b000@0i/b000<0o`000000003o0000=P3Vc800
0`3o000000000?l0000<0>K<P0030?l000000000o`0003H0i/b000<0o`000000003o0000303Vc800
0`3o000000000?l0000f0>K<P0030000003o0000o`0000`0i/b000<0o`000000003o0000=P3Vc800
0`3o000000000?l0000<0>K<P080o`0000<000000>K<P03Vc8006`3Vc8000240i/b000<000000>K<
P03Vc8000`3Vc8020?l000030000003Vc800i/b003D0i/b00P3o00000`000000i/b00>K<P0090>K<
P0040?l000000000o`000?l003H0i/b000<0o`000000003o0000303Vc8000`3o000000000?l0000f
0>K<P0030?l000000000o`0000`0i/b000<0o`000000003o0000=P3Vc8000`3o000000000?l0000<
0>K<P0030?l000000000o`0001d0i/b0000Q0>K<P0<000000`3Vc8020?l000030000003Vc800i/b0
03H0i/b000<0o`000000003o00002P3Vc8000`3o000000000?l0000g0>K<P0030?l000000000o`00
00/0i/b00P3o00000`000000o`000>K<P00e0>K<P080o`0000<000000>K<P03Vc8002P3Vc8000`3o
000000000?l0000f0>K<P0030?l000000000o`0000/0i/b000@0o`00000000000000o`007@3Vc800
0240i/b000<000000>K<P03Vc8000`3Vc8020?l000030000003Vc800i/b003H0i/b000<0o`000000
003o00002P3Vc8000`3o000000000?l0000g0>K<P0030?l000000000o`0000/0i/b00P3o00000`00
0000i/b00>K<P00f0>K<P0030?l000000000o`0000X0i/b000<0o`000000003o0000=`3Vc8000`3o
000000000?l0000;0>K<P0030?l000000000o`0001h0i/b0000Q0>K<P0030000003Vc800i/b000<0
i/b00P3o00000`000000i/b00>K<P00f0>K<P0030?l000000000o`0000X0i/b000<0o`000000003o
0000>03Vc8000`000000o`000?l0000:0>K<P080o`0000<000000>K<P03Vc800=P3Vc8000`3o0000
00000?l0000:0>K<P0030?l000000000o`0003L0i/b000<0o`000000003o00002`3Vc8000`000000
o`000?l0000N0>K<P0008@3Vc8000`000000i/b00>K<P0020>K<P080o`0000<000000?l0003Vc800
;03Vc804000000D0i/b00P0000000`3o000000000?l0000:0>K<P0030?l000000000o`0001/0i/b0
1P0000040>K<P0<000001@3Vc803000000P0i/b000<000000?l0003o00002P3Vc802000000030?l0
003Vc800i/b000`0i/b01P0000030>K<P0@000001@3Vc803000001D0i/b000<0o`000000003o0000
2P3Vc800103o000000000?l0003Vc806000000@0i/b00`0000050>K<P0<000008P3Vc800103o0000
00000?l0003Vc806000000<0i/b000@000000?l0003o000000001@3Vc803000001D0i/b0000Q0>K<
P0030000003Vc800i/b00080i/b00P3o00000`000000i/b00>K<P00`0>K<P0050000003Vc800i/b0
0>K<P00000000P3Vc8020?l000030000003Vc800i/b000L0i/b000@0o`000000003o0000o`007P3V
c8000`000000i/b00>K<P0030>K<P0040000003Vc800i/b0000000@0i/b000@000000>K<P03Vc800
0000203Vc8000`000000o`000?l0000:0>K<P0030000003o0000o`000140i/b000<000000>K<P03V
c8001`3Vc8001@000000i/b00>K<P03Vc80000000080i/b000<000000>K<P03Vc8004`3Vc8000`3o
000000000?l0000:0>K<P0030?l000000000o`000080i/b000D000000>K<P03Vc800i/b000000003
0>K<P0040000003Vc800i/b0000000@0i/b000@000000>K<P03Vc80000008P3Vc8000`3o00000000
0?l000020>K<P0050000003Vc800i/b00>K<P00000000`3Vc8001@000000o`000?l0003Vc8000000
00<0i/b000@000000>K<P03Vc80000005@3Vc8000240i/b000<000000>K<P03Vc8000P3Vc8000`3o
000000000000000b0>K<P0040000003Vc800i/b0000000<0i/b00P3o00000`000000o`000>K<P007
0>K<P0030?l000000000o`0001l0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P002
0>K<P0040000003Vc800i/b0000000@0i/b000<000000>K<P03Vc8001@3Vc8000`3o000000000?l0
00090>K<P0040?l000000000o`000?l00140i/b000<000000>K<P03Vc8001`3Vc80010000000i/b0
0>K<P00000040>K<P0030000003Vc800i/b001<0i/b000<0o`000000003o0000203Vc8020?l00003
0000003o0000i/b00080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P004
0000003Vc800i/b0000000@0i/b000<000000>K<P03Vc8007`3Vc8000`3o000000000?l000030>K<
P0030000003Vc800i/b000<0i/b000H0o`000000003o0000o`000>K<P00000020>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc8004P3Vc8000240i/b00`0000020>K<P0030000003o0000
o`000380i/b000@000000>K<P03Vc8000000103Vc8000`3o000000000?l000080>K<P0030?l00000
0000o`0001l0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0020>K<P0040000003V
c800i/b0000000@0i/b000<000000>K<P03Vc8001@3Vc8000`3o00000000000000090>K<P0030?l0
00000000o`000180i/b000<000000>K<P03Vc8001`3Vc80010000000i/b00>K<P00000040>K<P003
0000003Vc800i/b001<0i/b000<0o`000000003o0000203Vc8020?l000030000003Vc800i/b000<0
i/b00P0000030>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc8000000103Vc8000`00
0000i/b00>K<P00O0>K<P0030?l000000000o`0000@0i/b00P0000030>K<P0030?l000000000o`00
0080i/b000@000000>K<P03Vc8000000103Vc8000`000000i/b00>K<P00B0>K<P0008@3Vc8000`00
0000i/b00>K<P0020>K<P0030000003o0000o`0002h0i/b0100000030>K<P0030000003Vc800i/b0
0080i/b000<0o`000000003o0000203Vc8000`3o000000000?l0000O0>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc8000P3Vc80010000000i/b00>K<P00000040>K<P0030000003Vc800
i/b000H0i/b000<0o`00000000000000203Vc8000`3o000000000?l0000B0>K<P0030000003Vc800
i/b000<0i/b0100000030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8004`3Vc800
0`3o000000000?l000080>K<P080o`0000<000000>K<P03Vc800103Vc80200000080i/b000<00000
0>K<P03Vc8000P3Vc80010000000i/b00>K<P00000040>K<P0030000003Vc800i/b00200i/b000<0
00000?l0003o0000103Vc80200000080i/b000<0o`000000003o00000P0000030>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc8004P3Vc8000240i/b000L000000>K<P03Vc800i/b00?l0
00000000o`0002l0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0020>K<P0030?l0
00000000o`0000L0i/b00P3o00000`000000o`000>K<P00N0>K<P0030000003Vc800i/b00080i/b0
00<000000>K<P03Vc8000P3Vc80010000000i/b00>K<P00000040>K<P0030000003Vc800i/b000H0
i/b00P3o00000`000000i/b00>K<P0050>K<P080o`0000<000000?l0003Vc8004@3Vc8000`000000
i/b00>K<P0030>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8000P3Vc8000`000000
i/b00>K<P00C0>K<P0030?l000000000o`0000P0i/b000<0o`000000003o00001`3Vc80010000000
i/b00>K<P00000040>K<P0040000003Vc800i/b0000000@0i/b000<000000>K<P03Vc800803Vc800
0`3o00000000000000050>K<P0040000003Vc800i/b000000080o`001@3Vc8000`000000i/b00>K<
P0020>K<P0030000003Vc800i/b00180i/b0000Q0>K<P0070000003Vc800i/b00>K<P03o00000000
0?l0000_0>K<P0030000003Vc800i/b000D0i/b000L000000>K<P03Vc80000000?l000000000o`00
00L0i/b00P3o00000`000000i/b00>K<P00N0>K<P0030000003Vc800i/b000<0i/b000@000000>K<
P03Vc8000000103Vc80010000000i/b00>K<P00000090>K<P080o`0000<000000>K<P03Vc8001@3V
c8000`3o000000000?l0000C0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8001@3V
c80010000000i/b00>K<P000000G0>K<P0030000003o0000o`0000H0i/b000@0o`00000000000000
o`000P3Vc8000`000000i/b00>K<P0020>K<P0050000003Vc800i/b00>K<P00000000P3Vc8000`00
0000i/b00>K<P0020>K<P0040000003Vc800i/b0000002<0i/b00P3o00000`000000o`000>K<P003
0>K<P0040000003Vc800o`0000000080o`001P3Vc80010000000i/b00>K<P000000E0>K<P0008@3V
c8001`000000i/b00>K<P03Vc800o`000000003o0000;`3Vc804000000@0i/b010000000103Vc800
00000?l0003o00050>K<P080o`000P00000N0>K<P0<000001@3Vc804000000@0i/b01000000:0>K<
P0030?l000000000o`0000H0i/b000<0o`000000003o00004@3Vc803000000D0i/b0100000040>K<
P0@000005`3Vc8000`000000o`000?l000060>K<P0030000003o0000o`0000<0i/b01@0000040>K<
P0@00000103Vc804000002@0i/b00P3o000500000080i/b000<0o`000000003o00000`0000040>K<
P0@000005@3Vc8000240i/b00`0000020?l000030000003o0000i/b003/0i/b000<0o`000000003o
00001@3Vc8000`3o000000000?l0000m0>K<P0030?l000000000o`0000D0i/b00P3o00000`000000
o`000>K<P00k0>K<P0030?l000000000o`0000D0i/b000@0o`000000003o0000o`00?03Vc8020?l0
00030000003o0000i/b000<0i/b00P3o00000`000000o`000>K<P00O0>K<P0008@3Vc8001P000000
i/b00>K<P03o000000000?l003d0i/b000@0o`00000000000000o`00103Vc8000`3o000000000?l0
000m0>K<P0040?l000000000o`000?l000@0i/b00P3o00000`000000i/b00>K<P00k0>K<P0040?l0
00000000o`000?l000@0i/b000<0o`000000003o0000?P3Vc8000`3o000000000?l000040>K<P080
o`0000<000000>K<P03Vc8007`3Vc8000240i/b000H000000>K<P03o0000o`000000003o000n0>K<
P080o`0000<000000?l0003Vc8000P3Vc8000`000000o`000?l0000n0>K<P0040?l000000000o`00
0?l00080i/b00`3o00000`000000i/b00>K<P00l0>K<P0<0000000D0o`000>K<P03Vc800o`000000
00020?l003h0i/b000@0o`000000003o0000o`000P3Vc800103o000000000000003o000Q0>K<P000
8@3Vc8001@000000i/b00?l0003o0000000003l0i/b00P3o00001P000000o`000>K<P03Vc800o`00
00000080o`00?P3Vc8000`3o000000000?l000040?l00080000000<0o`000>K<P03Vc800?03Vc802
0?l000070000003o0000i/b00>K<P03o000000000?l000100>K<P0040?l000000000o`000>K<P080
o`0000<000000?l0003Vc8008@3Vc8000240i/b00P3o000300000400i/b000<0o`000000003o0000
0`3o00000`000000o`000>K<P00o0>K<P08000000`3o00000`000000o`000?l000100>K<P0030?l0
00000000o`0000<0o`0000<000000?l0003Vc800?`3Vc8000`3o000000000?l000030?l000030000
003o0000i/b001T0i/b0100000040>K<P000803Vc8020?l000040000003o0000o`000?l00400i/b0
0P3o000400000080o`00@03Vc8000`3o0000000000000003000000030?l0003Vc800i/b00400i/b0
00<0o`000000003o00000`0000000`3o0000i/b00>K<P00n0>K<P0060?l00000000000000000003o
000000000P3o000I0>K<P0030000003Vc800i/b000H0i/b0000J0>K<P0H0000000<0o`0000000000
00000P3o0012000000030?l00000000000000080000000<0o`00000000000000@00000020?l00080
00000P3o001200000080o`0000@000000?l0003o0000o`00@P0000030?l000030000003o0000o`00
00h00000303Vc8000`000000i/b00>K<P0060>K<P000803Vc8040?l000T0i/b000<000000>K<P03V
c8002@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03V
c8002@3Vc8000`000000i/b00>K<P0080>K<P0@0o`00203Vc8000`000000i/b00>K<P0090>K<P003
0000003Vc800i/b000T0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0090>K<P003
0000003Vc800i/b000P0i/b000<000000?l0003o00000P3o00070>K<P0030000003Vc800i/b000T0
i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000T0
i/b000<000000>K<P03Vc800203Vc8000`000000i/b00?l000030?l000H0i/b000<000000>K<P03V
c8002@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03V
c8002@3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000@0o`001@3Vc8000`000000
i/b00>K<P00C0>K<P0030000003Vc800i/b000H0i/b0000Q0>K<P0030000003Vc800i/b003T0i/b0
00<000000>K<P03Vc800>03Vc8000`000000i/b00>K<P00h0>K<P0030000003Vc800i/b003P0i/b0
00<000000>K<P03Vc800>03Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b000H0i/b0
000Q0>K<P0030000003Vc800i/b00?l0i/b0>`3Vc805000000D0i/b0000Q0>K<P0030000003Vc800
i/b00?l0i/b0?03Vc8000`000000i/b00>K<P0060>K<P0008@3Vc8000`000000i/b00>K<P03o0>K<
P3`0i/b000<000000>K<P03Vc8001P3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3V
c8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3V
c8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3V
c8000?l0i/b0J@3Vc8000001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-28.6562, 0.928673, 1.05651, \
0.000441802}}],

Cell[BoxData[
    InterpretationBox[\("Mean Propability of measuring \
|+z\[RightAngleBracket]: "\[InvisibleSpace]0.969042530468553`\),
      SequenceForm[ 
      "Mean Propability of measuring |+z\[RightAngleBracket]: ", 
        0.96904253046855304],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Amplitude of oscillation: \
"\[InvisibleSpace]0.03086123314942884`\),
      SequenceForm[ "Amplitude of oscillation: ", 0.030861233149428839],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rabi frequency: \
"\[InvisibleSpace]0.10323519817784782`\[InvisibleSpace]"  Period of \
Rabi-oscillation: "\[InvisibleSpace]60.862820221018666`\),
      SequenceForm[ 
      "Rabi frequency: ", 0.10323519817784782, 
        "  Period of Rabi-oscillation: ", 60.862820221018666],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Paramter Dependence", "Section"],

Cell["\<\
We want to observe the effect of a variation in \[Omega]1 and \
\[Omega] on the Rabi frequency and the amplitude.\
\>", "Text"],

Cell[BoxData[
    \(\[Omega]1list = {0.05, 0.1, 0.2, 0.3}; \[Omega]list = {0.8, 0.9, 0.95, 
        0.99, 1, 1.01, 1.05, 1.1, 1.2}; 
    colldata = 
      Table[Table[{0, 0, 0, 
            0\ }, {Length[\[Omega]1list]}], {Length[\[Omega]list]}];\)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(imax = Length[\[Omega]list]; 
    jmax = Length[\[Omega]1list];\), "\[IndentingNewLine]", 
    \(\(Do[\(Do[\[IndentingNewLine]numsol[
              1, \[Omega]1list[\([j]\)], \[Omega]list[\([i]\)]]; \
\[IndentingNewLine]numfourier[pup, tmax]; \[IndentingNewLine]cosfit[pup, 
              meanpop, 1 - meanpop, 
              n0]; \[IndentingNewLine]\[Omega]R = \[Omega]est\ n1 /. 
                fitres; \[IndentingNewLine]ampR = 
              amp1 /. fitres; \[IndentingNewLine] (*\(Print["\<\[Omega]1= \
\>", \[Omega]1list[\([j]\)], "\< \[RawEscape]\[Omega]= \>", \
\[Omega]list[\([i]\)], \*"\"\<    \!\(\[Omega]\_R\)= \>\"", \[Omega]R, "\<  \
Amplitude: \>", ampR];\)*) \[IndentingNewLine]colldata[\([i, 
                  j]\)] = {\[Omega]1list[\([j]\)], \[Omega]list[\([i]\)], \
\[Omega]R, ampR};\[IndentingNewLine], {j, 1, 
              jmax}];\)\[IndentingNewLine], {i, 1, imax}];\)\)}], "Input"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(imax\)\" is similar to \
existing symbols \!\({lmax, nmax, tmax}\)."\)], "Message"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(jmax\)\" is similar to \
existing symbols \!\({imax, lmax, nmax, tmax}\)."\)], "Message"]
}, Open  ]],

Cell[TextData[{
  "We plot the amplidtude of the Rabi oscillation as a function of the \
frequency of the perturbation for several choices of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(plAmpl = 
        MultipleListPlot[colldata[\([All, 4, {2, 4}]\)], 
          colldata[\([All, 3, {2, 4}]\)], colldata[\([All, 2, {2, 4}]\)], 
          colldata[\([All, 1, {2, 4}]\)], 
          PlotStyle \[Rule] {GrayLevel[0.1], Hue[0.3], Hue[0.6], Hue[1]}, 
          SymbolStyle \[Rule] {GrayLevel[0.1], Hue[0.3], Hue[0.6], Hue[1]}, 
          PlotJoined \[Rule] True, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[{plAmpl, 
          Graphics[{\[IndentingNewLine]Text[
                ToString[\ \[Omega]1list[\([4]\)], 
                  StandardForm], {1.025\ Last[\[Omega]list], 
                  colldata[\([imax, 4, 4\ ]\)]}], \ 
              Text[ToString[\[Omega]1list[\([3]\)], 
                  StandardForm], {0.975\ First[\[Omega]list], 
                  colldata[\([imax, 3, 4\ ]\)]}]\ , \[IndentingNewLine]Text[
                ToString[\[Omega]1list[\([2]\)], 
                  StandardForm], {1.025\ Last[\[Omega]list], 
                  colldata[\([imax, 2, 4\ ]\)]}], \ 
              Text[ToString[\[Omega]1list[\([1]\)], 
                  StandardForm], {0.975\ First[\[Omega]list], 
                  colldata[\([imax, 1, 4\ ]\)]}]\[IndentingNewLine]}\ ]}, 
        AxesLabel \[Rule] {\*"\"\<\[Omega]/\!\(\[Omega]\_0\)\>\"", "\<\>"}, 
        PlotLabel -> "\<Amplitude of oscillation\>", 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.62698 2.1164 0.0147151 1.17736 [
[.06614 .00222 -9 -9 ]
[.06614 .00222 9 0 ]
[.27778 .00222 -9 -9 ]
[.27778 .00222 9 0 ]
[.70106 .00222 -9 -9 ]
[.70106 .00222 9 0 ]
[.9127 .00222 -9 -9 ]
[.9127 .00222 9 0 ]
[1.025 .01472 0 -4.90625 ]
[1.025 .01472 10 4.90625 ]
[.47692 .13245 -18 -4.5 ]
[.47692 .13245 0 4.5 ]
[.47692 .25019 -18 -4.5 ]
[.47692 .25019 0 4.5 ]
[.47692 .36792 -18 -4.5 ]
[.47692 .36792 0 4.5 ]
[.47692 .48566 -18 -4.5 ]
[.47692 .48566 0 4.5 ]
[.47692 .6034 -18 -4.5 ]
[.47692 .6034 0 4.5 ]
[.5 .63053 -74 0 ]
[.5 .63053 74 10.125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06614 .01472 m
.06614 .02097 L
s
[(0.8)] .06614 .00222 0 1 Mshowa
.27778 .01472 m
.27778 .02097 L
s
[(0.9)] .27778 .00222 0 1 Mshowa
.70106 .01472 m
.70106 .02097 L
s
[(1.1)] .70106 .00222 0 1 Mshowa
.9127 .01472 m
.9127 .02097 L
s
[(1.2)] .9127 .00222 0 1 Mshowa
.125 Mabswid
.10847 .01472 m
.10847 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.19312 .01472 m
.19312 .01847 L
s
.23545 .01472 m
.23545 .01847 L
s
.32011 .01472 m
.32011 .01847 L
s
.36243 .01472 m
.36243 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.44709 .01472 m
.44709 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.57407 .01472 m
.57407 .01847 L
s
.6164 .01472 m
.6164 .01847 L
s
.65873 .01472 m
.65873 .01847 L
s
.74339 .01472 m
.74339 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.82804 .01472 m
.82804 .01847 L
s
.87037 .01472 m
.87037 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.95503 .01472 m
.95503 .01847 L
s
.99735 .01472 m
.99735 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.48942 .13245 m
.49567 .13245 L
s
[(0.1)] .47692 .13245 1 0 Mshowa
.48942 .25019 m
.49567 .25019 L
s
[(0.2)] .47692 .25019 1 0 Mshowa
.48942 .36792 m
.49567 .36792 L
s
[(0.3)] .47692 .36792 1 0 Mshowa
.48942 .48566 m
.49567 .48566 L
s
[(0.4)] .47692 .48566 1 0 Mshowa
.48942 .6034 m
.49567 .6034 L
s
[(0.5)] .47692 .6034 1 0 Mshowa
.125 Mabswid
.48942 .03826 m
.49317 .03826 L
s
.48942 .06181 m
.49317 .06181 L
s
.48942 .08536 m
.49317 .08536 L
s
.48942 .1089 m
.49317 .1089 L
s
.48942 .156 m
.49317 .156 L
s
.48942 .17955 m
.49317 .17955 L
s
.48942 .20309 m
.49317 .20309 L
s
.48942 .22664 m
.49317 .22664 L
s
.48942 .27373 m
.49317 .27373 L
s
.48942 .29728 m
.49317 .29728 L
s
.48942 .32083 m
.49317 .32083 L
s
.48942 .34438 m
.49317 .34438 L
s
.48942 .39147 m
.49317 .39147 L
s
.48942 .41502 m
.49317 .41502 L
s
.48942 .43857 m
.49317 .43857 L
s
.48942 .46211 m
.49317 .46211 L
s
.48942 .50921 m
.49317 .50921 L
s
.48942 .53275 m
.49317 .53275 L
s
.48942 .5563 m
.49317 .5563 L
s
.48942 .57985 m
.49317 .57985 L
s
.25 Mabswid
.48942 0 m
.48942 .61803 L
s
gsave
.5 .63053 -135 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Amplitude) show
123.000 11.562 moveto
(of) show
141.000 11.562 moveto
(oscillation) show
207.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.1 g
.001 w
.06614 .23961 m
.27778 .42641 L
.3836 .54326 L
.46825 .5983 L
.48942 .6009 L
.51058 .59832 L
.59524 .54124 L
.70106 .41427 L
.9127 .21286 L
s
.0001 w
.06614 .23961 -1.875 0 Mabsadd m
.06614 .23961 0 2.5 Mabsadd L
.06614 .23961 1.875 0 Mabsadd L
.06614 .23961 0 -2.5 Mabsadd L
.06614 .23961 -1.875 0 Mabsadd L closepath F
.27778 .42641 -1.875 0 Mabsadd m
.27778 .42641 0 2.5 Mabsadd L
.27778 .42641 1.875 0 Mabsadd L
.27778 .42641 0 -2.5 Mabsadd L
.27778 .42641 -1.875 0 Mabsadd L closepath F
.3836 .54326 -1.875 0 Mabsadd m
.3836 .54326 0 2.5 Mabsadd L
.3836 .54326 1.875 0 Mabsadd L
.3836 .54326 0 -2.5 Mabsadd L
.3836 .54326 -1.875 0 Mabsadd L closepath F
.46825 .5983 -1.875 0 Mabsadd m
.46825 .5983 0 2.5 Mabsadd L
.46825 .5983 1.875 0 Mabsadd L
.46825 .5983 0 -2.5 Mabsadd L
.46825 .5983 -1.875 0 Mabsadd L closepath F
.48942 .6009 -1.875 0 Mabsadd m
.48942 .6009 0 2.5 Mabsadd L
.48942 .6009 1.875 0 Mabsadd L
.48942 .6009 0 -2.5 Mabsadd L
.48942 .6009 -1.875 0 Mabsadd L closepath F
.51058 .59832 -1.875 0 Mabsadd m
.51058 .59832 0 2.5 Mabsadd L
.51058 .59832 1.875 0 Mabsadd L
.51058 .59832 0 -2.5 Mabsadd L
.51058 .59832 -1.875 0 Mabsadd L closepath F
.59524 .54124 -1.875 0 Mabsadd m
.59524 .54124 0 2.5 Mabsadd L
.59524 .54124 1.875 0 Mabsadd L
.59524 .54124 0 -2.5 Mabsadd L
.59524 .54124 -1.875 0 Mabsadd L closepath F
.70106 .41427 -1.875 0 Mabsadd m
.70106 .41427 0 2.5 Mabsadd L
.70106 .41427 1.875 0 Mabsadd L
.70106 .41427 0 -2.5 Mabsadd L
.70106 .41427 -1.875 0 Mabsadd L closepath F
.9127 .21286 -1.875 0 Mabsadd m
.9127 .21286 0 2.5 Mabsadd L
.9127 .21286 1.875 0 Mabsadd L
.9127 .21286 0 -2.5 Mabsadd L
.9127 .21286 -1.875 0 Mabsadd L closepath F
.2 1 0 r
.001 w
.06614 .1423 m
.27778 .31578 L
.3836 .48719 L
.46825 .59649 L
.48942 .60229 L
.51058 .59645 L
.59524 .48257 L
.70106 .30111 L
.9127 .12364 L
s
.0001 w
.06614 .1423 0 2.5 Mabsadd m
.06614 .1423 -0.56518 .7779 Mabsadd L
.06614 .1423 -2.37764 .77254 Mabsadd L
.06614 .1423 -0.91448 -0.29713 Mabsadd L
.06614 .1423 -1.46946 -2.02254 Mabsadd L
.06614 .1423 0 -0.96154 Mabsadd L
.06614 .1423 1.46946 -2.02254 Mabsadd L
.06614 .1423 .91448 -0.29713 Mabsadd L
.06614 .1423 2.37764 .77254 Mabsadd L
.06614 .1423 .56518 .7779 Mabsadd L
.06614 .1423 0 2.5 Mabsadd L closepath F
.27778 .31578 0 2.5 Mabsadd m
.27778 .31578 -0.56518 .7779 Mabsadd L
.27778 .31578 -2.37764 .77254 Mabsadd L
.27778 .31578 -0.91448 -0.29713 Mabsadd L
.27778 .31578 -1.46946 -2.02254 Mabsadd L
.27778 .31578 0 -0.96154 Mabsadd L
.27778 .31578 1.46946 -2.02254 Mabsadd L
.27778 .31578 .91448 -0.29713 Mabsadd L
.27778 .31578 2.37764 .77254 Mabsadd L
.27778 .31578 .56518 .7779 Mabsadd L
.27778 .31578 0 2.5 Mabsadd L closepath F
.3836 .48719 0 2.5 Mabsadd m
.3836 .48719 -0.56518 .7779 Mabsadd L
.3836 .48719 -2.37764 .77254 Mabsadd L
.3836 .48719 -0.91448 -0.29713 Mabsadd L
.3836 .48719 -1.46946 -2.02254 Mabsadd L
.3836 .48719 0 -0.96154 Mabsadd L
.3836 .48719 1.46946 -2.02254 Mabsadd L
.3836 .48719 .91448 -0.29713 Mabsadd L
.3836 .48719 2.37764 .77254 Mabsadd L
.3836 .48719 .56518 .7779 Mabsadd L
.3836 .48719 0 2.5 Mabsadd L closepath F
.46825 .59649 0 2.5 Mabsadd m
.46825 .59649 -0.56518 .7779 Mabsadd L
.46825 .59649 -2.37764 .77254 Mabsadd L
.46825 .59649 -0.91448 -0.29713 Mabsadd L
.46825 .59649 -1.46946 -2.02254 Mabsadd L
.46825 .59649 0 -0.96154 Mabsadd L
.46825 .59649 1.46946 -2.02254 Mabsadd L
.46825 .59649 .91448 -0.29713 Mabsadd L
.46825 .59649 2.37764 .77254 Mabsadd L
.46825 .59649 .56518 .7779 Mabsadd L
.46825 .59649 0 2.5 Mabsadd L closepath F
.48942 .60229 0 2.5 Mabsadd m
.48942 .60229 -0.56518 .7779 Mabsadd L
.48942 .60229 -2.37764 .77254 Mabsadd L
.48942 .60229 -0.91448 -0.29713 Mabsadd L
.48942 .60229 -1.46946 -2.02254 Mabsadd L
.48942 .60229 0 -0.96154 Mabsadd L
.48942 .60229 1.46946 -2.02254 Mabsadd L
.48942 .60229 .91448 -0.29713 Mabsadd L
.48942 .60229 2.37764 .77254 Mabsadd L
.48942 .60229 .56518 .7779 Mabsadd L
.48942 .60229 0 2.5 Mabsadd L closepath F
.51058 .59645 0 2.5 Mabsadd m
.51058 .59645 -0.56518 .7779 Mabsadd L
.51058 .59645 -2.37764 .77254 Mabsadd L
.51058 .59645 -0.91448 -0.29713 Mabsadd L
.51058 .59645 -1.46946 -2.02254 Mabsadd L
.51058 .59645 0 -0.96154 Mabsadd L
.51058 .59645 1.46946 -2.02254 Mabsadd L
.51058 .59645 .91448 -0.29713 Mabsadd L
.51058 .59645 2.37764 .77254 Mabsadd L
.51058 .59645 .56518 .7779 Mabsadd L
.51058 .59645 0 2.5 Mabsadd L closepath F
.59524 .48257 0 2.5 Mabsadd m
.59524 .48257 -0.56518 .7779 Mabsadd L
.59524 .48257 -2.37764 .77254 Mabsadd L
.59524 .48257 -0.91448 -0.29713 Mabsadd L
.59524 .48257 -1.46946 -2.02254 Mabsadd L
.59524 .48257 0 -0.96154 Mabsadd L
.59524 .48257 1.46946 -2.02254 Mabsadd L
.59524 .48257 .91448 -0.29713 Mabsadd L
.59524 .48257 2.37764 .77254 Mabsadd L
.59524 .48257 .56518 .7779 Mabsadd L
.59524 .48257 0 2.5 Mabsadd L closepath F
.70106 .30111 0 2.5 Mabsadd m
.70106 .30111 -0.56518 .7779 Mabsadd L
.70106 .30111 -2.37764 .77254 Mabsadd L
.70106 .30111 -0.91448 -0.29713 Mabsadd L
.70106 .30111 -1.46946 -2.02254 Mabsadd L
.70106 .30111 0 -0.96154 Mabsadd L
.70106 .30111 1.46946 -2.02254 Mabsadd L
.70106 .30111 .91448 -0.29713 Mabsadd L
.70106 .30111 2.37764 .77254 Mabsadd L
.70106 .30111 .56518 .7779 Mabsadd L
.70106 .30111 0 2.5 Mabsadd L closepath F
.9127 .12364 0 2.5 Mabsadd m
.9127 .12364 -0.56518 .7779 Mabsadd L
.9127 .12364 -2.37764 .77254 Mabsadd L
.9127 .12364 -0.91448 -0.29713 Mabsadd L
.9127 .12364 -1.46946 -2.02254 Mabsadd L
.9127 .12364 0 -0.96154 Mabsadd L
.9127 .12364 1.46946 -2.02254 Mabsadd L
.9127 .12364 .91448 -0.29713 Mabsadd L
.9127 .12364 2.37764 .77254 Mabsadd L
.9127 .12364 .56518 .7779 Mabsadd L
.9127 .12364 0 2.5 Mabsadd L closepath F
0 .4 1 r
.001 w
.06614 .05293 m
.27778 .13727 L
.3836 .31259 L
.46825 .58058 L
.48942 .60312 L
.51058 .58036 L
.59524 .30521 L
.70106 .1279 L
.9127 .04636 L
s
.0001 w
.06614 .05293 -2.5 2.5 Mabsadd m
.06614 .05293 2.5 2.5 Mabsadd L
.06614 .05293 2.5 -2.5 Mabsadd L
.06614 .05293 -2.5 -2.5 Mabsadd L
.06614 .05293 -2.5 2.5 Mabsadd L closepath F
.27778 .13727 -2.5 2.5 Mabsadd m
.27778 .13727 2.5 2.5 Mabsadd L
.27778 .13727 2.5 -2.5 Mabsadd L
.27778 .13727 -2.5 -2.5 Mabsadd L
.27778 .13727 -2.5 2.5 Mabsadd L closepath F
.3836 .31259 -2.5 2.5 Mabsadd m
.3836 .31259 2.5 2.5 Mabsadd L
.3836 .31259 2.5 -2.5 Mabsadd L
.3836 .31259 -2.5 -2.5 Mabsadd L
.3836 .31259 -2.5 2.5 Mabsadd L closepath F
.46825 .58058 -2.5 2.5 Mabsadd m
.46825 .58058 2.5 2.5 Mabsadd L
.46825 .58058 2.5 -2.5 Mabsadd L
.46825 .58058 -2.5 -2.5 Mabsadd L
.46825 .58058 -2.5 2.5 Mabsadd L closepath F
.48942 .60312 -2.5 2.5 Mabsadd m
.48942 .60312 2.5 2.5 Mabsadd L
.48942 .60312 2.5 -2.5 Mabsadd L
.48942 .60312 -2.5 -2.5 Mabsadd L
.48942 .60312 -2.5 2.5 Mabsadd L closepath F
.51058 .58036 -2.5 2.5 Mabsadd m
.51058 .58036 2.5 2.5 Mabsadd L
.51058 .58036 2.5 -2.5 Mabsadd L
.51058 .58036 -2.5 -2.5 Mabsadd L
.51058 .58036 -2.5 2.5 Mabsadd L closepath F
.59524 .30521 -2.5 2.5 Mabsadd m
.59524 .30521 2.5 2.5 Mabsadd L
.59524 .30521 2.5 -2.5 Mabsadd L
.59524 .30521 -2.5 -2.5 Mabsadd L
.59524 .30521 -2.5 2.5 Mabsadd L closepath F
.70106 .1279 -2.5 2.5 Mabsadd m
.70106 .1279 2.5 2.5 Mabsadd L
.70106 .1279 2.5 -2.5 Mabsadd L
.70106 .1279 -2.5 -2.5 Mabsadd L
.70106 .1279 -2.5 2.5 Mabsadd L closepath F
.9127 .04636 -2.5 2.5 Mabsadd m
.9127 .04636 2.5 2.5 Mabsadd L
.9127 .04636 2.5 -2.5 Mabsadd L
.9127 .04636 -2.5 -2.5 Mabsadd L
.9127 .04636 -2.5 2.5 Mabsadd L closepath F
1 0 0 r
.001 w
.06614 .02476 m
.27778 .05105 L
.3836 .13483 L
.46825 .52248 L
.48942 .60332 L
.51058 .52178 L
.59524 .13013 L
.70106 .04779 L
.9127 .02296 L
s
.0001 w
.06614 .02476 0 2.5 Mabsadd m
.06614 .02476 -2.165 -1.25 Mabsadd L
.06614 .02476 2.165 -1.25 Mabsadd L
.06614 .02476 0 2.5 Mabsadd L closepath F
.27778 .05105 0 2.5 Mabsadd m
.27778 .05105 -2.165 -1.25 Mabsadd L
.27778 .05105 2.165 -1.25 Mabsadd L
.27778 .05105 0 2.5 Mabsadd L closepath F
.3836 .13483 0 2.5 Mabsadd m
.3836 .13483 -2.165 -1.25 Mabsadd L
.3836 .13483 2.165 -1.25 Mabsadd L
.3836 .13483 0 2.5 Mabsadd L closepath F
.46825 .52248 0 2.5 Mabsadd m
.46825 .52248 -2.165 -1.25 Mabsadd L
.46825 .52248 2.165 -1.25 Mabsadd L
.46825 .52248 0 2.5 Mabsadd L closepath F
.48942 .60332 0 2.5 Mabsadd m
.48942 .60332 -2.165 -1.25 Mabsadd L
.48942 .60332 2.165 -1.25 Mabsadd L
.48942 .60332 0 2.5 Mabsadd L closepath F
.51058 .52178 0 2.5 Mabsadd m
.51058 .52178 -2.165 -1.25 Mabsadd L
.51058 .52178 2.165 -1.25 Mabsadd L
.51058 .52178 0 2.5 Mabsadd L closepath F
.59524 .13013 0 2.5 Mabsadd m
.59524 .13013 -2.165 -1.25 Mabsadd L
.59524 .13013 2.165 -1.25 Mabsadd L
.59524 .13013 0 2.5 Mabsadd L closepath F
.70106 .04779 0 2.5 Mabsadd m
.70106 .04779 -2.165 -1.25 Mabsadd L
.70106 .04779 2.165 -1.25 Mabsadd L
.70106 .04779 0 2.5 Mabsadd L closepath F
.9127 .02296 0 2.5 Mabsadd m
.9127 .02296 -2.165 -1.25 Mabsadd L
.9127 .02296 2.165 -1.25 Mabsadd L
.9127 .02296 0 2.5 Mabsadd L closepath F
0 g
gsave
.97619 .21286 -75 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3`) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02381 .12364 -75 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2`) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .04636 -75 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1`) show
87.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.02381 .02296 -78 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05`) show
93.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3Vc81Y
0>K<P0005`3Vc803000000D0i/b00P0000050>K<P0@00000<03Vc803000000D0i/b00P0000040>K<
P0<00000LP3Vc806000000@0i/b00P0000040>K<P0H00000;@3Vc806000000@0i/b00P0000040>K<
P0H00000<P3Vc80001H0i/b000@000000>K<P03Vc80000001@3Vc802000000@0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P00/0>K<P0040000003Vc800i/b0000000D0i/b00P000007
0>K<P0030000003Vc800i/b00780i/b000<000000>K<P03Vc800103Vc802000000L0i/b000<00000
0>K<P03Vc800<03Vc8000`000000i/b00>K<P0040>K<P08000001@3Vc8001@000000i/b00>K<P03V
c80000000380i/b0000E0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800203Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b002/0i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P00<0>K<P0030000003Vc800i/b00740i/b000<000000>K<P03Vc8003@3Vc800
0`000000i/b00>K<P00`0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc800<`3Vc800
01D0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b0
00800000;@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000T0i/b01000001c0>K<
P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800<03Vc8000`000000i/b00>K<P00=0>K<
P0800000<`3Vc80001D0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0090>K<P0@0
0000;P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000P0i/b000D000000>K<P03V
c800i/b00000001c0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800<03Vc8000`00
0000i/b00>K<P00>0>K<P0800000<P3Vc80001D0i/b000<000000>K<P03Vc8000P3Vc8000`000000
i/b00>K<P0080>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800:`3Vc8000`000000
i/b00>K<P0020>K<P0030000003Vc800i/b000P0i/b000D000000>K<P03Vc800i/b00000001c0>K<
P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800<03Vc8000`000000i/b00>K<P00?0>K<
P0030000003Vc800i/b00300i/b0000F0>K<P0040000003Vc800i/b0000000/0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P00/0>K<P0040000003Vc800i/b0000000/0i/b000D00000
0>K<P03Vc800i/b00000001c0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800<03V
c8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800<03V
c80001H0i/b01000000<0>K<P0@00000;`3Vc804000000`0i/b00`00001b0>K<P0<000003@3Vc803
00000300i/b00`00000<0>K<P0D00000<`3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000:D0i/b0
00<000000>K<P03Vc800`03Vc8000:D0i/b000<000000>K<P03Vc800`03Vc8000:D0i/b000<00000
0>K<P03Vc800Z@3Vc80500000180i/b0002U0>K<P0030000003Vc800i/b00:P0i/b000@000000>K<
P03Vc80000000P3Vc8000`000000i/b00>K<P00?0>K<P000303Vc83o000003`000002@3Vc8001000
0000i/b00>K<P00000020>K<P0030000003Vc800i/b000l0i/b000030>K<P0<000001@3Vc8020000
00H0i/b00`0000040>K<P0@000000P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b0
00X0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b0
00X0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b0
00X0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b0
00/0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b0
00/0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b0
00/0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b0
00/0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b0
00P0i/b000@000000>K<P03Vc80000000P3Vc8000`000000i/b00>K<P00?0>K<P0000P3Vc8001000
0000i/b00>K<P00000050>K<P08000001@3Vc80010000000i/b00>K<P00000080>K<P0030000003V
c80000000480i/b000<000000>K<P03Vc800?`3Vc8000`000000i/b00>K<P0100>K<P0030000003V
c800i/b003h0i/b0103o000T0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8003`3V
c80000030>K<P0000000i/b000<0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b000D0i/b000<000000?l0003o00000`3o00210>K<P0030000003Vc800
i/b007l0i/b01P3o000U0>K<P0050000003Vc800i/b00>K<P00000004@3Vc80000030>K<P0000000
i/b000<0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800
i/b000D0i/b000@000000?l0003o0000o`000P3Vc8080?l007T0i/b000<000000>K<P03Vc800M`3V
c8080?l000<0i/b00P3o000l0>K<P00000<0i/b00000003Vc8000`3Vc8000`000000i/b00>K<P008
0>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc800i/b0100000020>K<P080o`002P3V
c8070?l00780i/b000<000000>K<P03Vc800K`3Vc8080?l000`0i/b000<0o`000>K<P03Vc800>P3V
c80000030>K<P0000000i/b000<0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P002
0>K<P0050000003Vc800i/b00>K<P00000001@3Vc8000`3o0000i/b00>K<P00@0>K<P0P0o`00JP3V
c8000`000000i/b00>K<P01V0>K<P0T0o`00D@3Vc8000080i/b000@000000>K<P03Vc8000000303V
c80010000000i/b00>K<P00000040>K<P0030000003Vc800i/b001h0i/b01`3o001S0>K<P0030000
003Vc800i/b005h0i/b0203o001J0>K<P0000P3Vc804000000`0i/b0100000040>K<P0@000001P3V
c8000`000000i/b00>K<P00K0>K<P0L0o`00G03Vc803000005D0i/b02@3o000Q0>K<P0L006Ko103V
c803000000D0i/b00P0000040>K<P0H000008P3Vc80004T0i/b0203o001D0>K<P0030000003Vc800
i/b004d0i/b0203o000Z0>K<P0L006Ko0`3Vc80010000000i/b00>K<P00000050>K<P08000001`3V
c8000`000000i/b00>K<P00R0>K<P0007@3Vc807001Vobd0i/b01`3o001=0>K<P0030000003Vc800
i/b003h0i/b01@3o00020>K<P0P0o`00<P3Vc807001Vo`80i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P00;0>K<P0030000003Vc800i/b00280i/b0000M0>K<P0L006Ko=03Vc8080?l0
00030>K<P03o0000o`0000<0o`00?`3Vc8000`000000i/b00>K<P00o0>K<P0H0o`00>P3Vc807001V
o`80i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b0
0280i/b0000M0>K<P0L006Ko?03Vc8050?l00400i/b000<000000>K<P03Vc800?`3Vc8030?l003/0
i/b02@00I_l20>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3Vc8000`000000
i/b00>K<P00R0>K<P0007@3Vc807001Voch0i/b00`3o00100>K<P0030000003Vc800i/b003d0i/b0
0P3o00000`3Vc800o`000>K<P00h0>K<P0<006Ko0P3Vc807001Vo`80i/b000<000000>K<P03Vc800
0P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b00280i/b0000M0>K<P0X006Ko?03V
c800103o0000i/b00?l0003o000n0>K<P0030000003Vc800i/b003`0i/b000<0o`000>K<P03Vc800
>@3Vc802001Vo`l0i/b000@000000>K<P03Vc80000003P3Vc8000`000000i/b00>K<P00R0>K<P000
7@3Vc807001Vo`<0i/b00P00I_ln0>K<P0030?l0003Vc800i/b003/0i/b00`00000k0>K<P0030?l0
003Vc800i/b003L0i/b00`00I_lA0>K<P0@00000303Vc803000000L0i/b000<000000>K<P03Vc800
6P3Vc80002T0i/b00`00I_ll0>K<P0030?l0003Vc800i/b003X0i/b000<000000>K<P03Vc800>P3V
c8000`3o0000i/b00>K<P00f0>K<P08006KoB`3Vc80002`0i/b00P00I_lk0>K<P0030?l0003Vc800
i/b003T0i/b000<000000>K<P03Vc800>03Vc8020?l003H0i/b00`00I_m=0>K<P000;P3Vc803001V
ocT0i/b00P3o000i0>K<P0030000003Vc800i/b003L0i/b000<0o`000>K<P03Vc800=03Vc802001V
oe00i/b0000a0>K<P08006Ko>@3Vc8000`3o0000i/b00>K<P00f0>K<P0030000003Vc800i/b003H0
i/b000<0o`000>K<P03Vc800<P3Vc803001Voe80i/b0000c0>K<P0<006Ko=`3Vc8000`3o0000i/b0
0>K<P00e0>K<P0030000003Vc800i/b003@0i/b00P3o000b0>K<P0<006KoE@3Vc80003H0i/b00P00
I_lf0>K<P080o`00=@3Vc8000`000000i/b00>K<P00c0>K<P0030?l0003Vc800i/b00300i/b00P00
I_mH0>K<P000>03Vc803001VocD0i/b000<0o`000>K<P03Vc800<P3Vc8000`000000i/b00>K<P00b
0>K<P0030?l0003Vc800i/b002h0i/b00`00I_mJ0>K<P000>`3Vc802001Voc@0i/b000<0o`000>K<
P03Vc800<@3Vc80300000340i/b000<0o`000>K<P03Vc800;@3Vc802001Voed0i/b0000m0>K<P0<0
06Ko<P3Vc8000`3o0000i/b00>K<P00`0>K<P0030000003Vc800i/b002l0i/b00P3o000]0>K<P0<0
06KoG`3Vc8000400i/b00P00I_la0>K<P080o`00<03Vc8000`000000i/b00>K<P00^0>K<P0030?l0
003Vc800i/b002/0i/b00P00I_mR0>K<P000@P3Vc802001Voc40i/b000<0o`000>K<P03Vc800;@3V
c8000`000000i/b00>K<P00]0>K<P0030?l0003Vc800i/b002T0i/b00`00I_mT0>K<P000A03Vc803
001Vobl0i/b000<0o`000>K<P03Vc800;03Vc8000`000000i/b00>K<P00/0>K<P0030?l0003Vc800
i/b002L0i/b00`00I_mW0>K<P000A`3Vc802001Vobh0i/b000<0o`000>K<P03Vc800:`3Vc8000`00
0000i/b00>K<P00Z0>K<P080o`00:03Vc802001VofX0i/b000190>K<P0<006Ko;03Vc8020?l002/0
i/b000<000000>K<P03Vc800:@3Vc8000`3o0000i/b00>K<P00U0>K<P0<006KoK03Vc80004`0i/b0
0P00I_l/0>K<P0030?l0003Vc800i/b002P0i/b00`00000X0>K<P0030?l0003Vc800i/b002@0i/b0
0P00I_m_0>K<P000CP3Vc803001VobX0i/b000<0o`000>K<P03Vc8009`3Vc8000`000000i/b00>K<
P00V0>K<P080o`00903Vc803001Vog40i/b0001A0>K<P08006Ko:@3Vc8020?l002L0i/b000<00000
0>K<P03Vc8009@3Vc8000`3o0000i/b00>K<P00R0>K<P08006KoM03Vc80000L0i/b00`0000050>K<
P0800000103Vc806000003P0i/b00`00I_lX0>K<P0030?l0003Vc800i/b002@0i/b000<000000>K<
P03Vc800903Vc8000`3o0000i/b00>K<P00P0>K<P0<006Ko=`3Vc80303?o03`0i/b000060>K<P004
0000003Vc800i/b0000000D0i/b00P0000050>K<P0050000003Vc800i/b00>K<P0000000>`3Vc802
001VobL0i/b000<0o`000>K<P03Vc8008`3Vc8000`000000i/b00>K<P00S0>K<P0030?l0003Vc800
i/b001L0i/b01P00I_l0103Vc80006Ko001Vo`00I_lj0>K<P0<0<ol0?03Vc80000D0i/b000<00000
0>K<P03Vc8000P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b003h0i/b00`00I_lU
0>K<P0030?l0003Vc800i/b000X0i/b00`0000050>K<P0800000103Vc806000000@0i/b000<00000
0>K<P03Vc8008@3Vc8020?l001X0i/b01`00I_ll0>K<P0D0<ol0>`3Vc80000D0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P00;0>K<P0800000@@3Vc802001Vob@0i/b00P3o00090>K<
P0040000003Vc800i/b0000000D0i/b00P0000070>K<P0030000003Vc800i/b000@0i/b000<00000
0>K<P03Vc8007@3Vc8040?l001`0i/b01P00I_lo0>K<P00303?o003Vc800i/b003/0i/b000050>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800303Vc80200000480i/b02@00I_lM0>K<
P0@0o`00103Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000/0i/b000<000000>K<
P03Vc800103Vc803000001h0i/b00`3o000L0>K<P0H006Ko?@3Vc80203?o03h0i/b000050>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P0130>K<P0H0
06Ko7@3Vc8030?l000D0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00;0>K<P003
0000003Vc800i/b000@0i/b000<000000>K<P03Vc8007P3Vc8020?l001d0i/b01P00I_ll0>K<P003
03?o003Vc800i/b003h0i/b000060>K<P0040000003Vc800i/b0000000/0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P0020>K<P0<0<ol0?P3Vc806001Voah0i/b00P3o00050>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P0040>K<P003
0000003Vc800i/b001l0i/b000<0o`000>K<P03Vc8006`3Vc806001Voc/0i/b000<0<ol00>K<P03V
c800?`3Vc80000H0i/b01000000;0>K<P0D000001@3Vc8000`0co`00000003?o000n0>K<P0H006Ko
7P3Vc8000`3o0000i/b00>K<P0040>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800
2`3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b001h0i/b000<0o`000>K<P03Vc800
7@3Vc8000`00I_l0i/b00>K<P00l0>K<P00303?o003Vc800i/b00400i/b0000M0>K<P0H0<ol0?@3V
c806001Voal0i/b000<0o`000>K<P03Vc800103Vc80010000000i/b00>K<P000000>0>K<P0030000
003Vc800i/b000@0i/b000<000000>K<P03Vc8007P3Vc8000`3o0000i/b00>K<P00L0>K<P003001V
o`3Vc800i/b003`0i/b000<0<ol00>K<P03Vc800@@3Vc8000200i/b000@0<ol00>K<P00co`00<ol0
?03Vc806001Voal0i/b000<0o`000>K<P03Vc800103Vc804000000`0i/b00`0000060>K<P0030000
003Vc800i/b001h0i/b000<0o`000>K<P03Vc8006`3Vc8000`00I_l0i/b00>K<P00k0>K<P080<ol0
A03Vc8000200i/b000D0<ol00>K<P03Vc800i/b003?o00100>K<P003001Vo`3Vc800i/b001d0i/b0
00<0o`000>K<P03Vc8007@3Vc8000`000000i/b00>K<P00N0>K<P0030?l0003Vc800i/b001/0i/b0
00<006Ko0>K<P03Vc800>P3Vc8000`0co`00i/b00>K<P0140>K<P0009@3Vc8000`0co`00i/b00>K<
P00n0>K<P003001Vo`3Vc800i/b001`0i/b000<0o`000>K<P03Vc8007@3Vc8000`000000i/b00>K<
P00M0>K<P0030?l0003Vc800i/b001/0i/b000<006Ko0>K<P03Vc800>P3Vc8000`0co`00i/b00>K<
P0150>K<P0009P3Vc8000`0co`00i/b00>K<P00n0>K<P003001Vo`3Vc800i/b001`0i/b000<0o`00
0>K<P03Vc800703Vc803000001d0i/b000<0o`000>K<P03Vc8006`3Vc8000`00I_l0i/b00>K<P00i
0>K<P00303?o003Vc800i/b004H0i/b0000W0>K<P00303?o003Vc800i/b003d0i/b000<006Ko0>K<
P03Vc800703Vc8000`3o0000i/b00>K<P00L0>K<P0030000003Vc800i/b001d0i/b000<0o`000>K<
P03Vc8006P3Vc8000`00I_l0i/b00>K<P00h0>K<P080<ol0B@3Vc80002P0i/b00P0co`0n0>K<P003
001Vo`3Vc800i/b001/0i/b000<0o`000>K<P03Vc800703Vc8000`000000i/b00>K<P00M0>K<P003
0?l0003Vc800i/b001X0i/b000<006Ko0>K<P03Vc800=`3Vc8000`0co`00i/b00>K<P0190>K<P000
:P3Vc8000`0co`00i/b00>K<P00k0>K<P003001Vo`3Vc800i/b001/0i/b000<0o`000>K<P03Vc800
703Vc8000`000000i/b00>K<P00M0>K<P0030?l0003Vc800i/b001T0i/b000<006Ko0>K<P03Vc800
=`3Vc8000`0co`00i/b00>K<P01:0>K<P000:`3Vc8000`0co`00i/b00>K<P00k0>K<P003001Vo`3V
c800i/b001X0i/b000<0o`000>K<P03Vc800703Vc8000`000000i/b00>K<P00L0>K<P0030?l0003V
c800i/b001T0i/b000<006Ko0>K<P03Vc800=`3Vc8000`0co`00i/b00>K<P01;0>K<P000;03Vc800
0`0co`00i/b00>K<P00k0>K<P003001Vo`3Vc800i/b001X0i/b000<0o`000>K<P03Vc8006`3Vc800
0`000000i/b00>K<P00L0>K<P0030?l0003Vc800i/b001T0i/b000<006Ko0>K<P03Vc800=P3Vc800
0`0co`00i/b00>K<P01<0>K<P000;@3Vc80203?o03/0i/b000<006Ko0>K<P03Vc8006P3Vc8000`3o
0000i/b00>K<P00K0>K<P0030000003Vc800i/b001`0i/b000<0o`000>K<P03Vc800603Vc8000`00
I_l0i/b00>K<P00e0>K<P080<ol0C`3Vc80002l0i/b000<0<ol00>K<P03Vc800>@3Vc8000`00I_l0
i/b00>K<P00I0>K<P0030?l0003Vc800i/b001/0i/b00`00000L0>K<P0030?l0003Vc800i/b001P0
i/b000<006Ko0>K<P03Vc800=03Vc8000`0co`00i/b00>K<P01?0>K<P000<03Vc8000`0co`00i/b0
0>K<P00h0>K<P003001Vo`3Vc800i/b001T0i/b000<0o`000>K<P03Vc8006`3Vc8000`000000i/b0
0>K<P00K0>K<P0030?l0003Vc800i/b001P0i/b000<006Ko0>K<P03Vc800=03Vc8000`0co`00i/b0
0>K<P01@0>K<P000<@3Vc8000`0co`00i/b00>K<P00h0>K<P003001Vo`3Vc800i/b001T0i/b000<0
o`000>K<P03Vc8006P3Vc8000`000000i/b00>K<P00K0>K<P0030?l0003Vc800i/b001L0i/b000<0
06Ko0>K<P03Vc800=03Vc8000`0co`00i/b00>K<P01A0>K<P000<P3Vc8000`0co`00i/b00>K<P00h
0>K<P003001Vo`3Vc800i/b001P0i/b000<0o`000>K<P03Vc8006P3Vc8000`000000i/b00>K<P00K
0>K<P0030?l0003Vc800i/b001L0i/b000<006Ko0>K<P03Vc800<`3Vc8000`0co`00i/b00>K<P01B
0>K<P000<`3Vc80203?o03P0i/b000<006Ko0>K<P03Vc800603Vc8000`3o0000i/b00>K<P00J0>K<
P0030000003Vc800i/b001/0i/b000<0o`000>K<P03Vc8005P3Vc8000`00I_l0i/b00>K<P00b0>K<
P080<ol0E@3Vc80003D0i/b000<0<ol00>K<P03Vc800=P3Vc8000`00I_l0i/b00>K<P00G0>K<P003
0?l0003Vc800i/b001X0i/b000<000000>K<P03Vc8006`3Vc8000`3o0000i/b00>K<P00F0>K<P003
001Vo`3Vc800i/b00340i/b000<0<ol00>K<P03Vc800E@3Vc80003H0i/b000<0<ol00>K<P03Vc800
=@3Vc8000`00I_l0i/b00>K<P00G0>K<P0030?l0003Vc800i/b001X0i/b000<000000>K<P03Vc800
6P3Vc8000`3o0000i/b00>K<P00F0>K<P003001Vo`3Vc800i/b00340i/b000<0<ol00>K<P03Vc800
EP3Vc80003L0i/b000<0<ol00>K<P03Vc800=@3Vc8000`00I_l0i/b00>K<P00G0>K<P0030?l0003V
c800i/b001T0i/b000<000000>K<P03Vc8006P3Vc8000`3o0000i/b00>K<P00E0>K<P003001Vo`3V
c800i/b00340i/b000<0<ol00>K<P03Vc800E`3Vc80003P0i/b000<0<ol00>K<P03Vc800=@3Vc800
0`00I_l0i/b00>K<P00F0>K<P0030?l0003Vc800i/b001T0i/b00`00000J0>K<P0030?l0003Vc800
i/b001D0i/b000<006Ko0>K<P03Vc800;`3Vc80203?o01d0i/b000<06ATI0>K<P03Vc800>P3Vc800
03T0i/b00P0co`0e0>K<P003001Vo`3Vc800i/b001H0i/b000<0o`000>K<P03Vc8006@3Vc8000`00
0000i/b00>K<P00J0>K<P0030?l0003Vc800i/b001@0i/b000<006Ko0>K<P03Vc800;`3Vc8000`0c
o`00i/b00>K<P00L0>K<P0806ATI1P3Vc803000000D0i/b00P0000040>K<P0@00000903Vc80003/0
i/b000<0<ol00>K<P03Vc800<`3Vc8000`00I_l0i/b00>K<P00E0>K<P0030?l0003Vc800i/b001T0
i/b000<000000>K<P03Vc8006P3Vc8000`3o0000i/b00>K<P00D0>K<P003001Vo`3Vc800i/b002h0
i/b000<0<ol00>K<P03Vc800703Vc80401TI6@@0i/b000@000000>K<P03Vc80000001@3Vc8020000
00P0i/b000<000000>K<P03Vc8008@3Vc80003`0i/b000<0<ol00>K<P03Vc800<P3Vc8000`00I_l0
i/b00>K<P00F0>K<P0030?l0003Vc800i/b001P0i/b000<000000>K<P03Vc8006@3Vc8000`3o0000
i/b00>K<P00D0>K<P003001Vo`3Vc800i/b002h0i/b000<0<ol00>K<P03Vc800703Vc80501TI6@<0
i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b00240
i/b0000m0>K<P00303?o003Vc800i/b00380i/b000<006Ko0>K<P03Vc8005@3Vc8000`3o0000i/b0
0>K<P00H0>K<P0030000003Vc800i/b001T0i/b000<0o`000>K<P03Vc800503Vc8000`00I_l0i/b0
0>K<P00]0>K<P00303?o003Vc800i/b001h0i/b0100I6AT30>K<P0030000003Vc800i/b00080i/b0
00<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00Q0>K<P000?P3Vc80203?o03<0i/b000<0
06Ko0>K<P03Vc800503Vc8000`3o0000i/b00>K<P00H0>K<P0030000003Vc800i/b001T0i/b000<0
o`000>K<P03Vc8004`3Vc8000`00I_l0i/b00>K<P00/0>K<P080<ol08@3Vc80301TI6@@0i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00:0>K<P0800000903Vc8000400i/b000<0<ol0
0>K<P03Vc800<03Vc8000`00I_l0i/b00>K<P00D0>K<P0030?l0003Vc800i/b001P0i/b000<00000
0>K<P03Vc8006@3Vc8000`3o0000i/b00>K<P00B0>K<P003001Vo`3Vc800i/b002`0i/b000<0<ol0
0>K<P03Vc800803Vc8000`0I6AT0i/b00>K<P0050>K<P0030000003Vc800i/b00080i/b000<00000
0>K<P03Vc800303Vc8000`000000i/b00>K<P00Q0>K<P000@@3Vc8000`0co`00i/b00>K<P00`0>K<
P003001Vo`3Vc800i/b001<0i/b000<0o`000>K<P03Vc800603Vc803000001P0i/b000<0o`000>K<
P03Vc8004`3Vc8000`00I_l0i/b00>K<P00[0>K<P00303?o003Vc800i/b00200i/b000<06ATI0>K<
P03Vc8001`3Vc80010000000i/b00>K<P000000?0>K<P0030000003Vc800i/b00240i/b000120>K<
P00303?o003Vc800i/b002l0i/b000<006Ko0>K<P03Vc800503Vc8000`3o0000i/b00>K<P00G0>K<
P0030000003Vc800i/b001P0i/b000<0o`000>K<P03Vc8004P3Vc8000`00I_l0i/b00>K<P00[0>K<
P00303?o003Vc800i/b00200i/b000<06ATI0>K<P03Vc800203Vc804000000/0i/b0100000070>K<
P0030000003Vc800i/b001X0i/b0000P0>K<P00301TI6@3Vc800i/b00200i/b000<0<ol00>K<P03V
c800;`3Vc8000`00I_l0i/b00>K<P00C0>K<P0030?l0003Vc800i/b001L0i/b000<000000>K<P03V
c800603Vc8000`3o0000i/b00>K<P00B0>K<P003001Vo`3Vc800i/b002T0i/b00P0co`0R0>K<P003
01TI6@3Vc800i/b00400i/b0000O0>K<P0<06ATI8P3Vc80203?o0300i/b000<006Ko0>K<P03Vc800
4P3Vc8000`3o0000i/b00>K<P00G0>K<P0030000003Vc800i/b001P0i/b000<0o`000>K<P03Vc800
4@3Vc8000`00I_l0i/b00>K<P00Y0>K<P00303?o003Vc800i/b00240i/b000<06ATI0>K<P03Vc800
@@3Vc80001h0i/b01@0I6ATS0>K<P00303?o003Vc800i/b002d0i/b000<006Ko0>K<P03Vc8004P3V
c8000`3o0000i/b00>K<P00G0>K<P0030000003Vc800i/b001P0i/b000<0o`000>K<P03Vc800403V
c8000`00I_l0i/b00>K<P00Y0>K<P00303?o003Vc800i/b00200i/b00P0I6AU40>K<P0007`3Vc803
01TI6BD0i/b000<0<ol00>K<P03Vc800;@3Vc8000`00I_l0i/b00>K<P00B0>K<P0040?l000000000
0000000000D0i/b00P0000040>K<P0H00000103Vc8000`000000i/b00>K<P00G0>K<P0030?l0003V
c800i/b00140i/b000<006Ko0>K<P03Vc800:03Vc8000`0co`00i/b00>K<P00P0>K<P00301TI6@3V
c800i/b004@0i/b0000P0>K<P00301TI6@3Vc8006ATI02D0i/b000<0<ol00>K<P03Vc800;03Vc800
0`00I_l0i/b00>K<P00B0>K<P0040?l0003Vc800i/b0000000D0i/b00P0000050>K<P0050000003V
c800i/b00>K<P0000000103Vc8000`000000i/b00>K<P00G0>K<P0030?l0003Vc800i/b00100i/b0
00<006Ko0>K<P03Vc800:03Vc8000`0co`00i/b00>K<P00P0>K<P00301TI6@3Vc800i/b004D0i/b0
000S0>K<P00301TI6@3Vc800i/b002<0i/b00P0co`0]0>K<P003001Vo`3Vc800i/b00100i/b000<0
00000?l0003Vc8000P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000D0i/b00`00
000G0>K<P0030?l0003Vc800i/b00100i/b000<006Ko0>K<P03Vc8009P3Vc80203?o0280i/b000<0
6ATI0>K<P03Vc800AP3Vc80002@0i/b00P0I6ATU0>K<P00303?o003Vc800i/b002/0i/b000<006Ko
0>K<P03Vc8003`3Vc8000`000000o`000>K<P0020>K<P0030000003Vc800i/b000/0i/b00P000005
0>K<P0030000003Vc800i/b001L0i/b000<0o`000>K<P03Vc8003`3Vc8000`00I_l0i/b00>K<P00V
0>K<P00303?o003Vc800i/b00240i/b000<06ATI0>K<P03Vc800A`3Vc80002H0i/b000<06ATI0>K<
P03Vc8008`3Vc8000`0co`00i/b00>K<P00Z0>K<P003001Vo`3Vc800i/b000l0i/b000<000000?l0
003Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P0800000103Vc8000`000000i/b00>K<P00F0>K<
P0030?l0003Vc800i/b000l0i/b000<006Ko0>K<P03Vc8009P3Vc8000`0co`00i/b00>K<P00Q0>K<
P00301TI6@3Vc800i/b004P0i/b0000W0>K<P00301TI6@3Vc800i/b002<0i/b000<0<ol00>K<P03V
c800:P3Vc8000`00I_l0i/b00>K<P00>0>K<P0030000003Vc800o`000080i/b000<000000>K<P03V
c8003@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001H0i/b000<0o`000>K<P03V
c8003`3Vc8000`00I_l0i/b00>K<P00U0>K<P00303?o003Vc800i/b00240i/b000<06ATI0>K<P03V
c800B@3Vc80002P0i/b000<06ATI0>K<P03Vc8008`3Vc8000`0co`00i/b00>K<P00Y0>K<P003001V
o`3Vc800i/b000l0i/b000@000000?l0003Vc80000002`3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8005P3Vc8000`3o0000i/b00>K<P00>0>K<P003
001Vo`3Vc800i/b002D0i/b000<0<ol00>K<P03Vc8008@3Vc8000`0I6AT0i/b00>K<P01:0>K<P000
:@3Vc8000`0I6AT0i/b00>K<P00S0>K<P080<ol0:P3Vc8000`00I_l0i/b00>K<P00>0>K<P0040000
003o00000000000000/0i/b01@0000050>K<P0030000003Vc800i/b001H0i/b000<0o`000>K<P03V
c8003P3Vc8000`00I_l0i/b00>K<P00S0>K<P080<ol08`3Vc8000`0I6AT0i/b00>K<P01;0>K<P000
:P3Vc8000`0I6AT0i/b00>K<P00T0>K<P00303?o003Vc800i/b002P0i/b000<006Ko0>K<P03Vc800
3P3Vc8000`3o0000i/b00>K<P00E0>K<P0030000003Vc800i/b001H0i/b000<0o`000>K<P03Vc800
3@3Vc8000`00I_l0i/b00>K<P00S0>K<P00303?o003Vc800i/b00280i/b000<06ATI0>K<P03Vc800
C03Vc80002/0i/b000<06ATI0>K<P03Vc800903Vc8000`0co`00i/b00>K<P00W0>K<P003001Vo`3V
c800i/b000l0i/b000<0o`000>K<P03Vc800503Vc8000`000000i/b00>K<P00E0>K<P0030?l0003V
c800i/b000d0i/b000<006Ko0>K<P03Vc8008`3Vc8000`0co`00i/b00>K<P00R0>K<P00301TI6@3V
c800i/b004d0i/b0000/0>K<P0806ATI9@3Vc8000`0co`00i/b00>K<P00W0>K<P003001Vo`3Vc800
i/b000h0i/b000<0o`000>K<P03Vc800503Vc803000001D0i/b000<0o`000>K<P03Vc8003@3Vc800
0`00I_l0i/b00>K<P00R0>K<P00303?o003Vc800i/b00280i/b000<06ATI0>K<P03Vc800CP3Vc800
02h0i/b000<06ATI0>K<P03Vc8008`3Vc8000`0co`00i/b00>K<P00V0>K<P003001Vo`3Vc800i/b0
00h0i/b000<0o`000>K<P03Vc800503Vc8000`000000i/b00>K<P00E0>K<P0030?l0003Vc800i/b0
00`0i/b000<006Ko0>K<P03Vc8008@3Vc80203?o02@0i/b000<06ATI0>K<P03Vc800C`3Vc80002l0
i/b000<06ATI0>K<P03Vc8008`3Vc80203?o02L0i/b000<006Ko0>K<P03Vc8003@3Vc8000`3o0000
i/b00>K<P00D0>K<P0030000003Vc800i/b001D0i/b000<0o`000>K<P03Vc800303Vc8000`00I_l0
i/b00>K<P00P0>K<P00303?o003Vc800i/b002<0i/b000<06ATI0>K<P03Vc800D03Vc8000300i/b0
00<06ATI0>K<P03Vc800903Vc8000`0co`00i/b00>K<P00U0>K<P003001Vo`3Vc800i/b000`0i/b0
00<0o`000>K<P03Vc800503Vc8000`000000i/b00>K<P00D0>K<P0030?l0003Vc800i/b000`0i/b0
00<006Ko0>K<P03Vc800803Vc8000`0co`00i/b00>K<P00S0>K<P00301TI6@3Vc800i/b00540i/b0
000a0>K<P00301TI6@3Vc800i/b002@0i/b000<0<ol00>K<P03Vc800903Vc8000`00I_l0i/b00>K<
P00=0>K<P0030?l0003Vc800i/b001<0i/b000<000000>K<P03Vc800503Vc8000`3o0000i/b00>K<
P00<0>K<P003001Vo`3Vc800i/b001l0i/b000<0<ol00>K<P03Vc8008`3Vc8000`0I6AT0i/b00>K<
P01B0>K<P000<P3Vc8000`0I6AT0i/b00>K<P00T0>K<P00303?o003Vc800i/b002@0i/b000<006Ko
0>K<P03Vc800303Vc8000`3o0000i/b00>K<P00C0>K<P0030000003Vc800i/b001@0i/b000<0o`00
0>K<P03Vc8002`3Vc8000`00I_l0i/b00>K<P00O0>K<P00303?o003Vc800i/b00280i/b00P0I6AUE
0>K<P000<`3Vc8000`0I6AT0i/b00>K<P00T0>K<P080<ol0903Vc8000`00I_l0i/b00>K<P00<0>K<
P0030?l0003Vc800i/b001<0i/b000<000000>K<P03Vc800503Vc8000`3o0000i/b00>K<P00:0>K<
P003001Vo`3Vc800i/b001h0i/b00P0co`0T0>K<P00301TI6@3Vc800i/b005D0i/b0000d0>K<P080
6ATI9P3Vc8000`0co`00i/b00>K<P00R0>K<P003001Vo`3Vc800i/b000/0i/b000<0o`000>K<P03V
c8004`3Vc803000001@0i/b000<0o`000>K<P03Vc8001@3Vc806001Voad0i/b00`0co`0U0>K<P003
01TI6@3Vc800i/b005H0i/b0000f0>K<P00301TI6@3Vc800i/b002@0i/b000<0<ol00>K<P03Vc800
8P3Vc8000`00I_l0i/b00>K<P00;0>K<P0030?l0003Vc800i/b00180i/b000<000000>K<P03Vc800
4`3Vc8000`3o0000i/b00>K<P0060>K<P0H006Ko7@3Vc80203?o02D0i/b000<06ATI0>K<P03Vc800
E`3Vc80003L0i/b000<06ATI0>K<P03Vc800903Vc8000`0co`00i/b00>K<P00Q0>K<P003001Vo`3V
c800i/b000/0i/b000<0o`000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00C0>K<P0030?l0003V
c800i/b000H0i/b01P00I_lK0>K<P0H0<ol08P3Vc8000`0I6AT0i/b00>K<P01H0>K<P000>03Vc800
0`0I6AT0i/b00>K<P00T0>K<P00303?o003Vc800i/b001l0i/b01P00I_l90>K<P0030?l0003Vc800
i/b00180i/b000<000000>K<P03Vc8004`3Vc8000`3o0000i/b00>K<P0060>K<P0H006Ko7@3Vc802
03?o02<0i/b000<06ATI0>K<P03Vc800F@3Vc80003T0i/b000<06ATI0>K<P03Vc800903Vc80203?o
0080i/b000<0<ol00>K<P03Vc8006P3Vc806001Vo`T0i/b000<0o`000>K<P03Vc8004P3Vc8000`00
0000i/b00>K<P00C0>K<P0030?l0003Vc800i/b000H0i/b01P00I_lL0>K<P00303?o003Vc800i/b0
0280i/b000<06ATI0>K<P03Vc800FP3Vc80003X0i/b000<06ATI0>K<P03Vc8009@3Vc80303?o01`0
i/b01P00I_l90>K<P0030?l0003Vc800i/b00180i/b000<000000>K<P03Vc8004P3Vc8000`3o0000
i/b00>K<P0070>K<P0H006Ko703Vc8000`0co`00i/b00>K<P00Q0>K<P00301TI6@3Vc800i/b005/0
i/b0000k0>K<P00301TI6@3Vc800i/b002@0i/b00P0co`0M0>K<P0H006Ko2P3Vc8000`3o0000i/b0
0>K<P00A0>K<P0030000003Vc800i/b00180i/b000<0o`000>K<P03Vc8001`3Vc806001Voa/0i/b0
00<0<ol00>K<P03Vc8008@3Vc8000`0I6AT0i/b00>K<P01L0>K<P000?03Vc8000`0I6AT0i/b00>K<
P00Q0>K<P0H0<ol06`3Vc806001Vo`X0i/b000<0o`000>K<P03Vc8004@3Vc8000`000000i/b00>K<
P00B0>K<P0030?l0003Vc800i/b000T0i/b000<006Ko0>K<P03Vc800703Vc8000`0co`00i/b00>K<
P00P0>K<P00301TI6@3Vc800i/b005d0i/b0000m0>K<P0806ATI903Vc80203?o01`0i/b01P00I_l:
0>K<P0030?l0003Vc800i/b00140i/b00`00000B0>K<P0030?l0003Vc800i/b000P0i/b000<006Ko
0>K<P03Vc800703Vc8000`0co`00i/b00>K<P00P0>K<P00301TI6@3Vc800i/b005h0i/b0000o0>K<
P00301TI6@3Vc800i/b002<0i/b000<0<ol00>K<P03Vc8007@3Vc8000`00I_l0i/b00>K<P0090>K<
P0030?l0003Vc800i/b00140i/b000<000000>K<P03Vc8004P3Vc8000`3o0000i/b00>K<P0080>K<
P003001Vo`3Vc800i/b001/0i/b000<0<ol00>K<P03Vc800803Vc8000`0I6AT0i/b00>K<P01O0>K<
P000@03Vc8000`0I6AT0i/b00>K<P00R0>K<P00303?o003Vc800i/b001h0i/b000<006Ko0>K<P03V
c800203Vc8000`3o0000i/b00>K<P00A0>K<P0030000003Vc800i/b00140i/b000<0o`000>K<P03V
c8002@3Vc8000`00I_l0i/b00>K<P00K0>K<P00303?o003Vc800i/b001l0i/b000<06ATI0>K<P03V
c800H03Vc8000440i/b000<06ATI0>K<P03Vc8008P3Vc8000`0co`00i/b00>K<P00M0>K<P003001V
o`3Vc800i/b000T0i/b000<0o`000>K<P03Vc800403Vc8000`000000i/b00>K<P00A0>K<P0030?l0
003Vc800i/b000P0i/b000<006Ko0>K<P03Vc8006`3Vc8000`0co`00i/b00>K<P00O0>K<P00301TI
6@3Vc800i/b00640i/b000120>K<P00301TI6@3Vc800i/b00280i/b000<0<ol00>K<P03Vc800703V
c8000`00I_l0i/b00>K<P0090>K<P0030?l0003Vc800i/b00100i/b000<000000>K<P03Vc8004@3V
c8000`3o0000i/b00>K<P0080>K<P003001Vo`3Vc800i/b001/0i/b000<0<ol00>K<P03Vc8007P3V
c8000`0I6AT0i/b00>K<P01R0>K<P000@`3Vc8000`0I6AT0i/b00>K<P00Q0>K<P00303?o003Vc800
i/b001d0i/b000<006Ko0>K<P03Vc800203Vc8000`3o0000i/b00>K<P00@0>K<P0030000003Vc800
i/b00140i/b000<0o`000>K<P03Vc800203Vc8000`00I_l0i/b00>K<P00J0>K<P00303?o003Vc800
i/b001d0i/b00P0I6AUU0>K<P000A03Vc8000`0I6AT0i/b00>K<P00Q0>K<P00303?o003Vc800i/b0
01`0i/b000<006Ko0>K<P03Vc800203Vc8000`3o0000i/b00>K<P00@0>K<P0030000003Vc800i/b0
0140i/b000<0o`000>K<P03Vc800203Vc8000`00I_l0i/b00>K<P00I0>K<P00303?o003Vc800i/b0
01d0i/b000<06ATI0>K<P03Vc800I@3Vc80004D0i/b00P0I6ATQ0>K<P00303?o003Vc800i/b001`0
i/b000<006Ko0>K<P03Vc8002@3Vc8000`3o0000i/b00>K<P00?0>K<P0<00000403Vc8000`3o0000
i/b00>K<P0080>K<P003001Vo`3Vc800i/b001X0i/b000<0<ol00>K<P03Vc800703Vc8000`0I6AT0
i/b00>K<P01V0>K<P000A`3Vc8000`0I6AT0i/b00>K<P00O0>K<P00303?o003Vc800i/b001`0i/b0
00<006Ko0>K<P03Vc800203Vc8000`3o0000i/b00>K<P00?0>K<P0030000003Vc800i/b00100i/b0
00<0o`000>K<P03Vc800203Vc8000`00I_l0i/b00>K<P00I0>K<P00303?o003Vc800i/b001`0i/b0
00<06ATI0>K<P03Vc800I`3Vc80004P0i/b000<06ATI0>K<P03Vc8007`3Vc8000`0co`00i/b00>K<
P00K0>K<P003001Vo`3Vc800i/b000P0i/b000<0o`000>K<P03Vc8003`3Vc8000`000000i/b00>K<
P00@0>K<P0030?l0003Vc800i/b000P0i/b000<006Ko0>K<P03Vc8006@3Vc8000`0co`00i/b00>K<
P00K0>K<P00301TI6@3Vc800i/b006P0i/b000190>K<P00301TI6@3Vc800i/b001h0i/b000<0<ol0
0>K<P03Vc8006`3Vc8000`00I_l0i/b00>K<P0080>K<P0030?l0003Vc800i/b000l0i/b000<00000
0>K<P03Vc800403Vc8000`3o0000i/b00>K<P0070>K<P003001Vo`3Vc800i/b001T0i/b000<0<ol0
0>K<P03Vc8006`3Vc8000`0I6AT0i/b00>K<P01Y0>K<P000BP3Vc8000`0I6AT0i/b00>K<P00N0>K<
P00303?o003Vc800i/b001X0i/b000<006Ko0>K<P03Vc800203Vc8000`3o0000i/b00>K<P00?0>K<
P0030000003Vc800i/b000l0i/b000<0o`000>K<P03Vc800203Vc8000`00I_l0i/b00>K<P00I0>K<
P00303?o003Vc800i/b001X0i/b000<06ATI0>K<P03Vc800JP3Vc80004/0i/b000<06ATI0>K<P03V
c8007P3Vc8000`0co`00i/b00>K<P00J0>K<P004001Vo`3Vc800i/b00>K<P0<00000103Vc8000`3o
00000000000000040>K<P0@000001P3Vc8000`000000i/b00>K<P00?0>K<P0030?l0003Vc800i/b0
00P0i/b000<006Ko0>K<P03Vc800603Vc8000`0co`00i/b00>K<P00J0>K<P00301TI6@3Vc800i/b0
06/0i/b0001<0>K<P00301TI6@3Vc800i/b001d0i/b000<0<ol00>K<P03Vc8006P3Vc8001000I_l0
i/b00>K<P00000020>K<P0030000003Vc800i/b00080i/b000<0o`00000000000000203Vc8000`00
0000i/b00>K<P0030>K<P0030000003Vc800i/b000l0i/b000<0o`000>K<P03Vc8001`3Vc8000`00
I_l0i/b00>K<P00H0>K<P00303?o003Vc800i/b001X0i/b000<06ATI0>K<P03Vc800K03Vc80004d0
i/b000<06ATI0>K<P03Vc8007@3Vc8000`0co`00i/b00>K<P00I0>K<P003001Vo`3Vc800000000@0
i/b000D000000>K<P03Vc800i/b00?l0000:0>K<P0030000003Vc800i/b000<0i/b00`00000?0>K<
P0030?l0003Vc800i/b000L0i/b000<006Ko0>K<P03Vc800603Vc8000`0co`00i/b00>K<P00I0>K<
P00301TI6@3Vc800i/b006d0i/b0001>0>K<P0806ATI7@3Vc8000`0co`00i/b00>K<P00J0>K<P003
001Vo`000000i/b000<0i/b000D000000>K<P03Vc800i/b00?l0000:0>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P03Vc8003`3Vc8000`3o0000i/b00>K<P0070>K<P003001Vo`3Vc800i/b0
01L0i/b000<0<ol00>K<P03Vc8006@3Vc8000`0I6AT0i/b00>K<P01^0>K<P000D03Vc8000`0I6AT0
i/b00>K<P00K0>K<P00303?o003Vc800i/b001T0i/b000<006Ko0000003Vc8000`3Vc8000`000000
i/b00>K<P0020>K<P0030?l0003Vc800i/b000D0i/b00P0000060>K<P0030000003Vc800i/b000h0
i/b000<0o`000>K<P03Vc8001`3Vc8000`00I_l0i/b00>K<P00H0>K<P00303?o003Vc800i/b001P0
i/b000<06ATI0>K<P03Vc800K`3Vc8000540i/b000<06ATI0>K<P03Vc8006`3Vc8000`0co`00i/b0
0>K<P00H0>K<P003001Vo`000000i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`3o0000i/b0
0>K<P0070>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8003P3Vc8000`3o0000i/b0
0>K<P0070>K<P003001Vo`3Vc800i/b001L0i/b000<0<ol00>K<P03Vc800603Vc8000`0I6AT0i/b0
0>K<P01`0>K<P000DP3Vc8000`0I6AT0i/b00>K<P00J0>K<P00303?o003Vc800i/b001T0i/b000D0
06Ko0000003Vc800i/b0000000050>K<P0030?l0003Vc800i/b000L0i/b000<000000>K<P03Vc800
0`3Vc8000`000000i/b00>K<P00>0>K<P0030?l0003Vc800i/b000L0i/b000<006Ko0>K<P03Vc800
5`3Vc8000`0co`00i/b00>K<P00G0>K<P00301TI6@3Vc800i/b00740i/b0001C0>K<P00301TI6@3V
c800i/b001X0i/b000<0<ol00>K<P03Vc800603Vc8000`00I_l0000000000002000000D0i/b000<0
o`000>K<P03Vc8000`3Vc804000000H0i/b000<000000>K<P03Vc8003P3Vc8000`3o0000i/b00>K<
P0060>K<P003001Vo`3Vc800i/b001L0i/b000<0<ol00>K<P03Vc8005`3Vc8000`0I6AT0i/b00>K<
P01b0>K<P000E03Vc8000`0I6AT0i/b00>K<P00I0>K<P00303?o003Vc800i/b001P0i/b000<006Ko
0>K<P03Vc8001`3Vc8000`3o0000i/b00>K<P00=0>K<P0030000003Vc800i/b000d0i/b000<0o`00
0>K<P03Vc8001`3Vc8000`00I_l0i/b00>K<P00F0>K<P00303?o003Vc800i/b001L0i/b000<06ATI
0>K<P03Vc800L`3Vc80005D0i/b000<06ATI0>K<P03Vc8006@3Vc8000`0co`00i/b00>K<P00H0>K<
P003001Vo`3Vc800i/b000L0i/b000<0o`000>K<P03Vc800303Vc8000`000000i/b00>K<P00=0>K<
P0030?l0003Vc800i/b000L0i/b000<006Ko0>K<P03Vc8005P3Vc8000`0co`00i/b00>K<P00E0>K<
P0806ATIMP3Vc80005H0i/b00P0I6ATJ0>K<P00303?o003Vc800i/b001L0i/b000<006Ko0>K<P03V
c8001`3Vc8000`3o0000i/b00>K<P00<0>K<P0<000003@3Vc8000`3o0000i/b00>K<P0070>K<P003
001Vo`3Vc800i/b001D0i/b000<0<ol00>K<P03Vc8005@3Vc8000`0I6AT0i/b00>K<P01f0>K<P000
F03Vc8000`0I6AT0i/b00>K<P00G0>K<P00303?o003Vc800i/b001L0i/b000<006Ko0>K<P03Vc800
1`3Vc8000`3o0000i/b00>K<P00<0>K<P0030000003Vc800i/b000d0i/b000<0o`000>K<P03Vc800
1P3Vc8000`00I_l0i/b00>K<P00F0>K<P00303?o003Vc800i/b001@0i/b000<06ATI0>K<P03Vc800
M`3Vc80005T0i/b000<06ATI0>K<P03Vc8005`3Vc8000`0co`00i/b00>K<P00G0>K<P003001Vo`3V
c800i/b000H0i/b000<0o`000>K<P03Vc800303Vc8000`000000i/b00>K<P00=0>K<P0030?l0003V
c800i/b000H0i/b000<006Ko0>K<P03Vc8005@3Vc8000`0co`00i/b00>K<P00D0>K<P00301TI6@3V
c800i/b007P0i/b0001J0>K<P00301TI6@3Vc800i/b001H0i/b000<0<ol00>K<P03Vc8005`3Vc800
0`00I_l0i/b00>K<P0070>K<P0030?l0003Vc800i/b000/0i/b000<000000>K<P03Vc800303Vc800
0`3o0000i/b00>K<P0070>K<P003001Vo`3Vc800i/b001@0i/b000<0<ol00>K<P03Vc800503Vc800
0`0I6AT0i/b00>K<P01i0>K<P000F`3Vc8000`0I6AT0i/b00>K<P00F0>K<P00303?o003Vc800i/b0
01H0i/b000<006Ko0>K<P03Vc8001`3Vc8000`3o0000i/b00>K<P00;0>K<P0030000003Vc800i/b0
00`0i/b000<0o`000>K<P03Vc8001P3Vc8000`00I_l0i/b00>K<P00E0>K<P00303?o003Vc800i/b0
01<0i/b000<06ATI0>K<P03Vc800NP3Vc80005`0i/b000<06ATI0>K<P03Vc8005P3Vc8000`0co`00
i/b00>K<P00F0>K<P003001Vo`3Vc800i/b000H0i/b000<0o`000>K<P03Vc8002`3Vc8000`000000
i/b00>K<P00<0>K<P0030?l0003Vc800i/b000H0i/b000<006Ko0>K<P03Vc800503Vc8000`0co`00
i/b00>K<P00A0>K<P00301TI6@3Vc8006ATI07d0i/b0001M0>K<P00301TI6@3Vc800i/b001D0i/b0
00<0<ol00>K<P03Vc8005P3Vc8000`00I_l0i/b00>K<P0060>K<P0030?l0003Vc800i/b000/0i/b0
00<000000>K<P03Vc800303Vc8000`3o0000i/b00>K<P0060>K<P003001Vo`3Vc800i/b001@0i/b0
00<0<ol00>K<P03Vc800403Vc80301TI6Gh0i/b0001N0>K<P0806ATI5P3Vc8000`0co`00i/b00>K<
P00E0>K<P003001Vo`3Vc800i/b000H0i/b000<0o`000>K<P03Vc8002`3Vc803000000/0i/b000<0
o`000>K<P03Vc8001P3Vc8000`00I_l0i/b00>K<P00D0>K<P00303?o003Vc800i/b00100i/b0100I
6AUn0>K<P000H03Vc8000`0I6AT0i/b00>K<P00D0>K<P00303?o003Vc800i/b001D0i/b000<006Ko
0>K<P03Vc8001P3Vc8000`3o0000i/b00>K<P00:0>K<P0030000003Vc800i/b000/0i/b000<0o`00
0>K<P03Vc8001P3Vc8000`00I_l0i/b00>K<P00D0>K<P00303?o003Vc800i/b00140i/b00`0I6AUn
0>K<P000H@3Vc8000`0I6AT0i/b001TI6@0C0>K<P00303?o003Vc800i/b001D0i/b000<006Ko0>K<
P03Vc8001P3Vc8000`3o0000i/b00>K<P00:0>K<P0030000003Vc800i/b000/0i/b000<0o`000>K<
P03Vc8001P3Vc8000`00I_l0i/b00>K<P00C0>K<P00303?o003Vc800i/b00140i/b000<06ATI0>K<
P00I6AT0O`3Vc8000680i/b00`0I6ATC0>K<P00303?o003Vc800i/b001@0i/b000<006Ko0>K<P03V
c8001P3Vc8000`3o0000i/b00>K<P00:0>K<P0030000003Vc800i/b000/0i/b000<0o`000>K<P03V
c8001@3Vc8000`00I_l0i/b00>K<P00C0>K<P00303?o003Vc800i/b00180i/b000<06ATI0>K<P03V
c800O`3Vc8000640i/b0100I6ATC0>K<P00303?o003Vc800i/b001D0i/b000<006Ko0>K<P03Vc800
1@3Vc8000`3o0000i/b00>K<P00:0>K<P0030000003Vc800i/b000/0i/b000<0o`000>K<P03Vc800
1@3Vc8000`00I_l0i/b00>K<P00C0>K<P00303?o003Vc800i/b00140i/b000<06ATI0>K<P03Vc800
P03Vc8000680i/b00`0I6ATD0>K<P00303?o003Vc800i/b001@0i/b000<006Ko0>K<P03Vc8001P3V
c8000`3o0000i/b00>K<P0090>K<P0030000003Vc800i/b000X0i/b000<0o`000>K<P03Vc8001P3V
c8000`00I_l0i/b00>K<P00B0>K<P00303?o003Vc800i/b00140i/b000<06ATI0>K<P03Vc800P@3V
c80006<0i/b000<06ATI0>K<P00I6AT0503Vc8000`0co`00i/b00>K<P00C0>K<P003001Vo`3Vc800
i/b000H0i/b000<0o`000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00:0>K<P0030?l0003Vc800
i/b000D0i/b000<006Ko0>K<P03Vc8004`3Vc8000`0co`00i/b00>K<P00@0>K<P00301TI6@3Vc800
i/b00880i/b0001V0>K<P00301TI6@3Vc800i/b00140i/b000<0<ol00>K<P03Vc800503Vc8000`00
I_l0i/b00>K<P0050>K<P0030?l0003Vc800i/b000T0i/b000<000000>K<P03Vc8002P3Vc8000`3o
0000i/b00>K<P0050>K<P003001Vo`3Vc800i/b00180i/b000<0<ol00>K<P03Vc800403Vc8000`0I
6AT0i/b00>K<P0230>K<P000I`3Vc8000`0I6AT0i/b00>K<P00A0>K<P00303?o003Vc800i/b001<0
i/b000<006Ko0>K<P03Vc8001@3Vc8000`3o0000i/b00>K<P0090>K<P0<000002P3Vc8000`3o0000
i/b00>K<P0050>K<P003001Vo`3Vc800i/b00180i/b000<0<ol00>K<P03Vc8003`3Vc8000`0I6AT0
i/b00>K<P0240>K<P000J03Vc8000`0I6AT0i/b00>K<P00@0>K<P00303?o003Vc800i/b001<0i/b0
00<006Ko0>K<P03Vc8001@3Vc8000`3o0000i/b00>K<P0090>K<P0030000003Vc800i/b000T0i/b0
00<0o`000>K<P03Vc8001P3Vc8000`00I_l0i/b00>K<P00A0>K<P00303?o003Vc800i/b00100i/b0
00<06ATI0>K<P03Vc800Q03Vc80006P0i/b000<06ATI0>K<P03Vc8004@3Vc8000`0co`00i/b00>K<
P00B0>K<P003001Vo`3Vc800i/b000H0i/b000<0o`000>K<P03Vc800203Vc8000`000000i/b00>K<
P0090>K<P0030?l0003Vc800i/b000D0i/b000<006Ko0>K<P03Vc8004@3Vc8000`0co`00i/b00>K<
P00@0>K<P00301TI6@3Vc800i/b008D0i/b0001Y0>K<P00301TI6@3Vc800i/b00140i/b000<0<ol0
0>K<P03Vc8004P3Vc8000`00I_l0i/b00>K<P0050>K<P0030?l0003Vc800i/b000P0i/b000<00000
0>K<P03Vc8002@3Vc8000`3o0000i/b00>K<P0050>K<P003001Vo`3Vc800i/b00140i/b000<0<ol0
0>K<P03Vc8003`3Vc8000`0I6AT0i/b00>K<P0260>K<P000JP3Vc8000`0I6AT0i/b00>K<P00@0>K<
P00303?o003Vc800i/b00180i/b000<006Ko0>K<P03Vc8001@3Vc8000`3o0000i/b00>K<P0080>K<
P0030000003Vc800i/b000T0i/b000<0o`000>K<P03Vc8001@3Vc8000`00I_l0i/b00>K<P00@0>K<
P00303?o003Vc800i/b000l0i/b000<06ATI0>K<P03Vc800Q`3Vc80006/0i/b000<06ATI0>K<P03V
c800403Vc8000`0co`00i/b00>K<P00A0>K<P003001Vo`3Vc800i/b000D0i/b000<0o`000>K<P03V
c800203Vc8000`000000i/b00>K<P0090>K<P0030?l0003Vc800i/b000@0i/b000<006Ko0>K<P03V
c8004@3Vc8000`0co`00i/b00>K<P00>0>K<P00301TI6@3Vc800i/b008P0i/b0001/0>K<P00301TI
6@3Vc800i/b000l0i/b000<0<ol00>K<P03Vc8004P3Vc8000`00I_l0i/b00>K<P0050>K<P0030?l0
003Vc800i/b000L0i/b000<000000>K<P03Vc800203Vc8000`3o0000i/b00>K<P0050>K<P003001V
o`3Vc800i/b00100i/b000<0<ol00>K<P03Vc8003P3Vc8000`0I6AT0i/b00>K<P0290>K<P000K@3V
c8000`0I6AT0i/b00>K<P00?0>K<P00303?o003Vc800i/b00140i/b000<006Ko0>K<P03Vc8001@3V
c8000`3o0000i/b00>K<P0070>K<P0<00000203Vc8000`3o0000i/b00>K<P0050>K<P003001Vo`3V
c800i/b000l0i/b000<0<ol00>K<P03Vc8003`3Vc8000`0I6AT0i/b00>K<P0290>K<P000KP3Vc800
0`0I6AT0i/b00>K<P00?0>K<P00303?o003Vc800i/b00100i/b000<006Ko0>K<P03Vc8001@3Vc800
0`3o0000i/b00>K<P0070>K<P0030000003Vc800i/b000P0i/b000<0o`000>K<P03Vc800103Vc800
0`00I_l0i/b00>K<P00@0>K<P00303?o003Vc800i/b000h0i/b000<06ATI0>K<P03Vc800RP3Vc800
06l0i/b000<06ATI0>K<P03Vc8003P3Vc8000`0co`00i/b00>K<P00A0>K<P003001Vo`3Vc800i/b0
00@0i/b000<0o`000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0080>K<P0030?l0003Vc800i/b0
00@0i/b000<006Ko0>K<P03Vc8003`3Vc8000`0co`00i/b00>K<P00>0>K<P00301TI6@3Vc800i/b0
08/0i/b0001`0>K<P00301TI6@3Vc800i/b000h0i/b000<0<ol00>K<P03Vc800403Vc8000`00I_l0
i/b00>K<P0040>K<P0030?l0003Vc800i/b000L0i/b000<000000>K<P03Vc800203Vc8000`3o0000
i/b00>K<P0040>K<P003001Vo`3Vc800i/b000l0i/b000<0<ol00>K<P03Vc8003@3Vc8000`0I6AT0
i/b00>K<P02<0>K<P000L@3Vc8000`0I6AT0i/b00>K<P00>0>K<P00303?o003Vc800i/b000l0i/b0
00<006Ko0>K<P03Vc8001@3Vc8000`3o0000i/b00>K<P0060>K<P0030000003Vc800i/b000L0i/b0
00<0o`000>K<P03Vc800103Vc8000`00I_l0i/b00>K<P00?0>K<P00303?o003Vc800i/b000d0i/b0
00<06ATI0>K<P03Vc800S@3Vc8000780i/b000<06ATI0>K<P03Vc8003@3Vc8000`0co`00i/b00>K<
P0080>K<P0<000001@3Vc8000`00I_l000000>K<P0040>K<P0040?l0000000000000000000D0i/b0
00<000000>K<P03Vc8001`3Vc8000`3o0000i/b00>K<P0040>K<P003001Vo`3Vc800i/b000d0i/b0
0`0co`0?0>K<P00301TI6@3Vc800i/b008d0i/b0001c0>K<P00301TI6@3Vc800i/b000d0i/b000<0
<ol00>K<P00co`001P3Vc80010000000i/b00>K<P00000050>K<P003001Vo`000000i/b000@0i/b0
00<0o`000>K<P00000001P3Vc8000`000000i/b00>K<P0070>K<P0030?l0003Vc800i/b000@0i/b0
00<006Ko0>K<P03Vc8003@3Vc80203?o00l0i/b000<06ATI0>K<P03Vc800SP3Vc80007<0i/b000<0
6ATI0>K<P03Vc8003@3Vc80203?o00H0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<
P0020>K<P003001Vo`3Vc800i/b000<0i/b000<000000?l0000000000P0000050>K<P0<000001`3V
c8000`3o0000i/b00>K<P0030>K<P003001Vo`3Vc800i/b000`0i/b01P0co`0<0>K<P00301TI6@3V
c800i/b008l0i/b0001d0>K<P00301TI6@3Vc800i/b000/0i/b0100co`050>K<P0030000003Vc800
i/b00080i/b000<000000>K<P03Vc8000`3Vc8000`00I_l0i/b00>K<P0020>K<P0040000003Vc800
o`00000000H0i/b000<000000>K<P03Vc8001P3Vc8000`3o0000i/b00>K<P0040>K<P003001Vo`3V
c800i/b000h0i/b000<0<ol00>K<P03Vc800303Vc8000`0I6AT0i/b00>K<P02@0>K<P000M@3Vc800
0`0I6AT0i/b00>K<P0090>K<P0H0<ol0103Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800
i/b000<0i/b000<006Ko0>K<P03Vc8000`3Vc8000`000000o`00000000060>K<P0030000003Vc800
i/b000H0i/b000<0o`000>K<P03Vc800103Vc8000`00I_l0i/b00>K<P00=0>K<P00303?o003Vc800
i/b000`0i/b000<06ATI0>K<P03Vc800T@3Vc80007H0i/b000<06ATI0>K<P03Vc8002`3Vc8000`0c
o`00i/b003?o00040>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000`3Vc8000`00
I_l0i/b00>K<P0040>K<P0030?l000000000i/b000D0i/b000<000000>K<P03Vc8001P3Vc8000`3o
0000i/b00>K<P0030>K<P003001Vo`3Vc800i/b000d0i/b000<0<ol00>K<P03Vc800303Vc8000`0I
6AT0i/b00>K<P02B0>K<P000M`3Vc8000`0I6AT0i/b00>K<P00<0>K<P00303?o003Vc800i/b000<0
i/b000@000000>K<P03Vc80000001`3Vc8000`00I_l0i/b00>K<P0030>K<P0030?l000000000i/b0
00D0i/b000<000000>K<P03Vc8001P3Vc8000`3o0000i/b00>K<P0030>K<P003001Vo`3Vc800i/b0
00`0i/b000<0<ol00>K<P03Vc8003@3Vc8000`0I6AT0i/b00>K<P02B0>K<P000N03Vc8000`0I6AT0
i/b00>K<P00<0>K<P00303?o003Vc800i/b00080i/b0100000070>K<P003001Vo`3Vc800i/b000<0
i/b000<0o`000000003Vc8001@3Vc8000`000000i/b00>K<P0060>K<P0030?l0003Vc800i/b000<0
i/b000<006Ko0>K<P03Vc800303Vc8000`0co`00i/b00>K<P00<0>K<P00301TI6@3Vc800i/b009<0
i/b0001i0>K<P00301TI6@3Vc800i/b000`0i/b000<0<ol00>K<P03Vc800303Vc8000`00I_l0i/b0
0>K<P0040>K<P0030?l0003Vc800i/b000@0i/b000<000000>K<P03Vc8001@3Vc8000`3o0000i/b0
0>K<P0040>K<P003001Vo`3Vc800i/b000/0i/b000<0<ol00>K<P03Vc800303Vc8000`0I6AT0i/b0
0>K<P02D0>K<P000NP3Vc8000`0I6AT0i/b00>K<P00<0>K<P00303?o003Vc800i/b000`0i/b000<0
06Ko0>K<P03Vc8000`3Vc8000`3o0000i/b00>K<P0040>K<P0030000003Vc800i/b000D0i/b000<0
o`000>K<P03Vc8000`3Vc8000`00I_l0i/b00>K<P00;0>K<P00303?o003Vc800i/b000`0i/b000<0
6ATI0>K<P03Vc800U@3Vc80007/0i/b000<06ATI0>K<P03Vc800303Vc8000`0co`00i/b00>K<P00;
0>K<P003001Vo`3Vc800i/b000<0i/b000<0o`000>K<P03Vc800103Vc803000000D0i/b000<0o`00
0>K<P03Vc8000`3Vc8000`00I_l0i/b00>K<P00:0>K<P00303?o003Vc800i/b000`0i/b000<06ATI
0>K<P03Vc800UP3Vc80007`0i/b000<06ATI0>K<P03Vc8002`3Vc8000`0co`00i/b00>K<P00;0>K<
P003001Vo`3Vc800i/b000<0i/b000<0o`000>K<P03Vc800103Vc8000`000000i/b00>K<P0050>K<
P0030?l0003Vc800i/b000<0i/b000<006Ko0>K<P03Vc8002P3Vc8000`0co`00i/b00>K<P00;0>K<
P00301TI6@3Vc800i/b009L0i/b0001m0>K<P00301TI6@3Vc800i/b000/0i/b000<0<ol00>K<P03V
c8002`3Vc8000`00I_l0i/b00>K<P0030>K<P0030?l0003Vc800i/b000<0i/b000<000000>K<P03V
c800103Vc8000`3o0000i/b00>K<P0030>K<P003001Vo`3Vc800i/b000X0i/b000<0<ol00>K<P03V
c800303Vc8000`0I6AT0i/b00>K<P02G0>K<P000OP3Vc8000`0I6AT0i/b00>K<P00;0>K<P00303?o
003Vc800i/b000X0i/b000@006Ko0>K<P03Vc800i/b01@3o00030>K<P0030000003Vc800i/b00080
i/b01@3o00030>K<P003001Vo`3Vc800i/b000T0i/b000<0<ol00>K<P03Vc800303Vc8000`0I6AT0
i/b00>K<P02H0>K<P000OP3Vc8000`0I6AT0i/b00>K<P00<0>K<P00303?o003Vc800i/b000T0i/b0
00<006Ko0>K<P03Vc8000P3Vc8030?l000@0i/b000<000000>K<P03Vc8000`3Vc8030?l000@0i/b0
00<006Ko0>K<P03Vc800203Vc8000`0co`00i/b00>K<P00<0>K<P00301TI6@3Vc800i/b009T0i/b0
001o0>K<P00301TI6@3Vc800i/b000`0i/b000<0<ol00>K<P03Vc8002@3Vc8001000I_l0i/b00>K<
P03Vc8030?l000@0i/b000<000000>K<P03Vc8000`3Vc8030?l000<0i/b000<006Ko0>K<P03Vc800
2@3Vc8000`0co`00i/b00>K<P00;0>K<P00301TI6@3Vc800i/b009X0i/b000200>K<P00301TI6@3V
c800i/b000/0i/b000<0<ol00>K<P03Vc8002@3Vc8000`00I_l0i/b00>K<P0020>K<P0030?l0003V
c800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8020?l000@0i/b000<006Ko0>K<P03Vc800203V
c8000`0co`00i/b00>K<P00;0>K<P00301TI6@3Vc800i/b009/0i/b000210>K<P00301TI6@3Vc800
i/b000/0i/b000<0<ol00>K<P03Vc800203Vc8000`00I_l0i/b00>K<P0030>K<P0030?l0003Vc800
i/b00080i/b00`0000030>K<P0030?l0003Vc800i/b000<0i/b000<006Ko0>K<P03Vc8001`3Vc800
0`0co`00i/b00>K<P00;0>K<P00301TI6@3Vc800i/b009`0i/b000220>K<P00301TI6@3Vc8006ATI
00/0i/b000<0<ol00>K<P03Vc8001`3Vc8000`00I_l0i/b00>K<P0030>K<P0030?l0003Vc800i/b0
0080i/b000<000000>K<P03Vc8000`3Vc8000`3o0000i/b00>K<P0020>K<P003001Vo`3Vc800i/b0
00L0i/b000<0<ol00>K<P03Vc8002@3Vc80201TI6@030>K<P00I6AT0i/b009d0i/b000230>K<P0<0
6ATI2`3Vc8000`0co`00i/b00>K<P0070>K<P003001Vo`3Vc800i/b00080i/b000<0o`000>K<P03V
c8000P3Vc8000`000000i/b00>K<P0030>K<P0030?l0003Vc800i/b00080i/b000<006Ko0>K<P03V
c8001`3Vc8000`0co`00i/b00>K<P0080>K<P0@06ATIW`3Vc8000880i/b01@0I6AT:0>K<P00303?o
003Vc800i/b000L0i/b000<006Ko0>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0020>K<P0030000
003Vc800i/b00080i/b000<0o`000>K<P03Vc8000`3Vc8000`00I_l0i/b00>K<P0060>K<P00303?o
003Vc800i/b000P0i/b01@0I6AVO0>K<P000P`3Vc80401TI6@/0i/b000<0<ol00>K<P03Vc8001P3V
c8000`00I_l0i/b00>K<P0030>K<P0050?l0003Vc800i/b00>K<P0000000103Vc8000`3o0000i/b0
0>K<P0020>K<P003001Vo`3Vc800i/b000H0i/b000<0<ol00>K<P03Vc8002P3Vc80401TI6Il0i/b0
00230>K<P0<06ATI00<0i/b001TI6@3Vc8002P3Vc8000`0co`00i/b00>K<P0060>K<P003001Vo`3V
c800i/b00080i/b000D0o`000>K<P03Vc800i/b0000000040>K<P0030?l0003Vc800i/b00080i/b0
00<006Ko0>K<P03Vc8001@3Vc8000`0co`00i/b00>K<P00:0>K<P00401TI6@3Vc8006ATI01TI6J00
i/b000240>K<P00401TI6@3Vc800i/b00>K<P0806ATI2P3Vc8000`0co`00i/b00>K<P0050>K<P003
001Vo`3Vc800i/b00080i/b000D0o`000>K<P03Vc800i/b0000000030>K<P0030?l0003Vc800i/b0
00<0i/b000<006Ko0>K<P03Vc8001@3Vc8000`0co`00i/b00>K<P0080>K<P0806ATIY03Vc80008X0
i/b000<06ATI0>K<P03Vc800203Vc8000`0co`00i/b00>K<P0040>K<P003001Vo`3Vc800i/b00080
i/b000D0o`000>K<P03Vc800i/b0000000030>K<P0030?l0003Vc800i/b000<0i/b000<006Ko0>K<
P03Vc800103Vc8000`0co`00i/b00>K<P0080>K<P00301TI6@3Vc800i/b00:@0i/b0002;0>K<P080
6ATI203Vc8000`0co`00i/b00>K<P0050>K<P003001Vo`3Vc800i/b00080i/b000<0o`000>K<P03V
c8000`0000000`3Vc800o`000>K<P0030>K<P003001Vo`3Vc800i/b000@0i/b000<0<ol00>K<P03V
c8001`3Vc80201TI6JL0i/b0002=0>K<P00301TI6@3Vc800i/b000H0i/b000<0<ol00>K<P03Vc800
103Vc8000`00I_l0i/b00>K<P0020>K<P0040?l0003Vc800i/b0000000<0i/b000<0o`000>K<P03V
c8000P3Vc8000`00I_l0i/b00>K<P0030>K<P00303?o003Vc800i/b000L0i/b000<06ATI0>K<P03V
c800Y`3Vc80008h0i/b00P0I6AT70>K<P00303?o003Vc800i/b000<0i/b000<006Ko0>K<P03Vc800
0P3Vc800103o0000i/b00>K<P00000020>K<P0030?l0003Vc800i/b000<0i/b000<006Ko0>K<P03V
c8000`3Vc8000`0co`00i/b00>K<P0050>K<P0806ATIZP3Vc8000900i/b000<06ATI0>K<P03Vc800
1@3Vc8000`0co`00i/b00>K<P0030>K<P005001Vo`3Vc800i/b00>K<P03o00000P3Vc80010000000
i/b00>K<P03o00040>K<P003001Vo`3Vc800i/b000<0i/b000<0<ol00>K<P03Vc8001@3Vc8000`0I
6AT0i/b00>K<P02Z0>K<P000T@3Vc80201TI6@H0i/b000<0<ol00>K<P03Vc8000P3Vc8000`00I_l0
i/b00>K<P0020>K<P0030?l0003Vc80000000080i/b000<0o`000>K<P03Vc8000P3Vc8000`00I_l0
i/b00>K<P0020>K<P00303?o003Vc800i/b000@0i/b00P0I6AV]0>K<P000T`3Vc8000`0I6AT0i/b0
0>K<P0030>K<P00303?o003Vc800i/b000H006Ko00@0i/b00?l0003Vc80000000P3Vc8000`3o0000
06Ko001Vo`04001Vo`80i/b000<0<ol00>K<P03Vc800103Vc8000`0I6AT0i/b00>K<P02]0>K<P000
U03Vc80201TI6@@0i/b000<0<ol00>K<P000I_l01@00I_l01`3Vc800o`000>K<P0000000i/b00?l0
003Vc8001P00I_l20>K<P00303?o003Vc800i/b00080i/b00P0I6AV`0>K<P000UP3Vc8000`0I6AT0
i/b00>K<P0020>K<P00303?o0000I_l006Ko00@006Ko00<0i/b00?l0003Vc8000P0000000`3o0000
i/b0001Vo`05001Vo`030>K<P00co`00i/b000<0i/b000<06ATI0>K<P03Vc800/03Vc80009L0i/b0
0P0I6AT30>K<P0H006Ko0P3Vc8001@3o000000000>K<P03o0000i/b000H006Ko00@0<ol00>K<P03V
c800i/b00P0I6AVc0>K<P000V@3Vc8000`0I6AT0i/b00>K<P006001Vo`80i/b000<0o`000000003o
00000P3Vc806001Vo`<0i/b000<06ATI0>K<P03Vc800/`3Vc80009X0i/b00P0I6AT7001Vo`040>K<
P03o000000000?l00080i/b01P00I_l00`3Vc8006ATI01TI6@2f0>K<P000W03Vc8000`0I6AT0i/b0
03?o000203?o00080>K<P000I_l0i/b00?l0000I6AT0o`000>K<P000I_l20>K<P0<0<ol000<0i/b0
01TI6@3Vc800]`3Vc80008d0i/b00`0000050>K<P08000001@3Vc8000`0000006ATI03?o000203?o
00040>K<P000I_l006Ko001Vo`80o`000P00I_l20>K<P080<ol00P0I6AVi0>K<P000S03Vc8001000
0000i/b00>K<P00000050>K<P08000001@3Vc80603?o00<006Ko00@0o`00001Vo`00I_l006Ko1P0c
o`2i0>K<P000R`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000/0i/b000@06ATI
03?o000I6AT0i/b00P00I_l40?l00006001Vo`3Vc800i/b001TI6@0co`006ATI^P3Vc80008/0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P00301TI6@000000i/b0008006Ko
0`3o0002001Vo`<0i/b000<06ATI0>K<P03Vc800^@3Vc80008/0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P0090>K<P0@000000P3Vc803001Vo`040?l00000I_l006Ko001Vokl0i/b0
002;0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<
P0030>K<P0L006Ko_`3Vc80008`0i/b000@000000>K<P03Vc8000000303Vc8000`000000i/b00>K<
P0060>K<P0030000003Vc800i/b00<00i/b0002<0>K<P0@00000303Vc804000000D0i/b000<00000
0>K<P03Vc800`03Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3V
c8000?l0i/b0J@3Vc80005l0i/b01000003o0>K<P0H0i/b0001P0>K<P0030000003Vc800i/b00?l0
i/b01P3Vc80004l0i/b00`0000020>K<P0H0000000P0i/b0000000000000i/b00000003Vc8000000
0>K<P0<000000`3Vc80600000080i/b01P0000040>K<P0@000000`3Vc80600000080i/b00`000000
0`3Vc8000000000000030>K<P0@000001P3Vc804000000<0i/b01@00000:0>K<P0@000000`3Vc800
0`000000i/b000000002000000@0i/b0100000030>K<P0H000000P3Vc80600000080i/b01P000002
0>K<P0H00000103Vc80400000080i/b01P0000030>K<P0@000000P3Vc80300000080i/b00`00001P
0>K<P000D03Vc8000`000000i/b00>K<P0020>K<P0040000003Vc800i/b000000080i/b000D00000
0>K<P03Vc80000000>K<P002000000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P0050>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<
P0020>K<P0040000003Vc800i/b0000000<0i/b00P0000030>K<P0030000003Vc800i/b000L0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000T0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P002000000<0i/b000<000000>K<P03Vc800
0P0000030>K<P0800000103Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000D0i/b0
00<000000>K<P03Vc8000P3Vc8001@000000i/b00>K<P03Vc800000000@0i/b000<000000>K<P03V
c8001`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b000@000000>K<P03V
c8000000103Vc8000`000000i/b00>K<P01O0>K<P000D03Vc80600000080i/b000@000000>K<P03V
c80000000P3Vc8000`000000i/b0000000050>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc8001@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000@0i/b000<000000>K<
P03Vc8000P3Vc80010000000i/b00>K<P00000040>K<P0040000003Vc800i/b0000000X0i/b000<0
00000>K<P03Vc8000`3Vc8001@000000i/b00>K<P03Vc800000000/0i/b000<000000>K<P03Vc800
0`3Vc8000`000000i/b0000000030>K<P08000000P3Vc8000`000000i/b00>K<P0080>K<P0030000
003Vc800i/b000D0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0020>K<P0050000
003Vc800i/b00>K<P0000000103Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b00080
i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0000000040>K<P0030000003Vc800i/b005l0
i/b0001A0>K<P0040000003Vc800i/b0000000<0i/b000@000000>K<P03Vc80000000P3Vc8000`00
0000i/b0000000050>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8001@3Vc8000`00
0000i/b00>K<P0030>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8000P3Vc8001000
0000i/b00>K<P00000040>K<P0030000003Vc800i/b000H000001@3Vc8000`000000i/b00>K<P003
0>K<P0050000003Vc800i/b00>K<P00000002`3Vc8000`000000i/b00>K<P0030>K<P0030000003V
c800000000<00000103Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000D0i/b000<0
00000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0030>K<P0@00000103Vc8000`000000i/b00>K<
P0070>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00000
00040>K<P0030000003Vc800i/b005l0i/b0001A0>K<P0040000003Vc800i/b0000000<0i/b000@0
00000>K<P03Vc80000000P3Vc80010000000i/b00000000000030>K<P0030000003Vc800i/b000<0
i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000@0
i/b000<000000>K<P03Vc8000P3Vc80010000000i/b00>K<P00000030>K<P08000000P3Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8000P3Vc8001000
0000i/b00>K<P00000040>K<P0030000003Vc800i/b0008000000`3Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P006
0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc8000000103Vc8000`000000i/b00>K<
P01O0>K<P000DP3Vc8000`000000i/b0000000020>K<P0@0000000@0i/b0000000000000i/b00P00
0000103Vc80000000000000000060>K<P0030000003Vc800i/b000<0i/b00`0000040>K<P0D00000
0P3Vc802000000<0i/b00P0000030>K<P0<0000000<0i/b00000003Vc8000P3Vc804000000L0i/b0
100000030>K<P0D000002P3Vc804000000@0i/b01@0000030>K<P0D000000`3Vc803000000L0i/b0
00<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0030>K<P0@000000`3Vc805000000@0i/b0
0`0000050>K<P0@000000P3Vc80600000680i/b0001B0>K<P08000005`3Vc8000`000000i/b00>K<
P00;0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<
P00/0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<
P01k0>K<P000D03Vc804000001D0i/b00`00000=0>K<P0030000003Vc800i/b000l0i/b000<00000
0>K<P00000005`3Vc804000002T0i/b00`0000050>K<P0<000003@3Vc8000`000000i/b00>K<P01k
0>K<P000LP3Vc8000`000000i/b00>K<P01F0>K<P0030000003Vc800i/b002D0i/b000<000000>K<
P03Vc800LP3Vc8000001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0.750437, -0.041019, \
0.00187928, 0.00337816}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(plfreq = 
        Graphics3D[{Line /@ Transpose[colldata[\([All, All, {2, 1, 3}]\)]], 
            Line /@ colldata[\([All, All, {2, 1, 3}]\)]}\ , 
          Boxed \[Rule] True, Axes \[Rule] True, 
          AxesLabel \[Rule] {\*"\"\<\[Omega]1/\!\(\[Omega]\_0\)\>\"", \*"\"\<\
\[Omega]/\!\(\[Omega]\_0\)\>\"", \*"\"\<\!\(\[Omega]\_R\)/\!\(\[Omega]\_0\)\>\
\""}, PlotLabel -> "\<Rabi frequency\>"];\)\), "\[IndentingNewLine]", 
    \(\(Show[plfreq];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .90333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.49926e-17 1.00925 -0.0229072 1.00925 [
[.5 .91583 -44 0 ]
[.5 .91583 44 10.125 ]
[.05962 .25341 -18 -8.8998 ]
[.05962 .25341 0 .1002 ]
[.21357 .1943 -17.3573 -9 ]
[.21357 .1943 .64269 0 ]
[.37596 .13196 -5.50321 -9 ]
[.37596 .13196 .49679 0 ]
[.54752 .06614 -15.662 -9 ]
[.54752 .06614 2.33802 0 ]
[.72904 -0.00346 -14.8143 -9 ]
[.72904 -0.00346 3.18569 0 ]
[.33555 .08353 -14.6752 -9.8125 ]
[.33555 .08353 1.32476 0 ]
[.81231 .06777 0 -6.15839 ]
[.81231 .06777 18 2.84161 ]
[.88774 .18636 0 -6.05852 ]
[.88774 .18636 18 2.94148 ]
[.95607 .2938 0 -5.96999 ]
[.95607 .2938 18 3.03001 ]
[.92909 .1369 0 -6.63144 ]
[.92909 .1369 10 3.18106 ]
[.04079 .28129 -6 -2.78619 ]
[.04079 .28129 0 6.21381 ]
[.02194 .42619 -18 -2.89434 ]
[.02194 .42619 0 6.10566 ]
[.00148 .58362 -18 -3.01266 ]
[.00148 .58362 0 5.98734 ]
[-0.04308 .48918 -15.5625 -3.1901 ]
[-0.04308 .48918 0 6.6224 ]
[ 0 0 0 0 ]
[ 1 .90333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .91583 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Rabi) show
93.000 11.562 moveto
(frequency) show
147.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.05372 .26793 m
.75455 0 L
s
.06864 .26223 m
.07315 .26664 L
s
[(0.8)] .05962 .25341 1 .97773 Mshowa
.22215 .20354 m
.22644 .20816 L
s
[(0.9)] .21357 .1943 .92859 1 Mshowa
.38404 .14165 m
.38809 .14649 L
s
[(1)] .37596 .13196 .8344 1 Mshowa
.55503 .07628 m
.55878 .08135 L
s
[(1.1)] .54752 .06614 .74022 1 Mshowa
.73588 .00713 m
.73931 .01243 L
s
[(1.2)] .72904 -0.00346 .64603 1 Mshowa
.125 Mabswid
.0987 .25074 m
.10138 .25341 L
s
.12908 .23912 m
.13173 .24182 L
s
.15978 .22739 m
.16241 .23011 L
s
.1908 .21553 m
.1934 .21827 L
s
.25384 .19143 m
.25638 .19423 L
s
.28586 .17918 m
.28838 .18201 L
s
.31824 .16681 m
.32073 .16966 L
s
.35096 .15429 m
.35342 .15717 L
s
.41749 .12886 m
.41988 .13179 L
s
.45131 .11593 m
.45366 .11889 L
s
.4855 .10286 m
.48782 .10585 L
s
.52007 .08964 m
.52236 .09266 L
s
.59038 .06276 m
.5926 .06583 L
s
.62614 .04909 m
.62831 .05219 L
s
.6623 .03527 m
.66444 .03839 L
s
.69888 .02128 m
.70098 .02443 L
s
gsave
.33555 .08353 -75.6752 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.000 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.75455 0 m
.94813 .30408 L
s
.80047 .07214 m
.79455 .07432 L
s
[(0.1)] .81231 .06777 -1 .36853 Mshowa
.87582 .19049 m
.86985 .19255 L
s
[(0.2)] .88774 .18636 -1 .34634 Mshowa
.94408 .29771 m
.93808 .29967 L
s
[(0.3)] .95607 .2938 -1 .32667 Mshowa
.125 Mabswid
.81616 .09678 m
.8126 .09807 L
s
.83153 .12092 m
.82797 .1222 L
s
.84659 .14458 m
.84302 .14584 L
s
.86135 .16776 m
.85778 .16901 L
s
.89 .21277 m
.88642 .214 L
s
.90391 .23462 m
.90033 .23584 L
s
.91756 .25606 m
.91397 .25726 L
s
.93094 .27708 m
.92735 .27827 L
s
.78445 .04698 m
.78091 .0483 L
s
.76809 .02128 m
.76455 .02262 L
s
gsave
.92909 .1369 -61 -10.6314 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.05372 .26793 m
0 .68383 L
s
.05258 .2768 m
.05847 .27456 L
s
[(0)] .04079 .28129 1 -0.38085 Mshowa
.03383 .42195 m
.03977 .41983 L
s
[(0.1)] .02194 .42619 1 -0.35681 Mshowa
.01346 .57966 m
.01944 .57768 L
s
[(0.2)] .00148 .58362 1 -0.33052 Mshowa
.125 Mabswid
.04895 .3049 m
.05249 .30357 L
s
.04526 .33345 m
.04881 .33214 L
s
.04151 .36247 m
.04506 .36117 L
s
.0377 .39197 m
.04126 .39068 L
s
.02989 .45244 m
.03346 .45118 L
s
.02588 .48344 m
.02946 .4822 L
s
.02181 .51497 m
.02539 .51375 L
s
.01767 .54704 m
.02126 .54583 L
s
.00917 .61286 m
.01277 .61169 L
s
.0048 .64664 m
.00841 .64548 L
s
.00036 .68101 m
.00398 .67988 L
s
gsave
-0.04308 .48918 -76.5625 -7.1901 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
74.562 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.05372 .26793 m
0 .68383 L
s
0 .68383 m
.28589 .90333 L
s
.28589 .90333 m
.30658 .51291 L
s
.30658 .51291 m
.05372 .26793 L
s
.75455 0 m
.94813 .30408 L
s
.94813 .30408 m
1 .71659 L
s
1 .71659 m
.78843 .43702 L
s
.78843 .43702 m
.75455 0 L
s
.05372 .26793 m
0 .68383 L
s
0 .68383 m
.78843 .43702 L
s
.78843 .43702 m
.75455 0 L
s
.75455 0 m
.05372 .26793 L
s
.30658 .51291 m
.94813 .30408 L
s
.94813 .30408 m
1 .71659 L
s
1 .71659 m
.28589 .90333 L
s
.28589 .90333 m
.30658 .51291 L
s
0 0 m
1 0 L
1 .90333 L
0 .90333 L
closepath
clip
newpath
.5 Mabswid
.36406 .58108 m
.45376 .7289 L
s
.45376 .7289 m
.53262 .67051 L
s
.29568 .88445 m
.45376 .7289 L
s
.1993 .75848 m
.29568 .88445 L
s
.4453 .5098 m
.53262 .67051 L
s
.53262 .67051 m
.59645 .63791 L
s
.51042 .47075 m
.59645 .63791 L
s
.59645 .63791 m
.6126 .63212 L
s
.52684 .46435 m
.6126 .63212 L
s
.6126 .63212 m
.62887 .62733 L
s
.54334 .45941 m
.62887 .62733 L
s
.62887 .62733 m
.69527 .61799 L
s
.6107 .45368 m
.69527 .61799 L
s
.69527 .61799 m
.78221 .62646 L
s
.26748 .43737 m
.36406 .58108 L
s
.36406 .58108 m
.4453 .5098 L
s
.1993 .75848 m
.36406 .58108 L
s
.35235 .3471 m
.4453 .5098 L
s
.4453 .5098 m
.51042 .47075 L
s
.41935 .29422 m
.51042 .47075 L
s
.51042 .47075 m
.52684 .46435 L
s
.0938 .63939 m
.1993 .75848 L
s
.43604 .28666 m
.52684 .46435 L
s
.52684 .46435 m
.54334 .45941 L
s
.45276 .28199 m
.54334 .45941 L
s
.54334 .45941 m
.6107 .45368 L
s
.69912 .47116 m
.78221 .62646 L
s
.78221 .62646 m
.97332 .68827 L
s
.52081 .28674 m
.6107 .45368 L
s
.6107 .45368 m
.69912 .47116 L
s
.30309 .2702 m
.35235 .3471 L
s
.35235 .3471 m
.41935 .29422 L
s
.26748 .43737 m
.35235 .3471 L
s
.37175 .20299 m
.41935 .29422 L
s
.41935 .29422 m
.43604 .28666 L
s
.21568 .37104 m
.26748 .43737 L
s
.0938 .63939 m
.26748 .43737 L
s
.38862 .19385 m
.43604 .28666 L
s
.43604 .28666 m
.45276 .28199 L
s
.4054 .19027 m
.45276 .28199 L
s
.45276 .28199 m
.52081 .28674 L
s
.0367 .58332 m
.0938 .63939 L
s
.37175 .20299 m
.38862 .19385 L
s
.30309 .2702 m
.37175 .20299 L
s
.21568 .37104 m
.30309 .2702 L
s
.61044 .31887 m
.69912 .47116 L
s
.69912 .47116 m
.8947 .54885 L
s
.38862 .19385 m
.4054 .19027 L
s
.4054 .19027 m
.47345 .20741 L
s
.0367 .58332 m
.21568 .37104 L
s
.47345 .20741 m
.52081 .28674 L
s
.52081 .28674 m
.61044 .31887 L
s
.8947 .54885 m
.97332 .68827 L
s
.47345 .20741 m
.56352 .24726 L
s
.56352 .24726 m
.61044 .31887 L
s
.61044 .31887 m
.81015 .41109 L
s
.56352 .24726 m
.76514 .34344 L
s
.81015 .41109 m
.8947 .54885 L
s
.76514 .34344 m
.81015 .41109 L
s
.25 Mabswid
.75455 0 m
.94813 .30408 L
s
.94813 .30408 m
1 .71659 L
s
1 .71659 m
.78843 .43702 L
s
.78843 .43702 m
.75455 0 L
s
.05372 .26793 m
0 .68383 L
s
0 .68383 m
.78843 .43702 L
s
.78843 .43702 m
.75455 0 L
s
.75455 0 m
.05372 .26793 L
s
.05372 .26793 m
.75455 0 L
s
.06864 .26223 m
.07315 .26664 L
s
[(0.8)] .05962 .25341 1 .97773 Mshowa
.22215 .20354 m
.22644 .20816 L
s
[(0.9)] .21357 .1943 .92859 1 Mshowa
.38404 .14165 m
.38809 .14649 L
s
[(1)] .37596 .13196 .8344 1 Mshowa
.55503 .07628 m
.55878 .08135 L
s
[(1.1)] .54752 .06614 .74022 1 Mshowa
.73588 .00713 m
.73931 .01243 L
s
[(1.2)] .72904 -0.00346 .64603 1 Mshowa
.125 Mabswid
.0987 .25074 m
.10138 .25341 L
s
.12908 .23912 m
.13173 .24182 L
s
.15978 .22739 m
.16241 .23011 L
s
.1908 .21553 m
.1934 .21827 L
s
.25384 .19143 m
.25638 .19423 L
s
.28586 .17918 m
.28838 .18201 L
s
.31824 .16681 m
.32073 .16966 L
s
.35096 .15429 m
.35342 .15717 L
s
.41749 .12886 m
.41988 .13179 L
s
.45131 .11593 m
.45366 .11889 L
s
.4855 .10286 m
.48782 .10585 L
s
.52007 .08964 m
.52236 .09266 L
s
.59038 .06276 m
.5926 .06583 L
s
.62614 .04909 m
.62831 .05219 L
s
.6623 .03527 m
.66444 .03839 L
s
.69888 .02128 m
.70098 .02443 L
s
gsave
.33555 .08353 -75.6752 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.000 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 260.125},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001AB000`400?l00000o`00003oo`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y
0>K<P000m@3Vc806000000@0i/b00P0000040>K<P0H00000G@3Vc8000?P0i/b000<000000>K<P03V
c800103Vc802000000D0i/b000D000000>K<P03Vc800i/b00000001M0>K<P000n03Vc8000`000000
i/b00>K<P00<0>K<P0030000003Vc800i/b005h0i/b0003h0>K<P0030000003Vc800i/b000d0i/b0
0P00001N0>K<P000n03Vc8000`000000i/b00>K<P00>0>K<P0800000G@3Vc8000?P0i/b000<00000
0>K<P03Vc8003`3Vc8000`000000i/b00>K<P01K0>K<P000n03Vc8000`000000i/b00>K<P00:0>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800F`3Vc8000?H0i/b00`00000<0>K<P0D0
0000GP3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0i/b0403Vc8020000
05L0i/b0003o0>K<P0h0i/b00P0000000`3Vc80000000000001F0>K<P000o`3Vc80;0>K<P0<00000
0`3Vc802000005H0i/b0003o0>K<P0P0i/b0100000050>K<P0030000003Vc800000005D0i/b0003o
0>K<P0H0i/b00P0000040>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc8000000E03V
c8000?l0i/b00`3Vc803000000/0i/b000@000000>K<P03Vc8000000E03Vc8000?l0i/b00@3Vc802
000000h0i/b000D000000>K<P03Vc800i/b00000001C0>K<P000o@3Vc80300000140i/b000@00000
0>K<P00000000000D`3Vc8000?X0i/b00`0000020>K<P0030000003Vc800i/b000l0i/b000D00000
0>K<P03Vc800i/b00000001B0>K<P000n03Vc802000001L0i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P01?0>K<P000m@3Vc803000001T0i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P01?0>K<P000^P3Vc806000000@0i/b00P0000040>K<P0H000008P3Vc803000001`0
i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P01>0>K<P000_@3Vc8000`000000i/b0
0>K<P0040>K<P08000001`3Vc8000`000000i/b00>K<P00P0>K<P080000000<0i/b00000003Vc800
703Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b004d0i/b0002m0>K<P0030000003V
c800i/b000d0i/b000<000000>K<P03Vc8007@3Vc80300000240i/b000<000000>K<P03Vc800103V
c8000`000000i/b00>K<P01=0>K<P000_@3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800
i/b001/0i/b00P00000T0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800C03Vc800
0;d0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00H0>K<P0<000009P3Vc8000`00
0000i/b00>K<P0040>K<P0<00000C@3Vc8000;d0i/b000<000000>K<P03Vc8003@3Vc8000`000000
i/b00>K<P00E0>K<P0<00000:@3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000P0
i/b00`0000050>K<P0800000103Vc806000002l0i/b0002m0>K<P0030000003Vc800i/b000d0i/b0
00<000000>K<P03Vc8004`3Vc802000000<0i/b000<000000>K<P03Vc8009P3Vc8000`000000i/b0
0>K<P0070>K<P0030000003Vc800i/b000H0i/b000@000000>K<P03Vc80000001@3Vc802000000L0
i/b000<000000>K<P03Vc800;`3Vc80007`0i/b01@0000030>K<P0H00000<@3Vc803000000d0i/b0
0`00000B0>K<P0<00000;P3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000D0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b002l0i/b0
001k0>K<P0040000003Vc800i/b000000080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0
0>K<P01D0>K<P0800000<P3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000@0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b002l0i/b0
001k0>K<P0040000003Vc800i/b000000080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0
0>K<P01A0>K<P0<00000=03Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b002l0i/b0
001k0>K<P0040000003Vc800i/b000000080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0
0>K<P01>0>K<P0<000000P3Vc8000`000000i/b00>K<P00b0>K<P0030000003Vc800i/b000P0i/b0
00<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000/0i/b0
00<000000>K<P03Vc800;`3Vc80007`0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b004`0i/b00P00000j0>K<P0030000003Vc800i/b000T0i/b000<0
00000>K<P03Vc8000`3Vc80010000000i/b00>K<P000000>0>K<P0030000003Vc800i/b002l0i/b0
001m0>K<P0050000003Vc800i/b00>K<P00000001@3Vc8000`000000i/b00>K<P0190>K<P0<00000
?03Vc8000`000000i/b00>K<P0090>K<P0800000103Vc804000000`0i/b00`00000a0>K<P000Q`3V
c8000`000000i/b00>K<P0170>K<P0800000?`3Vc8000`000000i/b00>K<P0080>K<P0030000003V
c800000004P0i/b000250>K<P0<00000AP3Vc80400000400i/b000<000000>K<P03Vc8002`3Vc800
0`000000i/b00>K<P0150>K<P000b`3Vc803000000@0i/b000<000000>K<P03Vc800?@3Vc8000`00
0000i/b00>K<P00<0>K<P0030000003Vc800i/b004@0i/b000390>K<P0800000A`3Vc8000`000000
i/b00>K<P00<0>K<P0030000003Vc800i/b004@0i/b000360>K<P0<00000B@3Vc8000`000000i/b0
0>K<P00=0>K<P0030000003Vc800i/b004<0i/b000330>K<P0@00000B`3Vc8000`000000i/b00>K<
P00=0>K<P0030000003Vc800i/b004<0i/b000310>K<P0800000C`3Vc8000`000000i/b00>K<P00>
0>K<P0030000003Vc800i/b00480i/b0002n0>K<P0<00000D@3Vc8000`000000i/b00>K<P00=0>K<
P0<00000@`3Vc8000980i/b01P00000T0>K<P0800000E@3Vc8000`000000i/b00>K<P00>0>K<P003
0000003Vc800i/b00440i/b0002E0>K<P0030000003Vc800i/b00240i/b00`00001G0>K<P0030000
003Vc800i/b000l0i/b000<000000>K<P03Vc800@03Vc80009D0i/b000<000000>K<P03Vc8007P3V
c80300000080i/b000<000000>K<P03Vc800E@3Vc8000`000000i/b00>K<P00@0>K<P0030000003V
c800i/b003l0i/b0002E0>K<P0030000003Vc800i/b001`0i/b00P00001M0>K<P0030000003Vc800
i/b00100i/b000<000000>K<P03Vc800?`3Vc80009D0i/b000<000000>K<P03Vc8006@3Vc8030000
05l0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00n0>K<P000U@3Vc8000`000000
i/b00>K<P00G0>K<P0800000HP3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b003d0
i/b0002E0>K<P0030000003Vc800i/b001@0i/b00`0000020>K<P0030000003Vc800i/b005l0i/b0
00<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00m0>K<P000T`3Vc803000001<0i/b00`00
001W0>K<P0030000003Vc800i/b00140i/b000<000000>K<P00000008@3Vc805000001P0i/b0002W
0>K<P0800000JP3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001h0i/b000@00000
0>K<P03Vc80000000P3Vc8000`000000i/b00>K<P00E0>K<P000Y03Vc803000006`0i/b000<00000
0>K<P03Vc800503Vc8000`000000i/b00>K<P00M0>K<P0040000003Vc800i/b000000080i/b000<0
00000>K<P03Vc8005@3Vc8000:40i/b00`0000020>K<P0030000003Vc800i/b006X0i/b000<00000
0>K<P03Vc8005@3Vc8000`000000i/b00>K<P00L0>K<P0040000003Vc800i/b000000080i/b000<0
00000>K<P03Vc8005@3Vc80009l0i/b00P00001b0>K<P0030000003Vc800i/b001D0i/b000<00000
0>K<P03Vc8007@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001D0i/b0002L0>K<
P0<00000M03Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b001d0i/b000D000000>K<
P03Vc800i/b00000000G0>K<P000VP3Vc802000007P0i/b000<000000>K<P03Vc8005P3Vc8000`00
0000i/b00>K<P00h0>K<P000U`3Vc803000000030>K<P0000000000007L0i/b000<000000>K<P03V
c8005@3Vc802000003X0i/b0002D0>K<P0<00000O@3Vc8000`000000i/b00>K<P00G0>K<P0030000
003Vc800i/b003L0i/b0002B0>K<P0800000P03Vc8000`000000i/b00>K<P00G0>K<P0030000003V
c800i/b003L0i/b0002?0>K<P0<00000PP3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800
i/b003H0i/b0002=0>K<P08000000P3Vc8000`000000i/b00>K<P0200>K<P0030000003Vc800i/b0
01T0i/b000<000000>K<P03Vc800=@3Vc80008X0i/b00`0000270>K<P0030000003Vc800i/b001T0
i/b000<000000>K<P03Vc800=@3Vc8000500i/b00`0000050>K<P0800000103Vc803000002H0i/b0
0`00002:0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc800=03Vc80004l0i/b000@0
00000>K<P03Vc80000001@3Vc802000000L0i/b000<000000>K<P03Vc8008@3Vc802000008d0i/b0
00<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P00c0>K<P000CP3Vc8000`000000i/b00>K<
P0020>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8007@3Vc803000000030>K<P000
0000i/b008`0i/b000<000000>K<P03Vc8006P3Vc802000000X0i/b00`0000050>K<P0800000103V
c806000001L0i/b0001>0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002@3Vc804
000001d0i/b00P00002B0>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc8001P3Vc800
10000000i/b00>K<P00000050>K<P08000001@3Vc8001@000000i/b00>K<P03Vc800000001L0i/b0
001>0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800203Vc8001@000000i/b00>K<
P03Vc800000001X0i/b00`00002D0>K<P0030000003Vc800i/b001d0i/b000<000000>K<P03Vc800
103Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc800
603Vc80004h0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0080>K<P0050000003V
c800i/b00>K<P00000005`3Vc803000009P0i/b000<000000>K<P03Vc800703Vc8000`000000i/b0
0>K<P0040>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3Vc802000001P0i/b0
001?0>K<P0040000003Vc800i/b0000000/0i/b000D000000>K<P03Vc800i/b00000000E0>K<P080
00000P3Vc8000`000000i/b00>K<P02F0>K<P0030000003Vc800i/b001d0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000`0i/b00P00000G0>K<P000
C`3Vc804000000`0i/b00`00000C0>K<P0<00000W@3Vc8000`000000i/b00>K<P00M0>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00=0>K<P0030000
003Vc800i/b001D0i/b0001b0>K<P0<00000:P3Vc80400000780i/b000<000000>K<P03Vc8007P3V
c802000000@0i/b000@000000>K<P03Vc80000002`3Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b001D0i/b0001`0>K<P0800000:P3Vc803000000<0i/b01@00001^0>K<P0030000003V
c800i/b001d0i/b000<000000>K<P0000000103Vc804000000/0i/b01@00000H0>K<P000K@3Vc803
00000080i/b000<000000>K<P03Vc8009@3Vc803000000D0i/b000<000000>K<P03Vc8000P3Vc804
000006X0i/b000<000000>K<P03Vc8007`3Vc8000`000000i/b00>K<P00^0>K<P000J`3Vc8020000
02/0i/b00P0000030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8001@3Vc8030000
06L0i/b000<000000>K<P03Vc800803Vc8000`000000i/b00>K<P00]0>K<P000J03Vc803000002`0
i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000P0
i/b01000001S0>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc800;03Vc80006D0i/b0
0`00000^0>K<P0030000003Vc800000000D0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0
0>K<P00;0>K<P0@00000G`3Vc8000`000000i/b00>K<P00Q0>K<P0030000003Vc800i/b002`0i/b0
001S0>K<P08000000`3Vc8000`000000i/b00>K<P00Z0>K<P0040000003Vc800i/b0000000D0i/b0
00<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00?0>K<P0<00000G03Vc8000`000000i/b0
0>K<P00R0>K<P0030000003Vc800i/b002/0i/b0001P0>K<P0<00000<@3Vc8000`000000i/b00>K<
P0020>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P00@0>K<P0<00000FP3Vc8000`000000i/b00>K<P00S0>K<P0030000003Vc800i/b002X0i/b0001M
0>K<P0<00000<`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc8000`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000800000F03Vc800
0`000000i/b00>K<P00R0>K<P0800000;03Vc80005/0i/b01000000c0>K<P0030000003Vc800i/b0
00D0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b0
0100i/b000@000000>K<P03Vc800i/b00`00001E0>K<P0030000003Vc800i/b002@0i/b000<00000
0>K<P03Vc800:@3Vc80005P0i/b00`00000f0>K<P0030000003Vc800i/b000H0i/b000<000000>K<
P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00100i/b000<000000>K<
P03Vc800103Vc802000005@0i/b000<000000>K<P03Vc8008`3Vc8000`000000i/b00>K<P00Y0>K<
P0007`3Vc803000000D0i/b00P0000050>K<P0@00000903Vc802000003P0i/b000<000000>K<P03V
c800203Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c800403Vc8000`000000i/b00>K<P0050>K<P0800000DP3Vc8000`000000i/b00>K<P00T0>K<P003
0000003Vc800i/b002P0i/b0000N0>K<P0040000003Vc800i/b0000000D0i/b00P0000040>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8007P3Vc803000003T0i/b000<000000>K<P03V
c8002@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8004@3Vc8000`000000i/b00>K<P0060>K<P0<00000C`3Vc8000`000000i/b00>K<P00U0>K<P003
0000003Vc800i/b002L0i/b0000M0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800
203Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001`0i/b00P0000000`3Vc8000000
0>K<P00h0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8002@3Vc802000004d0i/b0
00<000000>K<P03Vc8009@3Vc8000`000000i/b00>K<P00W0>K<P0007@3Vc8000`000000i/b00>K<
P0020>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8000P00000K0>K<P0<00000?03V
c8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3V
c8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000X0i/b00P00001;0>K<P0030000003V
c800i/b002H0i/b000<000000>K<P03Vc8009P3Vc80001d0i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P0090>K<P0@000006@3Vc803000003h0i/b000<000000>K<P03Vc8003P3Vc800
0`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800403Vc800
0`000000i/b00>K<P00<0>K<P0<00000B03Vc8000`000000i/b00>K<P00U0>K<P0030000003Vc800
000002L0i/b0000M0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800203Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b001@0i/b00P0000100>K<P0030000003Vc800i/b0
00l0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b0
0140i/b000<000000>K<P03Vc8003P3Vc802000004H0i/b000<000000>K<P03Vc8009`3Vc8000`00
0000i/b00>K<P00U0>K<P0007P3Vc80010000000i/b00>K<P000000;0>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc8004@3Vc803000000030>K<P0000000i/b003h0i/b000<000000>K<
P03Vc8004@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc8004@3Vc8000`000000i/b00>K<P00?0>K<P0800000A03Vc8000`000000i/b00>K<P00X0>K<
P0030000003Vc800i/b002@0i/b0000N0>K<P0@00000303Vc80400000140i/b00`0000130>K<P003
0000003Vc800i/b00180i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P003
0000003Vc800i/b00140i/b000<000000>K<P03Vc8004@3Vc80300000440i/b000<000000>K<P03V
c800:@3Vc8000`000000i/b00>K<P00S0>K<P000@@3Vc802000004D0i/b000<000000>K<P03Vc800
503Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800
4@3Vc8000`000000i/b00>K<P00B0>K<P0<00000?`3Vc8000`000000i/b00>K<P00Y0>K<P0030000
003Vc800i/b002<0i/b0000n0>K<P0@00000A@3Vc8000`000000i/b00>K<P00E0>K<P0030000003V
c800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00A0>K<P0030000003V
c800i/b00180i/b000<000000>K<P03Vc8000P00000m0>K<P0030000003Vc800i/b002X0i/b000<0
00000>K<P03Vc8008P3Vc80003`0i/b00P0000180>K<P0030000003Vc800i/b001L0i/b000<00000
0>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00140i/b000<00000
0>K<P03Vc8004P3Vc80010000000i/b00>K<P03Vc802000003/0i/b000<000000>K<P03Vc800:P3V
c802000002<0i/b0000i0>K<P0<00000B@3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800
i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800
i/b00180i/b000<000000>K<P03Vc8000P3Vc802000003T0i/b000<000000>K<P03Vc800:P3Vc802
000002<0i/b0000f0>K<P0<00000B`3Vc8000`000000i/b00>K<P00J0>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b0
0180i/b000<000000>K<P03Vc800103Vc802000003P0i/b000<000000>K<P03Vc800:`3Vc8000`00
0000i/b00>K<P00P0>K<P000=03Vc802000000030>K<P0000000i/b004X0i/b000<000000>K<P03V
c8006`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8004P3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b000D0i/b00P00000f0>K<P003
0000003Vc800i/b002/0i/b000<000000>K<P03Vc800803Vc8000380i/b00P0000040>K<P0030000
003Vc800i/b004L0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P0030>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00C0>K<P0030000
003Vc800i/b000H0i/b00P00000d0>K<P0030000003Vc800i/b002`0i/b000<000000>K<P03Vc800
7`3Vc8000380i/b00P00001=0>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03Vc8000`3V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8004P3V
c8000`000000i/b00>K<P0080>K<P0800000<P3Vc8000`000000i/b00>K<P00]0>K<P0030000003V
c800i/b001h0i/b0000b0>K<P0<00000B`3Vc8000`000000i/b00000000P0>K<P0030000003Vc800
i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800
i/b00180i/b000<000000>K<P03Vc8002@3Vc80200000300i/b000<000000>K<P03Vc800;@3Vc800
0`000000i/b00>K<P00N0>K<P000<@3Vc80200000080i/b000<000000>K<P03Vc800A`3Vc8001000
0000i/b00>K<P000000P0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc800
0`000000i/b00>K<P00B0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc8002P3Vc802
000002h0i/b000<000000>K<P03Vc800;@3Vc802000000X0i/b00`0000050>K<P0800000103Vc804
000000<0i/b0000a0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800A@3Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03Vc8000`3Vc8000`00
0000i/b00>K<P0020>K<P0L000003`3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b0
00`0i/b00P00000/0>K<P0030000003Vc800i/b002l0i/b000<000000>K<P03Vc8001P3Vc8001000
0000i/b00>K<P00000050>K<P0800000203Vc80100000040i/b00@3Vc80002T0i/b00`0000050>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800A03Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b001h0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020000
0080i/b000<000000>K<P03Vc8000P3Vc80;000000@0i/b000<000000>K<P03Vc8004`3Vc8000`00
0000i/b00>K<P00=0>K<P0800000:P3Vc8000`000000i/b00>K<P00_0>K<P0030000003Vc800i/b0
00D0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P04000000@3Vc8010>K<
P000:03Vc80010000000i/b00>K<P00000050>K<P0030000003Vc800i/b000@0i/b000<000000>K<
P03Vc800@P3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b001h0i/b000<000000>K<
P03Vc8000P3Vc803000000@0i/b000<000000>K<P03Vc8003@3Vc807000001<0i/b000<000000>K<
P03Vc8003`3Vc802000002P0i/b000<000000>K<P03Vc800<03Vc8000`000000i/b00>K<P0040>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800303Vc80100000040i/b00@3Vc80002L0
i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000D0
i/b000<000000>K<P03Vc800@03Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b001d0
i/b000<000000>K<P03Vc8000P0000020>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8004P3Vc80400000140i/b000<000000>K<P03Vc800403Vc802000002H0i/b000<000000>K<P03V
c800<03Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c8002P3Vc802000000<0i/b0000W0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800
0P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b003h0i/b000<000000>K<P03Vc800
1`3Vc8000`000000i/b00>K<P00N0>K<P0800000103Vc8000`000000i/b00>K<P0030>K<P0030000
003Vc800i/b00180i/b000@000000>K<P03Vc800i/b00P00000@0>K<P0030000003Vc800i/b00140
i/b00P00000T0>K<P0030000003Vc800i/b00340i/b000<000000>K<P03Vc8000`3Vc8000`000000
i/b00>K<P0020>K<P0030000003Vc800i/b000`0i/b00@0000010>K<P040i/b0000W0>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0070>K<P0030000
003Vc800i/b003`0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00L0>K<P0030000
003Vc800000000D0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00B0>K<P0030000
003Vc800i/b00080i/b00`00000=0>K<P0030000003Vc800i/b001<0i/b00`00000Q0>K<P0030000
003Vc800i/b00340i/b00P0000050>K<P0040000003Vc800i/b0000000l0i/b00@0000010>K<P040
i/b0000W0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b0
0>K<P0080>K<P0030000003Vc800i/b003X0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b0
0>K<P00I0>K<P08000000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P0050>K<P0<000002`3Vc8000`000000i/b0
0>K<P00E0>K<P0800000803Vc8000`000000i/b00>K<P00_0>K<P0030000003Vc800000000D0i/b0
1000000;0>K<P0@000000`3Vc80002P0i/b000@000000>K<P03Vc80000001@3Vc8000`000000i/b0
0>K<P0090>K<P0030000003Vc800i/b003P0i/b000<000000>K<P03Vc800303Vc8000`000000i/b0
0>K<P00H0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8001`3Vc803000000T0i/b0
00<000000>K<P03Vc8005P3Vc802000001h0i/b000<000000>K<P03Vc800<@3Vc802000001X0i/b0
000X0>K<P0@00000103Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b003H0i/b000<0
00000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b000@0i/b000<0
00000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00180i/b000<0
00000>K<P03Vc8002P3Vc803000000H0i/b000<000000>K<P03Vc800603Vc802000001`0i/b000<0
00000>K<P03Vc800;P3Vc803000000030>K<P0000000i/b001T0i/b0000`0>K<P0030000003Vc800
i/b000`0i/b000<000000>K<P03Vc800=@3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800
i/b001@0i/b00P0000080>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc800
0`000000i/b00>K<P00B0>K<P0030000003Vc800i/b000`0i/b00P0000050>K<P0030000003Vc800
i/b001T0i/b00P00000J0>K<P0030000003Vc800i/b002/0i/b00`0000040>K<P0030000003Vc800
i/b001P0i/b0000`0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800<`3Vc8000`00
0000i/b00>K<P00@0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800203Vc8000`00
0000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8004P3Vc8000`00
0000i/b00>K<P00>0>K<P0<000000`3Vc8000`000000i/b00>K<P00J0>K<P0800000603Vc8000`00
0000i/b00>K<P00X0>K<P0<000001`3Vc8000`000000i/b00>K<P00H0>K<P000<03Vc8000`000000
i/b00>K<P00>0>K<P0030000003Vc800i/b00340i/b000<000000>K<P03Vc8004P3Vc8000`000000
i/b00>K<P00@0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8000`3Vc8000`000000
i/b00>K<P0030>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800403Vc804000001h0
i/b00P00000F0>K<P0030000003Vc800i/b002D0i/b00`00000;0>K<P0030000003Vc800i/b001L0
i/b0000`0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800;`3Vc8000`000000i/b0
0>K<P00C0>K<P0030000003Vc800i/b000h0i/b00P00000=0>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b001<0i/b0
0`00000N0>K<P0800000503Vc8000`000000i/b00>K<P00R0>K<P0<000003P3Vc8000`000000i/b0
0>K<P00G0>K<P000<03Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b002d0i/b000<0
00000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000h0i/b000<0
00000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00180i/b000<0
00000>K<P03Vc800503Vc803000001h0i/b00P00000B0>K<P0030000003Vc800i/b001l0i/b00`00
000A0>K<P0030000003Vc800i/b001L0i/b0000`0>K<P0030000003Vc800i/b00140i/b000<00000
0>K<P03Vc800:`3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b000X0i/b000<00000
0>K<P03Vc8003`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc8004P3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b0008000007P3Vc802
00000100i/b000<000000>K<P03Vc800703Vc803000001@0i/b000<000000>K<P03Vc8005`3Vc800
0300i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00Y0>K<P0030000003Vc800i/b0
01P0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b0
01@0i/b000@000000>K<P03Vc800i/b00P00000N0>K<P08000003P3Vc8000`000000i/b00>K<P00I
0>K<P0<000005`3Vc8000`000000i/b00>K<P00G0>K<P000;`3Vc802000001D0i/b00P00000X0>K<
P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc8001P3Vc802000001@0i/b000<000000>K<
P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00180i/b000<000000>K<
P03Vc800503Vc8000`000000i/b00>K<P0030>K<P08000007P3Vc802000000`0i/b000<000000>K<
P03Vc8005P3Vc803000001X0i/b000<000000>K<P03Vc8005`3Vc80002l0i/b000<000000>K<P03V
c8005P3Vc8000`000000i/b00>K<P00U0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03V
c8001@3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03V
c800103Vc803000001d0i/b00P00000:0>K<P0030000003Vc800i/b001<0i/b00`00000M0>K<P003
0000003Vc800i/b001L0i/b0000_0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc800
8`3Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800
5P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800
4P3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b000L0i/b00P00000M0>K<P0800000
203Vc8000`000000i/b00>K<P00@0>K<P0<00000803Vc8000`000000i/b00>K<P00G0>K<P000;`3V
c8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc8007P3V
c8000`000000i/b00>K<P002000001X0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<
P0080>K<P08000007@3Vc802000000L0i/b000<000000>K<P03Vc800303Vc803000002@0i/b000<0
00000>K<P03Vc8005P3Vc80002l0i/b000<000000>K<P03Vc8006@3Vc8000`000000i/b00>K<P00O
0>K<P0030000003Vc800i/b001l0i/b000<000000>K<P0000000703Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00D
0>K<P0030000003Vc800i/b000T0i/b00P00000M0>K<P08000001@3Vc8000`000000i/b00>K<P009
0>K<P0<000009`3Vc8000`000000i/b00>K<P00F0>K<P000;`3Vc8000`000000i/b00>K<P00J0>K<
P0030000003Vc800i/b001d0i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P00L0>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00B0>K<
P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc8002`3Vc802000001d0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P0060>K<P0<00000:P3Vc8000`000000i/b00>K<P00F0>K<
P000;`3Vc8000`000000i/b00>K<P00K0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03V
c8008@3Vc8000`000000i/b00000000M0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03V
c800303Vc803000001X0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<P0<0
0000;@3Vc8000`000000i/b00>K<P00F0>K<P000;`3Vc8000`000000i/b00>K<P00L0>K<P0030000
003Vc800i/b001T0i/b000<000000>K<P03Vc8008@3Vc80010000000i/b00>K<P000000N0>K<P003
0000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00B0>K<P003
0000003Vc800i/b001@0i/b000<000000>K<P03Vc8003`3Vc802000001T0i/b000D000000>K<P03V
c800i/b0000000020>K<P0<00000<03Vc8000`000000i/b00>K<P00F0>K<P000;P3Vc8000`000000
i/b00>K<P00N0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc8008@3Vc8000`000000
i/b00>K<P0020>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8000`3Vc8000`000000
i/b00>K<P0030>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc800503Vc8000`000000
i/b00>K<P00@0>K<P0800000603Vc8000`000000i/b000000003000003<0i/b000<000000>K<P03V
c8005P3Vc80002h0i/b000<000000>K<P03Vc8007`3Vc8000`000000i/b00>K<P00F0>K<P0030000
003Vc800i/b00200i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00L0>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00B0>K<P0030000
003Vc800i/b001D0i/b000<000000>K<P03Vc8004@3Vc802000001D0i/b00`0000000`3Vc8000000
0>K<P00d0>K<P0030000003Vc800i/b001H0i/b0000^0>K<P08000008@3Vc8000`000000i/b00>K<
P00D0>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<
P00K0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P00C0>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc8004`3Vc80200000100i/b00`00
00020>K<P0030000003Vc800000003D0i/b000<000000>K<P03Vc8005P3Vc80002h0i/b000<00000
0>K<P03Vc8008@3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b00240i/b000<00000
0>K<P03Vc8001@3Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc8000`3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b001D0i/b000<00000
0>K<P03Vc800503Vc803000000X0i/b00`0000060>K<P0800000=P3Vc8000`000000i/b00>K<P00E
0>K<P000;P3Vc8000`000000i/b00>K<P00R0>K<P0030000003Vc800i/b00100i/b000<000000>K<
P03Vc8008@3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b001/0i/b000<000000>K<
P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b001<0i/b000<000000>K<
P03Vc800503Vc8000`000000i/b00>K<P00G0>K<P08000001@3Vc803000000X0i/b000<000000>K<
P03Vc800=03Vc8000`000000i/b00>K<P00E0>K<P000;P3Vc8000`000000i/b00>K<P00S0>K<P003
0000003Vc800i/b000h0i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P0090>K<P003
0000003Vc800i/b001/0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P003
0000003Vc800i/b00180i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00H0>K<P0D0
00003@3Vc8000`000000i/b00>K<P00d0>K<P0030000003Vc800i/b001D0i/b0000^0>K<P0030000
003Vc800i/b002@0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00000000Q0>K<P0030000
003Vc800i/b000X0i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P0030>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00D0>K<P0030000
003Vc800i/b001L0i/b01@00000>0>K<P0800000=@3Vc8000`000000i/b00>K<P00E0>K<P000;@3V
c8000`000000i/b00>K<P00V0>K<P0030000003Vc800i/b000X0i/b000D000000>K<P03Vc800i/b0
0000000O0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b0
0>K<P00E0>K<P0030000003Vc800i/b001<0i/b00`0000050>K<P0<000002`3Vc8000`000000i/b0
0000000d0>K<P0030000003Vc800i/b001D0i/b0000]0>K<P0030000003Vc800i/b002L0i/b000<0
00000>K<P03Vc800203Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001`0i/b000<0
00000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00K0>K<P0030000003Vc800i/b000@0i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001D0i/b000<0
00000>K<P03Vc8003`3Vc803000000/0i/b00P00000:0>K<P0030000003Vc800000003<0i/b000<0
00000>K<P03Vc8005@3Vc80002d0i/b000<000000>K<P03Vc800:03Vc8000`000000i/b00>K<P007
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<P00?
0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00<
0>K<P0<00000403Vc802000000P0i/b000<000000>K<P0000000<`3Vc8000`000000i/b00>K<P00E
0>K<P000;@3Vc8000`000000i/b00>K<P00Y0>K<P0030000003Vc800i/b000D0i/b000<000000>K<
P03Vc8001@3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b00100i/b000<000000>K<
P03Vc800703Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc8004`3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b000P0i/b00`00000E0>K<
P08000001P3Vc80010000000i/b00>K<P000000c0>K<P0030000003Vc800i/b001@0i/b0000]0>K<
P0800000:`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000L0i/b000<000000>K<
P03Vc8005P3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b001/0i/b000<000000>K<
P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00180i/b000<000000>K<
P03Vc8005@3Vc8000`000000i/b00>K<P0050>K<P0<000006P3Vc802000000@0i/b000D000000>K<
P03Vc800i/b00000000b0>K<P0030000003Vc800i/b001@0i/b0000]0>K<P0030000003Vc800i/b0
02/0i/b000D000000>K<P03Vc800i/b00000000;0>K<P0030000003Vc800i/b001D0i/b000<00000
0>K<P03Vc8004`3Vc8000`000000i/b00>K<P00K0>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc8000P3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001D0i/b000@00000
0>K<P03Vc800i/b00`00000O0>K<P0<0000000<0i/b00000003Vc8000P3Vc8000`000000i/b00>K<
P00`0>K<P0030000003Vc800i/b001@0i/b0000]0>K<P0030000003Vc800i/b002`0i/b000<00000
0>K<P0000000303Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b001@0i/b000<00000
0>K<P03Vc8006`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc8004P3Vc8000`000000i/b00>K<P00F0>K<P0<000009@3Vc802000000@0i/b000<00000
0>K<P03Vc800;`3Vc8000`000000i/b00>K<P00D0>K<P000;@3Vc8000`000000i/b00>K<P00]0>K<
P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00F0>K<
P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc8004P3Vc804000002P0i/b00`0000030>K<
P0030000003Vc800i/b002h0i/b000<000000>K<P03Vc800503Vc80002`0i/b000<000000>K<P03V
c800;@3Vc8000`000000i/b00000000>0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03V
c8005`3Vc8000`000000i/b00>K<P00K0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b000h0i/b00`0000040>K<P003
0000003Vc800i/b002D0i/b000<000000>K<P03Vc8000P0000020>K<P0030000003Vc800i/b002d0
i/b000<000000>K<P03Vc800503Vc80002`0i/b000<000000>K<P03Vc800;@3Vc80010000000i/b0
0>K<P000000>0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8006@3Vc8000`000000
i/b00>K<P00K0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000
i/b00>K<P00C0>K<P0030000003Vc800i/b000/0i/b00`0000070>K<P0030000003Vc800i/b002D0
i/b000<000000>K<P03Vc8000P3Vc803000002l0i/b000<000000>K<P03Vc800503Vc80002`0i/b0
00<000000>K<P03Vc800;03Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000`0i/b0
00<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00K0>K<P0030000003Vc800i/b001X0i/b0
00<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b001<0i/b0
00<000000>K<P03Vc8001`3Vc803000000/0i/b000<000000>K<P03Vc800903Vc8000`000000i/b0
0>K<P0040>K<P0800000;P3Vc8000`000000i/b00>K<P00D0>K<P000;03Vc8000`000000i/b00>K<
P00[0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<
P00:0>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<
P0040>K<P0<000003P3Vc8000`000000i/b00>K<P00T0>K<P0030000003Vc800i/b000H0i/b000<0
00000>K<P03Vc800;03Vc8000`000000i/b00>K<P00C0>K<P000;03Vc8000`000000i/b00>K<P00Z
0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P009
0>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P003
00000180i/b000<000000>K<P03Vc8008`3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800
i/b002`0i/b000<000000>K<P03Vc8004`3Vc80002`0i/b00P00000Z0>K<P0030000003Vc800i/b0
00P0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b0
01l0i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc8004`3Vc803000001H0i/b000<000000>K<P03Vc8008`3Vc8000`00
0000i/b00>K<P0060>K<P0030000003Vc800i/b002/0i/b000<000000>K<P03Vc8004`3Vc80002/0
i/b00P00000Z0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8002`3Vc8000`000000
i/b00>K<P0050>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc8006P3Vc8000`000000
i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8003`3Vc80300000003
0>K<P0000000i/b001H0i/b000<000000>K<P03Vc8008`3Vc8000`000000i/b00>K<P0060>K<P003
0000003Vc800i/b002/0i/b000<000000>K<P03Vc8004`3Vc80001<0i/b00`0000050>K<P0800000
103Vc806000000D0i/b000<000000>K<P03Vc800:03Vc8000`000000i/b00>K<P00;0>K<P0030000
003Vc800i/b000/0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00Q0>K<P0030000
003Vc800i/b001/0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b000`0i/b00`0000040>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03Vc800
8P3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b002X0i/b000<000000>K<P03Vc800
4`3Vc8000180i/b000@000000>K<P03Vc80000001@3Vc802000000L0i/b000<000000>K<P03Vc800
103Vc8000`000000i/b00>K<P00X0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800
2`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b002<0i/b000<000000>K<P03Vc800
6P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800
203Vc803000000P0i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00R0>K<P0030000
003Vc800i/b000P0i/b000<000000>K<P03Vc800:@3Vc8000`000000i/b00>K<P00C0>K<P0004@3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc800103V
c8000`000000i/b00>K<P00W0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8002P3V
c8001@000000i/b00>K<P03Vc800000002L0i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8001@3Vc803000000/0i/b0
00<000000>K<P03Vc8005P3Vc8000`000000i/b00>K<P00Q0>K<P0030000003Vc800i/b000P0i/b0
00<000000>K<P03Vc800:@3Vc8000`000000i/b00>K<P00C0>K<P0004@3Vc8000`000000i/b00>K<
P0020>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<
P00V0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00000
000X0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P0030>K<P0040000003Vc800i/b00>K<P0<000003`3Vc8000`000000i/b00>K<P00F0>K<P0030000
003Vc800i/b00200i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00X0>K<P0030000
003Vc800i/b001<0i/b0000A0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3V
c8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b002D0i/b000<000000>K<P03Vc8004`3V
c8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03Vc8006P3V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b01000000B0>K<P0030000003V
c800i/b001H0i/b000<000000>K<P03Vc8007`3Vc802000000`0i/b000<000000>K<P03Vc800:03V
c8000`000000i/b00>K<P00B0>K<P0004@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800
i/b000/0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00T0>K<P0030000003Vc800
i/b001D0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00000000Y0>K<P0030000003Vc800
i/b001X0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P004000001D0i/b000<00000
0>K<P03Vc8005P3Vc8000`000000i/b00>K<P00K0>K<P0<000000P3Vc8000`000000i/b00>K<P009
0>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03Vc8004P3Vc8000180i/b000@000000>K<
P03Vc80000003P3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b002<0i/b000<00000
0>K<P03Vc8005`3Vc8000`000000i/b00>K<P0060>K<P0040000003Vc800i/b0000002X0i/b000<0
00000>K<P03Vc8006P3Vc8000`000000i/b00>K<P0020>K<P0<000000`3Vc8000`000000i/b00>K<
P00C0>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03Vc8005`3Vc804000000H0i/b000<0
00000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00W0>K<P0030000003Vc800i/b00180i/b0000B
0>K<P0@00000303Vc803000000H0i/b000<000000>K<P03Vc8008`3Vc8000`000000i/b00>K<P00H
0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00W
0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P00000000P0000000`3Vc80000000>K<P004
0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc8005P3Vc8000`000000i/b00>K<P00C
0>K<P0<000002P3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b002L0i/b000<00000
0>K<P03Vc8004P3Vc80002/0i/b000<000000>K<P03Vc8008P3Vc8000`000000i/b00>K<P00J0>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00W0>K<
P0030000003Vc800i/b001P0i/b00`0000050>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc8004`3Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b00100i/b00`00000>0>K<
P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8009P3Vc8000`000000i/b00>K<P00B0>K<
P000:P3Vc8000`000000i/b00>K<P00R0>K<P0030000003Vc800i/b001`0i/b00P0000020>K<P003
0000003Vc800i/b000@0i/b000<000000>K<P03Vc800:03Vc8000`000000i/b00>K<P00D0>K<P0<0
00000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8003P3Vc808000001H0i/b000<000000>K<P03Vc800303Vc80300000180i/b000<000000>K<P03V
c8002@3Vc8000`000000i/b00>K<P00U0>K<P0030000003Vc800i/b00180i/b0000Z0>K<P0030000
003Vc800i/b00240i/b000<000000>K<P03Vc8007`3Vc802000000P0i/b000<000000>K<P03Vc800
9`3Vc8000`000000i/b00>K<P00A0>K<P0<000001P3Vc8000`000000i/b00>K<P0030>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc800103Vc80:000000H0i/b000<000000>K<P0000000
1@00000A0>K<P0030000003Vc800i/b000P0i/b00`00000F0>K<P0030000003Vc800i/b000P0i/b0
00<000000>K<P03Vc8009@3Vc8000`000000i/b00>K<P00B0>K<P000:P3Vc8000`000000i/b00>K<
P00P0>K<P0030000003Vc800i/b00200i/b00P0000090>K<P0030000003Vc800i/b002L0i/b000<0
00000>K<P03Vc800303Vc804000000T0i/b000<000000>K<P03Vc8000`3Vc80010000000i/b00>K<
P03Vc80800000100i/b000<000000>K<P03Vc8001@3Vc805000000`0i/b000<000000>K<P03Vc800
103Vc804000001T0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00T0>K<P0030000
003Vc800i/b00180i/b0000Z0>K<P0030000003Vc800i/b001l0i/b000<000000>K<P03Vc800803V
c80010000000i/b00>K<P00000080>K<P0030000003Vc800i/b002L0i/b000<000000>K<P03Vc800
2@3Vc803000000h0i/b000<000000>K<P03Vc8000P3Vc804000000<0i/b000<000000>K<P03Vc800
4`3Vc8000`000000i/b00>K<P0090>K<P0H000001`3Vc8000`000000i/b00>K<P003000001h0i/b0
00<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00U0>K<P0030000003Vc800i/b00140i/b0
000Z0>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03Vc800803Vc8000`000000i/b00>K<
P0020>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8009`3Vc8000`000000i/b00>K<
P0050>K<P0<000004@3Vc8000`000000i/b00>K<P002000000030>K<P0000000i/b000@0i/b000<0
00000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00?0>K<P0H0000000@0i/b00000000000000000
8P3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b002@0i/b000<000000>K<P03Vc800
4@3Vc80002X0i/b000<000000>K<P03Vc8007P3Vc8000`000000i/b00>K<P00O0>K<P0030000003V
c800i/b000@0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00V0>K<P0030000003V
c800i/b00080i/b00`00000E0>K<P0800000103Vc8000`000000i/b00>K<P0030>K<P0030000003V
c800i/b001<0i/b000<000000>K<P03Vc8004P3Vc806000002<0i/b000<000000>K<P03Vc800203V
c8000`000000i/b00>K<P00S0>K<P0030000003Vc800i/b00140i/b0000Z0>K<P0030000003Vc800
i/b001d0i/b000<000000>K<P03Vc8007`3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800
i/b000D0i/b000<000000>K<P03Vc8009`3Vc804000001H0i/b00P0000000`3Vc80000000>K<P003
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00?
0>K<P0<000001@3Vc80300000240i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00S
0>K<P0030000003Vc800i/b00140i/b0000Z0>K<P0030000003Vc800i/b001`0i/b000<000000>K<
P03Vc800803Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000D0i/b000<000000>K<
P03Vc800903Vc804000001H0i/b00P0000030>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc8000`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b000X0i/b0100000080>K<
P0030000003Vc800i/b000<000007`3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b0
0280i/b000<000000>K<P03Vc8004@3Vc80002T0i/b000<000000>K<P03Vc800703Vc8000`000000
i/b00>K<P00P0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8001@3Vc8000`000000
i/b00>K<P00P0>K<P0<000000`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b000@0
i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b001<0
i/b000<000000>K<P03Vc8001`3Vc803000000d0i/b000<000000>K<P03Vc8000P3Vc802000001h0
i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00R0>K<P0030000003Vc800i/b00140
i/b0000Y0>K<P0800000703Vc8000`000000i/b00>K<P00P0>K<P0030000003Vc800i/b000/0i/b0
00<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00M0>K<P0<000001`3Vc8000`000000i/b0
0>K<P00@0>K<P08000001`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P0030>K<P0<00000403Vc8000`000000i/b0
0>K<P0040>K<P0<00000703Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b00240i/b0
00<000000>K<P03Vc8004@3Vc80000X0i/b00P0000020>K<P0030000003Vc800i/b001P0i/b000<0
00000>K<P03Vc8006P3Vc8000`000000i/b00>K<P00P0>K<P0030000003Vc800i/b000d0i/b000<0
00000>K<P03Vc800103Vc8000`000000i/b00>K<P00I0>K<P0<000002P3Vc8000`000000i/b00>K<
P00?0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc8000`00000D0>K<P0030000003V
c800i/b000H0i/b00P00000J0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8008@3V
c8000`000000i/b00>K<P00@0>K<P0000`3Vc805000000<0i/b000<000000>K<P00000006`3Vc800
0`000000i/b00>K<P00J0>K<P0030000003Vc800i/b001l0i/b000<000000>K<P03Vc8003`3Vc800
0`000000i/b00>K<P0040>K<P0030000003Vc800i/b001D0i/b00`00000>0>K<P0030000003Vc800
i/b000`0i/b00P00000;0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc800
0`000000i/b00>K<P00B0>K<P0<000005`3Vc8000`000000i/b00>K<P0080>K<P0<00000603Vc800
0`000000i/b00>K<P0070>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc800403Vc800
0080i/b000@000000>K<P03Vc80000000P3Vc8000`000000i/b00>K<P002000001`0i/b000<00000
0>K<P03Vc8006@3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b00140i/b000<00000
0>K<P03Vc8000`3Vc8000`000000i/b00>K<P00B0>K<P0<000004P3Vc8000`000000i/b00>K<P009
0>K<P08000003P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc8003P3Vc804000000030>K<P0000000i/b001P0i/b000<000000>K<P03Vc8002P3Vc802
000001L0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00P0>K<P0030000003Vc800
i/b00100i/b000020>K<P0040000003Vc800i/b000000080i/b000D000000>K<P03Vc80000000>K<
P002000001X0i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P00O0>K<P0030000003V
c800i/b001<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00>0>K<P0<000005@3V
c8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8000`3V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000X0i/b00`0000060>K<P0030000003V
c800i/b001H0i/b000<000000>K<P03Vc800303Vc803000001D0i/b000<000000>K<P03Vc8001`3V
c8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b00100i/b000020>K<P0040000003Vc800
i/b000000080i/b000<000000>K<P00000001000000J0>K<P0030000003Vc800i/b001L0i/b000<0
00000>K<P03Vc8007`3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b000<0i/b000<0
00000>K<P03Vc8002P3Vc803000001T0i/b000<000000>K<P03Vc8001@3Vc80200000180i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000L0i/b00`00
00090>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc8003P3Vc802000001<0i/b000<0
00000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b00100i/b00003
0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P00G
0>K<P0030000003Vc800i/b00200i/b000<000000>K<P03Vc8005P3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b000L0i/b00`00000L0>K<P0030000003Vc800i/b000@0i/b000<00000
0>K<P03Vc8004P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc8000`3Vc803000000d0i/b000<000000>K<P03Vc8005P3Vc8000`000000i/b00>K<P00@
0>K<P0<000004@3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b001h0i/b000<00000
0>K<P03Vc800403Vc80000@0i/b000D000000>K<P03Vc800i/b00000000O0>K<P0030000003Vc800
i/b001H0i/b000<000000>K<P03Vc800803Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800
i/b00080i/b000<000000>K<P03Vc8000`3Vc80300000200i/b000@000000>K<P03Vc800i/b00P00
000F0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P00300000100i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P00B0>K<P0800000403V
c8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03Vc800403V
c80002P0i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00P0>K<P0030000003Vc800
i/b001X0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b000000002000002<0i/b000@00000
0>K<P00000000000603Vc8000`000000i/b00>K<P0030>K<P0040000003Vc800i/b00>K<P0@00000
503Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b001@0i/b00`00000>0>K<P0030000
003Vc800i/b000H0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P00@0>K<P000:03V
c8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b001l0i/b000<000000>K<P03Vc800703V
c8000`000000i/b00>K<P003000002L0i/b000<000000>K<P03Vc8006@3Vc8000`000000i/b00>K<
P0020>K<P0@000000P3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001L0i/b000<0
00000>K<P03Vc8005P3Vc803000000`0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<
P00M0>K<P0030000003Vc800i/b000l0i/b0000X0>K<P08000005@3Vc8000`000000i/b00>K<P00O
0>K<P0030000003Vc800i/b001h0i/b00P0000020>K<P0030000003Vc800i/b002@0i/b000<00000
0>K<P00000006P3Vc8000`000000i/b00>K<P004000000D0i/b000<000000>K<P03Vc8004`3Vc800
0`000000i/b00>K<P00G0>K<P0030000003Vc800i/b001P0i/b00P00000:0>K<P0030000003Vc800
i/b000H0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P00?0>K<P000:03Vc8000`00
0000i/b00>K<P00C0>K<P0030000003Vc800i/b001l0i/b000<000000>K<P03Vc8007`3Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b00280i/b000@000000>K<P03Vc80000006P3Vc803
000000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800
i/b001L0i/b000<000000>K<P03Vc8006P3Vc803000000P0i/b000<000000>K<P03Vc8001P3Vc800
0`000000i/b00>K<P00L0>K<P0030000003Vc800i/b000l0i/b0000X0>K<P0030000003Vc800i/b0
0180i/b000<000000>K<P03Vc8007`3Vc8000`000000i/b00>K<P00P0>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc800803Vc802000000@0i/b000<000000>K<P03Vc800503Vc8030000
00030>K<P0000000i/b000@0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00C0>K<
P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc800703Vc802000000L0i/b000<000000>K<
P03Vc8001@3Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b000l0i/b0000X0>K<P003
0000003Vc800i/b00140i/b000<000000>K<P03Vc8007`3Vc8000`000000i/b00>K<P00Q0>K<P003
0000003Vc800i/b000<0i/b000<000000>K<P03Vc8007P3Vc8000`000000i/b00>K<P0040>K<P003
0000003Vc800i/b00100i/b0100000050>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03V
c8007P3Vc803000000D0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00K0>K<P003
0000003Vc800i/b000l0i/b0000W0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800
803Vc8000`000000i/b00>K<P00Q0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc800
703Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000`0i/b00`0000090>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00C0>K<P0030000
003Vc800i/b001L0i/b000<000000>K<P03Vc800803Vc802000000<0i/b000<000000>K<P03Vc800
1P3Vc8000`000000i/b00>K<P00J0>K<P0030000003Vc800i/b000l0i/b0000W0>K<P0030000003V
c800i/b00100i/b000<000000>K<P03Vc800803Vc8000`000000i/b00>K<P00R0>K<P0030000003V
c800i/b000@0i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P0070>K<P0030000003V
c800i/b000T0i/b00`00000=0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000`3V
c8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc8008P3V
c803000000030>K<P0000000i/b000H0i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<
P00?0>K<P0009`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b001l0i/b000<00000
0>K<P03Vc8008`3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b001T0i/b000<00000
0>K<P03Vc8002@3Vc8000`000000i/b00>K<P0050>K<P0<00000403Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00G
0>K<P0030000003Vc800i/b002@0i/b00`0000070>K<P0030000003Vc800i/b001T0i/b000<00000
0>K<P03Vc8003`3Vc80002L0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00O0>K<
P0030000003Vc800i/b002@0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00F0>K<
P0800000303Vc8000`000000i/b00>K<P0020>K<P0<00000503Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00G0>K<
P0030000003Vc800i/b002H0i/b00`0000060>K<P0030000003Vc800i/b001T0i/b000<000000>K<
P03Vc8003P3Vc80002L0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00O0>K<P003
0000003Vc800i/b002D0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00E0>K<P003
0000003Vc800i/b000d0i/b01000000G0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03V
c8009P3Vc80010000000i/b00000000000040>K<P0030000003Vc800i/b001T0i/b000<000000>K<
P03Vc8003P3Vc80002L0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00O0>K<P003
0000003Vc800i/b002D0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00C0>K<P003
0000003Vc800i/b000/0i/b01000000K0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03V
c8009`3Vc8000`000000i/b00>K<P00300000080i/b000<000000>K<P03Vc800603Vc8000`000000
i/b00>K<P00>0>K<P0009`3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b001l0i/b0
00<000000>K<P03Vc8009P3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b00140i/b0
00<000000>K<P03Vc8002@3Vc803000000@0i/b000<000000>K<P03Vc800603Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b0
0>K<P00G0>K<P0030000003Vc800i/b002L0i/b000<000000>K<P03Vc8000P3Vc803000001X0i/b0
00<000000>K<P03Vc8003P3Vc80002H0i/b00P00000=0>K<P0030000003Vc800i/b001l0i/b000<0
00000>K<P03Vc8009`3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b00100i/b000<0
00000>K<P03Vc8001`3Vc803000000P0i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<
P0020>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<
P00F0>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03Vc8000`3Vc802000001T0i/b000<0
00000>K<P03Vc8003P3Vc80002H0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00O
0>K<P0030000003Vc800i/b002L0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00>
0>K<P0030000003Vc800i/b000D0i/b00`00000;0>K<P0030000003Vc800i/b001P0i/b000<00000
0>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b001<0i/b000<00000
0>K<P03Vc8005`3Vc8000`000000i/b00>K<P00W0>K<P0030000003Vc800i/b000D0i/b000<00000
0>K<P03Vc8005P3Vc8000`000000i/b00>K<P00>0>K<P0009P3Vc8000`000000i/b00>K<P00;0>K<
P0030000003Vc800i/b001l0i/b000<000000>K<P03Vc800:03Vc8000`000000i/b00>K<P00;0>K<
P0030000003Vc800i/b000/0i/b00P0000040>K<P0@000003`3Vc8000`000000i/b00>K<P00H0>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00D0>K<
P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc8009`3Vc8000`000000i/b00>K<P0040>K<
P0030000003Vc800i/b001H0i/b000<000000>K<P03Vc8003P3Vc80002H0i/b000<000000>K<P03V
c8002P3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b002T0i/b000<000000>K<P03V
c8002`3Vc8000`000000i/b00>K<P00:0>K<P0040000003Vc800i/b00>K<P0<000004`3Vc8000`00
0000i/b00>K<P00H0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`00
0000i/b00>K<P00C0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc800:03Vc8000`00
0000i/b00>K<P0040>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03Vc8003@3Vc80002H0
i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b002X0
i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P0080>K<P0030000003Vc80000000080
00005`3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03V
c800:03Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03V
c8003@3Vc80002H0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00O0>K<P0030000
003Vc800i/b002/0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P0060>K<P0<00000
6P3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800
0`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc800
:03Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc800
3@3Vc80002H0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00O0>K<P0030000003V
c800i/b002`0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P0020>K<P0@000007P3V
c8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000`3V
c8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc800:03V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc8003@3V
c80002H0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800
i/b002d0i/b000<000000>K<P03Vc8003P3Vc804000000030>K<P0000000000001l0i/b000<00000
0>K<P03Vc800603Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc8004`3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b002T0i/b000<00000
0>K<P03Vc8000`3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b000d0i/b0000V0>K<
P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8007P3Vc8000`000000i/b00>K<P00^0>K<
P0030000003Vc800i/b000`0i/b0100000020>K<P0030000003Vc800i/b00200i/b000<000000>K<
P03Vc800603Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc800503Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b002T0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b000d0i/b0000U0>K<P0<0
00001P3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b002h0i/b000<000000>K<P03V
c8002@3Vc803000000<0i/b000<000000>K<P0000000903Vc8000`000000i/b00>K<P00G0>K<P003
0000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00C0>K<P003
0000003Vc800i/b001L0i/b000<000000>K<P03Vc800:@3Vc8000`000000i/b00>K<P0030>K<P003
0000003Vc800i/b001<0i/b000<000000>K<P03Vc8003@3Vc80002D0i/b000<000000>K<P03Vc800
1@3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b002l0i/b000<000000>K<P03Vc800
1P3Vc803000000L0i/b000<000000>K<P03Vc8008`3Vc8000`000000i/b00>K<P00H0>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00D0>K<P0030000
003Vc800i/b001L0i/b000<000000>K<P03Vc800:@3Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b001<0i/b000<000000>K<P03Vc8003@3Vc80000`0i/b00`0000050>K<P0800000103V
c806000000D0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00O0>K<P0030000003V
c800i/b00300i/b000<000000>K<P03Vc8000P3Vc804000000T0i/b000<000000>K<P00000009@3V
c8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3V
c8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc800:P3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc800303V
c80000/0i/b000@000000>K<P03Vc80000001@3Vc802000000D0i/b000D000000>K<P03Vc800i/b0
000000050>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b0
0>K<P00a0>K<P0030000003Vc800000000800000303Vc80010000000i/b00>K<P000000U0>K<P003
0000003Vc800i/b001P0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<P003
0000003Vc800i/b001@0i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P00Z0>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00<0>K<P000
2P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc800
1P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc800
<@3Vc803000000h0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00S0>K<P0030000
003Vc800i/b001L0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000
003Vc800i/b001<0i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P00Z0>K<P0050000
003Vc800i/b00>K<P0000000503Vc8000`000000i/b00>K<P00<0>K<P0002P3Vc8000`000000i/b0
0>K<P0020>K<P0030000003Vc800i/b000/0i/b00P0000060>K<P0030000003Vc800i/b000L0i/b0
00<000000>K<P03Vc8006@3Vc8000`000000i/b00>K<P00_0>K<P0<0000000<0i/b00000003Vc800
3@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b002<0i/b000<000000>K<P03Vc800
603Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800
503Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b002X0i/b000<000000>K<P03Vc800
0P3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000`0i/b0000:0>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc800303Vc802000000D0i/b000<000000>K<P03Vc800203V
c8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b002d0i/b00`0000040>K<P0030000003V
c800i/b000/0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00S0>K<P0030000003V
c800i/b001L0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003V
c800i/b001<0i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P00Z0>K<P0050000003V
c800i/b00>K<P00000004`3Vc8000`000000i/b00>K<P00<0>K<P0002P3Vc8000`000000i/b00>K<
P0020>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<
P00:0>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc800:P3Vc804000000H0i/b000<0
00000>K<P03Vc800303Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b00280i/b000<0
00000>K<P03Vc800603Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b000<0
00000>K<P03Vc800503Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b002/0i/b000D0
00000>K<P03Vc800i/b00000000B0>K<P0030000003Vc800i/b000`0i/b0000;0>K<P0040000003V
c800i/b0000000/0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b000/0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P00W0>K<P0<00000
2P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800
8`3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800
0`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001P0i/b000<000000>K<P03Vc800
:`3Vc80010000000i/b00>K<P000000B0>K<P0030000003Vc800i/b000`0i/b0000;0>K<P0@00000
2`3Vc805000000D0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00B0>K<P0030000
003Vc800i/b002D0i/b00`00000=0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc800
2@3Vc8000`000000i/b00>K<P00R0>K<P0030000003Vc800i/b001P0i/b000<000000>K<P03Vc800
0P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc800
5`3Vc8000`000000i/b00>K<P00[0>K<P0050000003Vc800i/b00>K<P00000004@3Vc8000`000000
i/b00>K<P00<0>K<P000903Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b00100i/b0
00<000000>K<P03Vc8008`3Vc80300000100i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b0
0>K<P00;0>K<P0030000003Vc800i/b00280i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b0
0>K<P00H0>K<P0030000003Vc800i/b002/0i/b000@000000>K<P03Vc80000004P3Vc8000`000000
i/b00>K<P00;0>K<P000903Vc802000000l0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b0
0>K<P00Q0>K<P0<000004`3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000`0i/b0
00<000000>K<P03Vc8008`3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b00080i/b0
00<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b001L0i/b0
00<000000>K<P03Vc800;03Vc80010000000i/b00>K<P000000A0>K<P0030000003Vc800i/b000/0
i/b0000T0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800303Vc8000`000000i/b0
0>K<P00N0>K<P0@000005P3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000h0i/b0
00<000000>K<P03Vc8008P3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001P0i/b0
00<000000>K<P03Vc800;03Vc8000`000000i/b00000000A0>K<P0030000003Vc800i/b000/0i/b0
000T0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<
P00L0>K<P0<000006P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000l0i/b000<0
00000>K<P03Vc8008`3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b00080i/b000<0
00000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00A0>K<P0P000005@3Vc8000`000000i/b00>K<
P00/0>K<P0040000003Vc800i/b000000100i/b000<000000>K<P03Vc8002`3Vc80002@0i/b000<0
00000>K<P03Vc8004@3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b001X0i/b00`00
000M0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<
P00R0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b000T0i/b01`0000080>K<P0T000003@3Vc8000`000000i/b00>K<
P00/0>K<P0040000003Vc800i/b0000000l0i/b000<000000>K<P03Vc8002`3Vc80002<0i/b000<0
00000>K<P03Vc8004`3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b001P0i/b00`00
000P0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<
P00R0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b00080i/b01`00000H0>K<P0X000000`3Vc8000`000000i/b00>K<
P00]0>K<P0030000003Vc800000000l0i/b000<000000>K<P03Vc8002`3Vc80002<0i/b000<00000
0>K<P03Vc800503Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b001D0i/b00`00000S
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P00R
0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P002
0>K<P0D00000:@3Vc806000002h0i/b000<000000>K<P00000003P3Vc8000`000000i/b00>K<P00;
0>K<P0008`3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc8004P3Vc804000002H0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00F0>K<
P0030000003Vc800i/b00280i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b000800000=03Vc803000002/0i/b000<000000>K<P00000003P3Vc8000`00
0000i/b00>K<P00;0>K<P0008`3Vc8000`000000i/b00>K<P00F0>K<P0050000003Vc800i/b00>K<
P00000004P3Vc803000002X0i/b000D000000>K<P03Vc800i/b00000000I0>K<P0030000003Vc800
i/b00280i/b000<000000>K<P03Vc8005`3Vc80010000000i/b00>K<P03Vc804000003T0i/b00`00
000Y0>K<P0030000003Vc800000000h0i/b000<000000>K<P03Vc8002P3Vc80002<0i/b000<00000
0>K<P03Vc8005`3Vc8000`000000i/b00000000@0>K<P0<00000;@3Vc8001@000000i/b00>K<P03V
c800000001X0i/b000<000000>K<P03Vc8008P3Vc8000`000000i/b00>K<P00G0>K<P0<00000@03V
c804000002H0i/b00P00000>0>K<P0030000003Vc800i/b000X0i/b0000S0>K<P0030000003Vc800
i/b001P0i/b000<000000>K<P03Vc800303Vc80300000300i/b000@000000>K<P03Vc8000000703V
c8000`000000i/b00>K<P00R0>K<P0030000003Vc800i/b001@0i/b00P0000170>K<P0<00000903V
c802000000d0i/b000<000000>K<P03Vc8002P3Vc80002<0i/b000<000000>K<P03Vc8006@3Vc800
0`000000i/b00>K<P0080>K<P0<00000<`3Vc8000`000000i/b00000000M0>K<P0030000003Vc800
i/b00280i/b000<000000>K<P03Vc8004P3Vc802000004`0i/b00`00000Q0>K<P08000003@3Vc800
0`000000i/b00>K<P00:0>K<P0008P3Vc802000001`0i/b000<000000>K<P03Vc8000`3Vc8040000
03H0i/b00P00000O0>K<P0030000003Vc800i/b00280i/b000<000000>K<P03Vc8003`3Vc8020000
0540i/b00`00000O0>K<P0800000303Vc8000`000000i/b00>K<P00:0>K<P0008P3Vc8000`000000
i/b00>K<P00L0>K<P0030000003Vc800000000800000>P3Vc8000`000000i/b00>K<P00O0>K<P003
0000003Vc800i/b00240i/b000<000000>K<P03Vc8003@3Vc802000005H0i/b00`00000M0>K<P003
0000003Vc800i/b000X0i/b000<000000>K<P03Vc8002P3Vc8000280i/b000<000000>K<P03Vc800
6`3Vc803000003`0i/b00P00000Q0>K<P0030000003Vc800i/b00280i/b000<000000>K<P03Vc800
2P3Vc802000005/0i/b00`00000K0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc800
2P3Vc8000280i/b000<000000>K<P03Vc800603Vc80300000080i/b000<000000>K<P03Vc800>@3V
c802000002<0i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P0090>K<P0030000003V
c800i/b005h0i/b00`00000I0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8002@3V
c8000280i/b000<000000>K<P03Vc8005@3Vc803000000H0i/b000<000000>K<P03Vc800=`3Vc800
0`000000i/b00000000S0>K<P0030000003Vc800i/b00280i/b000<000000>K<P03Vc8001P3Vc802
000006@0i/b01000000E0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8002@3Vc800
0280i/b000<000000>K<P03Vc8004@3Vc804000000X0i/b000<000000>K<P03Vc800=@3Vc8001000
0000i/b00>K<P000000T0>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc800103Vc802
000006X0i/b00`00000C0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8002@3Vc800
0280i/b000<000000>K<P03Vc8003P3Vc803000000l0i/b000<000000>K<P03Vc800<`3Vc8001@00
0000i/b00>K<P03Vc800000002D0i/b000<000000>K<P03Vc8008@3Vc80010000000i/b00>K<P03V
c802000006l0i/b00`00000@0>K<P08000002@3Vc8000`000000i/b00>K<P0090>K<P0008P3Vc800
0`000000i/b00>K<P00;0>K<P0<000004`3Vc8000`000000i/b00>K<P00a0>K<P0030000003Vc800
i/b00080i/b000<000000>K<P03Vc8008`3Vc8000`000000i/b00>K<P00Q0>K<P0040000003Vc800
0000000007@0i/b00`00000>0>K<P0800000203Vc8000`000000i/b00>K<P0090>K<P0008P3Vc800
0`000000i/b00>K<P0080>K<P0<000005`3Vc8000`000000i/b00>K<P00`0>K<P0030000003Vc800
i/b00080i/b000<000000>K<P03Vc800903Vc8000`000000i/b00>K<P00Q0>K<P0030000003Vc800
i/b007L0i/b00`00000;0>K<P0800000203Vc8000`000000i/b00>K<P0090>K<P0008@3Vc8000`00
0000i/b00>K<P0060>K<P0<000006`3Vc8000`000000i/b00>K<P00^0>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P03Vc8009@3Vc8000`000000i/b00>K<P00N0>K<P0800000O@3Vc8030000
00T0i/b00P0000070>K<P0030000003Vc800i/b000T0i/b0000Q0>K<P0030000003Vc800i/b00080
i/b01000000O0>K<P0030000003Vc800i/b002`0i/b000<000000>K<P03Vc800103Vc8000`000000
i/b00>K<P00U0>K<P0030000003Vc800i/b001d0i/b000<000000>K<P03Vc800P03Vc804000000D0
i/b000<000000>K<P00000001P3Vc8000`000000i/b00>K<P0090>K<P0008@3Vc805000002@0i/b0
00<000000>K<P03Vc800:P3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b002H0i/b0
00<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P0250>K<P0<000000`3Vc8000`000000i/b0
000000060>K<P0030000003Vc800i/b000P0i/b0000Q0>K<P0800000:03Vc8000`000000i/b00>K<
P00X0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8009P3Vc8000`000000i/b00>K<
P00I0>K<P0800000R`3Vc804000000030>K<P0000000i/b000D0i/b000<000000>K<P03Vc800203V
c8000280i/b000<000000>K<P03Vc8009P3Vc8000`000000i/b00>K<P00W0>K<P0030000003Vc800
i/b000L0i/b000<000000>K<P03Vc8009`3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800
i/b008h0i/b00P0000000`3Vc80000000>K<P0040>K<P0030000003Vc800i/b000P0i/b0000S0>K<
P08000009`3Vc8000`000000i/b00>K<P00U0>K<P0030000003Vc800i/b000P0i/b000<000000>K<
P03Vc800:03Vc8000`000000i/b00>K<P00D0>K<P0800000U@3Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b000P0i/b0000U0>K<P0030000003Vc800i/b002D0i/b000<000000>K<P03V
c8008`3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03V
c8004`3Vc8000`000000i/b00>K<P02F0>K<P0050000003Vc800i/b00>K<P00000002P3Vc80002H0
i/b000<000000>K<P03Vc8009@3Vc8000`000000i/b00>K<P00Q0>K<P0030000003Vc800i/b000X0
i/b000<000000>K<P03Vc800:@3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b009L0
i/b000D000000>K<P03Vc800i/b00000000:0>K<P0009`3Vc802000002H0i/b000<000000>K<P03V
c8007`3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b002T0i/b000<000000>K<P03V
c8003`3Vc802000009/0i/b000@000000>K<P03Vc80000002P3Vc80002T0i/b000<000000>K<P03V
c800903Vc8000`000000i/b00>K<P00M0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03V
c800:P3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b009`0i/b000<000000>K<P000
00002P3Vc80002X0i/b000<000000>K<P03Vc800903Vc8000`000000i/b00>K<P00L0>K<P0030000
003Vc800i/b000`0i/b000<000000>K<P03Vc800:`3Vc8000`000000i/b00>K<P00;0>K<P0030000
003Vc800i/b009h0i/b000<000000>K<P00000002@3Vc80002/0i/b000<000000>K<P03Vc800903V
c8000`000000i/b00>K<P00J0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800:`3V
c8000`000000i/b00>K<P0090>K<P0800000X@3Vc8000`000000i/b0000000090>K<P000;03Vc802
000002D0i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800
i/b002d0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P02R0>K<P08000002@3Vc800
02h0i/b000<000000>K<P03Vc8008P3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b0
00h0i/b000<000000>K<P03Vc800;P3Vc8000`000000i/b00>K<P0040>K<P0800000Y@3Vc8020000
00T0i/b0000_0>K<P0030000003Vc800i/b00280i/b000<000000>K<P03Vc8005@3Vc8000`000000
i/b00>K<P00?0>K<P0030000003Vc800i/b002h0i/b000<000000>K<P03Vc8000`3Vc8000`000000
i/b00>K<P02Q0>K<P0@000002`3Vc8000300i/b00P00000S0>K<P0030000003Vc800i/b001<0i/b0
00<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00_0>K<P0050000003Vc800i/b00>K<P000
0000X03Vc804000000l0i/b0000b0>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc800
4@3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b002l0i/b000@000000>K<P0000000
0000W@3Vc804000001<0i/b0000c0>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc800
3`3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b00300i/b000<000000>K<P03Vc800
V@3Vc804000001L0i/b0000d0>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc8003@3V
c8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b002l0i/b000<000000>K<P03Vc800U`3V
c803000001/0i/b0000e0>K<P08000008P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800
i/b001@0i/b000<000000>K<P03Vc800;P3Vc8000`000000i/b00>K<P02D0>K<P0@000007P3Vc800
03L0i/b000<000000>K<P03Vc800803Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b0
01D0i/b000<000000>K<P03Vc800;@3Vc8000`000000i/b00>K<P02A0>K<P0@000008P3Vc80003P0
i/b000<000000>K<P03Vc800803Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b001H0
i/b000<000000>K<P03Vc800;03Vc8000`000000i/b00>K<P02>0>K<P0@000009P3Vc80003T0i/b0
0P00000Q0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8005P3Vc8000`000000i/b0
0>K<P00[0>K<P0030000003Vc800i/b008`0i/b00`00000Z0>K<P000>`3Vc8000`000000i/b00>K<
P00N0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<
P00Z0>K<P0030000003Vc800i/b008T0i/b01000000]0>K<P000?03Vc8000`000000i/b00>K<P00N
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P00Y
0>K<P0030000003Vc800i/b008H0i/b01000000a0>K<P000?@3Vc8000`000000i/b00>K<P00N0>K<
P0050000003Vc800i/b00>K<P00000006`3Vc8000`000000i/b00>K<P00X0>K<P0030000003Vc800
i/b008<0i/b01000000e0>K<P000?P3Vc802000001l0i/b000<000000>K<P0000000703Vc8000`00
0000i/b00>K<P00W0>K<P0030000003Vc800i/b00800i/b01000000i0>K<P000@03Vc8000`000000
i/b00>K<P00M0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8009P3Vc8000`000000
i/b00>K<P01n0>K<P0<00000?@3Vc8000440i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b0
0>K<P00J0>K<P0030000003Vc800i/b002D0i/b000<000000>K<P03Vc800N`3Vc80400000400i/b0
00120>K<P08000007@3Vc8000`000000i/b00>K<P00I0>K<P0030000003Vc800i/b002D0i/b000<0
00000>K<P03Vc800N03Vc804000004@0i/b000140>K<P0030000003Vc800i/b001/0i/b000<00000
0>K<P03Vc800603Vc8000`000000i/b00>K<P00T0>K<P0030000003Vc800i/b007D0i/b010000018
0>K<P000A@3Vc8000`000000i/b00>K<P00K0>K<P0030000003Vc800i/b001L0i/b000<000000>K<
P03Vc8008`3Vc8000`000000i/b00>K<P01c0>K<P0<00000C03Vc80004H0i/b000<000000>K<P03V
c8006`3Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b00280i/b000<000000>K<P03V
c800L03Vc804000004l0i/b000170>K<P08000006`3Vc8000`000000i/b00>K<P00F0>K<P0030000
003Vc800i/b00240i/b000<000000>K<P03Vc800K@3Vc804000005<0i/b000190>K<P0030000003V
c800i/b001T0i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00P0>K<P0030000003V
c800i/b006X0i/b01000001G0>K<P000BP3Vc8000`000000i/b00>K<P00I0>K<P0030000003Vc800
i/b001@0i/b000<000000>K<P03Vc8007`3Vc8000`000000i/b00>K<P01W0>K<P0@00000F`3Vc800
04/0i/b00P00000J0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc8007P3Vc8000`00
0000i/b00>K<P01U0>K<P0<00000G`3Vc80004d0i/b000<000000>K<P03Vc8005`3Vc8000`000000
i/b00>K<P00C0>K<P0030000003Vc800i/b001d0i/b000<000000>K<P03Vc800HP3Vc80400000680
i/b0001>0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b0
0>K<P00L0>K<P0030000003Vc800i/b005l0i/b01000001V0>K<P000C`3Vc8000`000000i/b00>K<
P00G0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<
P01L0>K<P0@00000JP3Vc8000500i/b00P00000H0>K<P0030000003Vc800i/b00100i/b000<00000
0>K<P03Vc8006P3Vc8000`000000i/b00>K<P01I0>K<P0@00000KP3Vc8000580i/b000<000000>K<
P03Vc8005@3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b001T0i/b000<000000>K<
P03Vc800E`3Vc80300000780i/b0001C0>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03V
c8003`3Vc8000`000000i/b00>K<P00G0>K<P0800000EP3Vc804000007D0i/b0001D0>K<P0800000
5P3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03Vc800
DP3Vc804000007T0i/b0001F0>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc8003@3V
c8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b004l0i/b01000001m0>K<P000E`3Vc800
0`000000i/b00>K<P00C0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800503Vc800
0`000000i/b00>K<P01=0>K<P0<00000P@3Vc80005P0i/b000<000000>K<P03Vc8004`3Vc8000`00
0000i/b00>K<P00<0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc800BP3Vc8040000
08@0i/b0001I0>K<P0800000503Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b001<0
i/b000<000000>K<P03Vc800A`3Vc804000008P0i/b0001K0>K<P0030000003Vc800i/b00180i/b0
00<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b004@0i/b0
1000002<0>K<P000G03Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000T0i/b000<0
00000>K<P03Vc8004@3Vc8000`000000i/b00>K<P0110>K<P0@00000T03Vc80005d0i/b00P00000B
0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00o
0>K<P0<00000U03Vc80005l0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P0070>K<
P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800?03Vc804000009L0i/b0001P0>K<P003
0000003Vc800i/b00100i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00>0>K<P003
0000003Vc800i/b003T0i/b01000002K0>K<P000H@3Vc8000`000000i/b00>K<P00?0>K<P0030000
003Vc800i/b000H0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00f0>K<P0@00000
W`3Vc8000680i/b00P00000@0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800303V
c8000`000000i/b00>K<P00c0>K<P0@00000X`3Vc80006@0i/b000<000000>K<P03Vc8003P3Vc800
0`000000i/b00>K<P0040>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc800<@3Vc803
00000:L0i/b0001U0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8000`3Vc8000`00
0000i/b00>K<P00:0>K<P0030000003Vc800i/b002h0i/b01000002Z0>K<P000IP3Vc802000000h0
i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b002/0
i/b01000002^0>K<P000J03Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b00080i/b0
00<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00X0>K<P0@00000/P3Vc80006T0i/b000<0
00000>K<P03Vc800303Vc8001@000000i/b00>K<P03Vc800000000T0i/b000<000000>K<P03Vc800
9P3Vc80300000;H0i/b0001Z0>K<P0030000003Vc800i/b000`0i/b000@000000>K<P03Vc8000000
203Vc8000`000000i/b00>K<P00S0>K<P0@00000^@3Vc80006/0i/b00P00000<0>K<P0040000003V
c800i/b0000000L0i/b000<000000>K<P03Vc800803Vc80400000;d0i/b0001]0>K<P0030000003V
c800i/b000X0i/b000<000000>K<P00000001P3Vc8000`000000i/b00>K<P00M0>K<P0@00000`@3V
c80006h0i/b000<000000>K<P03Vc8002P3Vc802000000D0i/b000<000000>K<P03Vc8006P3Vc804
00000<D0i/b0001_0>K<P08000002`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b0
01P0i/b00`0000390>K<P000L@3Vc8000`000000i/b00>K<P0070>K<P08000000`3Vc8000`000000
i/b00>K<P00E0>K<P0@00000c03Vc8000780i/b000<000000>K<P03Vc8001P3Vc8001@000000i/b0
0000003Vc800000001@0i/b01000003@0>K<P000L`3Vc8000`000000i/b00>K<P0050>K<P0040000
003Vc800i/b000000140i/b01000003D0>K<P000M03Vc802000000D0i/b000<000000>K<P03Vc800
3`3Vc80300000=P0i/b0001f0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3V
c80400000=/0i/b0001g0>K<P0050000003Vc800i/b00>K<P00000002@3Vc80400000=l0i/b0001h
0>K<P080000000<0i/b00000003Vc800103Vc80400000><0i/b0001j0>K<P080000000<0i/b00000
000000000P00003W0>K<P000N`3Vc80200000>/0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o
0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003<0>K<P0@00000803Vc805000007<0i/b0
003>0>K<P0030000003Vc800i/b00280i/b000<000000>K<P03Vc800LP3Vc80008`0i/b00`000002
0>K<P080000000<0i/b000000000000010000000103Vc80000000000003Vc803000000<0i/b01P00
00070>K<P0D000000`3Vc805000000D0i/b0100000030>K<P0<0000000<0i/b00000003Vc8000P3V
c806000000<0i/b010000000103Vc80000000000000000020>K<P0<000000P3Vc804000000D0i/b0
00<000000>K<P03Vc800LP3Vc80008d0i/b000@000000>K<P03Vc80000000`3Vc8001@000000i/b0
0>K<P03Vc800000000<0i/b00P0000030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8002@3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03V
c800103Vc80010000000i/b00>K<P03Vc80200000080i/b000<000000>K<P03Vc8000P3Vc8001@00
0000i/b00>K<P03Vc800000000H0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P002
000000<0i/b00P0000030>K<P0800000L`3Vc80008d0i/b000@000000>K<P03Vc80000000`3Vc800
1@000000i/b00>K<P03Vc800000000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8000P3Vc80010000000i/b00>K<
P00000040>K<P0040000003Vc800i/b0000000L0i/b000<000000>K<P03Vc8000P3Vc80010000000
i/b00>K<P00000080>K<P0040000003Vc800i/b000000780i/b0002=0>K<P0<000001@3Vc8040000
00<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b0
00T0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0030>K<P0H000000P3Vc8000`00
0000i/b00>K<P0020>K<P0040000003Vc800i/b0000000@0i/b000<000000>K<P03Vc8001P000002
0>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc8000000203Vc8001@000000i/b00>K<
P03Vc80000000740i/b0002=0>K<P0030000003Vc800i/b0008000001P3Vc80010000000i/b00>K<
P03Vc802000000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0090>K<P0030000
003Vc800i/b000D0i/b00P0000040>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc800
00000`3Vc80200000080i/b000<000000>K<P03Vc8000P3Vc80010000000i/b00>K<P00000040>K<
P0040000003Vc800i/b0000000@0i/b000<000000>K<P03Vc8000P0000030>K<P0040000003Vc800
i/b0000000@0i/b000<000000>K<P03Vc800K`3Vc80008d0i/b000D000000>K<P03Vc800i/b00000
00030>K<P0@000000`3Vc8000`000000i/b000000002000000@0i/b00`0000090>K<P0D000000`3V
c803000000030>K<P0000000000000<0i/b0100000040>K<P0<0000000<0i/b00000000000000P00
00030>K<P08000000`3Vc80400000080i/b01P0000040>K<P0D0000000@0i/b00000000000000000
0`3Vc80200000700i/b0002=0>K<P0050000003Vc800i/b00>K<P00000002P3Vc8000`000000i/b0
0>K<P00D0>K<P0030000003Vc800i/b00;80i/b0002<0>K<P0D000002P3Vc802000001H0i/b01000
002a0>K<P000YP3Vc8000`000000i/b00>K<P02o0>K<P000YP3Vc8000`000000i/b00>K<P02o0>K<
P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000\
\>"],
  ImageRangeCache->{{{0, 359}, {324.125, 0}} -> {-0.103434, -0.0291554, \
0.00390322, 0.00390322}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
        Graphics3D[{Line /@ Transpose[colldata[\([All, All, {2, 1, 4}]\)]], 
            Line /@ colldata[\([All, All, {2, 1, 4}]\)]}\ , 
          Axes \[Rule] True, 
          AxesLabel \[Rule] {\*"\"\<\[Omega]1/\!\(\[Omega]\_0\)\>\"", \*"\"\<\
\[Omega]/\!\(\[Omega]\_0\)\>\"", "\<\>"}, 
          AxesEdge \[Rule] {{\(-1\), \(-1\)}, {1, \(-1\)}, {\(-1\), \(-1\)}}, 
          PlotLabel -> "\<Amplitude\>"]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.25199 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128737 1.26513 1.29779e-16 1.26513 [
[.5 1.26449 -29 0 ]
[.5 1.26449 29 10.125 ]
[.08486 .23812 -17.4329 -9 ]
[.08486 .23812 .56707 0 ]
[.2306 .18068 -16.8038 -9 ]
[.2306 .18068 1.19621 0 ]
[.38246 .12085 -5.39155 -9 ]
[.38246 .12085 .60845 0 ]
[.54084 .05848 -15.5455 -9 ]
[.54084 .05848 2.45448 0 ]
[.70616 -0.00659 -14.9164 -9 ]
[.70616 -0.00659 3.08361 0 ]
[.33317 .05902 -14.3775 -9.8125 ]
[.33317 .05902 1.62253 0 ]
[.7903 .06173 0 -6.2174 ]
[.7903 .06173 18 2.7826 ]
[.86367 .17463 0 -6.13678 ]
[.86367 .17463 18 2.86322 ]
[.93166 .27928 0 -6.0634 ]
[.93166 .27928 18 2.9366 ]
[.92006 .11991 0 -6.71199 ]
[.92006 .11991 10 3.10051 ]
[.0651 .27682 -6 -2.74332 ]
[.0651 .27682 0 6.25668 ]
[.03697 .54751 -18 -2.90936 ]
[.03697 .54751 0 6.09064 ]
[.00489 .85637 -18 -3.10045 ]
[.00489 .85637 0 5.89955 ]
[ 0 0 0 0 ]
[ 1 1.25199 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.26449 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Amplitude) show
117.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.08146 .25523 m
.73171 0 L
s
.09567 .24966 m
.10107 .25543 L
s
[(0.8)] .08486 .23812 .93699 1 Mshowa
.24096 .19263 m
.24614 .1986 L
s
[(0.9)] .2306 .18068 .86709 1 Mshowa
.39232 .13322 m
.39724 .1394 L
s
[(1)] .38246 .12085 .79718 1 Mshowa
.55014 .07127 m
.55479 .07767 L
s
[(1.1)] .54084 .05848 .72728 1 Mshowa
.71484 .00662 m
.71919 .01323 L
s
[(1.2)] .70616 -0.00659 .65738 1 Mshowa
.125 Mabswid
.12426 .23844 m
.12748 .24192 L
s
.15308 .22712 m
.15627 .23063 L
s
.18213 .21572 m
.1853 .21925 L
s
.21142 .20422 m
.21456 .20778 L
s
.27073 .18094 m
.27381 .18455 L
s
.30075 .16916 m
.3038 .17279 L
s
.33102 .15728 m
.33404 .16094 L
s
.36154 .1453 m
.36453 .14898 L
s
.42335 .12104 m
.42627 .12477 L
s
.45465 .10875 m
.45754 .11251 L
s
.48621 .09636 m
.48907 .10015 L
s
.51804 .08387 m
.52086 .08768 L
s
.58251 .05856 m
.58527 .06242 L
s
.61517 .04574 m
.61789 .04963 L
s
.64811 .03282 m
.65079 .03673 L
s
.68133 .01978 m
.68397 .02371 L
s
gsave
.33317 .05902 -75.3775 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.000 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.73171 0 m
.9208 .29074 L
s
.77553 .06737 m
.76814 .07019 L
s
[(0.1)] .7903 .06173 -1 .38164 Mshowa
.8488 .18004 m
.84137 .18274 L
s
[(0.2)] .86367 .17463 -1 .36373 Mshowa
.91672 .28447 m
.90925 .28706 L
s
[(0.3)] .93166 .27928 -1 .34742 Mshowa
.125 Mabswid
.79064 .09061 m
.7862 .09229 L
s
.80552 .11349 m
.80108 .11515 L
s
.82017 .13602 m
.81572 .13766 L
s
.8346 .1582 m
.83014 .15983 L
s
.8628 .20155 m
.85833 .20316 L
s
.87658 .22275 m
.87211 .22434 L
s
.89016 .24363 m
.88569 .24521 L
s
.90354 .2642 m
.89906 .26577 L
s
.76017 .04376 m
.75574 .04547 L
s
.74457 .01978 m
.74015 .0215 L
s
gsave
.92006 .11991 -61 -10.712 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08146 .25523 m
0 1.04559 L
s
.07983 .27107 m
.08719 .2682 L
s
[(0)] .0651 .27682 1 -0.39037 Mshowa
.05188 .54224 m
.05933 .5396 L
s
[(0.2)] .03697 .54751 1 -0.35348 Mshowa
.01999 .85167 m
.02754 .84932 L
s
[(0.4)] .00489 .85637 1 -0.31101 Mshowa
.125 Mabswid
.07317 .33567 m
.0776 .33398 L
s
.0663 .40233 m
.07075 .40067 L
s
.05921 .47115 m
.06367 .46953 L
s
.04431 .61571 m
.04879 .61416 L
s
.03648 .69168 m
.04098 .69018 L
s
.02837 .77029 m
.03289 .76883 L
s
.0113 .93597 m
.01584 .93461 L
s
.00229 1.02336 m
.00685 1.02205 L
s
.25 Mabswid
.08146 .25523 m
0 1.04559 L
s
0 1.04559 m
.28068 1.25199 L
s
.28068 1.25199 m
.31357 .50112 L
s
.31357 .50112 m
.08146 .25523 L
s
.73171 0 m
.9208 .29074 L
s
.9208 .29074 m
1 1.07583 L
s
1 1.07583 m
.78056 .82375 L
s
.78056 .82375 m
.73171 0 L
s
.08146 .25523 m
0 1.04559 L
s
0 1.04559 m
.78056 .82375 L
s
.78056 .82375 m
.73171 0 L
s
.73171 0 m
.08146 .25523 L
s
.31357 .50112 m
.9208 .29074 L
s
.9208 .29074 m
1 1.07583 L
s
1 1.07583 m
.28068 1.25199 L
s
.28068 1.25199 m
.31357 .50112 L
s
0 0 m
1 0 L
1 1.25199 L
0 1.25199 L
closepath
clip
newpath
.5 Mabswid
.22875 .55719 m
.31084 .75486 L
s
.31084 .75486 m
.45335 .94112 L
s
.14405 .36368 m
.22875 .55719 L
s
.22875 .55719 m
.36753 .71464 L
s
.09908 .28281 m
.14405 .36368 L
s
.14405 .36368 m
.28438 .40452 L
s
.09908 .28281 m
.24321 .25516 L
s
.24321 .25516 m
.28438 .40452 L
s
.24321 .25516 m
.31467 .32145 L
s
.28438 .40452 m
.36753 .71464 L
s
.28438 .40452 m
.35369 .59025 L
s
.36753 .71464 m
.45335 .94112 L
s
.45335 .94112 m
.53273 1.0772 L
s
.84397 .32404 m
.92418 .53039 L
s
.77647 .83396 m
.92418 .53039 L
s
.36753 .71464 m
.44284 .91629 L
s
.76228 .12497 m
.84397 .32404 L
s
.68989 .59421 m
.84397 .32404 L
s
.31467 .32145 m
.35369 .59025 L
s
.31467 .32145 m
.3624 .80664 L
s
.55613 .13139 m
.60025 .27941 L
s
.55613 .13139 m
.72126 .03956 L
s
.47479 .25656 m
.55613 .13139 L
s
.72126 .03956 m
.76228 .12497 L
s
.60025 .27941 m
.76228 .12497 L
s
.60025 .27941 m
.68989 .59421 L
s
.51968 .52556 m
.60025 .27941 L
s
.68989 .59421 m
.77647 .83396 L
s
.70011 1.03081 m
.77647 .83396 L
s
.44284 .91629 m
.53273 1.0772 L
s
.53273 1.0772 m
.60037 1.13862 L
s
.61239 .86151 m
.68989 .59421 L
s
.47479 .25656 m
.51968 .52556 L
s
.39831 .79474 m
.47479 .25656 L
s
.35369 .59025 m
.44284 .91629 L
s
.35369 .59025 m
.41205 .94158 L
s
.61239 .86151 m
.70011 1.03081 L
s
.63442 1.13015 m
.70011 1.03081 L
s
.44284 .91629 m
.51 1.05452 L
s
.51 1.05452 m
.60037 1.13862 L
s
.60037 1.13862 m
.61744 1.13816 L
s
.52754 1.05855 m
.61744 1.13816 L
s
.61744 1.13816 m
.63442 1.13015 L
s
.54507 1.04521 m
.63442 1.13015 L
s
.51968 .52556 m
.61239 .86151 L
s
.44804 .9311 m
.51968 .52556 L
s
.54507 1.04521 m
.61239 .86151 L
s
.41205 .94158 m
.51 1.05452 L
s
.51 1.05452 m
.52754 1.05855 L
s
.42947 .97084 m
.52754 1.05855 L
s
.52754 1.05855 m
.54507 1.04521 L
s
.44804 .9311 m
.54507 1.04521 L
s
.3624 .80664 m
.41205 .94158 L
s
.41205 .94158 m
.42947 .97084 L
s
.3624 .80664 m
.37704 .92361 L
s
.39831 .79474 m
.44804 .9311 L
s
.42947 .97084 m
.44804 .9311 L
s
.37704 .92361 m
.39831 .79474 L
s
.37704 .92361 m
.42947 .97084 L
s
.25 Mabswid
.73171 0 m
.9208 .29074 L
s
.9208 .29074 m
1 1.07583 L
s
1 1.07583 m
.78056 .82375 L
s
.78056 .82375 m
.73171 0 L
s
.08146 .25523 m
0 1.04559 L
s
0 1.04559 m
.78056 .82375 L
s
.78056 .82375 m
.73171 0 L
s
.73171 0 m
.08146 .25523 L
s
.08146 .25523 m
.73171 0 L
s
.09567 .24966 m
.10107 .25543 L
s
[(0.8)] .08486 .23812 .93699 1 Mshowa
.24096 .19263 m
.24614 .1986 L
s
[(0.9)] .2306 .18068 .86709 1 Mshowa
.39232 .13322 m
.39724 .1394 L
s
[(1)] .38246 .12085 .79718 1 Mshowa
.55014 .07127 m
.55479 .07767 L
s
[(1.1)] .54084 .05848 .72728 1 Mshowa
.71484 .00662 m
.71919 .01323 L
s
[(1.2)] .70616 -0.00659 .65738 1 Mshowa
.125 Mabswid
.12426 .23844 m
.12748 .24192 L
s
.15308 .22712 m
.15627 .23063 L
s
.18213 .21572 m
.1853 .21925 L
s
.21142 .20422 m
.21456 .20778 L
s
.27073 .18094 m
.27381 .18455 L
s
.30075 .16916 m
.3038 .17279 L
s
.33102 .15728 m
.33404 .16094 L
s
.36154 .1453 m
.36453 .14898 L
s
.42335 .12104 m
.42627 .12477 L
s
.45465 .10875 m
.45754 .11251 L
s
.48621 .09636 m
.48907 .10015 L
s
.51804 .08387 m
.52086 .08768 L
s
.58251 .05856 m
.58527 .06242 L
s
.61517 .04574 m
.61789 .04963 L
s
.64811 .03282 m
.65079 .03673 L
s
.68133 .01978 m
.68397 .02371 L
s
gsave
.33317 .05902 -75.3775 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
75.000 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{230, 287.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O0001Ib000`400?l00000o`00003oo`3Vc80P
0>K<P000o`3Vc80P0>K<P000o`3Vc80P0>K<P000^P3Vc806000000@0i/b00P0000040>K<P0H00000
C`3Vc8000;d0i/b000<000000>K<P03Vc800103Vc802000000D0i/b000D000000>K<P03Vc800i/b0
0000001?0>K<P000_@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b00500i/b0002m
0>K<P0030000003Vc800i/b000d0i/b00P00001@0>K<P000_@3Vc8000`000000i/b00>K<P00>0>K<
P0800000C`3Vc8000;d0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P01=0>K<P000
_@3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800
C@3Vc8000;/0i/b00`00000<0>K<P0D00000D03Vc8000?l0i/b0803Vc8000?l0i/b0803Vc8000?l0
i/b0803Vc8000=80i/b00P00001;0>K<P000d03Vc802000000030>K<P0000000000004X0i/b0003=
0>K<P0<000000`3Vc802000004X0i/b0003;0>K<P08000000P3Vc8001`000000i/b00>K<P03Vc800
00000>K<P0000000B@3Vc8000<P0i/b00`0000050>K<P0040000003Vc800i/b000000080i/b000<0
00000>K<P03Vc800AP3Vc8000<H0i/b00P00000;0>K<P0040000003Vc800i/b0000004P0i/b0002>
0>K<P0H00000103Vc802000000@0i/b01P00000O0>K<P0@00000303Vc8000`000000i/b00>K<P002
000004L0i/b0002A0>K<P0030000003Vc800i/b000@0i/b00P0000070>K<P0030000003Vc800i/b0
01d0i/b00P0000040>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P0140>K<P000G@3Vc805000000<0i/b01P00000V0>K<P0030000003Vc800i/b000d0
i/b000<000000>K<P03Vc8006P3Vc80300000180i/b000<000000>K<P03Vc8000P3Vc8000`000000
i/b00>K<P0140>K<P000G03Vc80010000000i/b00>K<P00000020>K<P0030000003Vc800i/b000<0
i/b000<000000>K<P03Vc8009P3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b001P0
i/b00`00000E0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800@`3Vc80005`0i/b0
00@000000>K<P03Vc80000000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b002H0
i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00E0>K<P0<000000P3Vc8000`000000
i/b00>K<P00C0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800@P3Vc80005`0i/b0
00@000000>K<P03Vc80000000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b002H0
i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00B0>K<P0<00000603Vc80010000000
i/b00>K<P00000050>K<P0030000003Vc800i/b000T0i/b00`0000050>K<P0800000103Vc8060000
02D0i/b0001M0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000`3Vc8000`000000
i/b00>K<P00V0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800403Vc802000001T0
i/b00`0000020>K<P0030000003Vc800i/b000<0i/b00P0000090>K<P0040000003Vc800i/b00000
00D0i/b00P0000070>K<P0030000003Vc800i/b002D0i/b0001N0>K<P0050000003Vc800i/b00>K<
P00000001@3Vc8000`000000i/b00>K<P00T0>K<P0<000003@3Vc803000000l0i/b00`0000020>K<
P0030000003Vc800i/b001@0i/b00P0000030>K<P0030000003Vc800000000L0i/b000<000000>K<
P03Vc8001@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000/0i/b000<000000>K<
P03Vc8009@3Vc80006P0i/b000<000000>K<P03Vc800A03Vc802000001X0i/b00P0000050>K<P003
0000003Vc800000000L0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b000/0i/b000<000000>K<P03Vc8009@3Vc80006H0i/b00`0000130>K<P0<00000
6P3Vc802000000P0i/b00P0000080>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc800
0P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b002D0i/b0002Z0>K<P080000000<0
i/b00000003Vc8006@3Vc8000`000000i/b00>K<P0080>K<P08000002@3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<
P00U0>K<P000Y`3Vc803000000<0i/b000<000000>K<P03Vc8005P3Vc802000000`0i/b000<00000
0>K<P03Vc8001`3Vc8000`000000i/b00>K<P0040>K<P0040000003Vc800i/b0000000h0i/b000<0
00000>K<P03Vc8009@3Vc8000:D0i/b00P00000M0>K<P08000003P3Vc8000`000000i/b00>K<P007
0>K<P08000001@3Vc804000000`0i/b00`00000W0>K<P000XP3Vc803000001d0i/b00P00000@0>K<
P08000001`3Vc8000`000000i/b00000000o0>K<P000X03Vc80200000080i/b000<000000>K<P03V
c8006@3Vc80200000180i/b00P00000:0>K<P0030000003Vc800i/b003`0i/b0002M0>K<P0<00000
1@3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b00180i/b000<000000>K<P0000000
2P3Vc8000`000000i/b00>K<P00k0>K<P000LP3Vc806000002<0i/b00P00000P0>K<P08000005@3V
c8000`000000i/b00000000:0>K<P0030000003Vc800i/b003/0i/b0001e0>K<P0030000003Vc800
i/b00200i/b00`0000000`3Vc80000000>K<P00M0>K<P08000005`3Vc8000`000000i/b00000000;
0>K<P0030000003Vc800i/b003X0i/b0001e0>K<P0030000003Vc800i/b001h0i/b00P00000Q0>K<
P08000006@3Vc80010000000i/b00>K<P000000;0>K<P0030000003Vc800i/b003T0i/b0001e0>K<
P0030000003Vc800i/b001/0i/b00`00000R0>K<P0030000003Vc800i/b001X0i/b000<000000>K<
P00000002P3Vc802000003/0i/b0001e0>K<P0030000003Vc800i/b001T0i/b00`00000R0>K<P080
00007@3Vc80010000000i/b00>K<P000000;0>K<P0030000003Vc800i/b003P0i/b0001e0>K<P003
0000003Vc800i/b001H0i/b00`0000030>K<P0030000003Vc800i/b001d0i/b00P00000O0>K<P004
0000003Vc800i/b0000000`0i/b000<000000>K<P03Vc800=`3Vc80007D0i/b000<000000>K<P03V
c800503Vc802000002@0i/b00P00000Q0>K<P0050000003Vc800i/b00>K<P00000002`3Vc8000`00
0000i/b00>K<P00P0>K<P0D000004P3Vc80007<0i/b00`00000C0>K<P0<00000903Vc802000002<0
i/b000D000000>K<P03Vc800i/b00000000<0>K<P0030000003Vc800i/b001h0i/b000@000000>K<
P03Vc80000000P3Vc8000`000000i/b00>K<P00?0>K<P000Q`3Vc802000000<0i/b000<000000>K<
P03Vc800803Vc8000`000000i/b00>K<P00S0>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc800203Vc803000001l0i/b000@000000>K<P03Vc80000000P3Vc8000`000000i/b00>K<P00?
0>K<P000Q03Vc803000002H0i/b00P00000V0>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc8002P3Vc8000`000000i/b00>K<P00M0>K<P0040000003Vc800i/b000000080i/b000<00000
0>K<P03Vc8003`3Vc8000880i/b00P00000W0>K<P0800000:03Vc8000`000000i/b00>K<P0030>K<
P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b000l0i/b0001o0>K<P0<000000P3Vc8000`000000i/b00>K<P00R0>K<P080
0000:P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03V
c8007@3Vc8001@000000i/b00>K<P03Vc80000000140i/b0001l0>K<P0<00000:03Vc802000002`0
i/b000<000000>K<P03Vc8000P3Vc802000000d0i/b000<000000>K<P03Vc800<`3Vc80007X0i/b0
0P00000Z0>K<P0030000003Vc800i/b002`0i/b000D000000>K<P03Vc800i/b0000000020>K<P003
0000003Vc800i/b000/0i/b000<000000>K<P03Vc800<P3Vc80007L0i/b00`0000000`3Vc8000000
0>K<P00X0>K<P0800000;P3Vc80010000000i/b00>K<P00000030>K<P0030000003Vc800i/b000X0
i/b00`00000c0>K<P000M@3Vc802000000D0i/b000<000000>K<P03Vc8009P3Vc8000`000000i/b0
0000000]0>K<P0030000003Vc800000000D0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b0
0>K<P00a0>K<P000?@3Vc803000000D0i/b00P0000040>K<P0<00000903Vc803000002l0i/b000@0
00000>K<P03Vc8000000;@3Vc802000000H0i/b000<000000>K<P03Vc800303Vc8000`000000i/b0
0>K<P00`0>K<P000?03Vc80010000000i/b00>K<P00000050>K<P08000001`3Vc8000`000000i/b0
0>K<P00O0>K<P08000000P3Vc8000`000000i/b00>K<P00/0>K<P0050000003Vc800i/b00>K<P000
0000;@3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03V
c800;`3Vc80003/0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P0030000
003Vc800i/b001/0i/b00`00000c0>K<P0050000003Vc800i/b00>K<P0000000;03Vc802000000P0
i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00_0>K<P000>`3Vc8000`000000i/b0
0>K<P0020>K<P0030000003Vc800i/b000T0i/b01000000K0>K<P0800000=@3Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc800i/b002P0i/b000<000000>K<P0000000203Vc8000`000000i/b0
0>K<P00=0>K<P0030000003Vc800i/b000P0i/b00`0000050>K<P0800000103Vc80600000180i/b0
000k0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800203Vc8001@000000i/b00>K<
P03Vc800000001P0i/b00`0000000`3Vc80000000>K<P00c0>K<P0030000003Vc800i/b000@0i/b0
00<000000>K<P03Vc8009`3Vc8001@000000i/b00>K<P03Vc800000000P0i/b000<000000>K<P03V
c8002`3Vc803000000P0i/b000@000000>K<P03Vc80000001@3Vc802000000D0i/b000D000000>K<
P03Vc800i/b00000000B0>K<P000>`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b0
00P0i/b000D000000>K<P03Vc800i/b00000000F0>K<P0800000>@3Vc8000`000000i/b00>K<P004
0>K<P0030000003Vc800i/b002D0i/b00P0000040>K<P0030000003Vc800i/b000H0i/b000<00000
0>K<P03Vc8003@3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b00080i/b000<00000
0>K<P03Vc8002P3Vc8000`000000i/b00>K<P00C0>K<P000?03Vc80010000000i/b00>K<P000000;
0>K<P0050000003Vc800i/b00>K<P00000004`3Vc803000003X0i/b000<000000>K<P03Vc8001P3V
c8000`000000i/b00>K<P00S0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8001`3V
c8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P00;0>K<P08000004`3Vc80003`0i/b01000000<0>K<P0<000004P3Vc804
000003X0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00R0>K<P0030000003Vc800
i/b000D0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800
i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P08000004P3Vc800
05h0i/b00`00000m0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8008@3Vc8000`00
0000i/b00>K<P0060>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8003P3Vc8000`00
0000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8003@3Vc8000`00
0000i/b00>K<P00@0>K<P000G03Vc80200000400i/b000<000000>K<P03Vc800203Vc8000`000000
i/b00>K<P00P0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800203Vc8000`000000
i/b00>K<P00=0>K<P08000001@3Vc80010000000i/b00>K<P000000;0>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc800403Vc80005T0i/b00`0000110>K<P0030000003Vc800i/b000X0
i/b000<000000>K<P03Vc8007P3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000P0
i/b000<000000>K<P03Vc800303Vc80010000000i/b00>K<P00000040>K<P0@000002`3Vc8050000
01<0i/b0001G0>K<P08000000`3Vc8000`000000i/b00>K<P00m0>K<P0030000003Vc800i/b000/0
i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000T0
i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00Y0>K<P000E03Vc803000004D0i/b0
00<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b000X0i/b0
00<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b002P0i/b0
001B0>K<P0<00000AP3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b001X0i/b000<0
00000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000l0i/b000<0
00000>K<P03Vc8009`3Vc80004l0i/b00`0000030>K<P0030000003Vc800i/b00480i/b000<00000
0>K<P03Vc8003P3Vc8000`000000i/b00>K<P00I0>K<P0030000003Vc800i/b000`0i/b000<00000
0>K<P03Vc8002P3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b002L0i/b0000G0>K<
P0<000001@3Vc802000000D0i/b01000000S0>K<P0800000B`3Vc8000`000000i/b00>K<P00>0>K<
P0030000003Vc800i/b001P0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00:0>K<
P0030000003Vc800i/b000h0i/b00`00000X0>K<P0005P3Vc80010000000i/b00>K<P00000050>K<
P0800000103Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001d0i/b00`00001<0>K<
P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P00>0>K<
P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00U0>K<
P0005@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P00K0>K<P08000000`3Vc8000`000000i/b00>K<P0180>K<P003
0000003Vc800i/b00140i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00?0>K<P003
0000003Vc800i/b000/0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00U0>K<P000
5@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc800
0P00000J0>K<P0<00000D03Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b001@0i/b0
00<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b00100i/b0
00<000000>K<P03Vc800903Vc80001D0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<
P0090>K<P0@00000603Vc80300000580i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<
P00C0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<
P00@0>K<P0030000003Vc800i/b002@0i/b0000E0>K<P0030000003Vc800i/b00080i/b000<00000
0>K<P03Vc800203Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001<0i/b00P000003
0>K<P0030000003Vc800i/b004h0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P00A
0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00@
0>K<P0030000003Vc800i/b002<0i/b0000F0>K<P0040000003Vc800i/b0000000/0i/b000<00000
0>K<P03Vc8000P3Vc8000`000000i/b00>K<P00@0>K<P0<00000EP3Vc8000`000000i/b00>K<P00D
0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P00<
0>K<P0030000003Vc800i/b000l0i/b00`00000T0>K<P0005P3Vc804000000`0i/b01000000A0>K<
P0<00000E`3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b000l0i/b000<000000>K<
P03Vc8005@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b00140i/b000<000000>K<
P03Vc8008P3Vc80003P0i/b00`0000020>K<P0030000003Vc800i/b005@0i/b000<000000>K<P03V
c8005`3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03V
c8003@3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b00240i/b0000f0>K<P0800000
F`3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc800
5`3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800
803Vc80003<0i/b00`00001M0>K<P0030000003Vc800i/b001P0i/b000<000000>K<P03Vc8002P3V
c802000001X0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00A0>K<P0030000003V
c800i/b00200i/b0000a0>K<P08000000`3Vc8000`000000i/b00>K<P01I0>K<P0030000003Vc800
i/b001T0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00J0>K<P0030000003Vc800
i/b000h0i/b000<000000>K<P03Vc8004@3Vc80200000240i/b0000^0>K<P0<00000H03Vc8000`00
0000i/b00>K<P00K0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8006`3Vc8000`00
0000i/b00>K<P00?0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8007P3Vc80002`0
i/b00`00001R0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8001P3Vc8000`000000
i/b00>K<P00L0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8004P3Vc8000`000000
i/b00>K<P00N0>K<P000:P3Vc802000000<0i/b000<000000>K<P03Vc800803Vc803000003/0i/b0
00<000000>K<P03Vc800703Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b001d0i/b0
00<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001d0i/b0
000Z0>K<P08000008@3Vc80500000080i/b00P00000j0>K<P0030000003Vc800i/b001d0i/b000<0
00000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00N0>K<P0030000003Vc800i/b00100i/b000<0
00000>K<P03Vc8004`3Vc8000`000000i/b00>K<P0080>K<P0<000001@3Vc802000000@0i/b01000
00020>K<P000:P3Vc8000`000000i/b00000000J0>K<P0H00000203Vc802000003T0i/b000<00000
0>K<P03Vc8007@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001l0i/b000<00000
0>K<P03Vc800403Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b000L0i/b000@00000
0>K<P03Vc80000001@3Vc802000000P0i/b00@0000010>K<P000:P3Vc802000000030>K<P0000000
i/b001<0i/b01@00000>0>K<P0030000003Vc800000003P0i/b00P00000N0>K<P0050000003Vc800
i/b00>K<P00000008P3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b00140i/b000<0
00000>K<P00000001`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000`0i/b00@00
00010>K<P000:P3Vc8001@000000i/b00>K<P03Vc800000000h0i/b01@00000C0>K<P0030000003V
c800i/b000800000=@3Vc8000`000000i/b00000000N0>K<P0040000003Vc800i/b0000002<0i/b0
00<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b000@0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P04000000@3Vc80002T0i/b000<0
00000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0050>K<P0H00000603Vc8000`000000i/b00>K<
P0020>K<P0030000003Vc800i/b00380i/b000<000000>K<P00000007`3Vc802000002@0i/b000<0
00000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b000@0i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00:0>K<P08000000P3Vc8000240i/b00`000005
0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P00000001000000O0>K<P0030000003Vc800
i/b00080i/b000<000000>K<P03Vc800<@3Vc8000`000000i/b00000000O0>K<P0030000003Vc800
i/b002<0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800
i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P04000000@3Vc800
0200i/b000@000000>K<P03Vc80000001@3Vc8000`000000i/b00>K<P0030>K<P0<00000903Vc800
0`000000i/b00>K<P0030>K<P0030000003Vc800i/b00300i/b000<000000>K<P00000007`3Vc800
0`000000i/b00>K<P00S0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8005@3Vc800
0`000000i/b00>K<P0030>K<P0040000003Vc800i/b0000000l0i/b00@0000010>K<P0007`3Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800103Vc802
000002@0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00_0>K<P0030000003Vc800
000001h0i/b000<000000>K<P00000009@3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800
i/b00180i/b00`0000050>K<P0@000002`3Vc80400000080i/b0000O0>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc8000000
02@0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00^0>K<P0040000003Vc800i/b0
000001d0i/b000<000000>K<P00000009@3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800
i/b001@0i/b00P00000I0>K<P0007`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00000000S0>K<P0030000003Vc800i/b0
00D0i/b000<000000>K<P03Vc800;@3Vc80010000000i/b00>K<P000000M0>K<P0030000003Vc800
000002D0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00@0>K<P0<0000000<0i/b0
0000003Vc800603Vc80001l0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b000D0i/b000@000000>K<P03Vc80000008P3Vc8000`000000i/b00>K<P006
0>K<P0030000003Vc800i/b002`0i/b000@000000>K<P03Vc8000000703Vc80010000000i/b00>K<
P000000U0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc8003@3Vc803000000@0i/b0
00<000000>K<P03Vc8005`3Vc8000200i/b000@000000>K<P03Vc80000001@3Vc8000`000000i/b0
0>K<P0060>K<P0040000003Vc800i/b000000240i/b000<000000>K<P03Vc8001`3Vc8000`000000
i/b00>K<P00Z0>K<P0050000003Vc800i/b00>K<P0000000703Vc8001@000000i/b00>K<P03Vc800
000002@0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00:0>K<P0<000001`3Vc800
0`000000i/b00>K<P00G0>K<P000803Vc804000000D0i/b000<000000>K<P03Vc8001P3Vc8001@00
0000i/b00>K<P03Vc80000000240i/b000<000000>K<P03Vc8001`3Vc802000002X0i/b000D00000
0>K<P03Vc800i/b00000000L0>K<P0050000003Vc800i/b00>K<P0000000903Vc8000`000000i/b0
0>K<P00D0>K<P0030000003Vc800i/b000H0i/b00`00000:0>K<P0030000003Vc800i/b001L0i/b0
000Y0>K<P0030000003Vc800i/b000L0i/b000D000000>K<P03Vc800i/b00000000P0>K<P0030000
003Vc800i/b000T0i/b000<000000>K<P03Vc8009`3Vc8001@000000i/b00>K<P03Vc800000001/0
i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00R0>K<P0030000003Vc800i/b001@0
i/b000<000000>K<P03Vc800103Vc802000000d0i/b000<000000>K<P03Vc8005`3Vc80002P0i/b0
00<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001d0i/b0
00<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00V0>K<P0030000003Vc800i/b00080i/b0
00<000000>K<P03Vc800603Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00240i/b0
00<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00300000100i/b000<000000>K<P03Vc800
5P3Vc80002P0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0020>K<P0030000003V
c800i/b001d0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00U0>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P0030>K<P0030000003V
c800i/b00240i/b000<000000>K<P03Vc8005@3Vc803000001<0i/b000<000000>K<P03Vc8005P3V
c80002P0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800
i/b001`0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00T0>K<P0030000003Vc800
i/b00080i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800
i/b00240i/b000<000000>K<P03Vc8004P3Vc803000000030>K<P0000000i/b001<0i/b000<00000
0>K<P03Vc8005P3Vc80002P0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P0030>K<
P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00T0>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P0050>K<
P0030000003Vc800i/b00200i/b000<000000>K<P03Vc8003`3Vc803000000@0i/b000<000000>K<
P03Vc8004P3Vc8000`000000i/b00>K<P00F0>K<P000:03Vc8000`000000i/b00>K<P00:0>K<P003
0000003Vc800i/b000@0i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<P00;0>K<P003
0000003Vc800i/b002<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00G0>K<P003
0000003Vc800i/b000D0i/b000<000000>K<P03Vc800803Vc8000`000000i/b00>K<P00<0>K<P0<0
00001P3Vc802000001@0i/b000<000000>K<P03Vc8005P3Vc80002P0i/b00P00000<0>K<P0030000
003Vc800i/b000@0i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<P00:0>K<P0030000
003Vc800i/b002<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00F0>K<P0030000
003Vc800i/b000H0i/b000<000000>K<P03Vc800803Vc8000`000000i/b00>K<P0090>K<P0<00000
2@3Vc8000`000000i/b00000000C0>K<P0030000003Vc800i/b001H0i/b0000X0>K<P0030000003V
c800i/b000/0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00I0>K<P0030000003V
c800i/b000X0i/b00P00000T0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8005@3V
c8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b00200i/b000<000000>K<P03Vc8001P3V
c803000000/0i/b000@000000>K<P03Vc80000004`3Vc8000`000000i/b00>K<P00F0>K<P000:03V
c8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800603V
c8000`000000i/b00>K<P00:0>K<P0800000903Vc8000`000000i/b00>K<P0040>K<P0030000003V
c800i/b001D0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00O0>K<P0030000003V
c800i/b000<0i/b00`00000>0>K<P0050000003Vc800i/b00>K<P00000004P3Vc8000`000000i/b0
0>K<P00F0>K<P000:03Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000H0i/b000<0
00000>K<P03Vc8005`3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b00280i/b000<0
00000>K<P03Vc800103Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b000P0i/b000<0
00000>K<P03Vc8007`3Vc80010000000i/b00>K<P03Vc80200000100i/b000<000000>K<P03Vc800
0P3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b001H0i/b0000X0>K<P0030000003V
c800i/b000d0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00H0>K<P0030000003V
c800i/b000X0i/b000<000000>K<P03Vc8008P3Vc8000`000000i/b00>K<P0040>K<P0030000003V
c800i/b001@0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00P0>K<P0<000004P3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8005P3V
c80002L0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800
i/b001L0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00R0>K<P0030000003Vc800
i/b000@0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800
i/b001`0i/b01000000C0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc800403Vc800
0`000000i/b00>K<P00E0>K<P0009`3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b0
00H0i/b000<000000>K<P03Vc8005P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b0
0240i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b0
00X0i/b000<000000>K<P03Vc8006@3Vc803000000<0i/b000<000000>K<P03Vc800403Vc8000`00
0000i/b00>K<P0050>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8005@3Vc80002L0
i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b001H0
i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00Q0>K<P0030000003Vc800i/b000H0
i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b001H0
i/b00`0000060>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8001@3Vc8000`000000
i/b00>K<P00@0>K<P0030000003Vc800i/b001D0i/b0000W0>K<P0030000003Vc800i/b00100i/b0
0P0000080>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc8002@3Vc80200000280i/b0
00<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b000X0i/b0
00<000000>K<P03Vc8004`3Vc803000000T0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b0
0>K<P0070>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8005@3Vc80002L0i/b000<0
00000>K<P03Vc800403Vc8000`000000i/b000000003000000D0i/b000<000000>K<P03Vc800503V
c8000`000000i/b00>K<P0090>K<P08000008P3Vc8000`000000i/b00>K<P0060>K<P0030000003V
c800i/b00140i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00?0>K<P0<00000303V
c8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8003`3V
c8000`000000i/b00>K<P00E0>K<P0009`3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800
i/b00080i/b00`0000030>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc8002@3Vc802
00000280i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800
i/b000`0i/b000<000000>K<P03Vc800303Vc803000000l0i/b000<000000>K<P03Vc8003P3Vc800
0`000000i/b00>K<P0090>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8005@3Vc800
02L0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P0050>K<P0<0000000<0i/b00000
003Vc800503Vc8000`000000i/b00>K<P0080>K<P08000008P3Vc8000`000000i/b00>K<P0060>K<
P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P0090>K<
P0<000004P3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000T0i/b000<000000>K<
P03Vc8003P3Vc8000`000000i/b00>K<P00E0>K<P0009`3Vc8000`000000i/b00>K<P00B0>K<P003
0000003Vc800i/b000L0i/b01000000C0>K<P0030000003Vc800i/b000P0i/b00P00000R0>K<P003
0000003Vc800i/b000H0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00>0>K<P003
0000003Vc800i/b000H0i/b00P00000E0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03V
c8002P3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b001D0i/b0000W0>K<P0030000
003Vc800i/b00180i/b000<000000>K<P03Vc8002P3Vc80400000100i/b000<000000>K<P03Vc800
2@3Vc8000`000000i/b00>K<P00P0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800
3`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000<0i/b00`00000G0>K<P0030000
003Vc800i/b000`0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00=0>K<P0030000
003Vc800i/b001D0i/b0000W0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc8002P3V
c8000`000000i/b00>K<P003000000h0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<
P00O0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<
P00>0>K<P0030000003Vc800i/b000<000006P3Vc8000`000000i/b00>K<P00<0>K<P0030000003V
c800i/b000`0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00E0>K<P0009P3Vc800
0`000000i/b00>K<P00D0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8000P3Vc804
000000X0i/b000<000000>K<P03Vc800203Vc80200000200i/b000<000000>K<P03Vc800203Vc800
0`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000l0i/b00`00000M0>K<P0030000003Vc800
i/b000/0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800
i/b001@0i/b0000V0>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc800303Vc8000`00
0000i/b00>K<P0050>K<P0<000001`3Vc8000`000000i/b00>K<P0080>K<P0800000803Vc8000`00
0000i/b00>K<P0080>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc800303Vc8030000
00030>K<P0000000i/b001d0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00>0>K<
P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800503Vc80002H0i/b000<000000>K<P03V
c8005@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000L0i/b00`0000040>K<P003
0000003Vc800i/b000P0i/b00P00000P0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03V
c8003P3Vc8000`000000i/b00>K<P0090>K<P0<00000103Vc8000`000000i/b00>K<P00L0>K<P003
0000003Vc800i/b000X0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00=0>K<P003
0000003Vc800i/b001@0i/b0000V0>K<P08000005P3Vc8000`000000i/b00>K<P00=0>K<P0030000
003Vc800i/b000T0i/b0100000000`3Vc80000000>K<P0080>K<P0800000803Vc8000`000000i/b0
0>K<P0090>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8001P3Vc803000000L0i/b0
00<000000>K<P03Vc800703Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b00100i/b0
00<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00D0>K<P0009P3Vc8000`000000i/b00>K<
P00F0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800303Vc802000000T0i/b00P00
000P0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<
P0040>K<P0<000002`3Vc8000`000000i/b00>K<P00K0>K<P0030000003Vc800i/b000T0i/b000<0
00000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b001@0i/b0000V
0>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00=
0>K<P0030000003Vc800i/b000L0i/b00P00000P0>K<P0030000003Vc800i/b000T0i/b000<00000
0>K<P03Vc800303Vc80010000000i/b00>K<P03Vc803000000h0i/b000<000000>K<P03Vc8006`3V
c8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc8002`3V
c8000`000000i/b00>K<P00D0>K<P0009P3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800
i/b000d0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P0060>K<P08000007`3Vc800
0`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000`0i/b000@000000>K<P000000000004@3V
c8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8004`3V
c8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b001@0i/b0000V0>K<P0030000003Vc800
i/b001L0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800
i/b000H0i/b000<000000>K<P00000007P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800
i/b000/0i/b00`00000D0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8001P3Vc800
0`000000i/b00>K<P00D0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc800503Vc800
02H0i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b0
00/0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00000000N0>K<P0030000003Vc800i/b0
00X0i/b000<000000>K<P03Vc800203Vc804000001H0i/b000<000000>K<P03Vc8006`3Vc8000`00
0000i/b00>K<P0060>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc8002P3Vc8000`00
0000i/b00>K<P00D0>K<P0009P3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b000l0
i/b000<000000>K<P03Vc8002P3Vc802000000P0i/b00P00000N0>K<P0030000003Vc800i/b000/0
i/b000<000000>K<P03Vc800103Vc803000000<0i/b000<000000>K<P03Vc800503Vc8000`000000
i/b00>K<P00K0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8005P3Vc8000`000000
i/b00>K<P00:0>K<P0030000003Vc800i/b001@0i/b0000U0>K<P0030000003Vc800i/b001T0i/b0
00<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000H0i/b0
0P00000N0>K<P0030000003Vc800i/b000/0i/b000@000000>K<P03Vc800i/b00`0000050>K<P003
0000003Vc800i/b001D0i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P0050>K<P003
0000003Vc800i/b001H0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00C0>K<P000
9@3Vc8000`000000i/b00>K<P00J0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc800
2@3Vc802000000L0i/b00P00000N0>K<P0030000003Vc800i/b000/0i/b0100000080>K<P0030000
003Vc800i/b001H0i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<P0040>K<P0030000
003Vc800i/b001P0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00C0>K<P0009@3V
c8000`000000i/b00>K<P00J0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800203V
c802000000L0i/b00P00000N0>K<P0030000003Vc800i/b000T0i/b00`00000;0>K<P0030000003V
c800i/b001H0i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<P0030>K<P0030000003V
c800i/b001T0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00C0>K<P0009@3Vc800
0`000000i/b00>K<P00K0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8001`3Vc802
000000L0i/b00P00000N0>K<P0030000003Vc800i/b000H0i/b00`0000020>K<P0030000003Vc800
i/b000P0i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P00J0>K<P0030000003Vc800
i/b000<0i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800
i/b001<0i/b0000U0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8004P3Vc8000`00
0000i/b00>K<P0070>K<P08000001P3Vc8000`000000i/b00000000L0>K<P0030000003Vc800i/b0
00@0i/b00`0000050>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc800603Vc8000`00
0000i/b00>K<P00I0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8006`3Vc8000`00
0000i/b00>K<P0090>K<P0030000003Vc800i/b001<0i/b0000U0>K<P0030000003Vc800i/b001/0
i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P0060>K<P08000001P3Vc8000`000000
i/b00000000L0>K<P0030000003Vc800i/b00080i/b00P0000090>K<P0030000003Vc800i/b000L0
i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P00I0>K<P0030000003Vc800i/b00080
i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b001<0
i/b0000U0>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b0
0>K<P0050>K<P08000001P3Vc8000`000000i/b00000000L0>K<P0030000003Vc800000000800000
2`3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b001T0i/b000<000000>K<P03Vc800
6@3Vc8001@000000i/b00>K<P03Vc800000001l0i/b000<000000>K<P03Vc800203Vc8000`000000
i/b00>K<P00C0>K<P0009@3Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b001@0i/b0
00<000000>K<P03Vc800103Vc8000`000000i/b0000000050>K<P0030000003Vc800000001/0i/b0
0`00000>0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8006@3Vc8000`000000i/b0
0>K<P00I0>K<P0050000003Vc800i/b00>K<P00000007`3Vc8000`000000i/b00>K<P0080>K<P003
0000003Vc800i/b001<0i/b0000U0>K<P0030000003Vc800i/b001d0i/b000<000000>K<P03Vc800
503Vc8000`000000i/b00>K<P0040>K<P08000001@3Vc8000`000000i/b00000000H0>K<P0<00000
00<0i/b00000003Vc8003P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b001X0i/b0
00<000000>K<P03Vc800603Vc80010000000i/b00>K<P000000Q0>K<P0030000003Vc800i/b000L0
i/b000<000000>K<P03Vc8004`3Vc80002@0i/b000<000000>K<P03Vc8007P3Vc8000`000000i/b0
0>K<P00E0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P0000000103Vc8000`000000i/b0
0000000E0>K<P0<00000103Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000D0i/b0
00<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc80000000280i/b0
00<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00C0>K<P000903Vc8000`000000i/b00>K<
P00O0>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00000
00050>K<P08000004P3Vc803000000L0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<
P0050>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc800603Vc8000`000000i/b00000
000R0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8004`3Vc80002@0i/b00P00000P
0>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b000000005
0>K<P0030000003Vc800000000h0i/b00`0000090>K<P0030000003Vc800i/b000l0i/b000<00000
0>K<P03Vc800103Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b001L0i/b00P00000T
0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8004P3Vc80002@0i/b000<000000>K<
P03Vc800803Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b00080i/b000<000000>K<
P0000000103Vc8000`000000i/b00000000;0>K<P0<00000303Vc8000`000000i/b00>K<P00?0>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P00G0>K<
P0800000903Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b00180i/b0000T0>K<P003
0000003Vc800i/b00200i/b000<000000>K<P03Vc8005P3Vc8001`000000i/b00>K<P03Vc8000000
0>K<P0000000103Vc8000`000000i/b0000000080>K<P0<000003`3Vc8000`000000i/b00>K<P00?
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P00G
0>K<P08000009@3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b00180i/b0000T0>K<
P0030000003Vc800i/b00200i/b000<000000>K<P03Vc8005`3Vc8001P000000i/b00>K<P0000000
i/b0000000@0i/b000<000000>K<P00000001P3Vc80200000180i/b000<000000>K<P03Vc8003`3V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03Vc8005P3V
c802000002D0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00B0>K<P000903Vc800
0`000000i/b00>K<P00Q0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P00000000P3Vc800
1`000000i/b00>K<P03Vc80000000>K<P00000000`3Vc803000001@0i/b000<000000>K<P03Vc800
3`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001l0i/b000<000000>K<P03Vc800
5@3Vc8000`000000i/b00000000U0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800
4P3Vc80002@0i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P00H0>K<P0050000003V
c80000000>K<P00000000`3Vc8000`000000i/b000000003000001L0i/b000<000000>K<P03Vc800
3`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001l0i/b000<000000>K<P03Vc800
503Vc80010000000i/b00>K<P000000V0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03V
c8004P3Vc80002@0i/b000<000000>K<P03Vc8008P3Vc8000`000000i/b00>K<P00H0>K<P0800000
0P3Vc8000`000000i/b00>K<P003000001X0i/b000<000000>K<P03Vc800403Vc8001@000000i/b0
0>K<P03Vc80000000240i/b000<000000>K<P03Vc800503Vc80010000000i/b00>K<P000000V0>K<
P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8004P3Vc80002@0i/b000<000000>K<P03V
c8008P3Vc8000`000000i/b00>K<P00I0>K<P0030000003Vc800i/b000@000000P3Vc8000`000000
i/b00>K<P00G0>K<P0030000003Vc800i/b00100i/b000@000000>K<P03Vc80000008`3Vc8000`00
0000i/b00>K<P00B0>K<P0050000003Vc800i/b00>K<P00000009P3Vc8000`000000i/b00>K<P005
0>K<P0030000003Vc800i/b00180i/b0000S0>K<P0030000003Vc800i/b002@0i/b000<000000>K<
P03Vc800603Vc80400000080i/b000@000000>K<P03Vc8000000603Vc8000`000000i/b00>K<P00A
0>K<P0040000003Vc800i/b0000002<0i/b000<000000>K<P03Vc8004P3Vc8001@000000i/b00>K<
P03Vc800000002L0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00B0>K<P0008`3V
c8000`000000i/b00>K<P00T0>K<P0030000003Vc800i/b001T0i/b000@000000>K<P03Vc8000000
0P3Vc8000`000000i/b00000000H0>K<P0030000003Vc800i/b00140i/b000@000000>K<P03Vc800
00008`3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c8009@3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b00180i/b0000S0>K<P0030000
003Vc800i/b002@0i/b000<000000>K<P03Vc8006@3Vc80010000000i/b00>K<P00000020>K<P003
0000003Vc800000001P0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00000000U0>K<P003
0000003Vc800i/b00100i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00V0>K<P003
0000003Vc800i/b000@0i/b000<000000>K<P03Vc8004@3Vc80002<0i/b000<000000>K<P03Vc800
9@3Vc8000`000000i/b00>K<P00H0>K<P0040000003Vc800i/b000000080i/b000<000000>K<P000
0000603Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800000002D0i/b000<000000>K<P03V
c8003`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b002H0i/b000<000000>K<P03V
c800103Vc8000`000000i/b00>K<P00A0>K<P0008`3Vc8000`000000i/b00>K<P00U0>K<P0030000
003Vc800i/b001P0i/b00P0000020>K<P0050000003Vc80000000>K<P0000000603Vc8000`000000
i/b00>K<P00B0>K<P08000009@3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000@0
i/b000<000000>K<P03Vc8009P3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b00140
i/b0000S0>K<P0030000003Vc800i/b002H0i/b000<000000>K<P03Vc8005`3Vc80200000080i/b0
00D000000>K<P0000000i/b00000000H0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03V
c800903Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03V
c8009`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00140i/b0000S0>K<P0030000
003Vc800i/b002H0i/b000<000000>K<P03Vc8005`3Vc802000000<0i/b00P0000020>K<P0030000
003Vc800i/b001D0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00U0>K<P0030000
003Vc800i/b000`0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00W0>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8004@3Vc80002<0i/b000<000000>K<P03Vc8009`3V
c8000`000000i/b00>K<P00F0>K<P08000000`3Vc80200000080i/b000<000000>K<P03Vc800503V
c8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b002D0i/b000<000000>K<P03Vc800303V
c8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P00A0>K<P0008`3Vc8000`000000i/b00>K<P00W0>K<P0030000003Vc800
i/b001H0i/b000<000000>K<P00000000P3Vc80200000080i/b000<000000>K<P03Vc800503Vc800
0`000000i/b00>K<P00C0>K<P08000009P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800
i/b000H0i/b000<000000>K<P03Vc800:03Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800
i/b00140i/b0000S0>K<P0030000003Vc800i/b002L0i/b000<000000>K<P03Vc8005P3Vc8000`00
0000i/b0000000030>K<P0040000003Vc800i/b0000001H0i/b000<000000>K<P03Vc8004P3Vc800
0`000000i/b00000000W0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8001P3Vc800
0`000000i/b00>K<P00X0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8004@3Vc800
0280i/b00`00000Y0>K<P0030000003Vc800i/b001D0i/b000<000000>K<P00000000`3Vc8001000
0000i/b00>K<P000000F0>K<P0030000003Vc800i/b00180i/b000<000000>K<P00000009`3Vc800
0`000000i/b00>K<P0090>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8009P3Vc800
0`000000i/b00>K<P0030>K<P0030000003Vc800i/b00140i/b0000R0>K<P0030000003Vc800i/b0
02T0i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b0000000030>K<P0040000003Vc800i/b0
000001H0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00000000W0>K<P0030000003Vc800
i/b000P0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00V0>K<P0030000003Vc800
i/b000<0i/b000<000000>K<P03Vc8004@3Vc80000T0i/b00`0000050>K<P0800000103Vc8060000
00D0i/b000<000000>K<P03Vc800:P3Vc8000`000000i/b00>K<P00D0>K<P0040000003Vc800i/b0
000000<0i/b000<000000>K<P00000005P3Vc8000`000000i/b00>K<P00B0>K<P0040000003Vc800
i/b0000002H0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0090>K<P0030000003V
c800i/b002D0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00@0>K<P000203Vc800
10000000i/b00>K<P00000050>K<P08000001@3Vc8001@000000i/b00>K<P03Vc800000000D0i/b0
00<000000>K<P03Vc800:P3Vc8000`000000i/b00>K<P00C0>K<P0050000003Vc800i/b00>K<P000
00000`3Vc80010000000i/b00>K<P000000E0>K<P0030000003Vc800i/b00180i/b000@000000>K<
P03Vc80000009`3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000X0i/b000<00000
0>K<P03Vc8009@3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b00100i/b000070>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P0060>K<
P0030000003Vc800i/b002/0i/b000<000000>K<P03Vc8004P3Vc8001@000000i/b00>K<P03Vc800
000000<0i/b00P0000000`3Vc80000000>K<P00C0>K<P0030000003Vc800i/b001<0i/b000@00000
0>K<P03Vc80000009`3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000X0i/b000<0
00000>K<P03Vc800903Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b00100i/b00007
0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3Vc802000000H0i/b000<00000
0>K<P03Vc800:`3Vc8000`000000i/b00>K<P00B0>K<P0050000003Vc800i/b00>K<P00000000`3V
c802000000030>K<P0000000i/b001<0i/b000<000000>K<P03Vc8004P3Vc8001@000000i/b00>K<
P03Vc800000002L0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00;0>K<P0030000
003Vc800i/b002@0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00@0>K<P0001`3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000`0i/b00P0000050>K<P0030000003V
c800i/b002/0i/b00P00000C0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000P00
00000`3Vc80000000>K<P00C0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P00U0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8002`3V
c8000`000000i/b00>K<P00S0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800403V
c80000L0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800
i/b000<0i/b000<000000>K<P03Vc800;03Vc80200000180i/b000<000000>K<P03Vc8000P3Vc800
1@000000i/b00>K<P0000000i/b000800000503Vc8000`000000i/b00>K<P00B0>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc8009@3Vc8000`000000i/b00>K<P0030>K<P0030000003V
c800i/b000`0i/b000<000000>K<P03Vc8008`3Vc8000`000000i/b00>K<P0070>K<P0030000003V
c800i/b00100i/b000080>K<P0040000003Vc800i/b0000000/0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b002`0i/b000<000000>K<P00000004@3V
c8000`000000i/b00>K<P0020>K<P0050000003Vc800i/b00000003Vc8000P00000D0>K<P0030000
003Vc800i/b00180i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00U0>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00R0>K<P0030000
003Vc800i/b000P0i/b000<000000>K<P03Vc800403Vc80000P0i/b01000000;0>K<P0D000001P3V
c8000`000000i/b00>K<P00]0>K<P0030000003Vc80000000100i/b000<000000>K<P03Vc8000P3V
c8001@000000i/b00>K<P0000000i/b000800000503Vc8000`000000i/b00>K<P00B0>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8009@3Vc8001@000000i/b00>K<P03Vc800000000l0
i/b000<000000>K<P03Vc8008P3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b00100
i/b0000Q0>K<P0030000003Vc800i/b002h0i/b000<000000>K<P0000000403Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc80000000080i/b00P00000C0>K<P0030000003Vc800i/b00140i/b0
00<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00U0>K<P0040000003Vc800i/b000000100
i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b00100
i/b0000Q0>K<P0030000003Vc800i/b002l0i/b000<000000>K<P00000003`3Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc80000000080i/b00P00000C0>K<P0030000003Vc800i/b00140i/b0
00<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00U0>K<P0040000003Vc800i/b000000100
i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b00100
i/b0000Q0>K<P0030000003Vc800i/b002l0i/b000@000000>K<P03Vc80000003P3Vc8000`000000
i/b00>K<P0030>K<P0040000003Vc800i/b000000080i/b000<000000>K<P03Vc800403Vc8000`00
0000i/b00>K<P00B0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8009@3Vc8000`00
0000i/b00000000A0>K<P0030000003Vc800i/b00200i/b000<000000>K<P03Vc8002`3Vc8000`00
0000i/b00>K<P00?0>K<P0008@3Vc8000`000000i/b00>K<P00_0>K<P0050000003Vc800i/b00>K<
P00000003@3Vc8000`000000i/b00>K<P0030>K<P0040000003Vc800i/b000000080i/b000<00000
0>K<P03Vc800403Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b000D0i/b000<00000
0>K<P03Vc8009@3Vc80200000140i/b000<000000>K<P03Vc800803Vc8000`000000i/b00>K<P00;
0>K<P0030000003Vc800i/b000l0i/b0000Q0>K<P0030000003Vc800i/b00300i/b000D000000>K<
P03Vc800i/b00000000<0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P00000000P3Vc800
0`000000i/b00>K<P00@0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8001@3Vc800
0`000000i/b00>K<P00U0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8007`3Vc800
0`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000l0i/b0000Q0>K<P0030000003Vc800i/b0
0300i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b0
00@0i/b000<000000>K<P00000000P3Vc80200000140i/b000<000000>K<P03Vc8004P3Vc8000`00
0000i/b00>K<P0050>K<P0030000003Vc800i/b002D0i/b000<000000>K<P03Vc800403Vc8000`00
0000i/b00>K<P00O0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8003`3Vc8000240
i/b000<000000>K<P03Vc800<@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000P0
i/b000<000000>K<P03Vc800103Vc8000`000000i/b0000000020>K<P08000004@3Vc8000`000000
i/b00>K<P00A0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800903Vc8000`000000
i/b00000000A0>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03Vc8003@3Vc8000`000000
i/b00>K<P00?0>K<P0008@3Vc8000`000000i/b00>K<P00a0>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800000000<0i/b0
00<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000L0i/b0
00<000000>K<P03Vc8008`3Vc8000`000000i/b00000000B0>K<P0030000003Vc800i/b001d0i/b0
00<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00?0>K<P0008@3Vc8000`000000i/b00>K<
P00b0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<
P0050>K<P08000000`3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b00140i/b000<0
00000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00S0>K<P0030000003Vc80000000180i/b000<0
00000>K<P03Vc800703Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000l0i/b0000Q
0>K<P0030000003Vc800i/b00380i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P006
0>K<P0030000003Vc800i/b000D0i/b00P0000030>K<P08000003`3Vc8000`000000i/b00>K<P00B
0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8008`3Vc80010000000i/b00>K<P000
000A0>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<
P00?0>K<P000803Vc802000003@0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P005
0>K<P0030000003Vc800i/b000D0i/b00P0000030>K<P08000003`3Vc8000`000000i/b00>K<P00B
0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8008@3Vc8001@000000i/b00>K<P03V
c80000000140i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P00?0>K<P0030000003V
c800i/b000l0i/b0000P0>K<P0030000003Vc800i/b003@0i/b000<000000>K<P03Vc800103Vc800
0`000000i/b00>K<P0040>K<P0030000003Vc800i/b000H0i/b000@000000>K<P03Vc800i/b00P00
000?0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<
P00Q0>K<P0050000003Vc800i/b00>K<P00000004@3Vc8000`000000i/b00>K<P00K0>K<P0030000
003Vc800i/b000l0i/b000<000000>K<P03Vc8003`3Vc8000200i/b000<000000>K<P03Vc800=03V
c8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8001P3V
c80010000000i/b00>K<P03Vc802000000l0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b0
0>K<P0090>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b0
0>K<P00>0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc800403Vc8000`000000i/b0
0>K<P00?0>K<P000803Vc8000`000000i/b00>K<P00e0>K<P0030000003Vc800i/b000D0i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0060>K<P08000000`3Vc802000000h0i/b000<0
00000>K<P03Vc8004@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b00200i/b000<0
00000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b001X0i/b000<0
00000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00>0>K<P000803Vc8000`000000i/b00>K<P00e
0>K<P0030000003Vc800i/b000H0i/b000D000000>K<P03Vc800i/b0000000080>K<P08000000`3V
c802000000h0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00:0>K<P0030000003V
c800i/b001l0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00>0>K<P0030000003V
c800i/b001T0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00>0>K<P000803Vc800
0`000000i/b00>K<P00f0>K<P0030000003Vc800i/b000H0i/b000@000000>K<P03Vc80000002@3V
c80010000000i/b00>K<P03Vc802000000h0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b0
0>K<P00:0>K<P0030000003Vc800i/b001l0i/b000<000000>K<P03Vc800103Vc8000`000000i/b0
0>K<P00=0>K<P0030000003Vc800i/b001T0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b0
0>K<P00>0>K<P000803Vc8000`000000i/b00>K<P00f0>K<P0030000003Vc800i/b000H0i/b000@0
00000>K<P03Vc80000002@3Vc8001`000000i/b00>K<P03Vc80000000>K<P00000003@3Vc8000`00
0000i/b00>K<P00A0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8007P3Vc8000`00
0000i/b00>K<P0050>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800603Vc8000`00
0000i/b00>K<P00C0>K<P0030000003Vc800i/b000h0i/b0000P0>K<P0030000003Vc800i/b003H0
i/b000<000000>K<P03Vc8001`3Vc802000000X0i/b000L000000>K<P03Vc800i/b00000003Vc800
000000`0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800
i/b001h0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800
i/b001P0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00>0>K<P000803Vc8000`00
0000i/b00>K<P00g0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800203Vc8001`00
0000i/b00>K<P03Vc80000000>K<P0000000303Vc8000`000000i/b00>K<P00A0>K<P0030000003V
c800i/b000`0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P0060>K<P0030000003V
c800i/b000`0i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P00D0>K<P0030000003V
c800i/b000h0i/b0000P0>K<P0030000003Vc800i/b003L0i/b000<000000>K<P03Vc8001`3Vc802
000000T0i/b00P0000030>K<P0800000303Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800
i/b000`0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800
i/b000`0i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800
i/b000h0i/b0000O0>K<P0030000003Vc800i/b003T0i/b000<000000>K<P03Vc8001P3Vc8000`00
0000i/b0000000080>K<P08000000`3Vc8000`000000i/b00000000;0>K<P0030000003Vc800i/b0
0140i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b0
00P0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b0
01D0i/b000<000000>K<P03Vc8003P3Vc80001l0i/b000<000000>K<P03Vc800>@3Vc8000`000000
i/b00>K<P0060>K<P0040000003Vc800i/b0000000L0i/b00P0000030>K<P0030000003Vc8000000
00/0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b0
01/0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b0
01H0i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00>0>K<P0007`3Vc8000`000000
i/b00>K<P00j0>K<P0030000003Vc800i/b000D0i/b000D000000>K<P03Vc800i/b0000000060>K<
P08000000`3Vc8000`000000i/b00000000;0>K<P0030000003Vc800i/b00140i/b000<000000>K<
P03Vc8003@3Vc8000`000000i/b00>K<P00K0>K<P0030000003Vc800i/b000P0i/b000<000000>K<
P03Vc8002`3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b001H0i/b000<000000>K<
P03Vc8003P3Vc80001l0i/b000<000000>K<P03Vc800>P3Vc8000`000000i/b00>K<P0050>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc800103Vc80200000080i/b000<000000>K<P000
00002`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03V
c8006P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03V
c800503Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b000d0i/b0000O0>K<P0030000
003Vc800i/b003/0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b000@0i/b00P0000020>K<P0040000003Vc800i/b0000000T0i/b000<000000>K<P03V
c8004@3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03V
c8002P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03V
c800603Vc8000`000000i/b00>K<P00=0>K<P0007`3Vc8000`000000i/b00>K<P00k0>K<P0030000
003Vc800i/b000@0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0800000
0`3Vc8000`000000i/b0000000090>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800
3`3Vc8000`000000i/b00>K<P00I0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc800
2`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001P0i/b000<000000>K<P03Vc800
3@3Vc80001l0i/b000<000000>K<P03Vc800>`3Vc8000`000000i/b00>K<P0040>K<P0030000003V
c800i/b000@0i/b000<000000>K<P03Vc8000P3Vc802000000<0i/b000<000000>K<P00000002@3V
c8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800603V
c8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8004P3V
c8000`000000i/b00>K<P00I0>K<P0030000003Vc800i/b000d0i/b0000O0>K<P0030000003Vc800
i/b003`0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0050>K<P0070000003Vc800
i/b00>K<P0000000i/b0000000020>K<P0030000003Vc800000000T0i/b000<000000>K<P03Vc800
4@3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b001P0i/b000<000000>K<P03Vc800
303Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800
6@3Vc8000`000000i/b00>K<P00=0>K<P0007`3Vc8000`000000i/b00>K<P00l0>K<P0030000003V
c800i/b000<0i/b000<000000>K<P03Vc8001P3Vc8001P000000i/b00>K<P0000000i/b000000080
i/b000@000000>K<P03Vc8000000203Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b0
0100i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b0
00X0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00J0>K<P0030000003Vc800i/b0
00d0i/b0000N0>K<P0800000?`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000L0
i/b000D000000>K<P0000000i/b0000000020>K<P0040000003Vc800i/b0000000P0i/b000<00000
0>K<P03Vc800403Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b001L0i/b000<00000
0>K<P03Vc8003@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b00140i/b000<00000
0>K<P03Vc8006P3Vc8000`000000i/b00>K<P00=0>K<P0007P3Vc8000`000000i/b00>K<P00n0>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800203Vc802000000050>K<P0000000i/b0
0>K<P00000000P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b00100i/b000<00000
0>K<P03Vc8004@3Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b000h0i/b000<00000
0>K<P03Vc8002@3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b001/0i/b000<00000
0>K<P03Vc8003@3Vc80001h0i/b000<000000>K<P03Vc800?`3Vc8001@000000i/b00>K<P03Vc800
000000/0i/b000@000000>K<P03Vc80000000P3Vc80010000000i/b00>K<P00000070>K<P0030000
003Vc800i/b00100i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00F0>K<P0030000
003Vc800i/b000h0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00@0>K<P0030000
003Vc800i/b001/0i/b000<000000>K<P03Vc8003@3Vc80001h0i/b000<000000>K<P03Vc800?`3V
c8001@000000i/b00>K<P03Vc800000000/0i/b000@000000>K<P03Vc80000000P3Vc80010000000
i/b00>K<P00000060>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8004P3Vc8000`00
0000i/b00>K<P00E0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800203Vc8000`00
0000i/b00>K<P00?0>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc8003@3Vc80001h0
i/b000<000000>K<P03Vc800?`3Vc8001@000000i/b00>K<P03Vc800000000/0i/b00P0000001@3V
c80000000>K<P03Vc80000000080i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00A
0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P00@
0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00M
0>K<P0030000003Vc800i/b000`0i/b0000N0>K<P0030000003Vc800i/b00400i/b000@000000>K<
P03Vc8000000303Vc80300000080i/b000@000000>K<P03Vc80000001P3Vc8000`000000i/b00>K<
P00@0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<
P00@0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<
P00N0>K<P0030000003Vc800i/b000`0i/b0000N0>K<P0030000003Vc800i/b00400i/b000@00000
0>K<P03Vc8000000303Vc8001P000000i/b0000000000000i/b0000000<0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03V
c800503Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03V
c8003P3Vc8000`000000i/b00>K<P00N0>K<P0030000003Vc800i/b000`0i/b0000N0>K<P0030000
003Vc800i/b00440i/b000<000000>K<P0000000303Vc8001P000000i/b00>K<P0000000i/b00000
00<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b0
01@0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b0
00L0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b0
00`0i/b0000N0>K<P0030000003Vc800i/b00440i/b000<000000>K<P0000000303Vc80010000000
i/b00>K<P00000020>K<P0040000003Vc800i/b0000000D0i/b000<000000>K<P03Vc800403Vc800
0`000000i/b00>K<P00D0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8004`3Vc800
0`000000i/b00>K<P0060>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8007`3Vc800
0`000000i/b00>K<P00<0>K<P0007P3Vc8000`000000i/b00>K<P0120>K<P0800000303Vc8001`00
0000i/b00>K<P03Vc80000000>K<P00000000P3Vc8000`000000i/b00>K<P0030>K<P0030000003V
c800i/b00100i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P00B0>K<P0030000003V
c800i/b001<0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00<0>K<P0030000003V
c800i/b00200i/b000<000000>K<P03Vc800303Vc80001d0i/b000<000000>K<P03Vc800@`3Vc802
000000`0i/b000L000000>K<P03Vc800i/b00000003Vc800000000<0i/b000D000000>K<P03Vc800
i/b00000000C0>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc8004P3Vc8000`000000
i/b00>K<P00C0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800303Vc8000`000000
i/b00>K<P00P0>K<P0030000003Vc800i/b000`0i/b0000M0>K<P0030000003Vc800i/b004<0i/b0
0P00000<0>K<P0030000003Vc800i/b00080i/b00P0000030>K<P0050000003Vc800i/b00>K<P000
00004P3Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03V
c8005@3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03V
c8008@3Vc8000`000000i/b00>K<P00<0>K<P0007@3Vc8000`000000i/b00>K<P0140>K<P0030000
003Vc800i/b000X0i/b000<000000>K<P03Vc8000P3Vc802000000<0i/b000D000000>K<P03Vc800
i/b00000000B0>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03Vc800403Vc8000`000000
i/b00>K<P00E0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8002P3Vc8000`000000
i/b00>K<P00Q0>K<P0030000003Vc800i/b000`0i/b0000M0>K<P0030000003Vc800i/b004<0i/b0
0P00000<0>K<P0030000003Vc800i/b00080i/b00P0000040>K<P0040000003Vc800i/b000000180
i/b000<000000>K<P03Vc8005P3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b001D0
i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b00280
i/b000<000000>K<P03Vc800303Vc80001d0i/b000<000000>K<P03Vc800@`3Vc8000`000000i/b0
0000000;0>K<P0030000003Vc800i/b000<0i/b00P0000030>K<P0040000003Vc800i/b000000180
i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b001L0
i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b002<0
i/b000<000000>K<P03Vc8002`3Vc80001d0i/b000<000000>K<P03Vc800@`3Vc8000`000000i/b0
0000000;0>K<P0030000003Vc800i/b000<0i/b00P0000030>K<P0040000003Vc800i/b000000180
i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b001L0
i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b002@0
i/b000<000000>K<P03Vc8002`3Vc80001d0i/b000<000000>K<P03Vc800@`3Vc80010000000i/b0
0>K<P000000;0>K<P0030000003Vc800i/b00080i/b00P0000030>K<P0040000003Vc800i/b00000
0140i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b0
01L0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b0
02@0i/b000<000000>K<P03Vc8002`3Vc80001d0i/b000<000000>K<P03Vc800@`3Vc80010000000
i/b00>K<P000000;0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3Vc8020000
0180i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b0
01T0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b0
02D0i/b000<000000>K<P03Vc8002`3Vc80001d0i/b000<000000>K<P03Vc800@`3Vc8001@000000
i/b00>K<P03Vc800000000X0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<
P08000004P3Vc8000`000000i/b00>K<P00I0>K<P0030000003Vc800i/b000`0i/b000<000000>K<
P03Vc8006@3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b000L0i/b000<000000>K<
P03Vc8009@3Vc8000`000000i/b00>K<P00;0>K<P0007@3Vc8000`000000i/b00>K<P0130>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0030>K<P080
00000`3Vc80200000180i/b000<000000>K<P03Vc8006@3Vc8000`000000i/b00>K<P00<0>K<P003
0000003Vc800i/b001T0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0060>K<P003
0000003Vc800i/b002H0i/b000<000000>K<P03Vc8002`3Vc80001`0i/b000<000000>K<P03Vc800
A03Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800
0`3Vc802000000<0i/b00P00000B0>K<P0030000003Vc800i/b001T0i/b000<000000>K<P03Vc800
303Vc8000`000000i/b00>K<P00J0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800
1P3Vc8000`000000i/b00>K<P00V0>K<P0030000003Vc800i/b000/0i/b0000L0>K<P0800000A@3V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800103V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8006@3V
c8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8000`3V
c8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b002L0i/b000<000000>K<P03Vc8002`3V
c80001`0i/b000<000000>K<P03Vc800A03Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800
i/b000D0i/b000<000000>K<P03Vc800103Vc802000000<0i/b000<000000>K<P03Vc8003`3Vc800
0`000000i/b00>K<P00K0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8006`3Vc800
0`000000i/b00>K<P0030>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8009`3Vc800
0`000000i/b00>K<P00;0>K<P000703Vc8000`000000i/b00>K<P0140>K<P0030000003Vc800i/b0
00D0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0040>K<P08000000`3Vc8000`00
0000i/b00>K<P00?0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8002P3Vc8000`00
0000i/b00>K<P00L0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800103Vc8000`00
0000i/b00>K<P00X0>K<P0030000003Vc800i/b000/0i/b0000L0>K<P0030000003Vc800i/b004@0
i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b000@0
i/b000<000000>K<P00000000P3Vc80200000100i/b000<000000>K<P03Vc8006`3Vc8000`000000
i/b00>K<P0090>K<P0030000003Vc800i/b001d0i/b000<000000>K<P03Vc8000P3Vc8000`000000
i/b00>K<P0040>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03Vc8002`3Vc80001`0i/b0
00<000000>K<P03Vc800A03Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc800103Vc8001`000000i/b00000003Vc80000000>K<P0000000403Vc8000`00
0000i/b00>K<P00L0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8007@3Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800:P3Vc8000`00
0000i/b00>K<P00:0>K<P000703Vc8000`000000i/b00>K<P0140>K<P0030000003Vc800i/b000L0
i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0070000003Vc80000000>K<
P0000000i/b00000000@0>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc800203Vc800
0`000000i/b00>K<P00N0>K<P0050000003Vc800i/b00>K<P00000001@3Vc8000`000000i/b00>K<
P00Z0>K<P0030000003Vc800i/b000X0i/b0000L0>K<P0030000003Vc800i/b004@0i/b000<00000
0>K<P03Vc800203Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000@0i/b000H00000
0>K<P000000000000>K<P000000?0>K<P0030000003Vc800i/b001d0i/b000<000000>K<P03Vc800
1`3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b00080i/b000D000000>K<P03Vc800
i/b00000000]0>K<P0030000003Vc800i/b000X0i/b0000L0>K<P0030000003Vc800i/b004@0i/b0
00<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000@0i/b0
00@000000>K<P000000000000P3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b001d0
i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00P0>K<P0050000003Vc800i/b00>K<
P00000000`3Vc8000`000000i/b00>K<P00[0>K<P0030000003Vc800i/b000X0i/b0000L0>K<P003
0000003Vc800i/b004@0i/b000<000000>K<P03Vc8002@3Vc8001@000000i/b00>K<P03Vc8000000
00H0i/b000@000000>K<P000000000000P3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800
i/b001h0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00P0>K<P0050000003Vc800
i/b00>K<P00000000P3Vc8000`000000i/b00>K<P00/0>K<P0030000003Vc800i/b000X0i/b0000K
0>K<P0030000003Vc800i/b004D0i/b000<000000>K<P03Vc8002P3Vc80010000000i/b00>K<P000
00060>K<P0030000003Vc800i/b00080000000<0i/b00000003Vc8003@3Vc8000`000000i/b00>K<
P00N0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800803Vc8001@000000i/b00>K<
P03Vc80000000080i/b000<000000>K<P03Vc800;03Vc8000`000000i/b00>K<P00:0>K<P0006`3V
c8000`000000i/b00>K<P0150>K<P0030000003Vc800i/b000/0i/b000<000000>K<P00000001P3V
c8000`000000i/b000000002000000030>K<P0000000i/b000d0i/b000<000000>K<P03Vc8007P3V
c8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b00280i/b000H000000>K<P03Vc8000000
0>K<P000000_0>K<P0030000003Vc800i/b000X0i/b0000K0>K<P0030000003Vc800i/b004D0i/b0
00<000000>K<P03Vc8002`3Vc8000`000000i/b0000000060>K<P0050000003Vc80000000>K<P000
00000P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03V
c8001@3Vc8000`000000i/b00>K<P00R0>K<P0060000003Vc800i/b00000003Vc8000000;`3Vc800
0`000000i/b00>K<P00:0>K<P0006`3Vc8000`000000i/b00>K<P0150>K<P0030000003Vc800i/b0
00`0i/b00`0000060>K<P080000000D0i/b0000000000000i/b00000000<0>K<P0030000003Vc800
i/b00200i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00R0>K<P0030000003Vc800
i/b000800000<03Vc8000`000000i/b00>K<P00:0>K<P0006`3Vc8000`000000i/b00>K<P0150>K<
P0030000003Vc800i/b000d0i/b00P0000060>K<P080000000D0i/b0000000000000i/b00000000<
0>K<P0030000003Vc800i/b00200i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00T
0>K<P0040000003Vc800000000000300i/b000<000000>K<P03Vc8002P3Vc80001/0i/b000<00000
0>K<P03Vc800A@3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000@0i/b00P000002
0>K<P0040000003Vc800i/b0000000/0i/b000<000000>K<P03Vc800803Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b002@0i/b00`00000b0>K<P0030000003Vc800i/b000T0i/b0000K
0>K<P0030000003Vc800i/b004D0i/b000<000000>K<P03Vc8003P3Vc802000000D0i/b00P000002
0>K<P080000000<0i/b00000003Vc8002P3Vc8000`000000i/b00>K<P00Q0>K<P0030000003Vc800
i/b00080i/b000<000000>K<P03Vc8008@3Vc804000000030>K<P000000000000340i/b000<00000
0>K<P03Vc8002@3Vc80001/0i/b000<000000>K<P03Vc800A03Vc8000`000000i/b00>K<P00?0>K<
P08000001@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800000000/0i/b000<000000>K<
P03Vc8008@3Vc8001@000000i/b00>K<P03Vc80000000240i/b00`0000040>K<P0040000003Vc800
i/b000000300i/b000<000000>K<P03Vc8002@3Vc80001/0i/b000<000000>K<P03Vc800A03Vc800
0`000000i/b00>K<P00?0>K<P0030000003Vc800000000@0i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00000000:0>K<P0030000003Vc800i/b00280i/b000D000000>K<P03Vc800i/b00000
000M0>K<P0@000001`3Vc8001@000000i/b00>K<P03Vc800000002l0i/b000<000000>K<P03Vc800
2@3Vc80001/0i/b000<000000>K<P03Vc800A03Vc8000`000000i/b00>K<P00?0>K<P0040000003V
c8000000000000<0i/b00P0000030>K<P080000000<0i/b00000003Vc800203Vc8000`000000i/b0
0>K<P00R0>K<P0050000003Vc800i/b00>K<P00000006P3Vc803000000/0i/b000D000000>K<P03V
c800i/b00000000_0>K<P0030000003Vc800i/b000T0i/b0000J0>K<P0030000003Vc800i/b004D0
i/b000<000000>K<P03Vc8003`3Vc80010000000i/b00000000000030>K<P0800000103Vc8000`00
0000i/b0000000090>K<P0030000003Vc800i/b002<0i/b000@000000>K<P03Vc80000005P3Vc804
000000d0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00/0>K<P0030000003Vc800
i/b000T0i/b0000J0>K<P0030000003Vc800i/b004D0i/b000<000000>K<P03Vc8003`3Vc8000`00
0000i/b00>K<P00200000080i/b00P0000040>K<P0030000003Vc800000000T0i/b000<000000>K<
P03Vc8008`3Vc8000`000000i/b00000000D0>K<P0<000004@3Vc8000`000000i/b00>K<P0040>K<
P0030000003Vc800i/b002/0i/b000<000000>K<P03Vc8002@3Vc80001X0i/b00`0000150>K<P003
0000003Vc800i/b000l0i/b000D000000>K<P03Vc80000000>K<P002000000030>K<P0000000i/b0
00<0i/b00`0000090>K<P0030000003Vc800i/b002<0i/b000<000000>K<P0000000403Vc8040000
01<0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00Z0>K<P0030000003Vc800i/b0
00T0i/b00000103Vc80000000000000000050>K<P08000001P3Vc803000000H0i/b000<000000>K<
P03Vc800A@3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc80000000080i/b000<000000>K<
P00000001@3Vc8000`000000i/b0000000080>K<P0030000003Vc800i/b002<0i/b000<000000>K<
P00000003@3Vc803000001L0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00Y0>K<
P0030000003Vc800i/b000T0i/b0000010000000i/b00>K<P00000050>K<P08000001`3Vc8000`00
0000i/b00>K<P0050>K<P0030000003Vc800i/b004D0i/b000<000000>K<P03Vc800403Vc8002000
0000i/b00>K<P0000000i/b00000003Vc80000001@3Vc8000`000000i/b0000000070>K<P0030000
003Vc800i/b002D0i/b000<000000>K<P03Vc800203Vc804000001X0i/b000<000000>K<P03Vc800
203Vc8000`000000i/b00>K<P00X0>K<P0030000003Vc800i/b000T0i/b000040>K<P0030000003V
c800i/b000P0i/b01@0000060>K<P0030000003Vc800i/b004D0i/b000<000000>K<P03Vc800403V
c8001@000000i/b00>K<P0000000i/b00080000000<0i/b00000003Vc800103Vc802000000L0i/b0
00<000000>K<P03Vc8009@3Vc8000`000000i/b00>K<P0050>K<P0<000007@3Vc8000`000000i/b0
0>K<P00:0>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03Vc800203Vc80000@0i/b000<0
00000>K<P03Vc800203Vc80010000000i/b00>K<P00000070>K<P0030000003Vc800i/b004D0i/b0
00<000000>K<P03Vc800403Vc80010000000i/b00>K<P03Vc802000000030>K<P0000000000000D0
i/b00P0000070>K<P0030000003Vc800i/b002D0i/b00P0000020>K<P0@00000803Vc8000`000000
i/b00>K<P00:0>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03Vc800203Vc80000@0i/b0
00<000000>K<P03Vc8002@3Vc8000`000000i/b0000000070>K<P0030000003Vc800i/b004D0i/b0
00<000000>K<P03Vc800403Vc80010000000i/b00>K<P03Vc80200000080i/b000<000000>K<P03V
c8000`3Vc803000000H0i/b000<000000>K<P03Vc800903Vc8000`000000i/b000000002000002<0
i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00W0>K<P0030000003Vc800i/b000P0
i/b000040>K<P0030000003Vc800i/b000X0i/b00P0000070>K<P0030000003Vc800i/b004D0i/b0
00<000000>K<P03Vc800403Vc8001@000000i/b00>K<P03Vc800000000<0i/b000<000000>K<P03V
c800103Vc802000000H0i/b000<000000>K<P03Vc8008P3Vc804000000030>K<P0000000i/b002<0
i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00V0>K<P0030000003Vc800i/b000P0
i/b0000010000000i/b00>K<P000000=0>K<P08000001P3Vc8000`000000i/b00>K<P0160>K<P003
0000003Vc800i/b00100i/b000@000000>K<P03Vc800i/b00P0000020>K<P08000001@3Vc8020000
00H0i/b000<000000>K<P03Vc8007`3Vc80300000080i/b000@000000>K<P03Vc8000000903Vc800
0`000000i/b00>K<P00>0>K<P0030000003Vc800i/b002D0i/b000<000000>K<P03Vc800203Vc800
00@000003P3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b004H0i/b000<000000>K<
P03Vc8004@3Vc8000`000000i/b00>K<P00200000080i/b000<000000>K<P00000001@3Vc8020000
00@0i/b000<000000>K<P03Vc800703Vc804000000@0i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P00P0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc800903Vc8000`00
0000i/b00>K<P0080>K<P0006@3Vc8000`000000i/b00>K<P0160>K<P0030000003Vc800i/b00140
i/b000<000000>K<P03Vc8000P0000030>K<P0030000003Vc800000000@0i/b00P0000040>K<P003
0000003Vc800i/b001T0i/b00`0000080>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c800803Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b002<0i/b000<000000>K<P03V
c800203Vc80001T0i/b000<000000>K<P03Vc800AP3Vc8000`000000i/b00>K<P00A0>K<P0060000
003Vc800i/b00000003Vc80000000P3Vc8000`000000i/b0000000040>K<P0800000103Vc8000`00
0000i/b00>K<P00E0>K<P0@000002`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b0
01l0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00R0>K<P0030000003Vc800i/b0
00P0i/b0000I0>K<P0030000003Vc800i/b004H0i/b000<000000>K<P03Vc8004@3Vc8000`000000
i/b0000000020>K<P0040000003Vc800i/b000000080i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b00180i/b00`00000>0>K<P0030000003Vc800i/b0
00@0i/b000<000000>K<P03Vc8007P3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b0
0240i/b000<000000>K<P03Vc800203Vc80001T0i/b000<000000>K<P03Vc800AP3Vc8000`000000
i/b00>K<P00A0>K<P0030000003Vc800000000<0i/b000<000000>K<P00000000`3Vc80010000000
i/b00>K<P03Vc802000000<0i/b000<000000>K<P03Vc8003P3Vc80400000140i/b000<000000>K<
P03Vc8001@3Vc8000`000000i/b00>K<P00M0>K<P0030000003Vc800i/b001@0i/b000<000000>K<
P03Vc8008@3Vc8000`000000i/b00>K<P0080>K<P0006@3Vc8000`000000i/b00>K<P0160>K<P003
0000003Vc800i/b00140i/b000<000000>K<P00000000`3Vc8000`000000i/b0000000040>K<P003
0000003Vc800i/b0008000000P3Vc8000`000000i/b00>K<P00<0>K<P0<00000503Vc8000`000000
i/b00>K<P0060>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc8005P3Vc8000`000000
i/b00>K<P00Q0>K<P0030000003Vc800i/b000L0i/b0000I0>K<P0030000003Vc800i/b004H0i/b0
00<000000>K<P03Vc8004@3Vc8000`000000i/b0000000030>K<P0030000003Vc800000000@0i/b0
00D000000>K<P03Vc800i/b0000000020>K<P0030000003Vc800i/b000P0i/b01000000G0>K<P003
0000003Vc800i/b000L0i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P00G0>K<P003
0000003Vc800i/b00200i/b000<000000>K<P03Vc8001`3Vc80001T0i/b000<000000>K<P03Vc800
AP3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800000000@0i/b000<000000>K<P0000000
103Vc80010000000i/b00>K<P00000020>K<P0030000003Vc800i/b000D0i/b00`00000K0>K<P003
0000003Vc800i/b000L0i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P00H0>K<P003
0000003Vc800i/b001l0i/b000<000000>K<P03Vc8001`3Vc80001T0i/b000<000000>K<P03Vc800
AP3Vc8000`000000i/b00>K<P00B0>K<P0800000103Vc8000`000000i/b0000000050>K<P0060000
003Vc80000000000003Vc80000000`3Vc804000001d0i/b000<000000>K<P03Vc8002@3Vc8000`00
0000i/b00>K<P00I0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc8007P3Vc8000`00
0000i/b00>K<P0070>K<P000603Vc8000`000000i/b00>K<P0170>K<P0030000003Vc800i/b00180
i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0000000060>K<P0040000003Vc80000000>K<
P0@000008@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b001T0i/b000<000000>K<
P03Vc8006`3Vc8000`000000i/b00>K<P00M0>K<P0030000003Vc800i/b000L0i/b0000H0>K<P003
0000003Vc800i/b004L0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P0040>K<P080
00001P3Vc805000002@0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00G0>K<P003
0000003Vc800i/b001d0i/b000<000000>K<P03Vc800703Vc8000`000000i/b00>K<P0070>K<P000
603Vc8000`000000i/b00>K<P0170>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800
103Vc802000000@0i/b01P00000T0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc800
5`3Vc8000`000000i/b00>K<P00M0>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc800
1`3Vc80001P0i/b000<000000>K<P03Vc800AP3Vc8000`000000i/b00>K<P00D0>K<P0030000003V
c800i/b000@0i/b01@0000040>K<P0<000008`3Vc8000`000000i/b00>K<P00<0>K<P0030000003V
c800i/b001H0i/b000<000000>K<P03Vc8007P3Vc8000`000000i/b00>K<P00K0>K<P0030000003V
c800i/b000L0i/b0000H0>K<P0030000003Vc800i/b004H0i/b000<000000>K<P03Vc8005@3Vc800
10000000i/b00>K<P03Vc804000000P0i/b00P00000S0>K<P0030000003Vc800i/b000`0i/b000<0
00000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00P0>K<P0030000003Vc800i/b001X0i/b000<0
00000>K<P03Vc8001`3Vc80001P0i/b00P0000170>K<P0030000003Vc800i/b001D0i/b010000002
0>K<P0800000203Vc80300000240i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00D
0>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc8006@3Vc8000`000000i/b00>K<P007
0>K<P000603Vc8000`000000i/b00>K<P0160>K<P0030000003Vc800i/b00180i/b00`0000030>K<
P0050000003Vc800i/b00>K<P00000001`3Vc80010000000i/b000000000000Q0>K<P0030000003V
c800i/b000h0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00S0>K<P0030000003V
c800i/b001P0i/b000<000000>K<P03Vc8001`3Vc80001P0i/b000<000000>K<P03Vc800AP3Vc800
0`000000i/b00>K<P00>0>K<P0@000001`3Vc80010000000i/b00>K<P00000070>K<P0030000003V
c800i/b000800000803Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b00180i/b000<0
00000>K<P03Vc800903Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b000H0i/b0000H
0>K<P0030000003Vc800i/b004H0i/b000<000000>K<P03Vc8002`3Vc803000000`0i/b000@00000
0>K<P03Vc80000001@3Vc8000`000000i/b00>K<P0020>K<P08000007P3Vc8000`000000i/b00>K<
P00@0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8009@3Vc8000`000000i/b00>K<
P00G0>K<P0030000003Vc800i/b000H0i/b0000H0>K<P0030000003Vc800i/b004H0i/b000<00000
0>K<P03Vc8001`3Vc80400000100i/b000@000000>K<P00000000000103Vc8000`000000i/b00>K<
P0020>K<P08000007P3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b00100i/b000<0
00000>K<P03Vc8009P3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b000H0i/b0000G
0>K<P0030000003Vc800i/b004L0i/b000<000000>K<P03Vc800103Vc803000001D0i/b000@00000
0>K<P000000000000`3Vc8000`000000i/b00>K<P0030>K<P08000007@3Vc8000`000000i/b00>K<
P00B0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8009`3Vc8000`000000i/b00>K<
P00F0>K<P0030000003Vc800i/b000H0i/b0000G0>K<P0030000003Vc800i/b004L0i/b000<00000
0>K<P03Vc8001000000I0>K<P0@0000000<0i/b00000003Vc8001@3Vc803000001/0i/b000<00000
0>K<P03Vc8004`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b002T0i/b000<00000
0>K<P03Vc8005@3Vc8000`000000i/b00>K<P0060>K<P0005`3Vc8000`000000i/b00>K<P0170>K<
P0<000007`3Vc802000000030>K<P0000000i/b000H0i/b00`00000J0>K<P0030000003Vc800i/b0
01@0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00Z0>K<P0030000003Vc800i/b0
01@0i/b000<000000>K<P03Vc8001P3Vc80001L0i/b000<000000>K<P03Vc800@`3Vc80500000280
i/b00P0000080>K<P080000000<0i/b00000003Vc8005`3Vc8000`000000i/b00>K<P00E0>K<P003
0000003Vc800i/b000d0i/b000<000000>K<P03Vc800:`3Vc8000`000000i/b00>K<P00C0>K<P003
0000003Vc800i/b000H0i/b0000G0>K<P0030000003Vc800i/b00400i/b00`0000040>K<P0030000
003Vc800i/b00240i/b00P0000080>K<P080000000<0i/b00000003Vc8005P3Vc8000`000000i/b0
0>K<P00F0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc800;@3Vc8000`000000i/b0
0>K<P00B0>K<P0030000003Vc800i/b000H0i/b0000G0>K<P0030000003Vc800i/b003`0i/b01000
00070>K<P0030000003Vc800i/b00280i/b00P0000070>K<P0<0000000<0i/b00000003Vc8005@3V
c8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc800;P3V
c8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000H0i/b0000G0>K<P0030000003Vc800
i/b003T0i/b00`00000;0>K<P0030000003Vc800i/b002<0i/b00P0000070>K<P080000000<0i/b0
0000003Vc800503Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b000T0i/b000<00000
0>K<P03Vc800<03Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000H0i/b0000G0>K<
P0030000003Vc800i/b003D0i/b01000000>0>K<P0030000003Vc800i/b002@0i/b00P0000060>K<
P0<0000000<0i/b00000003Vc8004`3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b0
00T0i/b000<000000>K<P03Vc800<03Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b0
00D0i/b0000G0>K<P0030000003Vc800i/b00380i/b00`00000B0>K<P0030000003Vc800i/b002D0
i/b00P0000060>K<P08000000P3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b001T0
i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00a0>K<P0030000003Vc800i/b00100
i/b000<000000>K<P03Vc8001@3Vc80001L0i/b000<000000>K<P03Vc800;P3Vc804000001D0i/b0
00<000000>K<P03Vc8009P3Vc802000000D0i/b00`0000020>K<P0030000003Vc800i/b000l0i/b0
00<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b003<0i/b0
00<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P0050>K<P0005P3Vc8000`000000i/b00>K<
P00/0>K<P0<000006@3Vc8000`000000i/b00>K<P00W0>K<P08000001@3Vc802000000<0i/b000<0
00000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00K0>K<P0030000003Vc800i/b000H0i/b000<0
00000>K<P03Vc800=03Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000D0i/b0000F
0>K<P0030000003Vc800i/b002P0i/b01000000L0>K<P0030000003Vc800i/b002T0i/b000<00000
0>K<P03Vc8000P3Vc803000000<0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00K
0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800=@3Vc8000`000000i/b00>K<P00=
0>K<P0030000003Vc800i/b000D0i/b0000F0>K<P0030000003Vc800i/b002D0i/b00`00000P0>K<
P0030000003Vc800i/b002T0i/b00P0000040>K<P0<000000`3Vc8000`000000i/b00>K<P00;0>K<
P0030000003Vc800i/b001d0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00g0>K<
P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8001@3Vc80001H0i/b000<000000>K<P03V
c8008@3Vc804000002<0i/b000<000000>K<P03Vc800:P3Vc802000000<0i/b000<000000>K<P000
00000`3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b001d0i/b000<000000>K<P03V
c800103Vc8000`000000i/b00>K<P00h0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03V
c8001@3Vc80001H0i/b000<000000>K<P03Vc8007P3Vc803000002L0i/b000<000000>K<P03Vc800
:`3Vc802000000<0i/b00`0000030>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc800
7P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b003T0i/b000<000000>K<P03Vc800
2`3Vc8000`000000i/b00>K<P0050>K<P0005P3Vc8000`000000i/b00>K<P00J0>K<P0@00000:P3V
c8000`000000i/b00>K<P00/0>K<P08000000P3Vc8000`000000i/b0000000040>K<P0030000003V
c800i/b000P0i/b000<000000>K<P03Vc8007`3Vc8000`000000i/b00>K<P0020>K<P0030000003V
c800i/b003X0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P0050>K<P0005P3Vc800
0`000000i/b00>K<P00G0>K<P0<00000;P3Vc8000`000000i/b00>K<P00]0>K<P08000000P3Vc803
000000@0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00P0>K<P0050000003Vc800
i/b00>K<P0000000?@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000D0i/b0000F
0>K<P0030000003Vc800i/b001<0i/b01000000`0>K<P0030000003Vc800i/b002l0i/b00P000000
103Vc80000000>K<P00000050>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8008@3V
c80010000000i/b00>K<P000000o0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc800
103Vc80001D0i/b00`00000A0>K<P0<00000=03Vc8000`000000i/b00>K<P00`0>K<P080000000@0
i/b00000003Vc80000001@3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b00280i/b0
00<000000>K<P0000000@03Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000@0i/b0
000F0>K<P0030000003Vc800i/b000`0i/b01000000g0>K<P0030000003Vc800i/b00340i/b00`00
00000`3Vc8000000000000050>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8008P3V
c80200000480i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0040>K<P0005@3Vc800
0`000000i/b00>K<P00:0>K<P0<00000>`3Vc8000`000000i/b00>K<P00b0>K<P0<0000000<0i/b0
0000003Vc8001@3Vc8001@000000i/b00>K<P03Vc800000002H0i/b000<000000>K<P03Vc800@@3V
c8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000@0i/b0000E0>K<P0030000003Vc800
i/b000H0i/b01000000n0>K<P0030000003Vc800i/b003<0i/b01@0000050>K<P0050000003Vc800
i/b00>K<P00000009@3Vc8000`000000i/b00>K<P0120>K<P0030000003Vc800i/b000H0i/b000<0
00000>K<P03Vc800103Vc80001D0i/b000<000000>K<P03Vc8000`3Vc80300000480i/b000<00000
0>K<P03Vc800<`3Vc8000`000000i/b000000002000000H0i/b000@000000>K<P03Vc80000009@3V
c8000`000000i/b00>K<P0130>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800103V
c80001D0i/b000<000000>K<P00000000`0000150>K<P0030000003Vc800i/b003@0i/b00P000000
0`3Vc8000000000000060>K<P08000009@3Vc8000`000000i/b00>K<P0150>K<P0030000003Vc800
i/b000@0i/b000<000000>K<P03Vc800103Vc80001D0i/b00P0000190>K<P0030000003Vc800i/b0
03D0i/b00P0000000`3Vc80000000>K<P0060>K<P0030000003Vc800i/b00280i/b000<000000>K<
P03Vc800A`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000@0i/b0000F0>K<P080
0000B03Vc8000`000000i/b00>K<P00f0>K<P0040000003Vc800i/b0000000@0i/b00P0000000`3V
c80000000>K<P00R0>K<P0030000003Vc800i/b004P0i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P0040>K<P000603Vc8000`000000i/b00>K<P0150>K<P0030000003Vc800i/b003L0
i/b0100000000`3Vc8000000000000040>K<P0030000003Vc800i/b001l0i/b000<000000>K<P03V
c800BP3Vc8001@000000i/b00>K<P03Vc800000000H0i/b0000I0>K<P0030000003Vc800i/b004@0
i/b000<000000>K<P03Vc800>03Vc804000000L0i/b000<000000>K<P03Vc8007@3Vc8000`000000
i/b00>K<P01<0>K<P0050000003Vc800i/b00>K<P00000001@3Vc80001X0i/b00P0000140>K<P003
0000003Vc800i/b003T0i/b000@000000>K<P000000000001`3Vc8000`000000i/b00>K<P00L0>K<
P0030000003Vc800i/b004d0i/b000@000000>K<P03Vc80000001@3Vc80001`0i/b000<000000>K<
P03Vc800@@3Vc8000`000000i/b00>K<P00j0>K<P080000000<0i/b00000003Vc8001P3Vc8000`00
0000i/b00>K<P00J0>K<P0030000003Vc800i/b004h0i/b000@000000>K<P03Vc80000001@3Vc800
01d0i/b000<000000>K<P03Vc800@03Vc8000`000000i/b00>K<P00k0>K<P080000000<0i/b00000
003Vc8001P3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b00500i/b000<000000>K<
P00000001@3Vc80001h0i/b00P0000100>K<P0030000003Vc800i/b003`0i/b000<000000>K<P03V
c8000P0000060>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc800D@3Vc802000000D0
i/b0000P0>K<P0030000003Vc800i/b003d0i/b000<000000>K<P03Vc800?@3Vc8001@000000i/b0
0>K<P03Vc800000000H0i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P01A0>K<P0<0
00001@3Vc8000240i/b000<000000>K<P03Vc800?03Vc8000`000000i/b00>K<P00n0>K<P0050000
003Vc800i/b00>K<P00000001P3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b004d0
i/b0100000080>K<P0008P3Vc802000003`0i/b000<000000>K<P03Vc800?`3Vc8001@000000i/b0
0>K<P03Vc800000000H0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P01:0>K<P0@0
0000303Vc80002@0i/b000<000000>K<P03Vc800>@3Vc8000`000000i/b00>K<P0100>K<P0050000
003Vc800i/b00>K<P00000001P3Vc80200000140i/b000<000000>K<P03Vc800A`3Vc80400000100
i/b0000U0>K<P0030000003Vc800i/b003P0i/b000<000000>K<P03Vc800@@3Vc8001@000000i/b0
0>K<P03Vc800000000L0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P0130>K<P0@0
0000503Vc80002H0i/b00P00000h0>K<P0030000003Vc800i/b00480i/b00P0000020>K<P0030000
003Vc800i/b000D0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P0100>K<P0@00000
603Vc80002P0i/b000<000000>K<P03Vc800=@3Vc8000`000000i/b00>K<P0130>K<P08000000P3V
c802000000H0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00m0>K<P0@00000703V
c80002T0i/b000<000000>K<P03Vc800=03Vc8000`000000i/b00>K<P0140>K<P08000000`3Vc800
0`000000i/b00>K<P0040>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc800>@3Vc804
00000200i/b0000Z0>K<P0800000=03Vc8000`000000i/b00>K<P0150>K<P08000000`3Vc8000`00
0000i/b00>K<P0040>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800=P3Vc8040000
02@0i/b0000/0>K<P0030000003Vc800i/b00340i/b000<000000>K<P03Vc800A`3Vc8001@000000
i/b00>K<P03Vc800000000H0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00c0>K<
P0@00000:03Vc80002d0i/b00P00000`0>K<P0030000003Vc800i/b004T0i/b000D000000>K<P03V
c800i/b0000000060>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc800;`3Vc8040000
02`0i/b0000_0>K<P0030000003Vc800i/b002d0i/b000<000000>K<P03Vc800BP3Vc8001@000000
i/b00>K<P03Vc800000000H0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00/0>K<
P0@00000<03Vc8000300i/b000<000000>K<P03Vc800;03Vc8000`000000i/b00>K<P01;0>K<P005
0000003Vc800i/b00>K<P00000001P3Vc80010000000i/b00>K<P000000[0>K<P0@00000=03Vc800
0340i/b00P00000/0>K<P0030000003Vc800i/b004`0i/b000@000000>K<P03Vc800i/b00P000005
0>K<P0030000003Vc800000002L0i/b01000000h0>K<P000<`3Vc8000`000000i/b00>K<P00Y0>K<
P0030000003Vc800i/b004d0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0020>K<
P0800000903Vc804000003`0i/b0000d0>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03V
c800CP3Vc8000`000000i/b00>K<P0020>K<P0040000003Vc800000000000240i/b01@0000100>K<
P000=@3Vc802000002P0i/b000<000000>K<P03Vc800C`3Vc806000001l0i/b0100000150>K<P000
=`3Vc8000`000000i/b00>K<P00U0>K<P0030000003Vc800i/b00700i/b0100000190>K<P000>03V
c8000`000000i/b00>K<P00T0>K<P0030000003Vc800i/b006`0i/b01000001=0>K<P000>@3Vc802
000002@0i/b000<000000>K<P03Vc800J03Vc80400000540i/b0000k0>K<P0030000003Vc800i/b0
0240i/b000<000000>K<P03Vc800I03Vc804000005D0i/b0000l0>K<P0030000003Vc800i/b00200
i/b000<000000>K<P03Vc800H03Vc804000005T0i/b0000m0>K<P0800000803Vc8000`000000i/b0
0>K<P01L0>K<P0@00000G@3Vc80003l0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<
P01H0>K<P0@00000H@3Vc8000400i/b000<000000>K<P03Vc800703Vc8000`000000i/b00>K<P01D
0>K<P0@00000I@3Vc8000440i/b00P00000L0>K<P0030000003Vc800i/b00500i/b01000001Y0>K<
P000@`3Vc8000`000000i/b00>K<P00I0>K<P0030000003Vc800i/b004`0i/b01000001]0>K<P000
A03Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b004P0i/b01000001a0>K<P000A@3V
c802000001P0i/b000<000000>K<P03Vc800A03Vc804000007D0i/b000170>K<P0030000003Vc800
i/b001D0i/b000<000000>K<P03Vc800@03Vc804000007T0i/b000180>K<P08000005@3Vc8000`00
0000i/b00>K<P00l0>K<P0@00000O@3Vc80004X0i/b000<000000>K<P03Vc8004P3Vc8000`000000
i/b00>K<P00g0>K<P0D00000P@3Vc80004/0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b0
0>K<P00c0>K<P0@00000QP3Vc80004`0i/b00P00000A0>K<P0030000003Vc800i/b002l0i/b01000
002:0>K<P000CP3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b002`0i/b01000002>
0>K<P000C`3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b002P0i/b01000002B0>K<
P000D03Vc802000000`0i/b000<000000>K<P03Vc800903Vc804000009H0i/b0001B0>K<P0030000
003Vc800i/b000T0i/b000<000000>K<P03Vc800803Vc804000009X0i/b0001C0>K<P0030000003V
c800i/b000P0i/b000<000000>K<P03Vc800703Vc804000009h0i/b0001D0>K<P0800000203Vc800
0`000000i/b00>K<P00H0>K<P0@00000XP3Vc80005H0i/b000<000000>K<P03Vc8001@3Vc8000`00
0000i/b00>K<P00D0>K<P0@00000YP3Vc80005L0i/b000<000000>K<P03Vc800103Vc8000`000000
i/b00>K<P00@0>K<P0@00000ZP3Vc80005P0i/b00P0000040>K<P0030000003Vc800i/b000`0i/b0
1000002^0>K<P000FP3Vc8001@000000i/b00>K<P03Vc800000000X0i/b01000002b0>K<P000F`3V
c80010000000i/b00>K<P00000060>K<P0@00000]P3Vc80005`0i/b00`0000020>K<P0@00000^P3V
c80005h0i/b00`00002n0>K<P000o`3Vc80P0>K<P000o`3Vc80P0>K<P000o`3Vc80P0>K<P000o`3V
c80P0>K<P000Q@3Vc804000009H0i/b000260>K<P0030000003Vc800i/b009H0i/b0001e0>K<P0<0
00000P3Vc806000000080>K<P000000000000>K<P0000000i/b00000003Vc803000000<0i/b01P00
00020>K<P0H00000103Vc804000000<0i/b01P0000020>K<P0<0000000<0i/b00000000000000`3V
c804000006<0i/b0001f0>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc80000000P3V
c8001@000000i/b00>K<P0000000i/b0008000000`3Vc8000`000000i/b00>K<P0030>K<P0030000
003Vc800i/b000D0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0040>K<P0030000
003Vc800i/b00080i/b000@000000>K<P03Vc80000000`3Vc802000000<0i/b000<000000>K<P03V
c800I@3Vc80007H0i/b01P0000020>K<P0040000003Vc800i/b000000080i/b000<000000>K<P000
00001@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b00080i/b000@000000>K<P03V
c8000000103Vc80010000000i/b00>K<P000001X0>K<P000M`3Vc80010000000i/b00>K<P0000003
0>K<P0040000003Vc800i/b000000080i/b000<000000>K<P00000001@3Vc8000`000000i/b00>K<
P0020>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P0040>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc8000000103Vc8000`000000i/b0
0>K<P006000006<0i/b0001g0>K<P0040000003Vc800i/b0000000<0i/b000@000000>K<P03Vc800
00000P3Vc80010000000i/b00000000000030>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc8001@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000@0i/b000<000000>K<
P03Vc8000P3Vc80010000000i/b00>K<P00000030>K<P08000000P3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b00640i/b0001h0>K<P0030000003Vc80000000080i/b010000000103V
c80000000000003Vc802000000040>K<P00000000000000000H0i/b000<000000>K<P03Vc8000`3V
c803000000@0i/b01@0000020>K<P08000000`3Vc802000000<0i/b00`0000000`3Vc80000000>K<
P0020>K<P0@00000I03Vc80007P0i/b00P00000G0>K<P0030000003Vc800i/b000/0i/b000<00000
0>K<P03Vc8004@3Vc8000`000000i/b00>K<P01Y0>K<P000MP3Vc804000001D0i/b00`00000=0>K<
P0030000003Vc800i/b000l0i/b000<000000>K<P0000000J`3Vc80009P0i/b000<000000>K<P03V
c800Q03Vc80009P0i/b000<000000>K<P03Vc800Q03Vc8000?l0i/b0803Vc8000001\
\>"],
  ImageRangeCache->{{{0, 286.5}, {358.875, 0}} -> {0.0373689, -0.0450232, \
0.0037917, 0.0037917}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(plAmpl = 
        MultipleListPlot[colldata[\([All, 4, {2, 3}]\)], 
          colldata[\([All, 3, {2, 3}]\)], colldata[\([All, 2, {2, 3}]\)], 
          colldata[\([All, 1, {2, 3}]\)], 
          PlotStyle \[Rule] {GrayLevel[0.1], Hue[0.3], Hue[0.6], Hue[1]}, 
          SymbolStyle \[Rule] {GrayLevel[0.1], Hue[0.3], Hue[0.6], Hue[1]}, 
          PlotJoined \[Rule] True, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[plAmpl, 
        AxesLabel \[Rule] {\*"\"\<\[Omega]/\!\(\[Omega]\_0\)\>\"", \
\*"\"\<\!\(\[Omega]\_R\)/\!\(\[Omega]\_0\)\>\""}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.88095 2.38095 0.0147151 2.30605 [
[.02381 .00222 -9 -9 ]
[.02381 .00222 9 0 ]
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -9 -9 ]
[.97619 .00222 9 0 ]
[1.025 .01472 0 -4.90625 ]
[1.025 .01472 10 4.90625 ]
[.4875 .13002 -24 -4.5 ]
[.4875 .13002 0 4.5 ]
[.4875 .24532 -18 -4.5 ]
[.4875 .24532 0 4.5 ]
[.4875 .36062 -24 -4.5 ]
[.4875 .36062 0 4.5 ]
[.4875 .47592 -18 -4.5 ]
[.4875 .47592 0 4.5 ]
[.4875 .59123 -24 -4.5 ]
[.4875 .59123 0 4.5 ]
[.5 .64303 -7.78125 0 ]
[.5 .64303 7.78125 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(0.8)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(0.9)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1.1)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1.2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .13002 m
.50625 .13002 L
s
[(0.05)] .4875 .13002 1 0 Mshowa
.5 .24532 m
.50625 .24532 L
s
[(0.1)] .4875 .24532 1 0 Mshowa
.5 .36062 m
.50625 .36062 L
s
[(0.15)] .4875 .36062 1 0 Mshowa
.5 .47592 m
.50625 .47592 L
s
[(0.2)] .4875 .47592 1 0 Mshowa
.5 .59123 m
.50625 .59123 L
s
[(0.25)] .4875 .59123 1 0 Mshowa
.125 Mabswid
.5 .03778 m
.50375 .03778 L
s
.5 .06084 m
.50375 .06084 L
s
.5 .0839 m
.50375 .0839 L
s
.5 .10696 m
.50375 .10696 L
s
.5 .15308 m
.50375 .15308 L
s
.5 .17614 m
.50375 .17614 L
s
.5 .1992 m
.50375 .1992 L
s
.5 .22226 m
.50375 .22226 L
s
.5 .26838 m
.50375 .26838 L
s
.5 .29144 m
.50375 .29144 L
s
.5 .3145 m
.50375 .3145 L
s
.5 .33756 m
.50375 .33756 L
s
.5 .38368 m
.50375 .38368 L
s
.5 .40674 m
.50375 .40674 L
s
.5 .4298 m
.50375 .4298 L
s
.5 .45286 m
.50375 .45286 L
s
.5 .49898 m
.50375 .49898 L
s
.5 .52205 m
.50375 .52205 L
s
.5 .54511 m
.50375 .54511 L
s
.5 .56817 m
.50375 .56817 L
s
.5 .61429 m
.50375 .61429 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -68.7812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
74.562 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.1 g
.001 w
.02381 .60332 m
.2619 .43731 L
.38095 .3833 L
.47619 .36201 L
.5 .36038 L
.52381 .36029 L
.61905 .37505 L
.7381 .4236 L
.97619 .58083 L
s
.0001 w
.02381 .60332 -1.875 0 Mabsadd m
.02381 .60332 0 2.5 Mabsadd L
.02381 .60332 1.875 0 Mabsadd L
.02381 .60332 0 -2.5 Mabsadd L
.02381 .60332 -1.875 0 Mabsadd L closepath F
.2619 .43731 -1.875 0 Mabsadd m
.2619 .43731 0 2.5 Mabsadd L
.2619 .43731 1.875 0 Mabsadd L
.2619 .43731 0 -2.5 Mabsadd L
.2619 .43731 -1.875 0 Mabsadd L closepath F
.38095 .3833 -1.875 0 Mabsadd m
.38095 .3833 0 2.5 Mabsadd L
.38095 .3833 1.875 0 Mabsadd L
.38095 .3833 0 -2.5 Mabsadd L
.38095 .3833 -1.875 0 Mabsadd L closepath F
.47619 .36201 -1.875 0 Mabsadd m
.47619 .36201 0 2.5 Mabsadd L
.47619 .36201 1.875 0 Mabsadd L
.47619 .36201 0 -2.5 Mabsadd L
.47619 .36201 -1.875 0 Mabsadd L closepath F
.5 .36038 -1.875 0 Mabsadd m
.5 .36038 0 2.5 Mabsadd L
.5 .36038 1.875 0 Mabsadd L
.5 .36038 0 -2.5 Mabsadd L
.5 .36038 -1.875 0 Mabsadd L closepath F
.52381 .36029 -1.875 0 Mabsadd m
.52381 .36029 0 2.5 Mabsadd L
.52381 .36029 1.875 0 Mabsadd L
.52381 .36029 0 -2.5 Mabsadd L
.52381 .36029 -1.875 0 Mabsadd L closepath F
.61905 .37505 -1.875 0 Mabsadd m
.61905 .37505 0 2.5 Mabsadd L
.61905 .37505 1.875 0 Mabsadd L
.61905 .37505 0 -2.5 Mabsadd L
.61905 .37505 -1.875 0 Mabsadd L closepath F
.7381 .4236 -1.875 0 Mabsadd m
.7381 .4236 0 2.5 Mabsadd L
.7381 .4236 1.875 0 Mabsadd L
.7381 .4236 0 -2.5 Mabsadd L
.7381 .4236 -1.875 0 Mabsadd L closepath F
.97619 .58083 -1.875 0 Mabsadd m
.97619 .58083 0 2.5 Mabsadd L
.97619 .58083 1.875 0 Mabsadd L
.97619 .58083 0 -2.5 Mabsadd L
.97619 .58083 -1.875 0 Mabsadd L closepath F
.2 1 0 r
.001 w
.02381 .53579 m
.2619 .34502 L
.38095 .27502 L
.47619 .24697 L
.5 .24525 L
.52381 .24583 L
.61905 .26989 L
.7381 .33686 L
.97619 .52521 L
s
.0001 w
.02381 .53579 0 2.5 Mabsadd m
.02381 .53579 -0.56518 .7779 Mabsadd L
.02381 .53579 -2.37764 .77254 Mabsadd L
.02381 .53579 -0.91448 -0.29713 Mabsadd L
.02381 .53579 -1.46946 -2.02254 Mabsadd L
.02381 .53579 0 -0.96154 Mabsadd L
.02381 .53579 1.46946 -2.02254 Mabsadd L
.02381 .53579 .91448 -0.29713 Mabsadd L
.02381 .53579 2.37764 .77254 Mabsadd L
.02381 .53579 .56518 .7779 Mabsadd L
.02381 .53579 0 2.5 Mabsadd L closepath F
.2619 .34502 0 2.5 Mabsadd m
.2619 .34502 -0.56518 .7779 Mabsadd L
.2619 .34502 -2.37764 .77254 Mabsadd L
.2619 .34502 -0.91448 -0.29713 Mabsadd L
.2619 .34502 -1.46946 -2.02254 Mabsadd L
.2619 .34502 0 -0.96154 Mabsadd L
.2619 .34502 1.46946 -2.02254 Mabsadd L
.2619 .34502 .91448 -0.29713 Mabsadd L
.2619 .34502 2.37764 .77254 Mabsadd L
.2619 .34502 .56518 .7779 Mabsadd L
.2619 .34502 0 2.5 Mabsadd L closepath F
.38095 .27502 0 2.5 Mabsadd m
.38095 .27502 -0.56518 .7779 Mabsadd L
.38095 .27502 -2.37764 .77254 Mabsadd L
.38095 .27502 -0.91448 -0.29713 Mabsadd L
.38095 .27502 -1.46946 -2.02254 Mabsadd L
.38095 .27502 0 -0.96154 Mabsadd L
.38095 .27502 1.46946 -2.02254 Mabsadd L
.38095 .27502 .91448 -0.29713 Mabsadd L
.38095 .27502 2.37764 .77254 Mabsadd L
.38095 .27502 .56518 .7779 Mabsadd L
.38095 .27502 0 2.5 Mabsadd L closepath F
.47619 .24697 0 2.5 Mabsadd m
.47619 .24697 -0.56518 .7779 Mabsadd L
.47619 .24697 -2.37764 .77254 Mabsadd L
.47619 .24697 -0.91448 -0.29713 Mabsadd L
.47619 .24697 -1.46946 -2.02254 Mabsadd L
.47619 .24697 0 -0.96154 Mabsadd L
.47619 .24697 1.46946 -2.02254 Mabsadd L
.47619 .24697 .91448 -0.29713 Mabsadd L
.47619 .24697 2.37764 .77254 Mabsadd L
.47619 .24697 .56518 .7779 Mabsadd L
.47619 .24697 0 2.5 Mabsadd L closepath F
.5 .24525 0 2.5 Mabsadd m
.5 .24525 -0.56518 .7779 Mabsadd L
.5 .24525 -2.37764 .77254 Mabsadd L
.5 .24525 -0.91448 -0.29713 Mabsadd L
.5 .24525 -1.46946 -2.02254 Mabsadd L
.5 .24525 0 -0.96154 Mabsadd L
.5 .24525 1.46946 -2.02254 Mabsadd L
.5 .24525 .91448 -0.29713 Mabsadd L
.5 .24525 2.37764 .77254 Mabsadd L
.5 .24525 .56518 .7779 Mabsadd L
.5 .24525 0 2.5 Mabsadd L closepath F
.52381 .24583 0 2.5 Mabsadd m
.52381 .24583 -0.56518 .7779 Mabsadd L
.52381 .24583 -2.37764 .77254 Mabsadd L
.52381 .24583 -0.91448 -0.29713 Mabsadd L
.52381 .24583 -1.46946 -2.02254 Mabsadd L
.52381 .24583 0 -0.96154 Mabsadd L
.52381 .24583 1.46946 -2.02254 Mabsadd L
.52381 .24583 .91448 -0.29713 Mabsadd L
.52381 .24583 2.37764 .77254 Mabsadd L
.52381 .24583 .56518 .7779 Mabsadd L
.52381 .24583 0 2.5 Mabsadd L closepath F
.61905 .26989 0 2.5 Mabsadd m
.61905 .26989 -0.56518 .7779 Mabsadd L
.61905 .26989 -2.37764 .77254 Mabsadd L
.61905 .26989 -0.91448 -0.29713 Mabsadd L
.61905 .26989 -1.46946 -2.02254 Mabsadd L
.61905 .26989 0 -0.96154 Mabsadd L
.61905 .26989 1.46946 -2.02254 Mabsadd L
.61905 .26989 .91448 -0.29713 Mabsadd L
.61905 .26989 2.37764 .77254 Mabsadd L
.61905 .26989 .56518 .7779 Mabsadd L
.61905 .26989 0 2.5 Mabsadd L closepath F
.7381 .33686 0 2.5 Mabsadd m
.7381 .33686 -0.56518 .7779 Mabsadd L
.7381 .33686 -2.37764 .77254 Mabsadd L
.7381 .33686 -0.91448 -0.29713 Mabsadd L
.7381 .33686 -1.46946 -2.02254 Mabsadd L
.7381 .33686 0 -0.96154 Mabsadd L
.7381 .33686 1.46946 -2.02254 Mabsadd L
.7381 .33686 .91448 -0.29713 Mabsadd L
.7381 .33686 2.37764 .77254 Mabsadd L
.7381 .33686 .56518 .7779 Mabsadd L
.7381 .33686 0 2.5 Mabsadd L closepath F
.97619 .52521 0 2.5 Mabsadd m
.97619 .52521 -0.56518 .7779 Mabsadd L
.97619 .52521 -2.37764 .77254 Mabsadd L
.97619 .52521 -0.91448 -0.29713 Mabsadd L
.97619 .52521 -1.46946 -2.02254 Mabsadd L
.97619 .52521 0 -0.96154 Mabsadd L
.97619 .52521 1.46946 -2.02254 Mabsadd L
.97619 .52521 .91448 -0.29713 Mabsadd L
.97619 .52521 2.37764 .77254 Mabsadd L
.97619 .52521 .56518 .7779 Mabsadd L
.97619 .52521 0 2.5 Mabsadd L closepath F
0 .4 1 r
.001 w
.02381 .49163 m
.2619 .27386 L
.38095 .17881 L
.47619 .13258 L
.5 .13001 L
.52381 .13201 L
.61905 .17677 L
.7381 .27124 L
.97619 .48879 L
s
.0001 w
.02381 .49163 -2.5 2.5 Mabsadd m
.02381 .49163 2.5 2.5 Mabsadd L
.02381 .49163 2.5 -2.5 Mabsadd L
.02381 .49163 -2.5 -2.5 Mabsadd L
.02381 .49163 -2.5 2.5 Mabsadd L closepath F
.2619 .27386 -2.5 2.5 Mabsadd m
.2619 .27386 2.5 2.5 Mabsadd L
.2619 .27386 2.5 -2.5 Mabsadd L
.2619 .27386 -2.5 -2.5 Mabsadd L
.2619 .27386 -2.5 2.5 Mabsadd L closepath F
.38095 .17881 -2.5 2.5 Mabsadd m
.38095 .17881 2.5 2.5 Mabsadd L
.38095 .17881 2.5 -2.5 Mabsadd L
.38095 .17881 -2.5 -2.5 Mabsadd L
.38095 .17881 -2.5 2.5 Mabsadd L closepath F
.47619 .13258 -2.5 2.5 Mabsadd m
.47619 .13258 2.5 2.5 Mabsadd L
.47619 .13258 2.5 -2.5 Mabsadd L
.47619 .13258 -2.5 -2.5 Mabsadd L
.47619 .13258 -2.5 2.5 Mabsadd L closepath F
.5 .13001 -2.5 2.5 Mabsadd m
.5 .13001 2.5 2.5 Mabsadd L
.5 .13001 2.5 -2.5 Mabsadd L
.5 .13001 -2.5 -2.5 Mabsadd L
.5 .13001 -2.5 2.5 Mabsadd L closepath F
.52381 .13201 -2.5 2.5 Mabsadd m
.52381 .13201 2.5 2.5 Mabsadd L
.52381 .13201 2.5 -2.5 Mabsadd L
.52381 .13201 -2.5 -2.5 Mabsadd L
.52381 .13201 -2.5 2.5 Mabsadd L closepath F
.61905 .17677 -2.5 2.5 Mabsadd m
.61905 .17677 2.5 2.5 Mabsadd L
.61905 .17677 2.5 -2.5 Mabsadd L
.61905 .17677 -2.5 -2.5 Mabsadd L
.61905 .17677 -2.5 2.5 Mabsadd L closepath F
.7381 .27124 -2.5 2.5 Mabsadd m
.7381 .27124 2.5 2.5 Mabsadd L
.7381 .27124 2.5 -2.5 Mabsadd L
.7381 .27124 -2.5 -2.5 Mabsadd L
.7381 .27124 -2.5 2.5 Mabsadd L closepath F
.97619 .48879 -2.5 2.5 Mabsadd m
.97619 .48879 2.5 2.5 Mabsadd L
.97619 .48879 2.5 -2.5 Mabsadd L
.97619 .48879 -2.5 -2.5 Mabsadd L
.97619 .48879 -2.5 2.5 Mabsadd L closepath F
1 0 0 r
.001 w
.02381 .47991 m
.2619 .25278 L
.38095 .14395 L
.47619 .07694 L
.5 .07236 L
.52381 .07667 L
.61905 .1433 L
.7381 .25207 L
.97619 .47918 L
s
.0001 w
.02381 .47991 0 2.5 Mabsadd m
.02381 .47991 -2.165 -1.25 Mabsadd L
.02381 .47991 2.165 -1.25 Mabsadd L
.02381 .47991 0 2.5 Mabsadd L closepath F
.2619 .25278 0 2.5 Mabsadd m
.2619 .25278 -2.165 -1.25 Mabsadd L
.2619 .25278 2.165 -1.25 Mabsadd L
.2619 .25278 0 2.5 Mabsadd L closepath F
.38095 .14395 0 2.5 Mabsadd m
.38095 .14395 -2.165 -1.25 Mabsadd L
.38095 .14395 2.165 -1.25 Mabsadd L
.38095 .14395 0 2.5 Mabsadd L closepath F
.47619 .07694 0 2.5 Mabsadd m
.47619 .07694 -2.165 -1.25 Mabsadd L
.47619 .07694 2.165 -1.25 Mabsadd L
.47619 .07694 0 2.5 Mabsadd L closepath F
.5 .07236 0 2.5 Mabsadd m
.5 .07236 -2.165 -1.25 Mabsadd L
.5 .07236 2.165 -1.25 Mabsadd L
.5 .07236 0 2.5 Mabsadd L closepath F
.52381 .07667 0 2.5 Mabsadd m
.52381 .07667 -2.165 -1.25 Mabsadd L
.52381 .07667 2.165 -1.25 Mabsadd L
.52381 .07667 0 2.5 Mabsadd L closepath F
.61905 .1433 0 2.5 Mabsadd m
.61905 .1433 -2.165 -1.25 Mabsadd L
.61905 .1433 2.165 -1.25 Mabsadd L
.61905 .1433 0 2.5 Mabsadd L closepath F
.7381 .25207 0 2.5 Mabsadd m
.7381 .25207 -2.165 -1.25 Mabsadd L
.7381 .25207 2.165 -1.25 Mabsadd L
.7381 .25207 0 2.5 Mabsadd L closepath F
.97619 .47918 0 2.5 Mabsadd m
.97619 .47918 -2.165 -1.25 Mabsadd L
.97619 .47918 2.165 -1.25 Mabsadd L
.97619 .47918 0 2.5 Mabsadd L closepath F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3Vc81Y
0>K<P0003`3Vc803000000D0i/b00P0000050>K<P0@00000=P3Vc803000000D0i/b00P0000040>K<
P0<00000P03Vc806000000@0i/b00P0000040>K<P0H00000=03Vc806000000@0i/b00P0000040>K<
P0H000007`3Vc80000h0i/b000@000000>K<P03Vc80000001@3Vc802000000@0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P00b0>K<P0040000003Vc800i/b0000000D0i/b00P000007
0>K<P0030000003Vc800i/b00800i/b000<000000>K<P03Vc800103Vc802000000L0i/b000<00000
0>K<P03Vc800=`3Vc8000`000000i/b00>K<P0040>K<P08000001@3Vc8001@000000i/b00>K<P03V
c800000001l0i/b0000=0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800203Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b00340i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P00<0>K<P0030000003Vc800i/b007l0i/b000<000000>K<P03Vc8003@3Vc800
0`000000i/b00>K<P00g0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc800803Vc800
00d0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b0
00800000<`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000T0i/b0100000210>K<
P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800=`3Vc8000`000000i/b00>K<P00=0>K<
P0800000803Vc80000d0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0090>K<P0@0
0000=03Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000P0i/b000D000000>K<P03V
c800i/b0000000210>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800=`3Vc8000`00
0000i/b00>K<P00>0>K<P08000007`3Vc80000d0i/b000<000000>K<P03Vc8000P3Vc8000`000000
i/b00>K<P0080>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800<@3Vc8000`000000
i/b00>K<P0020>K<P0030000003Vc800i/b000P0i/b000D000000>K<P03Vc800i/b0000000210>K<
P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800=`3Vc8000`000000i/b00>K<P00?0>K<
P0030000003Vc800i/b001d0i/b0000>0>K<P0040000003Vc800i/b0000000/0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P00b0>K<P0040000003Vc800i/b0000000/0i/b000D00000
0>K<P03Vc800i/b0000000210>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800=`3V
c8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8007@3V
c80000h0i/b01000000<0>K<P0@00000=@3Vc804000000`0i/b00`0000200>K<P0<000003@3Vc803
000003L0i/b00`00000<0>K<P0D00000803Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000:/0i/b0
00<000000>K<P03Vc800^P3Vc8000:/0i/b000<000000>K<P03Vc800^P3Vc8000:/0i/b000<00000
0>K<P03Vc800XP3Vc805000001<0i/b0002[0>K<P0030000003Vc800i/b00:40i/b000@000000>K<
P03Vc80000000P3Vc8000`000000i/b00>K<P00@0>K<P000403Vc83o000003L000002@3Vc8001000
0000i/b00>K<P00000020>K<P0030000003Vc800i/b00100i/b0000H0>K<P0030000003Vc800i/b0
00`0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b0
00`0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b0
00`0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b0
00`0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b0
00`0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b0
00`0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b0
00`0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00>0>K<P0040000003Vc800i/b0
00000080i/b000<000000>K<P03Vc800403Vc80001P0i/b000<000000>K<P03Vc800AP3Vc8000`00
0000i/b00>K<P0170>K<P0030000003Vc800i/b004H0i/b000<000000>K<P03Vc800A`3Vc8000`00
0000i/b00>K<P00?0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800403Vc8000:/0
i/b000<000000>K<P03Vc800X`3Vc8001@000000i/b00>K<P03Vc80000000180i/b0002[0>K<P003
0000003Vc800i/b00;X0i/b0002[0>K<P0030000003Vc800i/b00;X0i/b0002[0>K<P0030000003V
c800i/b00;X0i/b0002[0>K<P0800000^`3Vc8000:/0i/b000<000000>K<P03Vc800^P3Vc8000:/0
i/b000<000000>K<P03Vc800^P3Vc8000:/0i/b000<000000>K<P03Vc800^P3Vc8000:/0i/b000<0
00000>K<P03Vc800^P3Vc8000:/0i/b000<000000>K<P03Vc800^P3Vc8000:/0i/b000<000000>K<
P03Vc800^P3Vc8000:/0i/b00P00002k0>K<P000Z`3Vc8000`000000i/b00>K<P02j0>K<P000Z`3V
c8000`000000i/b00>K<P02j0>K<P000Z@3Vc8050?l00;X0i/b0002W0>K<P0P0o`00^@3Vc8000:80
i/b01@3o00030>K<P0<0o`000P3Vc8060?l00;<0i/b0002Q0>K<P0@0o`001P3Vc8000`3o0000i/b0
0>K<P0030>K<P0@0o`00/`3Vc8000:00i/b000<0o`000>K<P03Vc8000P3o00060>K<P0030000003V
c800i/b000@0i/b000@0o`000>K<P03Vc800o`00/P3Vc80009l0i/b000D0o`000>K<P03Vc800i/b0
0?l000070>K<P08000002@3Vc8000`3o0000i/b00>K<P02_0>K<P000W@3Vc8020?l000`0i/b000<0
00000>K<P03Vc8002@3Vc8020?l00:l0i/b0002L0>K<P0030?l0003Vc800i/b000`0i/b000<00000
0>K<P03Vc8002`3Vc8000`3o0000i/b00>K<P02/0>K<P000V`3Vc8000`3o0000i/b00>K<P00=0>K<
P0030000003Vc800i/b000`0i/b00P3o002/0>K<P000V@3Vc8020?l00100i/b000<000000>K<P03V
c8003P3Vc8000`3o0000i/b00>K<P02Y0>K<P000V03Vc8000`3o0000i/b00>K<P00@0>K<P0030000
003Vc800i/b000l0i/b00P3o002Y0>K<P000UP3Vc8020?l001<0i/b000<000000>K<P03Vc8004@3V
c8000`3o0000i/b00>K<P02V0>K<P000U@3Vc8000`3o0000i/b00>K<P00C0>K<P08000004`3Vc800
0`3o0000i/b00>K<P02U0>K<P000U03Vc8000`3o0000i/b00>K<P00D0>K<P0030000003Vc800i/b0
01<0i/b00P3o002U0>K<P000TP3Vc8020?l001L0i/b000<000000>K<P03Vc8005@3Vc8000`3o0000
i/b00>K<P02R0>K<P000T@3Vc8000`3o0000i/b00>K<P00G0>K<P0030000003Vc800i/b001H0i/b0
0P3o002R0>K<P000RP3Vc80300000080i/b00P3o00000`3Vc8000000000000060>K<P0<00000103V
c804000000H0i/b000<000000>K<P03Vc800603Vc8000`3o0000i/b00>K<P02O0>K<P000R@3Vc800
1P000000i/b00>K<P0000000i/b00?l000<0i/b00P0000050>K<P0040000003Vc800i/b0000000<0
i/b01`00I_l00`3Vc80006Ko001Vo`04001Vo`030>K<P000I_l006Ko00@006Ko4P3Vc8020?l009l0
i/b000280>K<P0030000003Vc800i/b00080i/b000<0o`000>K<P03Vc800203Vc8000`000000i/b0
0>K<P0020>K<P0030000003Vc800i/b000L006Ko00<0i/b0001Vo`00I_l01000I_l00`3Vc80006Ko
001Vo`04001Voa@0i/b000<0o`000>K<P03Vc800W03Vc80008P0i/b000<000000>K<P03Vc8000P3o
00000`000000i/b00>K<P0080>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8005@00
I_lE0>K<P0030?l0003Vc800i/b009/0i/b000280>K<P0030000003Vc800o`000080i/b000<00000
0>K<P03Vc800203Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000L006Ko00<0i/b0
001Vo`00I_l01000I_l00`3Vc80006Ko001Vo`05001VoaD0i/b00P3o002K0>K<P000R03Vc8000`00
0000o`000>K<P0020>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P007001Vo`030>K<P000I_l006Ko00@006Ko00<0i/b0001Vo`00I_l01000I_l00`3V
c80006Ko001Vo`0E0>K<P0030?l0003Vc800i/b009P0i/b000270>K<P080o`0000@000000>K<P03V
c8000000303Vc8001@000000i/b00>K<P0000000i/b000T006Ko00<0i/b0001Vo`00I_l01000I_l0
0`3Vc80006Ko001Vo`04001Vo`<0i/b00P00I_lD0>K<P0@0o`00UP3Vc80008@0i/b01@3o00040000
00`0i/b00`000002001Vo`80i/b01`00I_l40>K<P0040000003Vc800i/b00>K<P0H006Ko1@3Vc802
001Voa<0i/b00`3o002F0>K<P000Q@3Vc8030?l00180i/b00P00I_l?0>K<P0030000003Vc800i/b0
00h0i/b00P00I_lA0>K<P0<0o`00UP3Vc80008@0i/b000<0o`000>K<P03o00004@3Vc802001Voa40
i/b000<000000>K<P03Vc800403Vc802001Voa00i/b000<0o`000>K<P03o0000U@3Vc80008<0i/b0
00<0o`000>K<P03Vc800403Vc802001Voa<0i/b00P00000C0>K<P0<006Ko403Vc8000`3o0000i/b0
0>K<P02B0>K<P000PP3Vc8000`3o0000i/b00>K<P00?0>K<P08006Ko5@3Vc8000`000000i/b00>K<
P00E0>K<P08006Ko3`3Vc8000`3o0000i/b00>K<P02A0>K<P000P@3Vc8000`3o0000i/b00>K<P00>
0>K<P08006Ko5`3Vc8000`000000i/b00>K<P00G0>K<P08006Ko3P3Vc8000`3o0000i/b00>K<P02@
0>K<P000O`3Vc8020?l000l0i/b00P00I_lI0>K<P0030000003Vc800i/b001T0i/b00P00I_l=0>K<
P0030?l0003Vc800i/b008l0i/b0001n0>K<P0030?l0003Vc800i/b000d0i/b00P00I_lK0>K<P003
0000003Vc800i/b001/0i/b00P00I_l<0>K<P0030?l0003Vc800i/b008h0i/b0001m0>K<P0030?l0
003Vc800i/b000`0i/b00P00I_lM0>K<P0030000003Vc800i/b001d0i/b02000I_l50>K<P0030?l0
003Vc800i/b008d0i/b0001l0>K<P0030?l0003Vc800i/b000@0i/b01P00I_l00`3Vc80006Ko001V
o`0O0>K<P0030000003Vc800i/b001h0i/b01`00I_l60>K<P080o`00S@3Vc80007/0i/b000<0o`00
0>K<P03Vc8001@3Vc807001Vob40i/b00P00000O0>K<P0L006Ko203Vc8000`3o0000i/b00>K<P02:
0>K<P000NP3Vc8000`3o0000i/b00>K<P0060>K<P0H006Ko8P3Vc8000`000000i/b00>K<P00N0>K<
P0L006Ko2@3Vc8000`3o0000i/b00>K<P0290>K<P000N@3Vc8000`3o0000i/b00>K<P0070>K<P0H0
06Ko8P3Vc8000`000000i/b00>K<P00N0>K<P0P006Ko2@3Vc8000`3o0000i/b00>K<P0280>K<P000
N03Vc8000`3o0000i/b00>K<P0080>K<P0H006Ko8P3Vc8000`000000i/b00>K<P00N0>K<P0L006Ko
00<0i/b0001Vo`3Vc800203Vc8000`3o0000i/b00>K<P0270>K<P000M`3Vc8000`3o0000i/b00>K<
P0080>K<P0L006Ko8P3Vc8000`000000i/b00>K<P00W0>K<P003001Vo`3Vc800i/b000L0i/b000<0
o`000>K<P03Vc800QP3Vc80007H0i/b000<0o`000>K<P03Vc800203Vc8000`00I_l0i/b00>K<P00W
0>K<P0030000003Vc800i/b002P0i/b000<006Ko0>K<P03Vc8001`3Vc8000`3o0000i/b00>K<P025
0>K<P000M@3Vc8000`3o0000i/b00>K<P0070>K<P08006Ko:P3Vc8000`000000i/b00>K<P00Y0>K<
P08006Ko203Vc8000`3o0000i/b00>K<P0240>K<P000L`3Vc8020?l000T0i/b000<006Ko0>K<P03V
c800:P3Vc802000002`0i/b000<006Ko0>K<P03Vc8001P3Vc8000`3o0000i/b00>K<P0230>K<P000
LP3Vc8000`3o0000i/b00>K<P0080>K<P003001Vo`3Vc800i/b002/0i/b000<000000>K<P03Vc800
;03Vc8000`00I_l0i/b00>K<P0060>K<P0030?l0003Vc800i/b00880i/b0001a0>K<P0030?l0003V
c800i/b000P0i/b000<006Ko0>K<P03Vc800;03Vc8000`000000i/b00>K<P00]0>K<P003001Vo`3V
c800i/b000H0i/b000<0o`000>K<P03Vc800P@3Vc8000700i/b000<0o`000>K<P03Vc8001`3Vc802
001Vobl0i/b000<000000>K<P03Vc800;P3Vc802001Vo`L0i/b000<0o`000>K<P03Vc800P03Vc800
06l0i/b000<0o`000>K<P03Vc8001`3Vc8000`00I_l0i/b00>K<P00_0>K<P0030000003Vc800i/b0
0300i/b000<006Ko0>K<P03Vc8001@3Vc8000`3o0000i/b00>K<P01o0>K<P000KP3Vc8000`3o0000
i/b00>K<P0070>K<P003001Vo`3Vc800i/b00300i/b000<000000>K<P03Vc800<@3Vc8000`00I_l0
i/b00>K<P0050>K<P0030?l0003Vc800i/b007h0i/b0001]0>K<P0030?l0003Vc800i/b000L0i/b0
00<006Ko0>K<P03Vc800<@3Vc8000`000000i/b00>K<P00b0>K<P003001Vo`3Vc800i/b000D0i/b0
00<0o`000>K<P03Vc800O@3Vc80006`0i/b000<0o`000>K<P03Vc8001P3Vc802001Voc@0i/b00P00
000d0>K<P003001Vo`3Vc800i/b000D0i/b000<0o`000>K<P03Vc800O03Vc80006/0i/b000<0o`00
0>K<P03Vc8001P3Vc8000`00I_l0i/b00>K<P00d0>K<P0030000003Vc800i/b003@0i/b00P00I_l6
0>K<P0030?l0003Vc800i/b007/0i/b0001Z0>K<P0030?l0003Vc800i/b000H0i/b000<006Ko0>K<
P03Vc800=@3Vc8000`000000i/b00>K<P00f0>K<P003001Vo`3Vc800i/b000@0i/b00P3o001k0>K<
P000J@3Vc8000`3o0000i/b00>K<P0050>K<P08006Ko>03Vc8000`000000i/b00>K<P00g0>K<P003
001Vo`3Vc800i/b000D0i/b000<0o`000>K<P03Vc800N03Vc80006L0i/b00P3o00070>K<P003001V
o`3Vc800i/b003P0i/b000<000000>K<P03Vc800>03Vc8000`00I_l0i/b00>K<P0050>K<P0030?l0
003Vc800i/b007L0i/b0001V0>K<P0030?l0003Vc800i/b000H0i/b000<006Ko0>K<P03Vc800803V
c803000000D0i/b00P0000040>K<P0H000001@3Vc8000`000000i/b00>K<P00i0>K<P08006Ko1P3V
c8000`3o0000i/b00>K<P01f0>K<P000I@3Vc8000`3o0000i/b00>K<P0060>K<P003001Vo`3Vc800
i/b00200i/b000@000000>K<P03Vc80000001@3Vc802000000H0i/b000<0<ol00000000co`001@3V
c80303?o00@0i/b00`0co`0e0>K<P003001Vo`3Vc800i/b000@0i/b000<0o`000>K<P03Vc800M@3V
c80006@0i/b000<0o`000>K<P03Vc8001@3Vc802001Vob80i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P00:0>K<P0<0<ol00P3Vc80803?o0080i/b00P0co`0g0>K<P003001Vo`3Vc800
i/b000@0i/b000<0o`000>K<P03Vc800M03Vc80006<0i/b000<0o`000>K<P03Vc8001@3Vc8000`00
I_l0i/b00>K<P00R0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002P3Vc80503?o
00030>K<P00co`00<ol000@0<ol000<0i/b003?o000co`00100co`0f0>K<P003001Vo`3Vc800i/b0
00@0i/b000<0o`000>K<P03Vc800L`3Vc8000600i/b0103o00060>K<P003001Vo`3Vc800i/b002<0
i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0070>K<P0L0<ol01@3Vc800100co`00
i/b00>K<P03Vc80:03?o03<0i/b00P00I_l50>K<P0@0o`00L@3Vc8000600i/b00`3o00060>K<P003
001Vo`3Vc800i/b002@0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<P0@0
<ol0103Vc8000`0co`00i/b00>K<P0050>K<P00303?o003Vc800i/b000@0i/b000<0<ol00>K<P03V
c800103Vc80403?o0340i/b000<006Ko0>K<P03Vc8000P3Vc8030?l00780i/b0001P0>K<P0<0o`00
103Vc802001VobP0i/b000@000000>K<P03Vc80000000`3Vc80303?o00P0i/b000<000000>K<P03V
c8001@3Vc8000`000000i/b00>K<P00?0>K<P0@0<ol0;P3Vc8000`00I_l0i/b00>K<P0020>K<P080
o`00LP3Vc80005l0i/b000<0o`000>K<P03o0000103Vc8000`00I_l0i/b00>K<P00X0>K<P0@00000
0`0co`090>K<P0<000001`3Vc8000`000000i/b00>K<P00C0>K<P0D0<ol0:P3Vc8001`00I_l0i/b0
0>K<P03Vc800o`000>K<P03o0000L@3Vc80005h0i/b000<0o`000>K<P03Vc800103Vc8000`00I_l0
i/b00>K<P00Z0>K<P0<0<ol05P3Vc8000`000000i/b00>K<P00H0>K<P0@0<ol0103Vc8000`0co`00
i/b00>K<P00P0>K<P0H006Ko00<0o`000>K<P03Vc800KP3Vc80005d0i/b000<0o`00001Vo`00I_l0
1@00I_lZ0>K<P0<0<ol06@3Vc8000`000000i/b00>K<P00L0>K<P0L0<ol0803Vc806001Vo`030>K<
P03o0000i/b006h0i/b0001L0>K<P0030?l0003Vc80006Ko00D006Ko8@3Vc80303?o00<0i/b0100c
o`0L0>K<P08000008@3Vc80303?o0200i/b01P00I_l20>K<P0030?l0003Vc800i/b006`0i/b0001K
0>K<P0030?l0003Vc800i/b000H006Ko8@3Vc80203?o00040>K<P00co`00<ol003?o0200i/b000<0
00000>K<P03Vc8007`3Vc80603?o01h0i/b01P00I_l30>K<P0030?l0003Vc800i/b006/0i/b0001J
0>K<P0040?l0003Vc800i/b00>K<P0H006Ko803Vc80403?o02<0i/b000<000000>K<P03Vc8009@3V
c80203?o01`0i/b01P00I_l40>K<P0030?l0003Vc800i/b006X0i/b0001I0>K<P0030?l0003Vc800
i/b00080i/b01P00I_lO0>K<P0H0<ol08P3Vc8000`000000i/b00>K<P00W0>K<P00303?o003Vc800
i/b001T0i/b01`00I_l40>K<P0030?l0003Vc800i/b006T0i/b0001H0>K<P0030?l0003Vc800i/b0
00<0i/b01P00I_lN0>K<P080<ol00P3Vc8000`0co`00i/b00>K<P00R0>K<P0030000003Vc800i/b0
02P0i/b00P0co`0I0>K<P0H006Ko00<0i/b0001Vo`3Vc8000`3Vc8020?l006T0i/b0001G0>K<P003
0?l0003Vc800i/b000<0i/b000<006Ko0>K<P03Vc800803Vc80203?o02T0i/b000<000000>K<P03V
c800:P3Vc80203?o01l0i/b000<006Ko0>K<P03Vc8000`3Vc8000`3o0000i/b00>K<P01V0>K<P000
EP3Vc8000`3o0000i/b00>K<P0030>K<P003001Vo`3Vc800i/b00200i/b000<0<ol00>K<P03Vc800
:@3Vc8000`000000i/b00>K<P00/0>K<P080<ol07P3Vc802001Vo`@0i/b000<0o`000>K<P03Vc800
I@3Vc80005@0i/b00P3o00040>K<P08006Ko8@3Vc80203?o02`0i/b00P00000_0>K<P00303?o003V
c800i/b001d0i/b000<006Ko0>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P01T0>K<P000D`3Vc800
0`3o0000i/b00>K<P0030>K<P003001Vo`3Vc800i/b001l0i/b00P0co`0^0>K<P0030000003Vc800
i/b002l0i/b00P0co`0N0>K<P003001Vo`3Vc800i/b00080i/b000<0o`000>K<P03Vc800H`3Vc800
0580i/b000<0o`000>K<P03Vc8000`3Vc8000`00I_l0i/b00>K<P00N0>K<P080<ol0<03Vc8000`00
0000i/b00>K<P00a0>K<P080<ol07@3Vc8000`00I_l0i/b00>K<P0020>K<P0030?l0003Vc800i/b0
0680i/b0001A0>K<P0030?l0003Vc800i/b000<0i/b000<006Ko0>K<P03Vc8007P3Vc8000`0co`00
i/b00>K<P00`0>K<P0030000003Vc800i/b003<0i/b000<0<ol00>K<P03Vc8006`3Vc8000`00I_l0
i/b00>K<P0020>K<P0030?l0003Vc800i/b00640i/b0001@0>K<P0030?l0003Vc800i/b000<0i/b0
00<006Ko0>K<P03Vc8007@3Vc80203?o03<0i/b000<000000>K<P03Vc800=03Vc80203?o01`0i/b0
00<006Ko0>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P01P0>K<P000C`3Vc8000`3o0000i/b00>K<
P0030>K<P003001Vo`3Vc800i/b001`0i/b00P0co`0e0>K<P0030000003Vc800i/b003H0i/b00P0c
o`0K0>K<P003001Vo`3Vc800i/b00080i/b000<0o`000>K<P03Vc800G`3Vc80004h0i/b000<0o`00
0>K<P03Vc8000`3Vc8000`00I_l0i/b00>K<P00K0>K<P080<ol0=`3Vc8000`000000i/b00>K<P00h
0>K<P080<ol06P3Vc8000`00I_l0i/b00>K<P0020>K<P0030?l0003Vc800i/b005h0i/b0001=0>K<
P0030?l0003Vc800i/b000<0i/b000<006Ko0>K<P03Vc8006P3Vc80203?o03T0i/b00P00000k0>K<
P00303?o003Vc800i/b001P0i/b000<006Ko0>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P01M0>K<
P000C03Vc8000`3o0000i/b00>K<P0030>K<P003001Vo`3Vc800i/b001X0i/b000<0<ol00>K<P03V
c800>@3Vc8000`000000i/b00>K<P00k0>K<P080<ol06@3Vc8000`00I_l0i/b00>K<P0020>K<P003
0?l0003Vc800i/b005`0i/b0001;0>K<P0030?l0003Vc800i/b000<0i/b000<006Ko0>K<P03Vc800
6@3Vc80203?o03`0i/b000<000000>K<P03Vc800?@3Vc80203?o01P0i/b000<006Ko0>K<P03Vc800
0P3Vc8000`3o0000i/b00>K<P01K0>K<P000BP3Vc8000`3o0000i/b00>K<P0030>K<P003001Vo`3V
c800i/b001P0i/b00P0co`0n0>K<P0030000003Vc800i/b003l0i/b000<0<ol00>K<P03Vc8005P3V
c802001Vo`<0i/b000<0o`000>K<P03Vc800FP3Vc80004T0i/b000<0o`000>K<P03Vc8000P3Vc802
001VoaT0i/b00P0co`100>K<P0030000003Vc800i/b00400i/b00P0co`0H0>K<P005001Vo`3Vc800
i/b00>K<P03o0000F`3Vc80004P0i/b000<0o`000>K<P03Vc8000P3Vc8000`00I_l0i/b00>K<P00H
0>K<P00303?o003Vc800i/b00400i/b000<000000>K<P03Vc800@P3Vc80203?o00040>K<P00co`00
<ol003?o01<0i/b000D006Ko0>K<P03Vc800i/b00?l0001J0>K<P000A`3Vc8000`3o0000i/b00>K<
P0020>K<P003001Vo`3Vc800i/b001L0i/b00P0co`130>K<P0030000003Vc800i/b004@0i/b0100c
o`0D0>K<P005001Vo`3Vc800i/b00>K<P03o0000F@3Vc80004H0i/b000<0o`000>K<P03Vc8000P3V
c8000`00I_l0i/b00>K<P00F0>K<P080<ol0A@3Vc802000004D0i/b01@0co`0D0>K<P004001Vo`3V
c800i/b00>K<P080o`00E`3Vc80004D0i/b000<0o`000>K<P03Vc8000P3Vc8000`00I_l0i/b00>K<
P00C0>K<P0@0<ol0A`3Vc8000`000000i/b00>K<P0130>K<P0H0<ol05@3Vc8000`00I_l0i/b00>K<
P0020>K<P0030?l0003Vc800i/b005@0i/b000140>K<P0030?l0003Vc800i/b00080i/b000<006Ko
0>K<P03Vc800503Vc80203?o04T0i/b000<000000>K<P03Vc800AP3Vc800100co`00i/b003?o000c
o`0E0>K<P003001Vo`3Vc800i/b00080i/b000<0o`000>K<P03Vc800D`3Vc80004<0i/b000<0o`00
0>K<P03Vc8000P3Vc8000`00I_l0i/b00>K<P00C0>K<P0H0<ol0A`3Vc8000`000000i/b00>K<P01:
0>K<P00303?o003Vc800i/b001<0i/b000<006Ko0>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P01B
0>K<P000@P3Vc8000`3o0000i/b00>K<P0020>K<P003001Vo`3Vc800i/b001@0i/b00P0co`000`3V
c800<ol00>K<P0180>K<P0030000003Vc800i/b004/0i/b000<0<ol00>K<P03Vc8004`3Vc8000`00
I_l0i/b00>K<P0020>K<P0030?l0003Vc800i/b00540i/b000110>K<P0030?l0003Vc800i/b00080
i/b000<006Ko0>K<P03Vc800503Vc8000`0co`00i/b00>K<P00Z0>K<P0<000001@3Vc802000000@0
i/b01P0000030>K<P080000000<06ATI0000003Vc800103Vc80201TI6@H0i/b000<06ATI0>K<P03V
c800A@3Vc80203?o01@0i/b000<006Ko0>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P01@0>K<P000
@03Vc8000`3o0000i/b00>K<P0020>K<P003001Vo`3Vc800i/b001@0i/b000<0<ol00>K<P03Vc800
:P3Vc80010000000i/b00>K<P00000050>K<P08000001`3Vc8000`000000i/b00>K<P0040>K<P0<0
6ATI00@000000>K<P03Vc800i/b0100I6AT40>K<P0<06ATIB03Vc8000`0co`00i/b00>K<P00B0>K<
P003001Vo`3Vc800i/b00080i/b000<0o`000>K<P03Vc800C`3Vc80003l0i/b000<0o`000>K<P03V
c8000P3Vc8000`00I_l0i/b00>K<P00D0>K<P00303?o003Vc800i/b002X0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b000<0i/b05@0I6AU70>K<P003
03?o003Vc800i/b00180i/b00P00I_l30>K<P0030?l0003Vc800i/b004h0i/b0000n0>K<P0040?l0
003Vc800i/b00>K<P08006Ko5@3Vc80203?o02d0i/b000<000000>K<P03Vc8000P3Vc8000`000000
i/b00>K<P00;0>K<P0030000003Vc8006ATI00<06ATI00<0i/b001TI6@0I6AT00P0I6AT30>K<P0@0
6ATI103Vc80301TI6@80i/b0200I6AU00>K<P00303?o003Vc800i/b001<0i/b000D006Ko0>K<P03V
c800i/b00?l0001?0>K<P000?03Vc8020?l000<0i/b000<006Ko0>K<P03Vc800503Vc8000`0co`00
i/b00>K<P00]0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002@3Vc80401TI6@@0
i/b000@0000001TI6@0I6AT06ATI1@3Vc80201TI6@H0i/b000<06ATI0>K<P03Vc8002@3Vc80701TI
6@X0i/b00P0I6AT^0>K<P080<ol0503Vc8001@00I_l0i/b00>K<P03Vc800o`0004h0i/b0000k0>K<
P0030?l0003Vc800i/b00080i/b000<006Ko0>K<P03Vc800503Vc8000`0co`00i/b00>K<P00^0>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8001@3Vc80401TI6@80i/b000<000000>K<
P03Vc8000`3Vc8000`000000i/b001TI6@070>K<P0030000003Vc800i/b001L0i/b0200I6AT00`3V
c8006ATI01TI6@0201TI6Bl0i/b000<0<ol00>K<P03Vc8004P3Vc8001@00I_l0i/b00>K<P03Vc800
o`0004d0i/b0000j0>K<P0030?l0003Vc800i/b00080i/b000<006Ko0>K<P03Vc800503Vc8000`0c
o`00i/b00>K<P00`0>K<P0040000003Vc800i/b0000000@0i/b0100I6AT60>K<P0030000003Vc800
i/b000<0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00O0>K<P0D06ATI<03Vc800
0`0co`00i/b00>K<P00B0>K<P005001Vo`3Vc800i/b00>K<P03o0000C03Vc80003T0i/b000<0o`00
0>K<P03Vc8000P3Vc8000`00I_l0i/b00>K<P00D0>K<P00303?o003Vc800i/b002h0i/b000<06ATI
0>K<P03Vc8001000000401TI6@P0i/b00`0000050>K<P0@000001P3Vc8000`000000i/b00>K<P00P
0>K<P0H06ATI;`3Vc8000`0co`00i/b00>K<P00B0>K<P005001Vo`3Vc800i/b00>K<P03o0000B`3V
c80003P0i/b000<0o`000>K<P03Vc8000P3Vc8000`00I_l0i/b00>K<P00C0>K<P080<ol0<03Vc803
01TI6@030>K<P00I6AT06ATI00806ATI7P3Vc8000`000000i/b00>K<P00Q0>K<P0806ATI0`3Vc802
01TI6Bh0i/b00P0co`0C0>K<P005001Vo`3Vc800i/b00>K<P03o0000BP3Vc80003L0i/b000<0o`00
0>K<P03Vc8000P3Vc8000`00I_l0i/b00>K<P00C0>K<P00303?o003Vc800i/b002l0i/b01@0I6ATR
0>K<P08000008`3Vc8000`0I6AT0i/b00>K<P0030>K<P0<06ATI;@3Vc8000`0co`00i/b00>K<P00A
0>K<P005001Vo`3Vc800i/b00>K<P03o0000B@3Vc80003H0i/b000<0o`000>K<P03Vc8000P3Vc800
0`00I_l0i/b00>K<P00C0>K<P00303?o003Vc800i/b002l0i/b01@0I6ATS0>K<P0030000003Vc800
i/b002/0i/b00P0I6AT/0>K<P00303?o003Vc800i/b00140i/b000D006Ko0>K<P03Vc800i/b00?l0
00180>K<P000=@3Vc8000`3o0000i/b00>K<P0020>K<P003001Vo`3Vc800i/b001<0i/b000<0<ol0
0>K<P03Vc800;P3Vc80201TI6@<0i/b000<06ATI0>K<P03Vc8008P3Vc8000`000000i/b00>K<P00]
0>K<P0<06ATI:P3Vc80203?o0180i/b000D006Ko0>K<P03Vc800i/b00?l000170>K<P000=03Vc800
0`3o0000i/b00>K<P0020>K<P003001Vo`3Vc800i/b00180i/b00P0co`0_0>K<P0806ATI:P3Vc800
0`000000i/b00>K<P00`0>K<P0806ATI:P3Vc8000`0co`00i/b00>K<P00@0>K<P005001Vo`3Vc800
i/b00>K<P03o0000AP3Vc80003<0i/b000<0o`000>K<P03Vc8000P3Vc8000`00I_l0i/b00>K<P00B
0>K<P00303?o003Vc800i/b002d0i/b00P0I6AT/0>K<P0030000003Vc800i/b00380i/b00P0I6ATY
0>K<P00303?o003Vc800i/b00100i/b000@006Ko0>K<P03Vc800i/b00P3o00140>K<P000<P3Vc800
103o0000i/b00>K<P03Vc802001Voa@0i/b000<0<ol00>K<P03Vc800;03Vc80201TI6Bh0i/b000<0
00000>K<P03Vc800=03Vc80301TI6BL0i/b000<0<ol00>K<P03Vc800403Vc802001Vo`<0i/b000<0
o`000>K<P03Vc800@@3Vc8000340i/b000D0o`000>K<P03Vc800i/b0001Vo`0E0>K<P00303?o003V
c800i/b002X0i/b00`0I6AT`0>K<P0030000003Vc800i/b003L0i/b00P0I6ATV0>K<P080<ol04P3V
c8001@00I_l0i/b00>K<P03Vc800o`000480i/b0000`0>K<P0050?l0003Vc800i/b00>K<P000I_l0
503Vc80203?o02/0i/b00P0I6ATc0>K<P0800000>P3Vc80301TI6BD0i/b000<0<ol00>K<P03Vc800
403Vc8001@00I_l0i/b00>K<P03Vc800o`000440i/b0000_0>K<P0050?l0003Vc800i/b00>K<P000
I_l0503Vc8000`0co`00i/b00>K<P00Y0>K<P0806ATI=@3Vc8000`000000i/b00>K<P00l0>K<P080
6ATI903Vc8000`0co`00i/b00>K<P00@0>K<P005001Vo`3Vc800i/b00>K<P03o0000@03Vc80002h0
i/b000D0o`000>K<P03Vc800i/b0001Vo`0D0>K<P00303?o003Vc800i/b002P0i/b00P0I6ATg0>K<
P0030000003Vc800i/b003h0i/b00P0I6ATS0>K<P00303?o003Vc800i/b00100i/b000D006Ko0>K<
P03Vc800i/b00?l0000o0>K<P000;@3Vc8001@3o0000i/b00>K<P03Vc80006Ko01@0i/b000<0<ol0
0>K<P03Vc8009`3Vc80201TI6CT0i/b000<000000>K<P03Vc800@03Vc80301TI6@<0i/b000<06ATI
0>K<P03Vc8006`3Vc80203?o0140i/b000D006Ko0>K<P03Vc800i/b00?l0000n0>K<P000;03Vc800
1@3o0000i/b00>K<P03Vc80006Ko01<0i/b00P0co`0W0>K<P0<06ATI>`3Vc8000`000000i/b00>K<
P0130>K<P0D06ATI7P3Vc8000`0co`00i/b00>K<P00?0>K<P005001Vo`3Vc800i/b00>K<P03o0000
?@3Vc80002/0i/b000D0o`000>K<P03Vc800i/b0001Vo`0C0>K<P00303?o003Vc800i/b002D0i/b0
0P0I6ATn0>K<P0030000003Vc800i/b004@0i/b01@0I6ATN0>K<P00303?o003Vc800i/b000l0i/b0
00D006Ko0>K<P03Vc800i/b00?l0000l0>K<P000:P3Vc8001@3o0000i/b00>K<P03Vc80006Ko01<0
i/b000<0<ol00>K<P03Vc800903Vc80201TI6D00i/b000<000000>K<P03Vc800A@3Vc80401TI6Al0
i/b00P0co`0@0>K<P005001Vo`3Vc800i/b00>K<P03o0000>`3Vc80002T0i/b000D0o`000>K<P03V
c800i/b0001Vo`0C0>K<P00303?o003Vc800i/b002<0i/b00P0I6AU20>K<P0800000AP3Vc80301TI
6@030>K<P00I6AT0i/b001l0i/b000<0<ol00>K<P03Vc8003P3Vc8001@00I_l0i/b00>K<P03Vc800
o`0003X0i/b0000X0>K<P0050?l0003Vc800i/b00>K<P000I_l04P3Vc80203?o0200i/b000@06ATI
0>K<P03Vc800i/b00P0I6AU40>K<P0030000003Vc800i/b004H0i/b000@06ATI0>K<P03Vc800i/b0
0P0I6ATO0>K<P00303?o003Vc800i/b000h0i/b000D006Ko0>K<P03Vc800i/b00?l0000i0>K<P000
9`3Vc8000`3o0000i/b00>K<P002001Voa80i/b000<0<ol00>K<P03Vc8007`3Vc80501TI6DH0i/b0
00<000000>K<P03Vc800C03Vc8000`0I6AT0i/b00>K<P00M0>K<P00303?o003Vc800i/b000h0i/b0
0P00I_l20>K<P0030?l0003Vc800i/b003H0i/b0000V0>K<P0040?l0003Vc800i/b0001Voa<0i/b0
00<0<ol00>K<P03Vc8007`3Vc80501TI6DL0i/b000<000000>K<P03Vc800C@3Vc80201TI6Ah0i/b0
0P0co`0@0>K<P004001Vo`3Vc800i/b00?l003L0i/b0000T0>K<P080o`000P3Vc8000`00I_l0i/b0
0>K<P00A0>K<P00303?o003Vc800i/b00200i/b0100I6AU80>K<P0030000003Vc800i/b004l0i/b0
00<06ATI0>K<P03Vc8007@3Vc8000`0co`00i/b00>K<P00>0>K<P004001Vo`3Vc800i/b00?l003H0
i/b0000S0>K<P0050?l0003Vc800i/b00>K<P000I_l04`3Vc8000`0co`00i/b00>K<P00P0>K<P004
01TI6@3Vc800i/b001TI6DT0i/b000<000000>K<P03Vc800D03Vc80201TI6Ah0i/b000<0<ol00>K<
P03Vc8003P3Vc8001000I_l0i/b00>K<P03o000e0>K<P0008P3Vc8001@3o0000i/b00>K<P03Vc800
06Ko0180i/b00P0co`0Q0>K<P0806ATIC@3Vc8000`000000i/b00>K<P01B0>K<P00301TI6@3Vc800
i/b001`0i/b00P0co`0?0>K<P004001Vo`3Vc800i/b00?l003@0i/b0000Q0>K<P0050?l0003Vc800
i/b00>K<P000I_l04P3Vc8000`0co`00i/b00>K<P00P0>K<P00301TI6@3Vc800i/b004d0i/b000<0
00000>K<P03Vc800D`3Vc80201TI6Ah0i/b000<0<ol00>K<P03Vc8003@3Vc8000`00I_l0i/b00>K<
P0020?l00380i/b0000P0>K<P0050?l0003Vc800i/b00>K<P000I_l04P3Vc8000`0co`00i/b00>K<
P00P0>K<P00301TI6@3Vc800i/b004h0i/b00P00001F0>K<P00301TI6@3Vc800i/b001`0i/b000<0
<ol00>K<P03Vc8003@3Vc8001@00I_l0i/b00>K<P03Vc800o`000340i/b0000O0>K<P0050?l0003V
c800i/b00>K<P000I_l04P3Vc8000`0co`00i/b00>K<P00O0>K<P0806ATID@3Vc8000`000000i/b0
0>K<P01F0>K<P0806ATI7@3Vc8000`0co`00i/b00>K<P00=0>K<P005001Vo`3Vc800i/b00>K<P03o
0000<03Vc80001h0i/b000D0o`000>K<P03Vc800i/b0001Vo`0A0>K<P080<ol08@3Vc8000`0I6AT0
i/b00>K<P01A0>K<P0030000003Vc800i/b005P0i/b000<06ATI0>K<P03Vc8006`3Vc80203?o00h0
i/b000D006Ko0>K<P03Vc800i/b00?l0000_0>K<P0007@3Vc8001@3o0000i/b00>K<P03Vc80006Ko
0140i/b000<0<ol00>K<P03Vc8007`3Vc80201TI6E@0i/b000<000000>K<P03Vc800F@3Vc80201TI
6Ad0i/b000<0<ol00>K<P03Vc800303Vc8001@00I_l0i/b00>K<P03Vc800o`0002h0i/b0000L0>K<
P0050?l0003Vc800i/b00>K<P000I_l04@3Vc8000`0co`00i/b00>K<P00O0>K<P00301TI6@3Vc800
i/b003/0i/b00`0000050>K<P0800000103Vc806000000D0i/b000<000000>K<P03Vc800F`3Vc800
0`0I6AT0i/b00>K<P00K0>K<P00303?o003Vc800i/b000`0i/b000D006Ko0>K<P03Vc800i/b00?l0
000]0>K<P0006`3Vc8000`3o0000i/b00>K<P002001Voa40i/b000<0<ol00>K<P03Vc8007P3Vc802
01TI6Cd0i/b000@000000>K<P03Vc80000001@3Vc802000000D0i/b000D000000>K<P03Vc800i/b0
000000050>K<P0030000003Vc800i/b005`0i/b00P0I6ATL0>K<P00303?o003Vc800i/b000`0i/b0
0P00I_l20>K<P0030?l0003Vc800i/b002X0i/b0000J0>K<P0040?l0003Vc800i/b0001Voa40i/b0
0P0co`0P0>K<P00301TI6@3Vc800i/b003`0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b0
0>K<P00:0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800GP3Vc8000`0I6AT0i/b0
0>K<P00J0>K<P080<ol03P3Vc8001000I_l0i/b00>K<P03o000[0>K<P0005P3Vc8050?l000030>K<
P000I_l0i/b00100i/b000<0<ol00>K<P03Vc8007`3Vc8000`0I6AT0i/b00>K<P00m0>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc8002`3Vc802000000H0i/b00`00001O0>K<P0806ATI
703Vc8000`0co`00i/b00>K<P00<0>K<P003001Vo`3Vc800o`0000@0o`009`3Vc80001L0i/b00`3o
00000`3Vc80006Ko0>K<P00@0>K<P00303?o003Vc800i/b001h0i/b00P0I6AU00>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc800303Vc802000000D0i/b000<000000>K<P03Vc800H@3V
c8000`0I6AT0i/b00>K<P00J0>K<P00303?o003Vc800i/b000`0i/b00P00I_l30?l00003001Vo`3V
c800i/b002D0i/b0000E0>K<P08006Ko0`3o00000`00I_l0i/b00>K<P00?0>K<P00303?o003Vc800
i/b001h0i/b000<06ATI0>K<P03Vc800@03Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800
i/b000d0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P01R0>K<P0806ATI6`3Vc802
03?o00`0i/b00P00I_l30?l00003001Vo`3Vc800i/b002D0i/b0000E0>K<P0<006Ko00<0o`00001V
o`00I_l03`3Vc80203?o01l0i/b00P0I6AU40>K<P0040000003Vc800i/b0000000/0i/b000<00000
0>K<P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b006@0i/b000<06ATI
0>K<P03Vc8006P3Vc8000`0co`00i/b00>K<P0090>K<P0<006Ko00<0o`00001Vo`00I_l09`3Vc800
01D0i/b01P00I_l>0>K<P00303?o003Vc800i/b001h0i/b000<06ATI0>K<P03Vc800A03Vc8040000
00/0i/b01@0000060>K<P0030000003Vc800i/b006D0i/b00P0I6ATK0>K<P00303?o003Vc800i/b0
00P0i/b01P00I_lW0>K<P0005@3Vc806001Vo`d0i/b000<0<ol00>K<P03Vc8007@3Vc80201TI6F40
i/b000<000000>K<P03Vc800I`3Vc8000`0I6AT0i/b00>K<P00I0>K<P00303?o003Vc800i/b000L0
i/b01P00I_lW0>K<P0005@3Vc806001Vo``0i/b000<0<ol00>K<P03Vc8007@3Vc8000`0I6AT0i/b0
0>K<P01Q0>K<P0030000003Vc800i/b006P0i/b00P0I6ATJ0>K<P080<ol01`3Vc806001VobL0i/b0
000E0>K<P0H006Ko2P3Vc80203?o01l0i/b000<06ATI0>K<P03Vc800HP3Vc802000006/0i/b000<0
6ATI0>K<P03Vc8006@3Vc8000`0co`00i/b00>K<P0040>K<P0H006Ko9`3Vc80001D0i/b01P00I_l9
0>K<P00303?o003Vc800i/b001d0i/b00P0I6AUU0>K<P0030000003Vc800i/b006/0i/b00P0I6ATJ
0>K<P00303?o003Vc800i/b00300i/b0000S0>K<P00303?o003Vc800i/b001d0i/b000<06ATI0>K<
P03Vc800I@3Vc8000`000000i/b00>K<P01]0>K<P0806ATI6@3Vc8000`0co`00i/b00>K<P00_0>K<
P0008P3Vc8000`0co`00i/b00>K<P00L0>K<P0806ATIJ03Vc8000`000000i/b00>K<P01_0>K<P003
01TI6@3Vc800i/b001L0i/b00P0co`0_0>K<P0008@3Vc8000`0co`00i/b00>K<P00L0>K<P00301TI
6@3Vc800i/b006P0i/b000<000000>K<P03Vc800L03Vc80201TI6AT0i/b000<0<ol00>K<P03Vc800
;03Vc80001l0i/b00P0co`0M0>K<P0806ATIJ`3Vc8000`000000i/b00>K<P01b0>K<P00301TI6@3V
c800i/b001L0i/b000<0<ol00>K<P03Vc800:`3Vc80001h0i/b000<0<ol00>K<P03Vc800703Vc800
0`0I6AT0i/b00>K<P01[0>K<P0030000003Vc800i/b007<0i/b00P0I6ATH0>K<P080<ol00P3Vc800
0`0co`00i/b00>K<P00V0>K<P0007@3Vc8000`0co`00i/b00>K<P00L0>K<P00301TI6@3Vc800i/b0
06`0i/b00P00001f0>K<P00301TI6@3Vc800i/b001L0i/b00P0co`0Y0>K<P000703Vc8000`0co`00
i/b00>K<P00K0>K<P0806ATIK`3Vc8000`000000i/b00>K<P01f0>K<P0806ATI5P3Vc80403?o02P0
i/b0000J0>K<P080<ol07@3Vc8000`0I6AT0i/b00>K<P01_0>K<P0030000003Vc800i/b007P0i/b0
00<06ATI0>K<P03Vc8004P3Vc80603?o02L0i/b0000G0>K<P0<0<ol07@3Vc80201TI6G80i/b000<0
00000>K<P03Vc800N@3Vc80201TI6AD0i/b000<0<ol00>K<P03Vc8009`3Vc80001L0i/b00P0co`0M
0>K<P00301TI6@3Vc800i/b00780i/b000<000000>K<P03Vc800N`3Vc8000`0I6AT0i/b00>K<P00l
0>K<P0005@3Vc80603?o01T0i/b00P0I6AUe0>K<P0030000003Vc800i/b007`0i/b00P0I6ATl0>K<
P000603Vc8000`0co`00i/b00>K<P00H0>K<P00301TI6@3Vc800i/b007D0i/b000<000000>K<P03V
c800OP3Vc8000`0I6AT0i/b00>K<P00i0>K<P000<P3Vc8000`0I6AT0i/b00>K<P01f0>K<P0800000
P03Vc80201TI6CT0i/b0000`0>K<P0806ATIN@3Vc8000`000000i/b00>K<P0210>K<P00301TI6@3V
c800i/b003H0i/b0000_0>K<P00301TI6@3Vc800i/b007T0i/b000<000000>K<P03Vc800PP3Vc802
01TI6CH0i/b0000]0>K<P0806ATIO03Vc8000`000000i/b00>K<P0240>K<P00301TI6@3Vc800i/b0
03<0i/b0000/0>K<P00301TI6@3Vc800i/b007`0i/b000<000000>K<P03Vc800Q@3Vc80201TI6C<0
i/b0000Z0>K<P0806ATIO`3Vc8000`000000i/b00>K<P0270>K<P00301TI6@3Vc800i/b00300i/b0
000Y0>K<P00301TI6@3Vc800i/b007l0i/b000<000000>K<P03Vc800R03Vc80201TI6C00i/b0000X
0>K<P00301TI6@3Vc800i/b00800i/b00P00002;0>K<P00301TI6@3Vc800i/b002d0i/b0000V0>K<
P0806ATIP`3Vc8000`000000i/b00>K<P02;0>K<P0806ATI;@3Vc80002D0i/b000<06ATI0>K<P03V
c800P`3Vc8000`000000i/b00>K<P02=0>K<P00401TI6@3Vc800i/b001TI6BT0i/b0000S0>K<P080
6ATIQP3Vc8000`000000i/b00>K<P02>0>K<P0@06ATI:03Vc8000280i/b000<06ATI0>K<P03Vc800
QP3Vc8000`000000i/b00>K<P02>0>K<P0@06ATI:03Vc8000200i/b00P0I6AUX0>K<P0<000001@3V
c802000000@0i/b01P0000030>K<P0@000001P3Vc8000`000000i/b00>K<P02?0>K<P0<06ATI:03V
c80001l0i/b000<06ATI0>K<P03Vc800I`3Vc80010000000i/b00>K<P00000050>K<P08000001@3V
c8001@000000i/b00>K<P03Vc800000000L0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0
0>K<P02@0>K<P00301TI6@3Vc800i/b002L0i/b0000N0>K<P00301TI6@3Vc800i/b006L0i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000P0i/b000<0
00000>K<P03Vc8000`3Vc80300000;X0i/b0000L0>K<P0806ATIJP3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b000/0i/b00P0000080>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc800^P3Vc80001L0i/b00P0I6AT20>K<P00301TI6@3Vc800i/b006X0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P08000000`3Vc804000000H0i/b000<000000>K<
P03Vc800^P3Vc80001H0i/b01@0I6AU]0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c8003@3Vc8001@000000i/b00>K<P03Vc800000000T0i/b000<000000>K<P03Vc800^P3Vc80001D0
i/b01@0I6AU_0>K<P0040000003Vc800i/b0000000/0i/b000<000000>K<P03Vc8000P3Vc8001@00
0000i/b00>K<P03Vc800000000T0i/b000<000000>K<P03Vc800^P3Vc80001H0i/b0100I6AU_0>K<
P0@000002`3Vc805000000@0i/b0100000060>K<P0030000003Vc800i/b00;X0i/b0000G0>K<P080
6ATITP3Vc8000`000000i/b00>K<P02j0>K<P000Z`3Vc80200000;/0i/b0002[0>K<P0030000003V
c800i/b00;X0i/b0002[0>K<P0030000003Vc800i/b00;X0i/b0003o0>K<P6T0i/b0003o0>K<P6T0
i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0
i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0002[0>K<P08000000P3Vc8000`000000i/b00>K<P02f
0>K<P000Y@3Vc80500000080i/b000<000000>K<P0000000^@3Vc8000:@0i/b000@000000>K<P03V
c80000000P3Vc80010000000i/b000000000002j0>K<P000Y03Vc80010000000i/b00>K<P0000002
0>K<P0040000003Vc80000000>K<P0800000^03Vc8000:@0i/b000@000000>K<P03Vc80000000P3V
c80600000;P0i/b0002U0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800^`3Vc800
0:H0i/b000D000000>K<P03Vc800i/b00000002m0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000
o`3Vc81Y0>K<P000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0.766931, -0.0212199, \
0.00170034, 0.00175557}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->"EditBar",
WindowSize->{1269, 916},
WindowMargins->{{0, Automatic}, {Automatic, 28}},
Magnification->1.25,
StyleDefinitions -> "PastelColor.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 45, 1, 130, "Title"],
Cell[1775, 55, 243, 4, 87, "Input"],

Cell[CellGroupData[{
Cell[2043, 63, 51, 0, 61, "Section"],
Cell[2097, 65, 4708, 141, 475, "Text"],
Cell[6808, 208, 565, 16, 60, "Input"],
Cell[7376, 226, 196, 4, 88, "Input"],
Cell[7575, 232, 2221, 65, 192, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9833, 302, 37, 0, 61, "Section"],
Cell[9873, 304, 96, 3, 36, "Text"],
Cell[9972, 309, 867, 15, 194, "Input"],

Cell[CellGroupData[{
Cell[10864, 328, 777, 14, 131, "Input"],
Cell[11644, 344, 53382, 2212, 243, 31708, 1940, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[65041, 2559, 241, 5, 88, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65319, 2569, 33, 0, 61, "Section"],
Cell[65355, 2571, 192, 6, 36, "Text"],
Cell[65550, 2579, 1070, 18, 330, "Input"],

Cell[CellGroupData[{
Cell[66645, 2601, 269, 4, 66, "Input"],
Cell[66917, 2607, 26843, 639, 243, 5203, 367, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[93775, 3249, 158, 4, 62, "Text"],

Cell[CellGroupData[{
Cell[93958, 3257, 93, 1, 45, "Input"],
Cell[94054, 3260, 200, 4, 47, "Print"]
}, Open  ]],
Cell[94269, 3267, 221, 4, 62, "Text"],
Cell[94493, 3273, 744, 13, 206, "Input"],

Cell[CellGroupData[{
Cell[95262, 3290, 1226, 21, 256, "Input"],
Cell[96491, 3313, 82598, 2134, 243, 22716, 1390, "GraphicsData", \
"PostScript", "Graphics"],
Cell[179092, 5449, 286, 6, 47, "Print"],
Cell[179381, 5457, 215, 4, 47, "Print"],
Cell[179599, 5463, 351, 7, 47, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[179999, 5476, 38, 0, 61, "Section"],
Cell[180040, 5478, 137, 3, 36, "Text"],
Cell[180180, 5483, 261, 6, 66, "Input"],

Cell[CellGroupData[{
Cell[180466, 5493, 928, 15, 255, "Input"],
Cell[181397, 5510, 191, 3, 28, "Message"],
Cell[181591, 5515, 197, 3, 28, "Message"]
}, Open  ]],
Cell[181803, 5521, 220, 6, 36, "Text"],

Cell[CellGroupData[{
Cell[182048, 5531, 1452, 25, 213, "Input"],
Cell[183503, 5558, 65807, 1304, 243, 16861, 695, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[249347, 6867, 487, 8, 87, "Input"],
Cell[249837, 6877, 89846, 1755, 346, 13407, 807, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[339720, 8637, 453, 8, 66, "Input"],
Cell[340176, 8647, 99666, 1826, 380, 11871, 738, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[439879, 10478, 679, 12, 108, "Input"],
Cell[440561, 10492, 45205, 986, 243, 14325, 600, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

